/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(sb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(){throw new Error("abort")}function q(m){h[2]=m}function r(){return h[2]}function qb(rb){var s=rb.a;var t=s.a;var u=t.buffer;t.grow=ob;var v=new Int8Array(u);var w=new Int16Array(u);var x=new Int32Array(u);var y=new Uint8Array(u);var z=new Uint16Array(u);var A=new Uint32Array(u);var B=new Float32Array(u);var C=new Float64Array(u);var D=Math.imul;var E=Math.fround;var F=Math.abs;var G=Math.clz32;var H=Math.min;var I=Math.max;var J=Math.floor;var K=Math.ceil;var L=Math.trunc;var M=Math.sqrt;var N=s.b;var O=s.c;var P=s.d;var Q=s.e;var R=s.f;var S=s.g;var T=s.h;var U=s.i;var V=s.j;var W=s.k;var X=s.l;var Y=s.m;var Z=s.n;var _=s.o;var $=s.p;var aa=s.q;var ba=s.r;var ca=s.s;var da=s.t;var ea=s.u;var fa=s.v;var ga=s.w;var ha=s.x;var ia=s.y;var ja=s.z;var ka=s.A;var la=s.B;var ma=s.C;var na=s.D;var oa=s.E;var pa=s.F;var qa=s.G;var ra=s.H;var sa=s.I;var ta=s.J;var ua=s.K;var va=s.L;var wa=s.M;var xa=s.N;var ya=s.O;var za=s.P;var Aa=s.Q;var Ba=s.R;var Ca=s.S;var Da=s.T;var Ea=s.U;var Fa=s.V;var Ga=s.W;var Ha=s.X;var Ia=s.Y;var Ja=s.Z;var Ka=s._;var La=s.$;var Ma=s.aa;var Na=s.ba;var Oa=s.ca;var Pa=s.da;var Qa=s.ea;var Ra=s.fa;var Sa=s.ga;var Ta=s.ha;var Ua=s.ia;var Va=s.ja;var Wa=s.ka;var Xa=s.la;var Ya=s.ma;var Za=s.na;var _a=s.oa;var $a=s.pa;var ab=s.qa;var bb=s.ra;var cb=s.sa;var db=s.ta;var eb=s.ua;var fb=568256;var gb=0;var hb=0;
// EMSCRIPTEN_START_FUNCS
function TM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,P=0,R=0,T=0,U=E(0),V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=E(0),Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=E(0),Va=0;da=fb-32|0;fb=da;ga=da+28|0;x[ga>>2]=48900;x[ga>>2]=48800;e=CB(da+20|0);f=CB(da+12|0);ha=b;oa=c;pa=x[e>>2];Ea=y[e+4|0];qa=x[f>>2];Fa=y[f+4|0];c=0;K=fb-96|0;fb=K;d=a;ra=a+24604|0;a=ra;a:{if(!x[a+16>>2]){break a}b=x[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=x[a+28>>2];if(a>>>0>4){break a}c=23>>>a&1}if(!c){a=K+80|0;sS(a,9133,13070,220,45);b=fb-48|0;fb=b;c=tc(b+24|0,18366);x[31725]=0;O(888,b+12|0,17442);e=x[31725];x[31725]=0;b:{c:{d:{e:{if((e|0)!=1){x[31725]=0;S(2,b+36|0,c|0,b+12|0);e=x[31725];x[31725]=0;if((e|0)==1){break e}x[31725]=0;S(889,a|0,1,b+36|0);a=x[31725];x[31725]=0;if((a|0)!=1){break b}a=N()|0;tb(b+36|0);break d}a=N()|0;break c}a=N()|0}tb(b+12|0)}tb(c);Q(a|0);p()}tb(b+36|0);tb(b+12|0);tb(c);fb=b+48|0}sa=d+8204|0;ta=d+397452|0;ua=d+397448|0;ba=d+393352|0;G=d+397456|0;Y=d+12|0;Ga=d+1074376|0;while(1){f:{g:{a=x[d+480208>>2];if(!(!ha|a&512)){h:{if(x[d+1074380>>2]){break h}ma=d;b=a|512;i:{if(a&256){break i}o=fb-48|0;fb=o;t=fb-32|0;fb=t;i=d+1074312|0;h=d+1074992|0;r=d+1298264|0;s=d+1074424|0;P=d+484360|0;k=d+1074448|0;q=d+1074376|0;a=x[d+1074392>>2];I=d+480210|0;j:{k:while(1){l:{a=a+1|0;x[d+1074392>>2]=a;if(Ql(q)>>>0>a>>>0){break l}OT(t+30|0,x[d+480180>>2],z[d+480188>>1],q,(x[d+480208>>2]&524288)>>>19|0);m:{n:{o:{p:{J=x[d+480208>>2];if(J&32){g=x[d+484348>>2];n=x[d+484344>>2];c=z[d+1074446>>1];break p}c=65535;C=Xb(x[d+484360>>2],y[d+484376|0]);l=x[C>>2];u=x[C+4>>2];e=Zc(l,u);a=z[d+1074448>>1];if(e>>>0>a>>>0){c=z[_b(l,a)>>1]}w[d+1074446>>1]=c;q:{r:{b=c&65535;n=x[d+484344>>2];g=x[d+484348>>2];T=gk(n,g);if(b>>>0>=T>>>0){break r}b=Wb(n,b);if(Ib(x[b>>2],x[b+4>>2])){break r}b=0;break q}b=1}while(1){if(!b){c=65534;w[d+1074446>>1]=65534;b=1;continue}j=z[C+28>>1];while(1){s:{t:{u:{b=c&65535;if(b>>>0>=T>>>0){c=a&65535;if(!((b|0)!=65535&e>>>0>c>>>0)){if(j){b=Zc(l,u);a=j;break t}if(!(a&65535)|c>>>0>e>>>0){break u}while(1){f=c;a=a-1|0;b=a&65535;if(!b){break u}c=f-1|0;if(z[_b(l,b)>>1]!=65535){continue}break}b=e;a=f;break t}a=a+1|0;w[k>>1]=a;c=a&65535;break s}w[d+1074450>>1]=a;break p}b=e;a=0}w[d+1074448>>1]=a;J=J&-524289;x[d+480208>>2]=J;while(1){c=a&65535;if(c>>>0>=b>>>0){break o}if(z[_b(l,c)>>1]==65534){a=a+1|0;w[k>>1]=a;continue}break}if(!cj(C,a&65535)){break o}}if(c>>>0>=e>>>0){c=65535;w[d+1074446>>1]=65535;continue}c=z[_b(l,c)>>1];w[d+1074446>>1]=c;if(c>>>0>=T>>>0){continue}b=Wb(n,c);if(Ib(x[b>>2],x[b+4>>2])){continue}break}b=0;continue}}b=c&65535;if(!He(n,g,b)){break n}a=x[s>>2];if(a>>>0>=A[Wb(n,b)+12>>2]){x[s>>2]=0;a=0}if(J&32?x[d+480272>>2]!=-1:0){break m}if(!Xu(r,z[k>>1],a,Oq(t+20|0,h),y[t+30|0])){break m}a=x[d+480272>>2];if(a){if((a|0)>0){x[d+480272>>2]=a-1}So(r,1);Xu(r,z[k>>1],x[s>>2],Oq(t+20|0,h),y[t+30|0]);break m}if(!(y[I|0]&64)){break o}if(!Wu(r,k,s)){x[d+1074424>>2]=0;x[d+1074428>>2]=0;x[d+1074448>>2]=0;b=Qj(x[d+484360>>2],x[d+484364>>2])-1|0;a=y[d+484376|0];if((b|0)<=(a|0)){ek(P,0);break o}ek(P,a+1&255);So(r,1)}a=0;while(1)if((a|0)==256){jS(d);x[d+1074416>>2]=x[d+480196>>2];x[d+1074420>>2]=x[d+480204>>2];x[d+1074456>>2]=x[d+480200>>2];a=z[d+1074448>>1];w[d+1074450>>1]=a;b=x[d+1074424>>2];x[d+1074428>>2]=b;c=Xb(x[d+484360>>2],y[d+484376|0]);e=x[c>>2];if(Zc(e,x[c+4>>2])>>>0>a>>>0){Sa=d,Ta=z[_b(e,a)>>1],w[Sa+1074446>>1]=Ta}Xu(r,a,b,Oq(t+20|0,h),y[t+30|0]);if(!He(x[d+484344>>2],x[d+484348>>2],z[d+1074446>>1])){break n}break m}else{Wo((D(a,872)+d|0)+1074992|0,d,a&65535,134217728);a=a+1|0;continue}}So(r,1)}a=0;break j}NT(d,q,(x[d+480208>>2]&32)>>>5|0);a=Wb(x[d+484344>>2],z[d+1074446>>1]);c=jd(x[a>>2],x[x[a+48>>2]+12>>2],x[d+1074424>>2],0);e=h+D(z[d+480188>>1],872)|0;a=h;while(1){if((a|0)==(e|0)){v:{w:{a=x[d+484344>>2];b=z[d+1074446>>1];if(yp(a,x[d+484348>>2],b)){a=Wb(a,b);b=x[a+16>>2];a=x[a+20>>2];if(KT(b,a)){break w}}x[d+1074408>>2]=x[d+480216>>2];a=x[d+480220>>2];break v}x[d+1074408>>2]=b}x[d+1074412>>2]=a;if(!y[t+30|0]){break l}a=x[d+1074416>>2];x[d+1074392>>2]=a;continue k}Jb(t+20|0,i,82);x:{if(!Hb(x[x[t+20>>2]>>2],x[t+24>>2])|y[a+805|0]!=1){break x}b=y[c+3|0];if((b|0)!=2&(b|0)!=3){break x}Sa=a,Ta=yh(d,y[a+800|0],w[a+772>>1],x[a+704>>2]),x[Sa+700>>2]=Ta}Jb(t+20|0,i,91);y:{if(!Hb(x[x[t+20>>2]>>2],x[t+24>>2])){break y}if(Tc(y[c|0])){break y}b=y[a+788|0];if(!Tc(b)|y[a+791|0]!=19){break y}f=y[a+793|0];if((f&240)!=208|A[d+1074416>>2]>(f&15)>>>0){break y}Sa=a,Ta=yh(d,b,w[a+772>>1],0),x[Sa+700>>2]=Ta}Jb(t+20|0,i,118);z:{if(!Hb(x[x[t+20>>2]>>2],x[t+24>>2])){break z}if(Tc(y[c|0])|!(y[a+89|0]&2)){break z}b=x[a+708>>2];if(!b){break z}if(!Tc(y[a+788|0])){break z}if(!Rl(y[a+790|0],y[a+791|0])){break z}x[a+700>>2]=b}Jb(t+20|0,i,92);A:{if(!Hb(x[x[t+20>>2]>>2],x[t+24>>2])){break A}Jb(t+12|0,i,5);if(Hb(x[x[t+12>>2]>>2],x[t+16>>2])|x[d+1074416>>2]!=1|y[a+791|0]!=17){break A}v[t+20|0]=1;Sa=d,Ta=D(y[ef(t+20|0,a+793|0)|0],1e4),x[Sa+1074420>>2]=Ta}b=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+788|0]=b;v[a+789|0]=b>>>8;v[a+790|0]=b>>>16;v[a+791|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8;v[a+792|0]=b;v[a+793|0]=b>>>8;b=x[a+676>>2];x[a+20>>2]=x[a+672>>2];x[a+24>>2]=b;x[a+88>>2]=x[a+88>>2]&-393217;Jb(t+20|0,i,21);if(!Hb(x[x[t+20>>2]>>2],x[t+24>>2])){v[a+831|0]=0}x[a+860>>2]=0;v[a+805|0]=0;c=c+6|0;a=a+872|0;continue}}break}b=x[d+1074416>>2];if(!b){x[d+1074416>>2]=1;b=1}a=x[d+480208>>2];e=x[d+1074392>>2];B:{C:{if(e){c=a&-4097;x[d+480208>>2]=c;f=x[d+480180>>2];if(f&1048580|!(a&2097152)&(f|0)==1){break B}if(Ql(q)>>>0<=e>>>0){break B}if(!((e>>>0)%(x[d+1074400>>2]+b>>>0)|0)){break C}break B}c=a&-528385}x[d+480208>>2]=c|4096}k=0;i=fb-16|0;fb=i;w[d+1074444>>1]=65535;a=d+1074436|0;x[a>>2]=-1;x[a+4>>2]=-1;W=d+1075809|0;s=d+1074312|0;u=d+906300|0;P=d+1074376|0;V=d+480209|0;Z=d+480210|0;while(1){if(z[d+480188>>1]<=k>>>0){D:{if(!(y[d+480209|0]&16)){break D}if(!CT(d,P,Xb(x[d+484360>>2],y[d+484376|0]),1)){break D}x[d+480208>>2]=x[d+480208>>2]|524288}fb=i+16|0}else{l=D(k,872)+d|0;g=l+1075785|0;b=y[g|0];m=l+1075784|0;q=y[m|0];R=l+1075781|0;c=y[R|0];a=x[d+1074392>>2];f=x[d+1074400>>2];h=x[d+1074416>>2];L=l+1075782|0;j=y[L|0];r=l+1075783|0;J=y[r|0];e=Rl(j,J);H=l+1075843|0;v[H|0]=x[d+480208>>2]>>>12&1|y[H|0]&254;n=(a>>>0)%(f+h>>>0)|0;T=l+1075780|0;a=y[T|0];E:{F:{G:{if((a|0)==252){h=Mj(j,q);C=Mj(J,b);a=252;f=c-1|0;if((f&255)>>>0>249){break G}if(!x[vd(u,f)>>2]){break G}a=x[vd(u,f)>>2];ib[x[x[a>>2]+44>>2]](a,h,E(E(C>>>0)/E(999)));a=y[T|0]}if((a&255)==251){break F}}if(B[l+1075852>>2]==E(0)|J){break E}}C=x[d+480208>>2]&4096;H:{if(!C){h=y[l+1075862|0];break H}h=y[R|0];v[l+1075862|0]=h}if((h-1&255)>>>0>249){break E}f=h-1|0;if(!x[vd(u,f)>>2]){break E}I:{if(!C){a=z[l+1075860>>1];break I}a=rB(y[L|0],y[m|0]);w[l+1075860>>1]=a;U=E(E(rB(y[r|0],y[g|0])>>>0)/E(999));B[l+1075856>>2]=U;h=x[vd(u,f)>>2];Sa=l+1075852|0,Ua=E(E(U-E(ib[x[x[h>>2]+48>>2]](h,a)))/E(Ql(P)>>>0)),B[Sa>>2]=Ua}h=x[d+1074392>>2];g=Ql(P);f=x[vd(u,f)>>2];m=a;a=(g|0)==(h+1|0);ib[x[x[f>>2]+(a?44:108)>>2]](f,m,B[(a?l+1075856|0:l+1075852|0)>>2]);a=y[T|0]}g=l+1074992|0;if(sT(a&255)){b=fb-16|0;fb=b;w[b+12>>1]=0;x[b+8>>2]=0;a=ch(b+8|0);c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[g+788|0]=c;v[g+789|0]=c>>>8;v[g+790|0]=c>>>16;v[g+791|0]=c>>>24;a=y[a+4|0]|y[a+5|0]<<8;v[g+792|0]=a;v[g+793|0]=a>>>8;fb=b+16|0;J=0;q=0;j=0;c=0;e=0;b=0}J:{if(!(y[V|0]&16)){VS(d,g);break J}if(!c){break J}x[l+1075752>>2]=0}K:{L:{if((J|0)==33){Jb(i+8|0,s,30);a=b>>>4|0;cB(d,k&65535,a+(b&15)|0,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));break L}a=0;if((J-19&255)>>>0>1){break L}M:{if(!(!(x[d+480180>>2]&16777250)|b)){b=y[l+1075825|0];break M}v[l+1075825|0]=b}f=b&240;if((f|0)==208){f=b&15;if(!f){f=x[d+480180>>2];if(f&16777248){a=1;break L}if((f|0)!=2){break L}break K}if(f>>>0>=x[d+1074400>>2]+x[d+1074416>>2]>>>0){Jb(i+8|0,s,14);a=f;if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break L}if(!c){break K}v[l+1075795|0]=c;break K}a=f;break L}if(!(x[d+480208>>2]&4096)|(f|0)!=224){break L}f=x[d+480180>>2];if(x[d+1074396>>2]?f&16777250:0){break L}h=b&15;if(!(f&2?h:1)){break L}x[d+1074396>>2]=h+1}I=b&15;f=x[d+480180>>2]==16&(J|0)==19&(b&240)==208;C=f?0:a;N:{if(!C|y[T|0]!=255|y[L|0]!=2){break N}Jb(i+8|0,s,74);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break N}v[L|0]=0}h=I|144;a=x[d+1074392>>2];Jb(i+8|0,s,72);O:{if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){r=0;if(C>>>0>=A[d+1074416>>2]){break O}}Jb(i+8|0,s,88);r=(n|0)==(C|0)|(a|0)==(C|0);if(!(!C|!Hb(x[x[i+8>>2]>>2],x[i+12>>2]))){break O}r=(a|0)==(C|0)}b=f?h:b;a=i+8|0;Jb(a,s,44);f=y[H|0];Sa=H,Ta=(Hb(x[x[i+8>>2]>>2],x[i+12>>2])?f&252|(n|0)==(C|0):f)&253,v[Sa|0]=Ta;Jb(a,s,66);h=(!C|Hb(x[x[i+8>>2]>>2],x[i+12>>2])^1)&e;P:{Q:{R:{if(!(x[d+1074392>>2]|(!(y[Z|0]&32)|!c))){x[l+1075652>>2]=0;if(r){e=y[T|0];break R}if(!Ui(x[g+8>>2],x[g+12>>2])){break P}v[l+1075795|0]=c;if(z[d+480190>>1]<c>>>0){break P}a=D(c,104)+d|0;x[l+1075680>>2]=z[a+484410>>1];w[l+1075764>>1]=v[a+484417|0];break P}if(!r){break P}e=y[T|0];if(!c){break Q}}v[l+1075795|0]=c}S:{T:{a=e&255;if(!Tc(a)){break T}Jb(i+8|0,s,67);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break T}f=w[l+1075762>>1];U:{if(!c|h){break U}n=xr(d,a,c);if(!n){break U}f=v[ui(d,n)+36|0]}e=(a+f|0)-132>>>0>=4294967176?e:0;break S}if(!(x[d+480180>>2]&25165856)){break S}f=z[d+480192>>1];if(!f){break S}if(a){a=Tc(a)}else{a=1}if(!a){break S}a=c;V:{if(!a){a=y[l+1075796|0];if(!a){break V}}if(x[((a<<2)+d|0)+900380>>2]?a>>>0<=f>>>0:0){break S}e=0}c=0}if(!((J|0)!=25|b)){Jb(i+8|0,s,55);a=Hb(x[x[i+8>>2]>>2],x[i+12>>2]);c=a?0:c;e=a?0:e}Jb(i+8|0,s,65);m=Hb(x[x[i+8>>2]>>2],x[i+12>>2]);M=1;if(!(x[d+480180>>2]&16777248)){Jb(i+8|0,s,107);M=Hb(x[x[i+8>>2]>>2],x[i+12>>2])}f=(c|0)!=0;a=e&255;X=!a;Jb(i+8|0,s,85);W:{if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break W}if(Ui(x[g+8>>2],x[g+12>>2])){break W}n=x[l+1075096>>2];if(n){if(je(x[n>>2],x[n+20>>2])){break W}}M=1}X=f&X;n=f&m;X:{Y:{Z:{_:{$:{aa:{if(!(x[d+480180>>2]&1048580)){break aa}ba:{if((a|0)!=255){break ba}if(!(!((j|0)==1|c)&(J|0)!=13)){Jb(i+8|0,s,55);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ba}}f=x[l+1075648>>2];if(v[f+60|0]&1?f:0){break ba}x[l+1075680>>2]=0;a=l+1075080|0;x[a>>2]=x[a>>2]|2097152;ca:{if(!(x[d+480208>>2]&4096)){break ca}Jb(i+8|0,s,86);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ca}x[a>>2]=x[a>>2]|4096}c=0;e=0;a=0;f=0;m=1;if(n){break Y}break X}Jb(i+8|0,s,59);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|x[d+480208>>2]&4096){break aa}da:{if(!a){e=y[l+1075789|0]-y[l+1075762|0]|0;break da}if(a>>>0>250){M=0;n=1;e=0;break da}ea:{if(c){break ea}Jb(i+8|0,s,98);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ea}c=0;break da}M=1;n=1}f=e;h=0;break $}f=0;if(!X){break _}}Jb(i+8|0,s,65);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Z}e=f;f=1}a=e;m=1;if(n){break Y}break X}e=f;f=1;m=n}fa:{ga:{if(!z[d+480192>>1]){if(z[d+480190>>1]<c>>>0){break fa}a=(D(c,104)+d|0)+484380|0;break ga}a=x[l+1075096>>2];if(!a){break fa}}ha:{if(w[a+34>>1]<0){break ha}if(x[d+480180>>2]==2){if(!je(x[a>>2],x[a+20>>2])){break ha}}x[l+1075680>>2]=z[a+30>>1];n=l+1075080|0;x[n>>2]=x[n>>2]|2097152}if(!m){break fa}Yq(g,z[a+28>>1],d)}a=e}Jb(i+8|0,s,71);if(!(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|!c)){v[l+1075831|0]=32}ia:{if(!z[d+480192>>1]){break ia}Jb(i+8|0,s,100);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|!c){break ia}if(Tc(a&255)){break ia}e=x[d+480208>>2];ja:{if(h){if(e&8){break ja}break ia}if(!(e&4)){break ia}}en(g);x[l+1075688>>2]=65536;e=l+1075080|0;x[e>>2]=x[e>>2]|2097152}if(f){Jb(i+8|0,s,11);ka:{la:{ma:{if(!(Hb(x[x[i+8>>2]>>2],x[i+12>>2])|x[d+480180>>2]==268435456)){e=z[d+480192>>1];break ma}Jb(i+8|0,s,87);f=0;if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){f=Ui(x[g+8>>2],x[g+12>>2])^1}e=z[d+480192>>1];na:{if(e){if(c>>>0>e>>>0){break la}if(x[l+1075648>>2]!=x[((c<<2)+d|0)+900380>>2]|f){break na}break la}if((f^-1)&x[l+1075096>>2]==((D(c,104)+d|0)+484380|0)){break ka}}a=y[l+1075789|0]}if(!(e&65535)){break ka}}if(!(x[d+480180>>2]&1048588)){break ka}en(g);v[l+1075810|0]=0;x[l+1075748>>2]=0;x[l+1075688>>2]=65536;e=l+1075080|0;x[e>>2]=x[e>>2]&-2101249|2097152;Jb(i+8|0,s,86);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ka}x[e>>2]=x[e>>2]&-2049}c=M?c:0}n=a&255;oa:{if(n>>>0<251){break oa}Jb(i+8|0,s,50);pa:{if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|!c){break pa}e=xr(d,y[l+1075791|0],c);if(!e){break pa}e=D(e,104)+d|0;if(w[e+484414>>1]<0){break pa}x[l+1075680>>2]=z[e+484410>>1]}Jb(i+8|0,s,100);if(Sa=Hb(x[x[i+8>>2]>>2],x[i+12>>2]),Ta=0,Va=x[d+480208>>2]&4,Va?Sa:Ta){break oa}c=0}e=Tc(n);if(e){v[l+1075794|0]=a;v[l+1075791|0]=a;if(!h){WS(d,k&65535,c,n,0)}wV(g)}qa:{ra:{sa:{ta:{ua:{if(c){f=l+1075096|0;m=x[f>>2];Ro(d,g,c,h,1,1);a=x[f>>2];va:{if(!a|!(y[a+35|0]&2)){break va}M=x[d+1298300>>2];if(!Dd(M)){break va}RB(M,k&65535,a+68|0)}wa:{xa:{if(x[d+480180>>2]==1){if(!h){break xa}Jb(i+8|0,s,85);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break xa}break wa}Jb(i+8|0,s,50);if((e|Hb(x[x[i+8>>2]>>2],x[i+12>>2])^1)!=1){break wa}}v[l+1075795|0]=0}Jb(i+8|0,s,42);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!e|(m|0)==x[f>>2]){break ta}break ua}if(x[d+480180>>2]&16777248){a=0;if(e&(m|0)!=x[f>>2]){break sa}}Jb(i+8|0,s,107);ya:{if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|(!(e^1|h)|(m|0)==x[f>>2])){break ya}a=l+1075068|0;if(A[a>>2]>=A[g+4>>2]){break ya}x[a>>2]=0;break ta}Jb(i+8|0,s,85);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ta}if(!Ui(x[g+8>>2],x[g+12>>2])){break ua}break ta}if(!n){a=h;break qa}f=0;m=l+1075795|0;a=y[m|0];if(!(!a|e^1)){Ro(d,g,a,h,!(x[l+1075096>>2]?1:x[l+1075648>>2]),!(x[d+480180>>2]&1048580));v[m|0]=0;f=1}a=h;break ra}x[g>>2]=0;x[g+4>>2]=0}a=h}f=0;if(!n){break qa}}e=x[l+1075096>>2];za:{if(!e|!(y[e+35|0]&2)){break za}h=x[d+1298300>>2];if(!Dd(h)){break za}if(!f){if(XS(h,k&65535)){break za}}RB(h,k&65535,e+68|0)}e=k&65535;Su(d,g,n,a,!(x[d+480180>>2]&1048580),0,e);HT(x[d+480180>>2],z[d+480188>>1],P,e);if(!(!(x[d+480180>>2]&1048580)|(!a|!c))){c=l+1075080|0;x[c>>2]=x[c>>2]|2097152;en(g);v[l+1075810|0]=0;x[l+1075748>>2]=0}if(!(x[l+1075080>>2]&512)){break qa}if(!Dd(x[d+1298300>>2])){break qa}if(n>>>0<=253){if((n|0)!=253){break qa}Jb(i+8|0,s,99);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break qa}}Jb(i+8|0,s,110);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){SB(x[d+1298300>>2],e,0,1,0)}Gk(x[d+1298300>>2],e)}Aa:{Ba:{switch(j-1|0){case 0:q=q>>>0>=64?64:q;x[l+1075680>>2]=q<<2;c=l+1075080|0;x[c>>2]=x[c>>2]|2097152;break Aa;case 1:break Ba;default:break Aa}}fn(d,g,q,6)}if(z[d+480192>>1]){US(d,k&65535)}h=a}Jb(i+8|0,s,77);if(Sa=Hb(x[x[i+8>>2]>>2],x[i+12>>2]),Ta=0,Va=x[((k<<5)+d|0)+480280>>2]&1024,Va?Sa:Ta){break K}a=x[d+1074392>>2];Jb(i+8|0,s,75);e=a>>>0>=C>>>0;Ca:{Da:{Ea:{Fa:{if(!C|!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Fa}c=x[d+1074392>>2];if(!c){break Ea}e=1;if((c|0)!=(C|0)){break Fa}e=!y[R|0]&(j|0)!=11}a=j;if(!e|a>>>0<3){break Ea}if((a|0)==11){a=i+8|0;vB(a,d,y[T+3|0],y[T+4|0],C);a=y[af(a)|0];bB(d,k&65535,z[i+8>>1]);if(a){break Da}j=11;break Ea}Jb(i+8|0,s,62);Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if(!(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|q)){q=0;j=0;Na:{switch(a-8|0){case 0:break Ma;case 1:break Na;default:break Ea}}if(y[V|0]&16){break Ea}x[l+1075684>>2]=0;break Ea}Jb(i+8|0,s,41);Oa:{if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Oa}if(q){v[l+1075826|0]=q;break Oa}q=y[l+1075826|0]}Pa:{switch(a-3|0){case 0:case 1:Qa:{Ra:{if(q){break Ra}Jb(i+8|0,s,41);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ra}q=y[l+1075826|0];if(q){break Qa}q=0;break Ea}v[l+1075826|0]=q}Po(d,g,((a|0)==3?q<<4:q)&255);break Ea;case 2:if((C|0)!=x[d+1074392>>2]){Jb(i+8|0,s,41);j=5;if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ea}}Jb(i+8|0,s,41);Oo(d,g,q,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));j=5;break Ea;case 3:if((C|0)!=x[d+1074392>>2]){Jb(i+8|0,s,41);j=6;if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ea}}Jb(i+8|0,s,41);No(d,g,q,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));j=6;break Ea;case 11:break Ga;case 12:break Ha;case 10:break Ia;case 9:break Ja;case 7:break Ka;case 6:break La;case 5:break Ma;case 4:break Pa;default:break Ea}}Jb(i+8|0,s,53);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){v[l+1075815|0]=q&15;j=7;break Ea}Pl(g,q<<4);j=7;break Ea}Pl(g,q);j=8;break Ea}Jb(i+8|0,s,62);aB(d,g,q,Hb(x[x[i+8>>2]>>2],x[i+12>>2])^1);j=9;break Ea}Jb(i+8|0,s,62);aB(d,g,q<<4&240,Hb(x[x[i+8>>2]>>2],x[i+12>>2])^1);j=10;break Ea}j=12;Jb(i+8|0,s,12);TS(d,k&65535,q<<2&252,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));break Ea}Jb(i+8|0,s,12);SS(d,k&65535,q<<2&252,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));j=13;break Ea}j=15;if(!r){break Ea}a=x[l+1075096>>2];if(!a|q>>>0>9){break Ea}Sa:{if(!q){c=x[l+1075656>>2];break Sa}c=x[yb(a+68|0,q-1|0)>>2];x[l+1075656>>2]=c}Qo(d,g,c);break Ea}j=14;if(q>>>0>1){break Ea}v[H|0]=y[H|0]&247|!q<<3}c=b;Ta:{Ua:{Va:{switch(J-1|0){case 12:if(!(y[d+480209|0]&16)){break Da}a=D(k,872)+d|0;x[a+1075680>>2]=b>>>0>=64?256:b<<2;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Da;case 45:if(!(y[d+480209|0]&16)){break Da}a=D(k,872)+d|0;x[a+1075680>>2]=b;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Da;case 1:if(!b){c=0;if(v[d+480180|0]&1){break Ca}}TS(d,k&65535,b,0);break Da;case 2:if(!b){c=0;if(v[d+480180|0]&1){break Ca}}SS(d,k&65535,b,0);break Da;case 10:if(!b){c=0;if(x[d+480180>>2]==1){break Ca}}Po(d,g,b);break Da;case 3:bB(d,k&65535,b);break Da;case 5:if(!(!b&x[d+480180>>2]==1)){Po(d,g,b)}bB(d,k&65535,0);break Da;case 4:Pl(g,b);break Da;case 6:if(!(!b&x[d+480180>>2]==1)){Po(d,g,b)}Pl(g,0);break Da;case 15:if(!(y[d+480209|0]&16)){break Da}break Ta;case 16:Jb(i+8|0,s,5);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!(y[d+480209|0]&16)){break Da}if(b){break Ta}break Da}c=Mo(d,z[d+1074446>>1],x[d+1074424>>2],k&65535,0);Wa:{if(!(x[d+480180>>2]&16777250)){break Wa}if(c){v[(D(k,872)+d|0)+1075827|0]=c;break Wa}c=y[(D(k,872)+d|0)+1075827|0]}x[i+8>>2]=D(c,1e4);wc(i+8|0,D(x[x[d+8>>2]+24>>2],1e4));a=fb-16|0;fb=a;e=x[i+8>>2];x[a+12>>2]=e;b=x[d+8>>2];Xa:{if(e>>>0>=(x[d+480180>>2]&16393?1e4:32e4)>>>0){e=x[d+480208>>2];Jb(a+4|0,d+1074312|0,92);if((Hb(x[x[a+4>>2]>>2],x[a+8>>2])|0)==((e&4096)>>>12|0)){break Xa}x[a+4>>2]=D(x[b+24>>2],1e4);Sa=d+1074420|0,Ta=x[Gb(a+12|0,a+4|0)>>2],x[Sa>>2]=Ta;break Xa}if(y[d+480209|0]&16){break Xa}f=d+1074420|0;e=(e>>>0)/1e4|0;h=D(e&15,1e4);x[f>>2]=x[f>>2]+((e&240)==16?h:0-h|0);e=x[b+20>>2];b=x[b+24>>2];Jb(a+4|0,d+1074312|0,8);Mp(f,D(e,1e4),Hb(x[x[a+4>>2]>>2],x[a+8>>2])?255e4:D(b,1e4))}fb=a+16|0;break Ca;case 9:if(!r|x[d+480180>>2]==4&h){break Da}GT(d,g,k&65535,x[d+1074424>>2],z[d+1074446>>1]);break Da;case 43:if(!r){break Da}c=ova(x[(D(k,872)+d|0)+1075068>>2],0,b,0);a=hb;h=a>>>8|0;Qo(d,g,Bc((a&255)<<24|c>>>8,h));break Da;case 0:if(x[d+1074392>>2]){break Da}a=D(k,872)+d|0;Ya:{if(y[a+1075789|0]?x[a+1075692>>2]:0){break Ya}a=x[a+1075648>>2];if(a){if(Tj(y[a+31|0])){break Ya}}Jb(i+8|0,s,13);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ya}if(x[d+480180>>2]&16777248){break Da}}if(!b){c=0;if(y[d+480180|0]&5){break Ca}v[(D(k,872)+d|0)+1075797|0]=1;break Ca}a=D(k,872)+d|0;v[a+1075798|0]=b;v[a+1075797|0]=1;break Da;case 14:if(x[d+480180>>2]&1048580){b=b&240?b:y[(D(k,872)+d|0)+1075799|0]&240|b;if(!(b&15)){b=y[(D(k,872)+d|0)+1075799|0]&15|b}b=b|256}c=b;Jb(i+8|0,s,23);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){b=k&65535;if(c){v[(D(k,872)+d|0)+1075799|0]=c;a=c}else{a=y[(D(k,872)+d|0)+1075799|0]}$A(d,b,a&255,(j|0)==15?q+1|0:0);break Ca}Za:{if(c){v[(D(k,872)+d|0)+1075799|0]=c;break Za}c=y[(D(k,872)+d|0)+1075799|0]}$A(d,k&65535,c,(j|0)==15?q+1|0:0);break Ca;case 17:if(!(y[d+480209|0]&16)){break Da}Jb(i+8|0,s,22);_a:{$a:{if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!b){b=0;break $a}if(y[d+480208|0]&4){break $a}a=b&240?b-16|0:b;b=a-((a&15)!=0)|0;v[(D(k,872)+d|0)+1075832|0]=b;break $a}Jb(i+8|0,s,71);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break _a}}a=(D(k,872)+d|0)+1075831|0;v[a|0]=y[a|0]|128}a=D(k,872)+d|0;v[a+1075797|0]=18;if(!b){c=0;break Ca}v[a+1075832|0]=b;break Da;case 22:if(!(y[d+480209|0]&16)){break Da}a=x[d+480180>>2];c=b<<!(a&59593760);if(c>>>0<=128){x[d+1074456>>2]=c<<1;break Ca}if(a&16777250){break Ca}x[d+1074456>>2]=256;break Ca;case 23:Jb(i+8|0,s,9);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){RS(d,b,(D(k,872)+d|0)+1075809|0);break Da}RS(d,b,W);break Da;case 8:if(!(y[d+480209|0]&16)){break Da}fn(d,g,b,8);break Da;case 28:aB(d,g,b,1);break Da;case 7:yT(g,b);break Da;case 25:zT(d,g,b);break Da;case 18:f=fb-16|0;fb=f;j=d+1074376|0;c=k&65535;h=D(c,872);e=(j+h|0)+616|0;a=b&15;ab:{bb:{switch(b>>>4|0){case 0:c=(b&1)<<14;e=z[d+480188>>1];a=0;while(1){if((a|0)==(e|0)){break ab}h=(D(a,872)+d|0)+1075080|0;x[h>>2]=(c|x[h>>2]&-16385)^16384;a=a+1|0;continue};case 1:if(!a){a=0;if(!(x[d+480180>>2]&1048580)){break ab}}nB(d,e,a);Jb(f+8|0,d+1074312|0,117);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break ab}Go(d,c,b|240,1);break ab;case 2:if(!a){a=0;if(!(x[d+480180>>2]&1048580)){break ab}}mB(d,e,a);Jb(f+8|0,d+1074312|0,117);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break ab}Go(d,c,0-(b|240)|0,1);break ab;case 3:c=(d+h|0)+1075080|0;x[c>>2]=x[c>>2]&-1048577|((a|0)!=0)<<20;break ab;case 4:v[(d+h|0)+1075814|0]=b&7;break ab;case 5:if(!(y[d+480209|0]&16)){break ab}h=x[d+480180>>2];if(h&69206025){e=D(c,872)+d|0;a=a<<28>>24;w[e+1075764>>1]=a;h=e+1075692|0;if(!x[h>>2]){break ab}if(!Tc(y[e+1075780|0])){break ab}c=D(c,872)+d|0;Sa=h,Ta=yh(d,y[c+1075789|0],a,x[c+1075696>>2]),x[Sa>>2]=Ta;break ab}e=Tc(y[(D(c,872)+d|0)+1075780|0]);if((h|0)==16){if(!e){break ab}e=D(c,872)+d|0;h=x[e+1075096>>2];if(!h){break ab}v[h+37|0]=a;w[e+1075764>>1]=a;e=e+1075692|0;if(!x[e>>2]){break ab}c=D(c,872)+d|0;Sa=e,Ta=yh(d,y[c+1075789|0],a,x[c+1075696>>2]),x[Sa>>2]=Ta;break ab}if(!e){break ab}a=D(c,872)+d|0;c=(b<<4^-128)<<24>>24;w[a+1075764>>1]=c;e=a+1075692|0;if(!x[e>>2]){break ab}Sa=e,Ta=yh(d,y[a+1075789|0],c,x[a+1075696>>2]),x[Sa>>2]=Ta;break ab;case 6:if(!(y[d+480209|0]&16)){break ab}uB(d,j,c,a);break ab;case 7:v[(d+h|0)+1075817|0]=b&7;break ab;case 8:if(!(y[d+480209|0]&16)){break ab}fn(d,e,a,4);break ab;case 9:$A(d,c,a,0);break ab;case 10:if(a){Oo(d,e,a,0);break ab}if(!(x[d+480180>>2]&1048580)){break ab}Oo(d,e,0,0);break ab;case 11:if(a){No(d,e,a,0);break ab}if(!(x[d+480180>>2]&1048580)){break ab}No(d,e,0,0);break ab;case 12:cB(d,c,a,0);break ab;case 15:break bb;default:break ab}}if(x[d+480180>>2]==1){v[(D(c,872)+d|0)+1075838|0]=a;if(!(y[d+480209|0]&16)){break ab}VS(d,e);break ab}v[(D(c,872)+d|0)+1075836|0]=a}fb=f+16|0;break Da;case 19:QS(d,k&65535,b);break Da;case 24:Jb(i+8|0,s,55);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(x[d+1074392>>2]!=(b|0)){break Da}a=x[(D(k,872)+d|0)+1075648>>2];if(v[a+60|0]&1?a:0){break Ua}if(!(!(y[R|0]|y[L|0])|b)){a=(D(k,872)+d|0)+1075080|0;x[a>>2]=x[a>>2]|4096;break Ua}a=D(k,872)+d|0;x[a+1075680>>2]=0;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ua}if(y[d+480209|0]&16){break Ua}break Da;case 27:a=(b&240)-16>>>4|0;if(a>>>0>9){break Da}if(!(1<<a&880)){if(a){if((a|0)!=1){break Da}lB(d,g,I);Jb(i+8|0,s,117);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Da}Go(d,k&65535,-224-I|0,1);break Da}oB(d,g,I);Jb(i+8|0,s,117);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Da}Go(d,k&65535,I|224,1);break Da}Jb(i+8|0,s,58);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Da}QS(d,k&65535,b);break Da;case 34:case 35:f=(J|0)==36;if(!(f|x[d+480208>>2]&4096)){break Da}c=k&65535;e=P+D(c,872)|0;h=e+616|0;a=DT(d,z[d+1074446>>1],x[d+1074424>>2],c);cb:{if(!f){break cb}f=Ql(P)-x[P+16>>2]|0;if((f|0)<2){break cb}m=a;a=w[(P+D(c,872)|0)+1390>>1];a=ed(((m-a|0)/(f|0)|0)+a|0)}w[e+1390>>1]=a;e=Kq(d,x[e+704>>2],x[h+656>>2]);if(e){ib[x[x[e>>2]+80>>2]](e,(a<<16>>16)+32768>>>2|0,c)}break Da;case 20:if(!(y[d+480209|0]&16)|b>>>0>64){break Da}a=D(k,872)+d|0;x[a+1075740>>2]=b;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Da;case 21:h=x[d+480180>>2];f=x[d+480208>>2];a=b;db:{if(a){v[g+816|0]=a;break db}a=y[g+816|0]}c=a&15;e=a&255;eb:{fb:{if(!((c|0)!=15|e>>>0<16)){if(!(f&4096)){break eb}a=e>>>4|0;break fb}f=f&4096;j=e&240;if(!(!c|(j|0)!=240)){if(!f){break eb}a=0-c|0;break fb}if(f){break eb}if(c){a=0-c|0;if(!j|!(h&25690144)){break fb}break eb}if((a&255)>>>0<16){break eb}a=e>>>4|0}Sa=g,Ta=Yb(a+x[g+748>>2]|0,0,64),x[Sa+748>>2]=Ta}break Da;case 26:xT(g,b);break Da;case 29:if(!(y[d+480209|0]&16)){break Da}a=D(k,872)+d|0;x[a+1075716>>2]=b;Jb(i+8|0,s,60);if(Sa=0,Ta=Hb(x[x[i+8>>2]>>2],x[i+12>>2]),Va=y[a+1075722|0]&4,Va?Sa:Ta){break Da}a=D(k,872)+d|0;x[a+1075732>>2]=b;x[a+1075724>>2]=b;break Da;case 11:BT(d,P,k&65535);break Da;case 13:a=AT(d,P,k&65535,b);if((a|0)==-1){break Da}x[d+1074436>>2]=a;if(!(y[d+480208|0]&32)){break Da}w[d+1074444>>1]=z[d+1074448>>1];break Da;case 37:case 38:case 39:case 40:pT(d,g,b,(J|0)==38|(J|0)==40,(J&254)==40);break Da;case 41:FT(g,b);break Da;case 42:if(x[d+1074392>>2]|I>>>0>1|b>>>0>47){break Da}a=(b&240)==16;f=a?z[d+480188>>1]-1|0:k;c=a?0:k;a=((I|0)==1)<<26;while(1){e=c&65535;if(e>>>0>(f&65535)>>>0){break Da}h=((e<<5)+d|0)+480280|0;x[h>>2]=a|x[h>>2]&-67108865;e=(D(e,872)+d|0)+1075080|0;x[e>>2]=a|x[e>>2]&-67108865;c=c+1|0;continue};case 44:break Va;default:break Ca}}ET(g,b);break Da}Lo(d,g);break Da}LT(d,P,b)}c=b}Jb(i+8|0,s,78);if(!(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|!c)){uT(g,c&255)}a=y[R|0];if(!a){break K}v[l+1075796|0]=a}k=k+1|0;continue}break}a=1}fb=t+32|0;M=a&x[d+1074420>>2]!=0;gb:{if(!M){break gb}a=JT(d,d+1074376|0);x[d+1074380>>2]=a;x[d+1074404>>2]=a;b=Kd(z[d+480188>>1],1,31);hb:{if(Ed(y[d+1074366|0])){a=x[d+24628>>2];if((a|0)>=129){a=((D(a-128|0,b+4|0)|0)/16|0)+128|0}r=((D(x[d+480228>>2],a)<<1&-128)>>>0)/y[(b>>>1|0)+30560|0]|0;break hb}r=x[d+480228>>2]}w[d+480212>>1]=0;s=d+1074312|0;P=d+480210|0;T=d+480209|0;n=0;while(1){if((n|0)==256){a=x[d+24608>>2];b=z[d+480212>>1];if(a>>>0>b>>>0){break gb}j=fb-16|0;fb=j;x[j+12>>2]=d;e=d+1074478|0;c=e+(a<<1)|0;if((c|0)!=(e|0)){a=e+(b<<1)|0;g=j+12|0;ib:{b=c-e|0;if((b|0)<3){break ib}f=b>>1;b=f-2>>>1|0;while(1){if((b|0)<0){break ib}WR(e,x[g>>2],f,e+(b<<1)|0);b=b-1|0;continue}}f=c-e>>1;b=c;while(1){if((a|0)!=(b|0)){if(Nl(x[g>>2],z[b>>1],z[e>>1])){VR(b,e);WR(e,x[g>>2],f,e)}b=b+2|0;continue}break}b=c-e>>1;while(1){if((b|0)>1){n=z[e>>1];a=e;r=x[g>>2];f=0;h=b;i=b-2>>>1|0;while(1){b=f<<1;f=b|1;m=b+2|0;b=m+a|0;if((h|0)>(m|0)){k=m;m=Nl(r,z[b>>1],z[b+2>>1]);f=m?k:f;b=m?b+2|0:b}w[a>>1]=z[b>>1];a=b;if((f|0)<=(i|0)){continue}break}b=c-2|0;jb:{if((b|0)==(a|0)){w[a>>1]=n;break jb}w[a>>1]=z[b>>1];w[b>>1]=n;n=x[g>>2];a=a+2|0;b=a-e>>1;kb:{if((b|0)<2){break kb}f=b-2|0;b=e+(f&-2)|0;a=a-2|0;if(!Nl(n,z[b>>1],z[a>>1])){break kb}f=f>>>1|0;m=z[a>>1];while(1){lb:{r=a;a=b;w[r>>1]=z[a>>1];if(!f){break lb}b=f-1|0;f=b>>>1|0;b=e+(b&-2)|0;if(Nl(n,z[b>>1],m)){continue}}break}w[a>>1]=m}}b=h-1|0;c=c-2|0;continue}break}}fb=j+16|0}else{k=D(n,872)+d|0;l=k+1075080|0;mb:{if(!(x[l>>2]&4096)|(x[k+1075016>>2]|(x[k+1075012>>2]|x[k+1075688>>2]))){break mb}Jb(o+16|0,s,64);if(Hb(x[x[o+16>>2]>>2],x[o+20>>2])){break mb}x[k+1075068>>2]=0;a=k+1075084|0;x[a>>2]=0;x[a+4>>2]=0}c=z[d+480188>>1];a=x[l>>2];nb:{if(x[k+1075068>>2]|c>>>0>n>>>0?a&1024:1){if(c>>>0>n>>>0){$R(d,n&65535)}w[k+1075834>>1]=0;break nb}b=0;I=k+1075712|0;x[I>>2]=0;t=k+1075672|0;x[t>>2]=0;i=k+1075e3|0;e=i;x[e>>2]=0;x[e+4>>2]=0;x[k+1075092>>2]=0;x[o+44>>2]=1065353216;w[o+42>>1]=0;C=k+1075648|0;J=x[C>>2];x[o+36>>2]=0;j=0;m=k+1075692|0;j=x[m>>2]?x[k+1075068>>2]!=0:j;f=k+1074992|0;ob:{pb:{qb:{if(c>>>0<=n>>>0){break qb}if(y[((n<<5)+d|0)+480288|0]){break pb}if(!J){break qb}b=y[J+34|0]!=0}if((b|j)!=1){break ob}}x[o+8>>2]=x[k+1075680>>2];x[o+32>>2]=x[k+1075744>>2];Jb(o+16|0,s,28);a=o+8|0;b=Hb(x[x[o+16>>2]>>2],x[o+20>>2])?o+32|0:a;c=d+1074312|0;rb:{if(Ob(c,28)){x[b>>2]=x[b>>2]+w[f+776>>1];Fe(b,0,64);break rb}e=Ob(c,1);c=w[f+776>>1];if(e){x[b>>2]=c+x[b>>2];Fe(b,0,256);break rb}x[f+688>>2]=c+x[f+688>>2];Fe(f+688|0,0,256);x[b>>2]=x[f+688>>2];w[f+776>>1]=0}sb:{tb:{b=d+1074312|0;if(!Ob(b,28)){if(!Ob(b,1)){break tb}}x[f+684>>2]=x[f+692>>2]+w[f+778>>1];Fe(f+684|0,0,256);break sb}x[f+692>>2]=x[f+692>>2]+w[f+778>>1];Fe(f+692|0,0,256);w[f+778>>1]=0;x[f+684>>2]=x[f+692>>2]}ub:{if(!(y[f+90|0]&4)|(x[d+480208>>2]&2101248)==2101248){break ub}vb:{if(x[a>>2]<=0){if(!Ob(d+1074312|0,21)){break vb}}c=5;if(!(y[d+480180|0]&5)){c=Ob(d+1074312|0,21)?5:6}b=JA(d,y[f+825|0],y[f+820|0]);wb:{if((y[f+825|0]&3)!=1){break wb}if(!Ob(d+1074312|0,89)){break wb}b=y[f+819|0];h=y[f+820|0];e=h<<2&124;b=(!(y[f+90|0]&2)|y[d+480209|0]&16?b:y[f+823|0]+b|0)&32?e^127:e;b=h&32?0-b|0:b}if(x[d+480180>>2]!=131072){b=x[a>>2]+((D(y[f+827|0],b)|0)/(1<<c)|0)|0}else{c=64-b|0;b=x[a>>2];b=((D(y[f+827|0],D(c,b))|0)/-8192|0)+b|0}x[a>>2]=b}b=x[d+480208>>2];if(!(x[d+480180>>2]&16777248)|b&4?b&4096:0){break ub}b=Ob(d+1074312|0,21);c=y[f+826|0];e=y[f+820|0];v[f+820|0]=(b?c<<2:e)+(b?e:c)}e=n&65535;h=fb-16|0;fb=h;b=d+1074312|0;Jb(h+8|0,b,71);xb:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){b=(D(e,872)+d|0)+1075831|0;c=v[b|0];if((c|0)>=0){break xb}if(!(y[d+480209|0]&16|y[(D(e,872)+d|0)+1075797|0]!=18)){yb:{zb:{if((c&-33)!=-64){c=c&223;if((c|0)!=128){break zb}c=y[(D(e,872)+d|0)+1075832|0]>>>4|-64;break yb}c=y[(D(e,872)+d|0)+1075832|0]&15|-128;break yb}c=c-1|0}v[b|0]=c;b=(D(e,872)+d|0)+1075080|0;x[b>>2]=x[b>>2]|2097152}if((c&224)!=128){break xb}x[a>>2]=0;break xb}if(y[(D(e,872)+d|0)+1075797|0]!=18){break xb}Jb(h+8|0,b,22);Ab:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){q=D(e,872)+d|0;b=q+1075831|0;g=y[b|0];c=g<<24>>24;if(!((c|0)>=0|!x[q+1075068>>2])){Bb:{Cb:{if((g|0)!=192){if((g|0)!=128){break Cb}c=y[(D(e,872)+d|0)+1075832|0]>>>4|-64;break Bb}c=y[(D(e,872)+d|0)+1075832|0]&15|-128;break Bb}c=c-1|0}v[b|0]=c}if((c&192)!=128){break Ab}x[a>>2]=0;break Ab}b=y[(D(e,872)+d|0)+1075832|0];c=b>>>4|0;u=c+(b&15)|0;g=x[d+480180>>2];if(!(y[d+480208|0]&4?0:g&16777248)){u=u+2|0;c=c+1|0}b=(D(e,872)+d|0)+1075831|0;q=y[b|0];if(!(g&4)){g=c;c=(q&255)>>>0<u>>>0?q:0;if(g>>>0<=(c&255)>>>0){x[a>>2]=0}v[b|0]=c+1;break Ab}Db:{if(y[d+480209|0]&16){b=q&255;g=b-1|0;q=b>>>0>=g>>>0?g:0;break Db}v[b|0]=q+1}if(((q&255)>>>0)%(u>>>0)>>>0<c>>>0){break Ab}x[a>>2]=0}b=(D(e,872)+d|0)+1075080|0;x[b>>2]=x[b>>2]|2097152}b=D(e,872)+d|0;Eb:{if(y[b+1075797|0]!=18){break Eb}c=x[b+1075648>>2];if(!c){break Eb}b=y[c+34|0];if(!b|y[c+15|0]&2){break Eb}g=D(e,872)+d|0;if(x[g+1075080>>2]&134218752){break Eb}g=g+1075791|0;q=y[g|0];if(!Tc(q)){break Eb}b=x[vd(d+906300|0,b-1|0)>>2];if(!b){break Eb}q=ib[x[x[b>>2]+104>>2]](b,q,e)|0;u=x[a>>2];if(!(!q|u)){ib[x[x[b>>2]+96>>2]](b,c,y[g|0]|256,0,e);break Eb}if(q|!u){break Eb}ib[x[x[b>>2]+96>>2]](b,c,y[g|0],z[(D(e,872)+d|0)+1075680>>1],e)}fb=h+16|0;Fe(a,0,256);x[o+8>>2]=x[o+8>>2]<<6;Fb:{if(J){Jb(o+16|0,s,31);if(Hb(x[x[o+16>>2]>>2],x[o+20>>2])){Nu(d,f)}a=o+8|0;Gb:{if(!HA(d,f,0)){break Gb}c=x[f+656>>2];h=d+1074312|0;g=Ob(h,31);b=x[f+724>>2];if(b?0:g){break Gb}q=b-Ob(h,31)|0;b=Xq(c+48|0,q,256,64);u=y[c+65|0];Hb:{if((u|0)==255){break Hb}g=w[f+728>>1];if((g|0)==-1){break Hb}u=yb(x[c+48>>2],u);H=y[u+2|0];c=H<<2;b=(q|0)==z[u>>1]?c:b;if(Ob(h,94)){b=g+(b-c<<1)|0;break Hb}if(!H){b=0;break Hb}b=(D(b,g)|0)/(c|0)|0}Sa=a,Ta=(D(Yb(b,0,512),x[a>>2])|0)/256|0,x[Sa>>2]=Ta}nT(f,a);Ib:{if(!HA(d,f,1)){break Ib}a=x[f+656>>2];b=d+1074312|0;h=Ob(b,31);c=x[f+732>>2];if(c?0:h){break Ib}b=Xq(a+68|0,c-Ob(b,31)|0,64,64)-32|0;a=x[f+684>>2];Sa=f,Ta=Yb(((D(b,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),x[Sa+684>>2]=Ta}Jb(o+16|0,s,115);if(Hb(x[x[o+16>>2]>>2],x[o+20>>2])){break Fb}b=y[k+1075789|0];if(!b){break Fb}a=x[C>>2];if(!a|!y[a+26|0]){break Fb}qT(k+1075676|0,b,y[a+26|0],y[a+27|0]);break Fb}if(!(y[l+1|0]&16)){break Fb}x[k+1075688>>2]=0;x[o+8>>2]=0}Jb:{if(y[k+1075843|0]&8){c=0;x[o+8>>2]=0;break Jb}c=x[o+8>>2];if(!c){c=0;break Jb}if(y[l+3|0]&8){x[t>>2]=0;break Jb}if(Ed(y[d+1074365|0])){a=D(x[o+32>>2],x[k+1075740>>2]);b=a;h=a>>31;a=c<<8;Sa=t,Ta=Gc(pva(ova(b,h,a,a>>31),hb,1048576,0),hb),x[Sa>>2]=Ta;break Jb}a=D(x[o+32>>2],x[k+1075740>>2]);b=a;h=a>>31;a=D(x[d+1074456>>2],c);Sa=t,Ta=Gc(pva(ova(b,h,a,a>>31),hb,1048576,0),hb),x[Sa>>2]=Ta}x[I>>2]=c;Kb:{Lb:{c=x[m>>2];if(!(x[d+480180>>2]==2|(c|0)>=x[d+480260>>2])){if(!Jj(d)){break Lb}c=x[m>>2]}if((c|0)<x[d+480264>>2]){break Kb}Jb(o+16|0,s,113);if(!Hb(x[x[o+16>>2]>>2],x[o+20>>2])){break Kb}if(Jj(d)){break Kb}x[m>>2]=x[d+480264>>2];break Kb}x[m>>2]=x[d+480260>>2]}Jb(o+16|0,s,73);a=x[m>>2];x[o+36>>2]=a;Mb:{if((x[l>>2]&1572864)!=1572864){break Mb}b=x[d+480208>>2];if(b&2097152){if(!Rl(y[k+1075782|0],y[k+1075783|0])|b&4096){break Mb}}b=k+1075704|0;Nb:{if((a|0)==x[b>>2]){c=x[k+1075708>>2];break Nb}x[b>>2]=a;c=a;a=k+1075764|0;b=k+1075696|0;c=yh(d,Ku(d,c,w[a>>1],x[b>>2]),w[a>>1],x[b>>2]);x[k+1075708>>2]=c}x[o+36>>2]=c}h=fb-16|0;fb=h;u=D(e,872)+d|0;H=u+1075648|0;a=x[H>>2];Ob:{if(!a){break Ob}b=y[a+34|0];if(x[(D(e,872)+d|0)+1075080>>2]&134218752|(!b|y[a+15|0]&2)){break Ob}if(!x[vd(d+906300|0,b-1|0)>>2]){break Ob}a=D(e,872)+d|0;g=a+1075780|0;b=y[a+1075793|0];R=a+1075783|0;q=y[R|0];Pb:{Qb:{if((q|0)==1){a=b;Rb:{Sb:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 0:a=b+(y[(D(e,872)+d|0)+1075798|0]>>>4|0)|0;break Rb;case 1:break Sb;default:break Rb}}a=b+(y[(D(e,872)+d|0)+1075798|0]&15)|0}c=D(e,872)+d|0;if(y[c+1075792|0]==(a&255)){break Pb}if(!(v[c+1075843|0]&1)){break Qb}if(!Tc(y[g|0])){break Qb}if(Rl(y[g+2|0],1)){break Qb}break Pb}if(y[g|0]){a=b;if(!Rl(y[g+2|0],q)){break Pb}}a=b;if(!y[(D(e,872)+d|0)+1075792|0]){break Pb}}dn(d,e,a&255|512,z[(D(e,872)+d|0)+1075680>>1])}L=(D(e,872)+d|0)+1075792|0;c=y[L|0];Tb:{Ub:{if(c){if((q|0)!=1|(a&255)!=(c|0)){break Ub}break Tb}if(!(v[(D(e,872)+d|0)+1075843|0]&1)|(q|0)!=1){break Tb}if(Tc(y[g|0])){break Tb}c=b;if(!Tc(b)){break Tb}}dn(d,e,c&255|256,0)}v[L|0]=y[R|0]==1?a:0}Vb:{if(y[u+1075797|0]!=1){break Vb}if(Uj(x[H>>2])){a=0;Wb:{Xb:{Yb:{switch(A[d+1074392>>2]%3|0){case 1:a=y[(D(e,872)+d|0)+1075798|0]>>>4|0;break Xb;case 0:break Xb;case 2:break Yb;default:break Wb}}a=y[(D(e,872)+d|0)+1075798|0]&15}w[o+42>>1]=a}a=(D(e,872)+d|0)+1075843|0;v[a|0]=y[a|0]|96;break Vb}if(!(!(y[d+480209|0]&16)|x[d+480180>>2]!=1048576)){a=D(e,872)+d|0;b=yh(d,y[a+1075789|0],w[a+1075764>>1],x[a+1075696>>2]);x[o+36>>2]=b;x[a+1075692>>2]=b}c=d+1074312|0;Jb(h+8|0,c,13);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){a=y[(D(e,872)+d|0)+1075798|0];if(!a){break Vb}b=65536;Zb:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:a=a<<4;case 0:b=x[((a&240)<<2)+35568>>2];break;default:break Zb}}e=Jj(d);a=x[o+36>>2];c=a>>31;if(e){a=ova(a,c,b,b>>31);e=hb;a=a+32768|0;e=a>>>0<32768?e+1|0:e;a=pva(a,e,65536,0);b=hb}else{e=(b|0)/2|0;q=e>>31;g=c<<16|a>>>16;c=a<<16;a=c+e|0;_=g+q|0;a=pva(a,a>>>0<c>>>0?_+1|0:_,b,b>>31);b=hb}Sa=o,Ta=Gc(a,b),x[Sa+36>>2]=Ta;break Vb}Jb(h+8|0,c,51);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){if(y[d+480209|0]&16){break Vb}_b:{$b:{a=x[d+1074416>>2];a=a-(A[d+1074392>>2]%(a>>>0)|0)|0;if((a|0)>16){break $b}if((a|0)==16){break Vb}b=0;ac:{switch((a|0)%3|0){case 0:break Vb;case 2:break $b;case 1:break ac;default:break _b}}b=y[(D(e,872)+d|0)+1075798|0]>>>4|0;break _b}b=y[(D(e,872)+d|0)+1075798|0]&15}c=b;a=D(e,872)+d|0;b=a+1075764|0;a=a+1075696|0;c=c+Ku(d,x[o+36>>2],w[b>>1],x[a>>2])|0;b=yh(d,c,w[b>>1],x[a>>2]);x[o+36>>2]=b;if(c>>>0<109){break Vb}x[h+8>>2]=b;Sa=h,Ta=yh(d,109,0,x[a>>2]),x[Sa+4>>2]=Ta;Sa=o,Ta=x[ad(h+8|0,h+4|0)>>2],x[Sa+36>>2]=Ta;break Vb}g=x[d+1074392>>2];a=x[d+480180>>2];bc:{if((a|0)!=1){b=y[(D(e,872)+d|0)+1075789|0];break bc}a=D(e,872)+d|0;b=Ku(d,x[o+36>>2],w[a+1075764>>1],x[a+1075696>>2]);a=x[d+480180>>2]}cc:{dc:{switch((((a&67633152?g+2|0:g)>>>0)%3|0)-1|0){case 0:b=(y[(D(e,872)+d|0)+1075798|0]>>>4|0)+b|0;break cc;case 1:break dc;default:break cc}}b=(y[(D(e,872)+d|0)+1075798|0]&15)+b|0}if(!(a&67633408|y[(D(e,872)+d|0)+1075789|0]!=(b&255))){Jb(h+8|0,c,82);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Vb}}if(y[d+480210|0]&32){a=b&255;if((a|0)==85){x[o+36>>2]=2147483647;break Vb}b=a>>>0>85?b-37|0:b}a=D(e,872)+d|0;g=yh(d,b&255,w[a+1075764>>1],x[a+1075696>>2]);x[o+36>>2]=g;if(x[d+480180>>2]&71860480){x[a+1075692>>2]=g;break Vb}Jb(h+8|0,c,82);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Vb}v[(D(e,872)+d|0)+1075792|0]=b}fb=h+16|0;if(!(!(y[P|0]&33)|x[o+36>>2]==2147483647)){ec:{if(x[d+480180>>2]==2){c=452;a=3424;break ec}a=D(z[k+1075764>>1]>>>4&15,24);b=z[a+31302>>1]>>>1|0;c=b>>>0<=452?452:b;a=z[a+31280>>1]<<1}Fe(o+36|0,c,a);Fe(m,c,a)}vT(d,f);a=x[l>>2]}fc:{if(!(a&256)|y[T|0]&64){break fc}Jb(o+16|0,s,37);if(!Hb(x[x[o+16>>2]>>2],x[o+20>>2])){break fc}x[k+1075676>>2]=128}a=IT(d,f);gc:{if((a|0)<0|!(y[l+1|0]&2)){break gc}b=x[d+1298300>>2];if(!Dd(b)){break gc}Vq(b,n&65535,a&255,1)}m=n&65535;$R(d,m);hc:{if(!j){break hc}a=oT(d,f,o+36|0);if((a|0)<0|!(y[l+1|0]&2)){break hc}b=x[d+1298300>>2];if(!Dd(b)){break hc}Vq(b,m,a>>>2&255,1)}ic:{if(y[k+1075782|0]!=8){break ic}jc:{kc:{a=y[k+1075783|0];switch(a-5|0){case 1:break ic;case 0:case 2:break jc;default:break kc}}if((a|0)!=26){break ic}}a=x[d+480180>>2];if((a|0)==4){if(y[T|0]&16){break ic}a=k+1075811|0;v[a|0]=y[a|0]+y[k+1075815|0];break ic}if(!(a&16777248)){break ic}Pl(f,y[k+1075784|0]);_R(d,m,o+36|0,o+44|0)}_R(d,m,o+36|0,o+44|0);lc:{if(!j){break lc}x[o+32>>2]=0;e=o+36|0;g=fb-16|0;fb=g;c=x[f+104>>2];mc:{if(!c|!y[c+40|0]){break mc}q=Uj(x[f+656>>2]);j=Jj(d);b=j?36592:35568;h=j?35568:36592;if(!(q|!Ob(d+1074312|0,21)|x[d+480180>>2]==1048576)){u=y[c+41|0];if(!u){break mc}a=y[f+818|0];x[g+12>>2]=x[f+756>>2]+y[c+39|0];Bi(g+12|0,y[c+40|0]<<8);q=x[g+12>>2];v[f+818|0]=a+u;x[f+756>>2]=q;q=(q|0)/256|0;nc:{oc:{switch(y[c+38|0]-1|0){case 3:c=YR(Ko(d))+-64|0;break nc;case 2:c=64-(a+1>>>1|0)|0;break nc;case 1:c=(a+1>>>1|0)+-64|0;break nc;case 0:c=(a^-1)>>>1&64;break nc;default:break oc}}c=v[a+31872|0]}Bi(e,8388607);a=x[e>>2]<<8;x[e>>2]=a;H=D(c,q);q=(H|0)/64|0;c=q>>31;q=(c^q)-c|0;c=q&3;q=q>>>2|0;u=a>>31;pc:{qc:{if((H|0)<=-64){b=x[(q<<2)+b>>2];b=Gc(pva(ova(b,b>>31,a,u),hb,65536,0),hb)-a|0;if(!c){break pc}h=j?35504:35440;break qc}b=x[h+(q<<2)>>2];b=Gc(pva(ova(b,b>>31,a,u),hb,65536,0),hb)-a|0;if(!c){break pc}h=j?35440:35504}c=x[(c<<2)+h>>2];b=(Gc(pva(ova(a,u,c,c>>31),hb,65536,0),hb)+b|0)-a|0}x[e>>2]=(b+a|0)/256;x[o+32>>2]=b&255;break mc}j=x[d+480180>>2]&16777248;a=y[c+39|0];rc:{if(!(j|a)){x[f+756>>2]=y[c+40|0]<<8;break rc}sc:{if(j){x[f+756>>2]=x[f+756>>2]+(a<<1);j=y[c+40|0];break sc}j=y[c+40|0];if(y[f+89|0]&8){break sc}x[f+756>>2]=x[f+756>>2]+(((j<<8&65280)>>>0)/(a>>>0)|0)}Bi(f+756|0,j<<8)}a=y[f+818|0]+y[c+41|0]|0;v[f+818|0]=a;a=a<<24>>24;tc:{uc:{switch(y[c+38|0]-1|0){case 3:v[f+818|0]=a+1;j=v[(a&63)+31808|0];break tc;case 2:j=(64-(a>>>1|0)&127)+-64|0;break tc;case 1:j=((a>>>1|0)- -64&127)+-64|0;break tc;case 0:j=(a|0)>=0?-64:64;break tc;default:break uc}}j=0-v[(a&255)+31872|0]|0;if(x[d+480180>>2]!=1048576){break tc}j=(64-v[(a+-64&255)+31872|0]|0)/2<<16>>16}a=j;u=D(a,x[f+756>>2]);j=(u|0)/256|0;if(q){B[o+44>>2]=B[o+44>>2]+E(E(E(E(y[c+40|0])*E(.05000000074505806))*E(a|0))*E(.000244140625));v[f+851|0]=y[f+851|0]|64;break mc}if(x[d+480180>>2]!=4){vc:{if((u|0)<=-256){j=0-j|0;c=j>>>8|0;a=(c<<2)+b|0;break vc}b=h;c=j>>>8|0;a=b+(c<<2)|0}h=x[e>>2];a=x[a>>2];a=((D(x[((c<<2)+b|0)+4>>2]-a|0,j>>>2&63)|0)/64|0)+a|0;a=Gc(pva(ova(h,h>>31,a,a>>31),hb,256,0),hb);x[e>>2]=a;x[o+32>>2]=a&255;x[e>>2]=x[e>>2]/256;break mc}x[e>>2]=x[e>>2]+((u|0)/16384|0)}fb=g+16|0;j=x[o+36>>2];if((j|0)<=x[d+480260>>2]){Jb(o+16|0,s,81);if(Hb(x[x[o+16>>2]>>2],x[o+20>>2])){x[k+1075068>>2]=0}j=x[d+480260>>2];x[o+36>>2]=j}wc:{if(!Uj(x[f+656>>2])){break wc}a=k+1075843|0;b=y[a|0];if(!(x[d+1074392>>2]|!(b&32)?b&64:1)){break wc}vV(f,B[o+44>>2],w[o+42>>1],d);b=a;a=y[a|0];v[b|0]=(a&64?-65:-33)&a}a=o+16|0;wB(a,d,f,j,x[o+32>>2]);e=zb(a);a=ova(x[o+16>>2],x[o+20>>2],x[d+480240>>2],0);h=hb;b=pva(a,h,65536,0);c=hb;g=b;a=a+65535|0;b=!(a>>>0<65535?h+1|0:h)&a>>>0<131071;a=b?1:g;x[o+16>>2]=a;b=b?0:c;x[o+20>>2]=b;x[i>>2]=a;x[i+4>>2]=b;if((x[l>>2]&134219264)!=512){break lc}if(!Dd(x[d+1298300>>2])){break lc}Jb(o+8|0,s,99);a=x[l>>2];c=a&4096;xc:{yc:{if(Sa=Hb(x[x[o+8>>2]>>2],x[o+12>>2]),Ta=1,Va=c,Va?Sa:Ta){b=x[d+480180>>2];break yc}b=x[d+480180>>2];if((b|0)!=2){break xc}}h=(b|0)==2;b=a&2048;zc:{if(b?h:0){break zc}a=x[d+480240>>2];h=ova(x[e>>2],0,261625,0);e=hb;h=h+66904|0;e=h>>>0<66904?e+1|0:e;a=ova(a,0,Bc(qva(h,e,133808,0),hb),0);h=hb;a=a+32768|0;h=a>>>0<32768?h+1|0:h;e=Bc((h&65535)<<16|a>>>16,h>>>16|0);a=1;Ac:{if(b){break Ac}a=0;if(!c){break Ac}a=!x[k+1075688>>2]}Jb(o+8|0,s,110);if(Sa=Hb(x[x[o+8>>2]>>2],x[o+12>>2]),Ta=0,Va=a,Va?Sa:Ta){break zc}b=x[d+1298300>>2];Jb(o+8|0,s,95);SB(b,m,e,a,Hb(x[x[o+8>>2]>>2],x[o+12>>2]))}a=x[d+1298300>>2];b=ova(D(x[k+1075744>>2],D(x[k+1075740>>2],x[I>>2])),0,63,0);g=hb;b=b+33554432|0;g=b>>>0<33554432?g+1|0:g;Vq(a,m,Bc((g&67108863)<<6|b>>>26,g>>>26|0)&255,0);a=k+1075676|0;h=a;b=x[a>>2];c=0;a=x[d+1298300>>2];e=Yl(a,m);Bc:{if((e|0)==255){break Bc}g=x[a>>2];if(Pj(g)){break Bc}c=xb(Hd(a+318|0,e),10);j=x[a+4>>2];e=cv(e)|192;a=y[c|0]&-49;a=(b|0)<171?a|16:a;a=(b|0)>84?a|32:a;Ah(g,j,m,e,a&255);c=(a>>>5&1)+(a<<27>>31)|0}x[h>>2]=(c<<7)+128}Cc:{a=x[C>>2];if(!a|(y[a+60|0]&7)!=1){break Cc}b=x[a+48>>2];a=x[a+52>>2];if(lc(b,a)){break Cc}b=x[ZR(f,0)>>2];a=xf(a);if(b>>>0<z[a>>1]|y[a+2|0]){break Cc}Oj(x[d+1298300>>2],m,1);Jb(o+8|0,s,109);a=x[l>>2];Sa=l,Ta=(Hb(x[x[o+8>>2]>>2],x[o+12>>2])?a:a&-4609)|4096,x[Sa>>2]=Ta;x[k+1075688>>2]=0;break lc}Jb(o+8|0,s,99);if(!Hb(x[x[o+8>>2]>>2],x[o+12>>2])|!(y[l+1|0]&16)|x[k+1075688>>2]){break lc}Oj(x[d+1298300>>2],m,1);x[l>>2]=x[l>>2]&-513}Dc:{if(!J){break Dc}Jb(o+16|0,s,31);if(Hb(x[x[o+16>>2]>>2],x[o+20>>2])){break Dc}Nu(d,f)}b=x[l>>2];a=b&-65537;g=x[t>>2];q=k+1075016|0;J=k+1075012|0;c=g|(x[q>>2]|x[J>>2])?(a|b<<7&65536)^65536:a;x[l>>2]=c;t=k+1075664|0;a=t;x[a>>2]=0;x[a+4>>2]=0;h=k+1075834|0;a=y[h|0];b=a-4|0;a=a>>>0>=b>>>0?b:0;v[h|0]=a;m=k+1075835|0;b=y[m|0];e=b-4|0;b=b>>>0>=e>>>0?e:0;v[m|0]=b;Ec:{Fc:{Gc:{Hc:{Ic:{Jc:{Kc:{Lc:{Mc:{e=x[k+1075096>>2];Nc:{if(!e){break Nc}j=x[e+20>>2];if(!je(x[e>>2],j)|!x[k+1075068>>2]){break Nc}if(Ui(x[f+8>>2],x[f+12>>2])){break Mc}}x[k+1075008>>2]=0;break Lc}x[k+1075008>>2]=j;if(j){break Kc}}if(!Lj(x[f+656>>2])){break Jc}j=0;if(c&6144){break Jc}}I=x[k+1075676>>2];e=(D(g,256-I|0)|0)/16384|0;e=e>>>0>=127?127:e;if(a<<24>>24<0){v[h|0]=e;$=e}else{$=a}a=e>>>1|0;if(($&255)>>>0<a>>>0){v[h|0]=a}a=(D(g,I)|0)/16384|0;a=a>>>0>=127?127:a;if(b<<24>>24<0){v[m|0]=a;b=a}a=a>>>1|0;if(a>>>0>(b&255)>>>0){break Ic}break Hc}if((a&255)>>>0>=129){v[h|0]=0}j=0;a=0;if((b&255)>>>0<129){break Gc}}v[m|0]=a}if(!j){break Gc}j=128;h=x[d+24624>>2];if(h>>>0>=2){j=Yb(x[k+1075676>>2],0,256)}x[o+16>>2]=j;a=D(g,r)>>>(Ed(y[d+1074366|0])?7:8)|0;Oc:{Pc:{Qc:{switch(y[d+1074364|0]){case 0:if(!(y[d+24616|0]&16)){break Pc}case 1:if((j|0)<=127){b=a>>>1|0;e=(D(a,j)|0)/256|0;break Oc}b=(D(a,256-j|0)|0)/256|0;e=a>>>1|0;break Oc;case 3:break Qc;default:break Pc}}Bi(o+16|0,255);e=x[o+16>>2];if((e|0)<=0){b=65536}else{b=z[(0-e<<1)+38128>>1]}b=D(b,a)>>>16|0;e=D(a,z[(e<<1)+37616>>1])>>>16|0;break Oc}b=(D(a,256-j|0)|0)/256|0;e=(D(a,j)|0)/256|0}a=x[C>>2];Rc:{if(a){j=y[a+14|0];if(Bp(j)){break Rc}}j=y[d+480268|0];if(Bp(j)){break Rc}a=y[d+24648|0];j=y[P|0]&128?x[d+24668>>2]?-1:a:a}g=k+1075668|0;m=k+1075786|0;v[m|0]=j;a=x[i>>2];q=x[i+4>>2];if(!(c&131072|((a|0)!=0|(q|0)!=1)|(x[k+1075748>>2]|(j&255)==255))){v[m|0]=0}m=b;b=1<<x[d+1074360>>2];x[t>>2]=(m|0)/(b|0);b=(e|0)/(b|0)|0;x[g>>2]=(c&256)>>>8|0?(h|0)==2?0-b|0:b:b;if(c&128){x[i>>2]=0-a;x[i+4>>2]=0-(((a|0)!=0)+q|0)}i=0;h=fb-16|0;fb=h;x[f+28>>2]=0;x[f+32>>2]=0;Bi(f+672|0,524287);Bi(f+676|0,524287);b=x[f+676>>2];a=x[f+672>>2];$=f;Sc:{Tc:{c=x[f+88>>2];if(!(c&65536)){break Tc}e=x[f+20>>2];g=x[f+24>>2];if((e|0)==(a|0)&(g|0)==(b|0)){break Tc}c=x[d+24620>>2];g=(a|0)<=(e|0)&(b|0)<=(g|0);Uc:{if(!g){b=ev(c,x[d+24636>>2]);break Uc}b=ev(c,x[d+24640>>2])}if(!(!Ob(d+1074312|0,4)|!(y[d+480180|0]&4))){a=x[d+24620>>2];a=ova(a,a>>31,5,0);e=hb;a=a+500|0;e=a>>>0<500?e+1|0:e;b=Gc(pva(a,e,1e3,0),hb)}a=b;c=x[f+656>>2];Vc:{if(g|!c){break Vc}c=z[c+12>>1];if(!c){break Vc}i=1;a=(D(c,x[d+24620>>2])>>>0)/1e5|0}j=a>>>0<=1?1:a;e=x[f+672>>2];m=x[f+20>>2];q=e-m<<12;c=x[f+676>>2];a=x[f+24>>2];g=c-a<<12;if(!(y[f+90|0]&32|(!(c|e)|(!(a|m)|i)))){x[h+12>>2]=x[d+1074380>>2];Fe(h+12|0,b,2048);j=x[h+12>>2]}g=(g|0)/(j|0)|0;x[f+32>>2]=g;m=(q|0)/(j|0)|0;x[f+28>>2]=m;b=c+((D(g,j)|0)/-4096|0)|0;x[f+24>>2]=b;a=e+((D(j,m)|0)/-4096|0)|0;x[f+20>>2]=a;if(g|m){x[f+100>>2]=j;c=x[f+88>>2];break Sc}x[f+24>>2]=c;x[f+20>>2]=e;b=c;a=e;c=x[f+88>>2]&-65537;break Sc}x[f+24>>2]=b;x[f+20>>2]=a;c=c&-65537}x[$+88>>2]=c&-2097153;x[f+40>>2]=b<<12;x[f+36>>2]=a<<12;fb=h+16|0;c=x[l>>2];if(!(c&512)){break Fc}break Ec}x[J>>2]=0;x[q>>2]=0;x[k+1075068>>2]=0;if(x[k+1075088>>2]){break Fc}if(!x[k+1075084>>2]){break Ec}}a=z[d+480212>>1];w[d+480212>>1]=a+1;w[((a<<1)+d|0)+1074478>>1]=n}x[k+1075660>>2]=c;a=k+1075843|0;v[a|0]=y[a|0]&253}n=n+1|0;continue}break}}fb=o+48|0;if(M){a=x[d+480208>>2];break h}if(Ed(y[d+1298424|0])){b=x[d+480208>>2]|512;break i}n=0;Wc:{a=x[d+24620>>2]/10|0;c=Gc(a,a>>31);if(!c){break Wc}b=c>>>0>=1048576?1048576:c;x[d+1074380>>2]=b;f=z[d+480212>>1];e=d+1074376|0;while(1){if((f|0)==(n|0)){break Wc}a=e+D(z[(e+(n<<1)|0)+102>>1],872)|0;h=a+1288|0;x[h>>2]=0;x[h+4>>2]=0;x[a+716>>2]=b;h=x[a+640>>2]<<12;x[a+656>>2]=h;g=x[a+636>>2]<<12;x[a+652>>2]=g;x[a+704>>2]=x[a+704>>2]|65536;x[a+644>>2]=(0-g|0)/(b|0);x[a+648>>2]=(0-h|0)/(b|0);n=n+1|0;continue}}a=x[d+480208>>2];b=a|256;if(c){break i}b=a|512}a=b;x[ma+480208>>2]=a}if(!(a&512)){break g}Sa=d+1074392|0,Ta=Ql(Ga),x[Sa>>2]=Ta}fb=K+96|0;break f}x[K+80>>2]=512;a=x[d+1074380>>2];x[K+88>>2]=ha;x[K+84>>2]=a;o=sE(K+80|0);if(x[d+24632>>2]){a=0;b=fb-48|0;fb=b;c=o<<2;while(1){if((a|0)==4){Xc:{a=0;while(1){if((a|0)==4){break Xc}x[(b+32|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}}}else{x[b+32>>2]=0;e=((a<<11)+d|0)+16396|0;Yz(e,c+e|0,b+32|0);a=a+1|0;continue}break}a=x[d+24632>>2];x[b+28>>2]=o;x[b+24>>2]=a;x[b+20>>2]=b+32;a=x[x[ga>>2]+8>>2];x[b+16>>2]=o;c=x[b+24>>2];x[b+8>>2]=x[b+20>>2];x[b+12>>2]=c;ib[a|0](ga,b+8|0);fb=b+48|0}if(Ed(Fa)){a=0;while(1){if((a|0)==4){a=x[d+24632>>2];x[K+76>>2]=o;x[K+72>>2]=a;x[K+68>>2]=K+80;a=x[x[qa>>2]+8>>2];x[K+40>>2]=o;b=x[K+72>>2];x[K+32>>2]=x[K+68>>2];x[K+36>>2]=b;ib[a|0](qa,K+32|0)}else{x[(K+80|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}break}}M=0;ia=0;j=fb-48|0;fb=j;if(o){t=d+12|0;J=d+24592|0;C=d+24588|0;Rn(t,o,J,C);if(A[d+24624>>2]>=3){Rn(d+8204|0,o,d+24600|0,d+24596|0)}w[j+42>>1]=0;va=d+1074312|0;Ha=d+24648|0;ca=d+906300|0;Ia=d+24596|0;Ja=d+24600|0;Ka=d+8204|0;P=d+397452|0;T=d+397448|0;q=d+393352|0;wa=d+397456|0;na=d+1074376|0;while(1){if(z[d+480212>>1]<=M>>>0){Sa=d,Ta=z[qe(d+480214|0,j+42|0)>>1],w[Sa+480214>>1]=Ta}else{n=na+(M<<1)|0;i=z[n+102>>1];a=D(i,872);L=a+na|0;Yc:{Zc:{if(x[L+632>>2]){break Zc}b=a+d|0;if(x[b+1075088>>2]){break Zc}if(!x[b+1075084>>2]){break Yc}}g=a+d|0;a=y[g+1075786|0]+1&255;if(a>>>0<=5){h=x[(a<<2)+26144>>2]}else{h=0}I=g+1075080|0;f=x[I>>2];_c:{if(!(!(f&16777216)&y[d+24612|0]>>>5)){a=J;c=C;b=f;e=t;if(!(b&8388608)){break _c}}a=T;c=P;if(!y[wa+12|0]){Rn(q,o,a,c)}v[wa+12|0]=1;i=z[n+102>>1];b=x[I>>2];e=q}b=b>>>8&A[d+24624>>2]>2;u=b?Ia:c;V=b?Ja:a;b=b?Ka:e;ea=wm(d,na,i&65535,2,1)-1|0;xa=(ea&255)>>>0>249;$c:{if(xa){break $c}if(!x[vd(ca,ea)>>2]){break $c}c=x[vd(ca,ea)>>2];a=x[c+24>>2];if(!a){break $c}u=c+36|0;V=c+40|0;if(!(v[c+28|0]&1)){Rn(a,o,V,u);x[c+28>>2]=x[c+28>>2]|1}b=a}n=L+616|0;if(y[g+1075843|0]&8){ZF(n,b,o);a=g+1075084|0;x[V>>2]=x[V>>2]+x[a>>2];x[u>>2]=x[u>>2]+x[g+1075088>>2];x[a>>2]=0;x[a+4>>2]=0;break Yc}ja=0;a=j+20|0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;c=d+1074312|0;Sa=a,Ta=Ob(c,33),v[Sa+16|0]=Ta;Sa=a,Ta=Ob(c,116)^1,v[Sa+17|0]=Ta;if(x[n+16>>2]){YF(a,n);c=x[n+12>>2];e=c>>31;r=e^x[n+8>>2];c=(c^e)-((e>>>0>r>>>0)+e|0)|0;x[a+12>>2]=c>>>0>8191?2:16384/(c+1>>>0)|0}La=f>>>12&8|(f>>>5&2|(h|f&1));Ma=ia&65535;Na=g+1075795|0;Oa=g+1075778|0;Pa=g+1075688|0;Qa=g+1075024|0;Ra=g+1075020|0;ma=g+1075668|0;$=g+1075664|0;W=g+1075088|0;Z=g+1075084|0;ya=g+1075016|0;za=g+1075012|0;ka=g+1075096|0;X=g+1075076|0;R=g+1075068|0;H=g+1075e3|0;la=g+1075072|0;aa=g+1075092|0;s=a;a=o;while(1){ad:{c=x[aa>>2];fa=c?a>>>0>c>>>0?c:a:a;x[j+12>>2]=fa;bd:{cd:{if(!fa){break cd}c=x[H+4>>2];m=c;f=x[H>>2];if(!(c|f)){break cd}g=x[R>>2];if(!g){break cd}c=x[s>>2];if(!c){break cd}i=x[I>>2];l=i&2;k=x[la>>2];x[L+632>>2]=c;c=x[n>>2];dd:{ed:{r=k&i<<30>>31;e=x[n+4>>2];if((r|0)>(e|0)){if((m|0)<0){c=jh(0,r<<1,c,e);x[n>>2]=c;e=hb;x[n+4>>2]=e;if(!(e>>>0<g+r>>>1>>>0&(e|0)>=(r|0))){c=0;x[n>>2]=c;e=r;x[n+4>>2]=e}fd:{if(i&4){i=i&-129;x[I>>2]=i;m=0-(((f|0)!=0)+m|0)|0;f=0-f|0;x[H>>2]=f;x[H+4>>2]=m;break fd}x[n>>2]=c;e=g-1|0;x[n+4>>2]=e}if(!l){break cd}if(e>>>0<g>>>0){break dd}break cd}if((e|0)>0|(e|0)>=0){break dd}e=0;break ed}if(e>>>0<g>>>0){break dd}if(!l){break cd}if(i&4){if(!!f&(m|0)>=0|(m|0)>0){m=0-(((f|0)!=0)+m|0)|0;f=0-f|0;x[H>>2]=f;x[H+4>>2]=m}i=i|128;x[I>>2]=i;if(y[j+37|0]){h=y[j+36|0];l=x[X>>2]-(h+k|0)|0;c=jh(c,e,0,g);e=hb;if(e>>>0<l>>>0){c=jh(0,g-h|0,c,e);e=hb;break ed}e=k;c=0;break ed}h=0-c|0;l=(g<<1)-((1-((c|0)!=0)|0)+e|0)|0;e=l;c=h;x[n>>2]=c;_=0;e=_|e;x[n+4>>2]=e;if(k>>>0<l>>>0&g>>>0>l>>>0){break dd}x[j+44>>2]=y[j+36|0]+1;e=_|g-x[Gb(R,j+44|0)>>2];break ed}if((m|0)<0){e=0-(((f|0)!=0)+m|0)|0;m=e;f=0-f|0;x[H>>2]=f;x[H+4>>2]=e}Pb(n,0,r-g|0);i=x[I>>2]|8192;x[I>>2]=i;c=x[n>>2];e=x[n+4>>2];break dd}x[n>>2]=c;x[n+4>>2]=e}gd:{if((e|0)<(r|0)){if((e|m)<0){break cd}x[j+44>>2]=fa;g=f;h=m;break gd}h=x[R>>2];if(h>>>0<e>>>0|(!!f&(m|0)>=0|(m|0)>0)&(e|0)==(h|0)){break cd}x[j+44>>2]=fa;h=m>>31;l=h^f;g=l-h|0;h=(h^m)-((h>>>0>l>>>0)+h|0)|0}k=g;l=h;wc(j+12|0,x[j+32>>2]);Aa=x[j+12>>2];hg(c,e,vf(f,m,Aa-1|0),hb);h=hb;g=x[la>>2];Ba=g>>>0>e>>>0|g+16>>>0<=e>>>0;if(Ba){i=i&-8193;x[I>>2]=i}g=h;hd:{id:{_=x[j+24>>2];jd:{if(_){h=x[j+28>>2];if(h>>>0<=e>>>0){kd:{if((m|0)<0){f=0;m=h;break kd}f=c;m=e;c=0;e=x[X>>2]}Sa=j,Ta=Np(jh(jh(c,e,f,m),hb,1,0),hb,k,l)+1|0,x[Sa+44>>2]=Ta;x[L+632>>2]=_;break hd}if(!(Ba|!(i&8192))){Sa=j,Ta=Np(jh(jh(0,r+16|0,c,e),hb,1,0),hb,k,l)+1|0,x[Sa+44>>2]=Ta;Sa=L,Ta=_+D(x[X>>2]-r|0,el(z[x[ka>>2]+34>>1]))|0,x[Sa+632>>2]=Ta;break hd}if(!f&(m|0)<=0|(m|0)<0){break jd}if(fa>>>0<2|g>>>0<h>>>0){break id}Sa=j,Ta=Np(jh(jh(0,h,c,e),hb,1,0),hb,k,l)+1|0,x[Sa+44>>2]=Ta;break hd}if((m|0)>0|(m|0)>=0){break id}}if((g|0)>=(r|0)){break hd}Sa=j,Ta=Np(jh(jh(c,e,0,r),hb,1,0),hb,k,l)+1|0,x[Sa+44>>2]=Ta;break hd}f=x[R>>2];if((f|0)>(g|0)){break hd}Sa=j,Ta=Np(jh(jh(0,f,c,e),hb,1,0),hb,k,l)+1|0,x[Sa+44>>2]=Ta}Mp(j+44|0,1,Aa);f=x[j+44>>2];if((f|0)>0){break bd}}x[L+632>>2]=0;x[R>>2]=0;x[n>>2]=0;x[n+4>>2]=0;x[aa>>2]=0;ZF(n,b,a);x[V>>2]=x[V>>2]+x[Z>>2];x[u>>2]=x[u>>2]+x[W>>2];x[W>>2]=0;x[Z>>2]=0;x[I>>2]=x[I>>2]&-129;break ad}ld:{md:{if(Ma>>>0<A[d+24608>>2]){c=4;if(x[aa>>2]){break md}c=0;if(x[ya>>2]|x[za>>2]){break md}}Pb(n,vf(x[H>>2],x[H+4>>2],f),hb);ja=0;x[W>>2]=0;x[Z>>2]=0;b=(f<<3)+b|0;break ld}e=(f<<3)+b|0;h=e-8|0;x[Z>>2]=0-x[h>>2];g=e-4|0;x[W>>2]=0-x[g>>2];ib[x[((c|La)<<2)+25760>>2]](n,Ha,b,f);x[Z>>2]=x[Z>>2]+x[h>>2];x[W>>2]=x[W>>2]+x[g>>2];ja=1;b=e}c=x[aa>>2];nd:{if(!c){break nd}if(c>>>0<=f>>>0){x[aa>>2]=0;x[za>>2]=x[$>>2];x[ya>>2]=x[ma>>2];x[Ra>>2]=0;x[Qa>>2]=0;if(x[Pa>>2]|!(y[I+1|0]&16)){break nd}x[R>>2]=0;x[L+632>>2]=0;break nd}x[aa>>2]=c-f}e=0;i=0;c=x[n+4>>2];i=c>>>0>=A[X>>2]?(y[I|0]&2)>>>1|0:i;h=c;c=x[R>>2];e=x[I>>2]&2|(h>>>0<c>>>0|!c)?e:!z[Oa>>1];a=a-f|0;Jb(j+12|0,va,85);od:{pd:{qd:{if(!Hb(x[x[j+12>>2]>>2],x[j+16>>2])){break qd}c=y[Na|0];if(!c){break qd}if(c>>>0<=z[d+480190>>1]){break pd}}k=0;break od}h=x[ka>>2];c=D(c,104)+d|0;f=c+484380|0;k=(h|0)!=(f|0);if((f|0)==(h|0)|(e|i)!=1){break od}x[ka>>2]=f;e=x[c+484400>>2];x[L+632>>2]=e;f=z[c+484414>>1];x[I>>2]=f|x[I>>2]&-768;h=f<<30>>31;f=x[c+484388>>2];x[R>>2]=h&f;c=x[c+484384>>2];x[la>>2]=c;x[X>>2]=f;x[n+4>>2]=c;YF(s,n);if(!e){break ad}if((a|0)>0){continue}break ad}rd:{if(!i|k){break rd}Jb(j+12|0,va,83);if(!Hb(x[x[j+12>>2]>>2],x[j+16>>2])|x[la>>2]){break rd}x[n>>2]=x[n>>2];x[n+4>>2]=0;c=x[x[ka>>2]+8>>2];x[R>>2]=c;x[X>>2]=c}if((a|0)>0){continue}}break}x[L+632>>2]=x[s>>2];ia=ja+ia|0;w[j+42>>1]=ia;if(xa|!ja){break Yc}if(!x[vd(ca,ea)>>2]){break Yc}a=x[vd(ca,ea)>>2];ib[x[x[a>>2]+152>>2]](a)}M=M+1|0;continue}break}}fb=j+48|0;l=x[d+1298300>>2];if(Dd(l)){a=Y;b=o;c=(D(x[d+480232>>2],x[d+480236>>2])>>>0)/48|0;n=fb-16|0;fb=n;sd:{if(!y[l+534|0]){break sd}e=ova(c,0,6169,0);c=hb;g=c>>>16|0;s=Bc((c&65535)<<16|e>>>16,g);while(1){if(!b){break sd}h=x[l>>2];j=x[h>>2];c=x[h+4>>2];while(1){if((c|0)>=(j|0)){x[h+8>>2]=x[h+12>>2];j=0;g=0;k=0;c=fb-16|0;fb=c;while(1){if((k|0)==18){e=(j|0)>=32767?32767:j;w[h+12>>1]=(e|0)<=-32768?-32768:e;e=(g|0)>=32767?32767:g;w[h+14>>1]=(e|0)<=-32768?-32768:e;w[h+3832>>1]=z[h+3832>>1]+1;e=(z[h+3834>>1]+1>>>0)%13440|0;w[h+3834>>1]=e;e=e>>>0<6720?e:13440-e|0;w[h+3836>>1]=e>>>8;if(!y[h+3843|0]){w[h+3836>>1]=e>>>10}e=z[h+3838>>1]+1|0;w[h+3838>>1]=e;if((e&65535)>>>0>=1024){w[h+3838>>1]=0;w[h+3840>>1]=z[h+3840>>1]+1&7}fb=c+16|0}else{f=h+D(k,44)|0;td:{if(!y[f+56|0]){w[c+12>>1]=0;w[c+14>>1]=0;break td}m=x[f+32>>2];e=z[m+3840>>1];if(e&3){m=(z[f+36>>1]>>>7&7)>>>!y[m+3844|0]>>>(e&1)<<z[f+38>>1];e=e&4?0-m|0:m}else{e=0}m=x[f+52>>2];ud:{if(m){t=z[m+32>>1];q=z[f+48>>1];e=e<<16>>16;m=Dg(x[f+16>>2],x[f+40>>2],e,0,w[f+46>>1]);r=x[f+40>>2];i=x[f+20>>2];if(!t){if(!q){m=Dg(i,r,e,m,0);m=Dg(x[f+24>>2],x[f+40>>2],e,m,0);e=Dg(x[f+28>>2],x[f+40>>2],e,m,0);break ud}r=Dg(i,r,e,0,0);r=Dg(x[f+24>>2],x[f+40>>2],e,r,0);e=Dg(x[f+28>>2],x[f+40>>2],e,r,0)+m|0;break ud}if(!q){m=Dg(i,r,e,m,0);r=Dg(x[f+24>>2],x[f+40>>2],e,0,0);e=Dg(x[f+28>>2],x[f+40>>2],e,r,0)+m|0;break ud}r=Dg(i,r,e,0,0);e=(Dg(x[f+24>>2],x[f+40>>2],e,r,0)+m|0)+Dg(x[f+28>>2],x[f+40>>2],e,0,0)|0;break ud}q=z[f+48>>1];e=e<<16>>16;m=Dg(x[f+16>>2],x[f+40>>2],e,0,w[f+46>>1]);r=x[f+40>>2];i=x[f+20>>2];if(!q){e=Dg(i,r,e,m,0);break ud}e=Dg(i,r,e,0,0)+m|0}w[c+14>>1]=y[f+57|0]?e:0;w[c+12>>1]=y[f+58|0]?e:0}k=k+1|0;g=w[c+12>>1]+g|0;j=w[c+14>>1]+j|0;continue}break}j=x[h>>2];c=x[h+4>>2]-j|0;x[h+4>>2]=c;continue}break}e=j-c|0;w[n+14>>1]=(D(w[h+12>>1],c)+D(e,w[h+8>>1])|0)/(j|0);w[n+12>>1]=(D(w[h+14>>1],c)+D(e,w[h+10>>1])|0)/(j|0);x[h+4>>2]=c+49716;x[a>>2]=x[a>>2]+D(s,w[n+14>>1]);x[a+4>>2]=x[a+4>>2]+D(s,w[n+12>>1]);a=a+8|0;b=b-1|0;continue}}fb=n+16|0}a=y[G+12|0];if(a|x[G+16>>2]){if(!a){Rn(ba,o,ua,ta)}a=x[G>>2];b=x[G+80>>2];c=D(a,b)>>>4|0;c=c>>>0>=32767?32767:c;w[G+98>>1]=c;w[G+96>>1]=c;c=x[G+49948>>2];e=D(c,a)>>>4|0;e=e>>>0>=65536?65536:e;f=e+127>>>3|0;w[G+49946>>1]=f;e=e+255>>>4|0;w[G+49944>>1]=e;w[G+49942>>1]=e;w[G+49940>>1]=f;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0<=8?8:a)|0;b=16-(D((b|0)>=32768?32768:b,a>>>0<=16?a:0)>>15)|0;a=0;while(1){if((a|0)!=(o|0)){c=a<<3;e=c+Y|0;x[e>>2]=x[e>>2]+D(b,x[c+ba>>2]>>4);c=c|4;e=c+Y|0;x[e>>2]=x[e>>2]+D(b,x[c+ba>>2]>>4);a=a+1|0;continue}break}n=G+68|0;a=0;f=w[G+84>>1];b=x[G+40>>2];c=x[G+36>>2];while(1){if((a|0)==(o|0)){x[G+40>>2]=b;x[G+36>>2]=c;c=o}else{e=(a<<3)+ba|0;h=x[e>>2]>>12;c=(D(f,h-c|0)>>15)+h|0;x[e>>2]=c;h=e;e=x[e+4>>2]>>12;b=(D(f,e-b|0)>>15)+e|0;x[h+4>>2]=b;a=a+1|0;continue}break}if(c){a=ba;b=c;k=x[n>>2]-1|0;e=z[n+22>>1];j=z[n+20>>1];h=w[n+26>>1];g=w[n+24>>1];l=w[n+18>>1];s=w[n+16>>1];f=x[n+4>>2];m=n+32928|0;while(1){if(b){r=nd(x[a>>2]);i=nd(x[a+4>>2]);j=nd((j<<16>>16)-r|0);e=nd((e<<16>>16)-i|0);j=ed(nd((D(j,s)|0)/65536<<1)+r|0);e=ed(nd((D(e,l)|0)/65536<<1)+i|0);i=m+(f<<2)|0;q=w[i>>1];r=ed(((D(q,g)|0)/-65536|0)+j|0);f=f+1&127;t=m+(f<<2)|0;i=w[i+2>>1];J=ed(((D(i,h)|0)/-65536|0)+e|0);w[t+2>>1]=J;w[t>>1]=r;k=k+1&8191;t=n+(k<<2)|0;Sa=t,Ta=ed(q+((D(g,r)|0)/65536|0)|0),w[Sa+160>>1]=Ta;Sa=t,Ta=ed(i+((D(h,J)|0)/65536|0)|0),w[Sa+162>>1]=Ta;a=a+8|0;b=b-1|0;continue}break}w[n+22>>1]=e;w[n+20>>1]=j;x[n+4>>2]=f}j=G+49892|0;J=G+33508|0;b=c;a=ba;while(1){if(b){f=x[G+76>>2];h=f&4095;k=J+(h<<2)|0;e=a;h=4096-h|0;t=f-x[G+49892>>2]&4095;f=4096-t|0;f=f>>>0>h>>>0?h:f;f=b>>>0<f>>>0?b:f;h=f>>>0>=64?64:f;q=h;f=0;m=fb-32|0;fb=m;g=x[n>>2];while(1){if((f|0)==7){vd:{s=w[n+28>>1]/8<<16>>16;wd:while(1){if(!q){break vd}q=q-1|0;f=0;g=0;i=0;while(1)if((f|0)==4){f=4;l=0;C=ed((i|0)/32768|0);P=ed((g|0)/32768|0);g=0;while(1)if((f|0)==7){f=ed(C+((g|0)/32768|0)|0);w[k>>1]=f;x[e>>2]=D(f,s);f=ed(P+((l|0)/32768|0)|0);w[k+2>>1]=f;x[e+4>>2]=D(f,s);e=e+8|0;k=k+4|0;continue wd}else{r=m+(f<<2)|0;i=x[r>>2]+1&8191;x[r>>2]=i;i=n+(i<<2)|0;T=w[i+160>>1];r=n+(f<<4)|0;i=w[i+162>>1];l=(D(T,w[r+44>>1])+l|0)+D(i,w[r+46>>1])|0;g=(D(T,w[r+40>>1])+g|0)+D(i,w[r+42>>1])|0;f=f+1|0;continue}}else{r=m+(f<<2)|0;l=x[r>>2]+1&8191;x[r>>2]=l;$=g;g=n+(l<<2)|0;l=w[g+160>>1];r=n+(f<<4)|0;C=w[g+162>>1];g=($+D(l,w[r+44>>1])|0)+D(C,w[r+46>>1])|0;i=(D(l,w[r+40>>1])+i|0)+D(C,w[r+42>>1])|0;f=f+1|0;continue}}}}else{x[m+(f<<2)>>2]=g+(x[(n+(f<<4)|0)+32>>2]^-1);f=f+1|0;continue}break}fb=m+32|0;k=J+(t<<2)|0;e=a;f=h;C=j+2|0;g=x[j+4>>2];m=j+24640|0;r=j+16448|0;while(1){i=g&2047;if(f){R=j+8256|0;P=w[R+((g+1206&2047)<<2)>>1];s=j- -64|0;t=w[s+((g+1750&2047)<<2)>>1];T=w[(C+((g+754&2047)<<2)|0)+8256>>1];I=w[(C+((g+1602&2047)<<2)|0)- -64>>1];l=w[k>>1];q=w[k+2>>1];u=m+((g+502&2047)<<2)|0;M=w[u>>1];H=nd(w[j+32>>1]-M|0);u=w[u+2>>1];L=nd(w[j+34>>1]-u|0);V=w[j+26>>1];W=m+((g+22&2047)<<2)|0;Z=w[W>>1];X=nd(w[j+36>>1]-Z|0);aa=w[j+28>>1];W=w[W+2>>1];_=nd(w[j+38>>1]-W|0);ca=w[j+30>>1];M=ed(nd((D(H,w[j+24>>1])|0)/65536<<1)+M|0);w[j+32>>1]=M;Sa=j,Ta=ed(nd((D(L,V)|0)/65536<<1)+u|0),w[Sa+34>>1]=Ta;Sa=j,Ta=ed(nd((D(X,aa)|0)/65536<<1)+Z|0),w[Sa+36>>1]=Ta;u=ed(nd((D(_,ca)|0)/65536<<1)+W|0);w[j+38>>1]=u;M=nd((D(M,w[j+16>>1])|0)/32768|0);H=nd((D(u,w[j+22>>1])|0)/32768|0);u=nd(M+((l|0)/4<<16>>16)|0);M=nd(H+((q|0)/4<<16>>16)|0);l=w[j+8>>1];H=nd(u+((D(l,t)|0)/-65536|0)|0);$=s;s=i<<2;L=$+s|0;q=w[j+10>>1];V=nd(M+((D(q,I)|0)/-65536|0)|0);w[L+2>>1]=V;w[L>>1]=H;t=nd(t+((D(l,H)|0)/65536|0)|0);H=s+r|0;L=nd(I+((D(q,V)|0)/65536|0)|0);w[H+2>>1]=L;w[H>>1]=t;I=nd(t+u|0);u=nd(M+L|0);t=r+((g+682&2047)<<2)|0;M=w[t+2>>1];H=w[t>>1];t=nd((D(M,w[j+42>>1])+D(H,w[j+40>>1])|0)/32768|0);g=r+((g+426&2047)<<2)|0;L=w[g+2>>1];V=w[g>>1];g=nd((D(L,w[j+46>>1])+D(V,w[j+44>>1])|0)/32768|0);H=nd(nd(I+H|0)-t|0);M=nd(nd(u+M|0)-g|0);I=nd(nd(I+V|0)-t|0);u=nd(nd(u+L|0)-g|0);t=nd(t+((D(l,P)|0)/-65536|0)|0);R=s+R|0;L=nd(g+((D(q,T)|0)/-65536|0)|0);w[R+2>>1]=L;w[R>>1]=t;l=(D(l,t)|0)/65536|0;g=nd(l+P|0);s=m+s|0;q=(D(q,L)|0)/65536|0;t=nd(q+T|0);w[s+2>>1]=t;w[s>>1]=g;Sa=e,Ta=(x[e>>2]+D(nd(g+H|0),w[j+48>>1])|0)+D(nd(t+M|0),w[j+50>>1])|0,x[Sa>>2]=Ta;Sa=e,Ta=(x[e+4>>2]+D(nd(nd(l)+I|0),w[j+52>>1])|0)+D(nd(nd(q)+u|0),w[j+54>>1])|0,x[Sa+4>>2]=Ta;e=e+8|0;g=i+1|0;k=k+4|0;f=f-1|0;continue}break}x[j+4>>2]=i;x[G+76>>2]=h+x[G+76>>2]&4095;x[G+68>>2]=h+x[G+68>>2]&8191;b=b-h|0;a=(h<<3)+a|0;continue}break}x[G+68>>2]=x[G+68>>2]&8191;j=ba;e=Y;f=c;a=0;b=0;k=x[G+56>>2];n=x[G- -64>>2];g=x[G+52>>2];h=x[G+60>>2];while(1){if(f){a=x[j>>2];b=x[j+4>>2];n=n-b|0;n=(((n|0)/1024|0)-n|0)+k|0;x[e+4>>2]=n+x[e+4>>2];h=h-a|0;h=(((h|0)/1024|0)-h|0)+g|0;x[e>>2]=h+x[e>>2];k=n+((n|0)/-512|0)|0;g=h+((h|0)/-512|0)|0;e=e+8|0;j=j+8|0;f=f-1|0;h=a;n=b;continue}break}x[G+64>>2]=b;x[G+60>>2]=a;x[G+56>>2]=k;x[G+52>>2]=g;a=x[G+20>>2];xd:{if(y[G+12|0]){break xd}a=x[G+16>>2];if(a>>>0>c>>>0){a=a-c|0;break xd}XP(G,ua,ta);a=0}v[G+12|0]=0;x[G+16>>2]=a}if(x[d+946300>>2]){yd:{g=0;j=0;e=o<<2;k=d+906300|0;l=z[d+480214>>1]!=0;Ca=B[d+1074336>>2];U=B[d+1074332>>2];while(1)if((g|0)==250){i=d+12|0;n=d+12300|0;m=d+14348|0;Ww(i,n,m,o,U);a=d+1074476|0;J=y[a|0];v[a|0]=0;a=m;b=n;while(1){zd:{Ad:{Bd:{if((j|0)!=250){r=vd(k,j);h=x[r>>2];if(!h|!x[h+24>>2]){break zd}if(!Ai(h+44|0)){break zd}e=h;Cd:{if(Lp(y[r+24|0])){break Cd}c=ib[x[x[h>>2]+148>>2]](h)|0;e=x[r>>2];if(c){break Cd}g=0;if(y[e+28|0]&2){break Cd}while(1){if((g|0)==(j|0)){break zd}c=vd(k,g);g=g+1|0;if((vm(x[c+28>>2])|0)!=(j|0)){continue}break}}c=x[h+44>>2];s=Hc(c,0);t=Hc(c,1);q=(b|0)==(s|0);b=q?n:b;c=b;a=q?m:a;g=x[r+28>>2];f=a;Dd:{if(!g){break Dd}g=vm(g);f=a;if(g>>>0<=j>>>0){break Dd}f=a;if(g>>>0>249){break Dd}f=a;if(!x[vd(k,g)>>2]){break Dd}g=x[vd(k,g)>>2];if(!(y[e+28|0]&4)){ib[x[x[g>>2]+152>>2]](g)}f=a;if(!Ai(g+44|0)){break Dd}f=x[g+44>>2];c=Hc(f,0);f=Hc(f,1)}if(!Lp(y[r+24|0])){break Ad}g=0;Ed:{if(q){break Ed}while(1){if((g|0)==(o|0)){break Ed}q=g<<2;C=q+s|0;P=b+q|0;B[C>>2]=B[P>>2]+B[C>>2];C=q+t|0;q=a+q|0;B[C>>2]=B[q>>2]+B[C>>2];x[P>>2]=0;x[q>>2]=0;g=g+1|0;continue}}a=f;b=c;if(!(l&1)){break Ad}a=x[r>>2];if(a){ib[x[x[a>>2]+152>>2]](a)}g=vm(x[r+28>>2]);a=j;while(1){b=g;g=b&255;if(g>>>0>249|g>>>0<=(a&255)>>>0){break Bd}q=vd(k,g);g=vm(x[q+28>>2]);a=b;b=x[q>>2];if(!b){continue}ib[x[x[b>>2]+152>>2]](b);continue}}c=0;while(1){if((c|0)!=(o|0)){U=E(B[b>>2]*Ca);Fd:{if(E(F(U))<E(2147483648)){e=~~U;break Fd}e=-2147483648}x[i>>2]=e;U=E(B[a>>2]*Ca);Gd:{if(E(F(U))<E(2147483648)){e=~~U;break Gd}e=-2147483648}x[i+4>>2]=e;c=c+1|0;i=i+8|0;a=a+4|0;b=b+4|0;continue}break}break yd}a=f;b=c}Hd:{Id:{g=y[r+24|0];if(!VF(g)){if(!UF(g)|!(y[e+28|0]&4)){break Id}}g=0;while(1){if((g|0)==(o|0)){break Hd}h=g<<2;r=h+c|0;B[r>>2]=B[h+s>>2]+B[r>>2];r=f+h|0;B[r>>2]=B[h+t>>2]+B[r>>2];g=g+1|0;continue}}if(J){ib[x[x[h>>2]+132>>2]](h)}ib[x[x[h>>2]+60>>2]](h,c,f,o);x[e+32>>2]=o+x[e+32>>2];if(!UF(y[r+24|0])){break Hd}if((ib[x[x[h>>2]+160>>2]](h)|0)<=0){break Hd}g=0;if(A[e+32>>2]<x[d+24620>>2]<<2>>>0){break Hd}Jd:{while(1){if((g|0)==(o|0)){break Jd}h=g<<2;U=B[h+c>>2];Kd:{if(U>=E(1.1920928955078125e-7)|U<=E(-1.1920928955078125e-7)){break Kd}U=B[f+h>>2];if(U>=E(1.1920928955078125e-7)){break Kd}g=g+1|0;if(!(U<=E(-1.1920928955078125e-7))){continue}}break}x[e+32>>2]=0;break Hd}x[e+28>>2]=x[e+28>>2]|4}x[e+28>>2]=x[e+28>>2]&-3}j=j+1|0;continue}}else{f=vd(k,g);a=x[f>>2];Ld:{if(!a|!x[a+24>>2]){break Ld}if(!Ai(a+44|0)){break Ld}if(!(ib[x[x[a>>2]+116>>2]](a)|0)){ib[x[x[a>>2]+112>>2]](a,1);ib[x[x[a>>2]+124>>2]](a)}c=x[a+44>>2];b=Hc(c,0);c=Hc(c,1);Md:{if(v[a+28|0]&1){Ww(x[a+24>>2],b,c,o,U);break Md}h=a+40|0;if(x[h>>2]|x[a+36>>2]){Rn(x[a+24>>2],o,h,a+36|0);Ww(x[a+24>>2],b,c,o,U);break Md}Tb(b,0,e);Tb(c,0,e)}b=a;a=x[a+28>>2];x[b+28>>2]=a&-2;if(Lp(y[f+24|0])){break Ld}l=!(a&4)|l}g=g+1|0;continue}}}if(x[d+24624>>2]==1){b=0;while(1){if((b|0)!=(o|0)){a=(b<<3)+Y|0;x[(b<<2)+Y>>2]=(x[a+4>>2]+x[a>>2]|0)/2;b=b+1|0;continue}break}}if(Ed(y[d+1074365|0])){h=0;f=fb-16|0;fb=f;Nd:{if(!x[d+1074376>>2]){n=d+1074460|0;a=n;x[a>>2]=0;x[a+4>>2]=0;a=x[d+1074456>>2];x[d+1074468>>2]=a;break Nd}a=x[d+1074456>>2];b=x[d+1074468>>2];Od:{if((a|0)==(b|0)){c=x[d+1074460>>2];break Od}x[d+1074468>>2]=a;c=x[d+24620>>2];e=d+1074460|0;Pd:{if((a|0)>(b|0)){c=ev(c,x[d+24636>>2]);break Pd}c=ev(c,x[d+24640>>2])}x[e>>2]=c;x[d+1074464>>2]=c;b=a}n=d+1074460|0;if((c|0)<=0){break Nd}b=(b<<12)-x[d+1074472>>2]|0;h=(b|0)/(c|0)|0;if(y[d+1074368|0]!=2){break Nd}x[f+12>>2]=50;e=x[d+1074464>>2];x[f+8>>2]=1e4/(e+1|0);g=x[Ze(f+12|0,f+8|0)>>2];while(1){j=h>>31;if((g|0)>=((j^h)-j|0)){break Nd}c=c+e|0;x[n>>2]=c;h=(b|0)/(c|0)|0;continue}}Qd:{Rd:{switch(x[d+24624>>2]-1|0){case 0:g=a<<12;c=d+12|0;j=a>>31;b=0;while(1){if((b|0)==(o|0)){break Qd}Sd:{if(x[n>>2]>0){e=x[d+1074472>>2]+h|0;x[d+1074472>>2]=e;m=x[c>>2];Sa=c,Ta=Gc(pva(ova(m,m>>31,e,e>>31),hb,1048576,0),hb),x[Sa>>2]=Ta;x[d+1074460>>2]=x[d+1074460>>2]-1;break Sd}e=x[c>>2];Sa=c,Ta=Gc(pva(ova(e,e>>31,a,j),hb,256,0),hb),x[Sa>>2]=Ta;x[d+1074472>>2]=g}b=b+1|0;c=c+4|0;continue};case 1:j=a<<12;c=d+12|0;e=a>>31;b=0;while(1){if((b|0)==(o|0)){break Qd}Td:{if(x[n>>2]>0){g=x[d+1074472>>2]+h|0;x[d+1074472>>2]=g;m=x[c>>2];Sa=c,Ta=Gc(pva(ova(m,m>>31,g,g>>31),hb,1048576,0),hb),x[Sa>>2]=Ta;g=x[d+1074472>>2];m=g;r=g>>31;g=x[c+4>>2];Sa=c,Ta=Gc(pva(ova(m,r,g,g>>31),hb,1048576,0),hb),x[Sa+4>>2]=Ta;x[d+1074460>>2]=x[d+1074460>>2]-1;break Td}g=x[c>>2];Sa=c,Ta=Gc(pva(ova(g,g>>31,a,e),hb,256,0),hb),x[Sa>>2]=Ta;g=x[c+4>>2];Sa=c,Ta=Gc(pva(ova(g,g>>31,a,e),hb,256,0),hb),x[Sa+4>>2]=Ta;x[d+1074472>>2]=j}b=b+1|0;c=c+8|0;continue};case 3:break Rd;default:break Qd}}m=a<<12;c=d+8204|0;b=d+12|0;e=a;g=a>>31;a=0;while(1){if((a|0)==(o|0)){break Qd}Ud:{if(x[n>>2]>0){j=x[d+1074472>>2]+h|0;x[d+1074472>>2]=j;r=x[b>>2];Sa=b,Ta=Gc(pva(ova(r,r>>31,j,j>>31),hb,1048576,0),hb),x[Sa>>2]=Ta;j=x[d+1074472>>2];r=j;k=j>>31;j=x[b+4>>2];Sa=b,Ta=Gc(pva(ova(r,k,j,j>>31),hb,1048576,0),hb),x[Sa+4>>2]=Ta;j=x[d+1074472>>2];r=j;k=j>>31;j=x[c>>2];Sa=c,Ta=Gc(pva(ova(r,k,j,j>>31),hb,1048576,0),hb),x[Sa>>2]=Ta;j=x[d+1074472>>2];r=j;k=j>>31;j=x[c+4>>2];Sa=c,Ta=Gc(pva(ova(r,k,j,j>>31),hb,1048576,0),hb),x[Sa+4>>2]=Ta;x[d+1074460>>2]=x[d+1074460>>2]-1;break Ud}j=x[b>>2];Sa=b,Ta=Gc(pva(ova(j,j>>31,e,g),hb,256,0),hb),x[Sa>>2]=Ta;j=x[b+4>>2];Sa=b,Ta=Gc(pva(ova(j,j>>31,e,g),hb,256,0),hb),x[Sa+4>>2]=Ta;j=x[c>>2];Sa=c,Ta=Gc(pva(ova(j,j>>31,e,g),hb,256,0),hb),x[Sa>>2]=Ta;j=x[c+4>>2];Sa=c,Ta=Gc(pva(ova(j,j>>31,e,g),hb,256,0),hb),x[Sa+4>>2]=Ta;x[d+1074472>>2]=m}a=a+1|0;c=c+8|0;b=b+8|0;continue}}fb=f+16|0}if(x[ra>>2]!=128){b=d+12|0;c=d+8204|0;a=x[d+24604>>2];e=x[d+24624>>2];Vd:{if((a|0)==128|e>>>0<2){break Vd}UR(b,o,a);if(e>>>0<4){break Vd}UR(c,o,a)}}a=x[d+24624>>2];if((a|0)==4){a=o;while(1){a=a-1|0;if((a|0)>=0){b=(a<<4)+Y|0;c=a<<3;e=c|4;x[b+12>>2]=x[e+sa>>2];x[b+8>>2]=x[c+sa>>2];x[b+4>>2]=x[e+Y>>2];x[b>>2]=x[c+Y>>2];continue}break}a=x[d+24624>>2]}if(Ed(Ea)){x[K- -64>>2]=o;x[K+60>>2]=a;x[K+56>>2]=Y;a=x[x[pa>>2]+8>>2];x[K+24>>2]=o;b=x[K+60>>2];x[K+16>>2]=x[K+56>>2];x[K+20>>2]=b;ib[a|0](pa,K+16|0);a=x[d+24624>>2]}x[K+52>>2]=o;x[K+48>>2]=a;x[K+44>>2]=Y;a=x[x[oa>>2]+8>>2];x[K+8>>2]=o;b=x[K+48>>2];x[K>>2]=x[K+44>>2];x[K+4>>2]=b;ib[a|0](oa,K);x[d+1074380>>2]=x[d+1074380>>2]-o;x[d+1074376>>2]=o+x[d+1074376>>2];ha=ha-o|0;Da=o+Da|0;continue}break}fb=da+32|0;return Da}function fg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=E(0),q=E(0),s=0,t=0,u=0,G=0,H=0,I=E(0),J=0,K=0,L=0,M=0,O=0,V=0;k=fb-2240|0;fb=k;a:{b:{c:{d:{e:{f:{if(Zw(x[c>>2])){wc(b,268435456);L=x[c+8>>2];H=k+2220|0;x[H>>2]=0;x[H+4>>2]=0;Nb(H+8|0);x[k+2216>>2]=0;g:{h:{i:{j:{k:{l:{m:{f=y[a+3|0];n:{o:{if((f-4&255)>>>0<=4){x[31725]=0;g=R(204,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break m}x[k+2216>>2]=g;break o}if(f>>>0>17){break n}p:{d=1<<f;if(!(d&63503)){if(!(d&198144)){break n}break p}if(y[a|0]){break p}break o}f=0;e=wD(a,x[b>>2]);x[31725]=0;S(188,k+48|0,c|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break l}e=k+48|0;d=x[e+4>>2];x[H>>2]=x[e>>2];x[H+4>>2]=d;Fn(H+8|0,e+8|0);Kc(e);e=$e(H);g=x[H>>2];x[k+2216>>2]=g;if(!e){break g}}f=y[a+3|0]}q:{r:{switch(f&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:i=!y[a|0];case 9:case 10:case 16:case 17:d=x[b>>2];if(!(d>>>0<262145|i)){f=f&255;x[k+48>>2]=((f|0)==10)<<4;g=g-x[Gb(k+48|0,k+2216|0)>>2]|0;if(f>>>0>15){break k}s:{if(!(1<<f&63503)){if((f|0)==10){break s}break k}if(!(y[a|0]&7)){break k}}d=(g|0)<0?-1:g<<1;break j}f=f&255;if(f>>>0>8){break h}if(1<<f&432){break q}if((f|0)!=6){break h}break;case 4:case 5:case 7:case 8:break q;case 6:break r;default:break i}}f=0;if(g>>>0<10){break g}x[31725]=0;P(185,c|0,4)|0;d=x[31725];x[31725]=0;if((d|0)==1){break m}x[31725]=0;d=R(153,c|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){x[k+48>>2]=d;x[k+28>>2]=x[k+2216>>2];d=x[Gb(k+48|0,k+28|0)>>2];Gh(c,8);d=((d>>>0>50529027?-1:D(d,85))>>>0)/(y[a|0]>>>3>>>0)|0;break j}a=N()|0;break a}d=8/(qr(y[a+1|0])>>>0)|0;f=D(d,g);ova(d,0,g,0);d=hb?-1:f;break j}a=N()|0;break a}a=N()|0;break a}d=0;h=qr(y[a+1|0]);t:{u:{switch(f|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:d=y[a|0];break t;case 9:d=16;break t;case 10:d=4;break t;case 16:case 17:break u;default:break t}}d=8}d=D(h,d&255)>>>3|0;f=(d+g|0)-1|0;d=((f>>>0<g>>>0?-1:f)>>>0)/(d>>>0)|0}wc(b,d)}d=x[b>>2]}if(!d){f=0;break g}w[b+34>>1]=z[b+34>>1]&65470|y[a|0]>15|(y[a+1|0]!=1)<<6;if(!Fh(b)){f=0;x[b>>2]=0;break g}v:{if(ne(a,Xc(k+48|0,8,1,0,10))){x[31725]=0;a=P(205,c|0,k+48|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){f=0;if(!a){break v}a=x[b>>2];g=0;x[31725]=0;x[k+28>>2]=a+1>>>1;a=R(204,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}wc(k+28|0,a);a=e+16|0;b=x[b+20>>2];e=x[k+28>>2];f=e;while(1)if(f){d=k+48|0;g=y[d|y[a|0]&15]+g|0;v[b|0]=g;g=y[d|y[a|0]>>>4]+(g&255)|0;v[b+1|0]=g;f=f-1|0;a=a+1|0;b=b+2|0;continue}else{f=e+16|0;break v}}a=N()|0;break a}w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{d=y[a+3|0];switch(d-4|0){case 3:break C;case 4:break F;case 5:break G;case 2:break H;case 0:case 1:break I;default:break E}}x[31725]=0;a=ba(206,k+1128|0,c|0,b|0,(d|0)==5|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}ub(a);f=x[c+8>>2]-L|0;break v}if(y[a+1|0]!=1){break D}x[31725]=0;P(185,c|0,4)|0;a=x[31725];x[31725]=0;if((a|0)==1){break f}x[31725]=0;a=R(153,c|0)|0;e=x[31725];x[31725]=0;J:{K:{L:{if((e|0)!=1){x[31725]=0;x[k+28>>2]=a;e=R(199,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break L}x[31725]=0;S(207,k+48|0,c|0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break K}wc(k+28|0,x[k+48>>2]);a=x[k+28>>2];Tn(k+1120|0,k+48|0);bc(k+1112|0,x[b+20>>2],Xk(x[b>>2],z[b+34>>1]));x[31725]=0;aa(208,x[k+1120>>2],x[k+1124>>2],x[k+1112>>2],x[k+1116>>2],e<<24>>24);b=x[31725];x[31725]=0;if((b|0)==1){break J}f=a+9|0;Kc(k+48|0);break v}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;Kc(k+48|0);break a}if(y[a+1|0]!=1|y[a|0]!=16){break D}d=x[k+2216>>2];a=cl(k+1110|0);f=x[b>>2];b=x[b+20>>2];g=z[a>>1];a=fb-16|0;fb=a;x[a+12>>2]=d>>>1;x[a+8>>2]=f;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){h=y[e|0]+g|0;g=h+y[e+1|0]|0;w[b>>1]=g<<8|h&255;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}fb=a+16|0;f=d<<1;break v}if(y[a+1|0]!=1|y[a|0]>16){break D}e=x[c+8>>2];d=x[c>>2];f=0;x[31725]=0;e=U(152,d|0,e|0,8)|0;d=x[31725];x[31725]=0;if((d|0)==1){break f}if(!e){break v}x[31725]=0;e=R(153,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break f}x[k+2216>>2]=e;if(e>>>0<4){break v}x[31725]=0;S(187,k+28|0,c|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break c}d=k+28|0;e=qs(k+48|0,d);ub(d);d=x[e>>2];x[31725]=0;d=R(209,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}f=d+4|0;h=y[a|0];j=(h|0)!=16;g=0;i=0;while(1){if(A[b>>2]<=i>>>0){break x}M:{if(j){break M}x[31725]=0;m=P(160,e|0,8)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break M}a=T(28848)|0;break y}x[31725]=0;t=P(160,e|0,1)|0;a=x[31725];x[31725]=0;if((a|0)==1){break z}x[31725]=0;a=P(160,e|0,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break z}N:{O:{P:{if(!a){d=8;while(1){x[31725]=0;a=P(160,e|0,1)|0;G=x[31725];x[31725]=0;if((G|0)==1){break N}if(a){break P}d=d+16|0;continue}}x[31725]=0;a=P(160,e|0,3)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break O}break z}x[31725]=0;a=P(160,e|0,4)|0;G=x[31725];x[31725]=0;if((G|0)==1){break z}a=a+d|0}g=(g&255)+(((t?-1:0)^a)&255)|0;Q:{if((h|0)!=16){v[x[b+20>>2]+i|0]=g;break Q}w[x[b+20>>2]+(i<<1)>>1]=m&255|g<<8}i=i+1|0;continue}break}a=T(28848)|0;break y}R:{if((d|0)==16){f=y[a|0];break R}f=y[a|0];if((d|0)!=17){break A}}if((f&255)!=16){break A}g=y[a+1|0];if((g-1&255)>>>0>1){break A}M=k,O=D(x[b>>2],qr(g)),x[M+48>>2]=O;wc(k+48|0,x[k+2216>>2]);a=x[b+20>>2];f=x[k+48>>2];if((d|0)==16){b=f;while(1){if(!b){break v}M=a,O=z[_b(28880,y[e|0])>>1],w[M>>1]=O;a=a+2|0;e=e+1|0;b=b-1|0;continue}}b=f;while(1){if(!b){break v}M=a,O=z[_b(29392,y[e|0])>>1],w[M>>1]=O;a=a+2|0;e=e+1|0;b=b-1|0;continue}}if((d|0)!=7){break B}}if(y[a+1|0]!=1|y[a|0]>16){break B}f=0;if(A[k+2216>>2]<5){break v}a=x[b+20>>2];e=z[b+34>>1];b=x[b>>2];x[31725]=0;f=U(210,c|0,a|0,Xk(b,e)|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break v}break f}f=y[a|0]}g=(f&255)!=8;if(!(g|y[a+1|0]!=1)){S:{switch(d|0){case 0:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2];x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0];b=b+1|0;e=e+1|0;f=f-1|0;continue}break};fb=d+16|0;f=a;break v;case 1:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2];x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0]^128;b=b+1|0;e=e+1|0;f=f-1|0;continue}break};fb=d+16|0;f=a;break v;default:f=0;if((d|0)!=11){break v}break;case 2:break S}}a=x[k+2216>>2];d=rv(k+27|0);f=x[b>>2];b=x[b+20>>2];g=y[d|0];d=fb-16|0;fb=d;x[d+12>>2]=a;x[d+8>>2]=f;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){g=y[e|0]+g|0;v[b|0]=g;b=b+1|0;e=e+1|0;f=f-1|0;continue}break}fb=d+16|0;f=a;break v}if(!(y[a+1|0]!=3|g)){T:{switch(d|0){case 0:g=fb-16|0;fb=g;a=x[k+2216>>2];x[g+12>>2]=a;f=x[b>>2];x[g+8>>2]=f;h=g+8|0;d=x[Gb(h,g+12|0)>>2];x[g+8>>2]=f;x[g+4>>2]=a-d;f=x[Gb(h,g+4|0)>>2];i=x[b+20>>2];a=d;h=e;while(1){if(a){v[i|0]=y[h|0];i=i+2|0;h=h+1|0;a=a-1|0;continue}break};i=x[b+20>>2]+1|0;h=x[b>>2]+e|0;a=f;while(1){if(a){v[i|0]=y[h|0];i=i+2|0;h=h+1|0;a=a-1|0;continue}break};fb=g+16|0;f=d+f|0;break v;case 1:g=fb-16|0;fb=g;a=x[k+2216>>2];x[g+12>>2]=a;f=x[b>>2];x[g+8>>2]=f;h=g+8|0;d=x[Gb(h,g+12|0)>>2];x[g+8>>2]=f;x[g+4>>2]=a-d;f=x[Gb(h,g+4|0)>>2];i=x[b+20>>2];a=d;h=e;while(1){if(a){v[i|0]=y[h|0]^128;i=i+2|0;h=h+1|0;a=a-1|0;continue}break};i=x[b+20>>2]+1|0;h=x[b>>2]+e|0;a=f;while(1){if(a){v[i|0]=y[h|0]^128;i=i+2|0;h=h+1|0;a=a-1|0;continue}break};fb=g+16|0;f=d+f|0;break v;default:f=0;if((d|0)!=11){break v}break;case 2:break T}}d=x[k+2216>>2];f=y[rv(k+26|0)|0];t=fb-16|0;fb=t;x[t+12>>2]=d;g=x[b>>2];x[t+8>>2]=g;h=t+8|0;i=x[Gb(h,t+12|0)>>2];x[t+8>>2]=g;x[t+4>>2]=d-i;j=x[Gb(h,t+4|0)>>2];g=b;m=x[b+20>>2];h=f;b=i;d=e;while(1){if(b){h=y[d|0]+h|0;v[m|0]=h;m=m+2|0;d=d+1|0;b=b-1|0;continue}break}m=x[g+20>>2]+1|0;d=x[g>>2]+e|0;b=j;while(1){if(b){f=y[d|0]+f|0;v[m|0]=f;m=m+2|0;d=d+1|0;b=b-1|0;continue}break}fb=t+16|0;f=i+j|0;if(y[a+3|0]!=11){break v}a=x[g+20>>2];b=a+(x[g>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break v}v[a+1|0]=y[a+1|0]+y[a|0];a=a+2|0;continue}}g=f&255;if(!((g|0)!=8|y[a+1|0]!=2)){f=0;U:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){v[b|0]=y[e|0];v[b+1|0]=y[e+1|0];b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<1;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){v[b|0]=y[e|0]^128;v[b+1|0]=y[e+1|0]^128;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<1;break v;case 2:break U;default:break v}}d=x[k+2216>>2];a=rv(k+25|0);h=x[b>>2];g=x[b+20>>2];a=y[a|0];f=fb-16|0;fb=f;x[f+12>>2]=d>>>1;x[f+8>>2]=h;b=a;h=x[Gb(f+12|0,f+8|0)>>2];d=h;while(1){if(d){a=y[e|0]+a|0;v[g|0]=a;b=y[e+1|0]+b|0;v[g+1|0]=b;g=g+2|0;e=e+2|0;d=d-1|0;continue}break}fb=f+16|0;f=h<<1;break v}if(!(y[a+2|0]|((g|0)!=16|y[a+1|0]!=1))){V:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){w[b>>1]=y[e|0]|y[e+1|0]<<8;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<1;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){w[b>>1]=(y[e|0]|y[e+1|0]<<8)^32768;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<1;break v;default:f=0;if((d|0)!=11){break v}break;case 2:break V}}d=x[k+2216>>2];a=cl(k+22|0);f=x[b>>2];b=x[b+20>>2];g=z[a>>1];a=fb-16|0;fb=a;x[a+12>>2]=d>>>1;x[a+8>>2]=f;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=(y[e|0]+g|0)+(y[e+1|0]<<8)|0;w[b>>1]=g;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}fb=a+16|0;f=d<<1;break v}g=f&255;if(!((g|0)!=16|y[a+1|0]!=1|y[a+2|0]!=1)){f=0;W:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=y[e|0]|y[e+1|0]<<8;w[b>>1]=g<<8|g>>>8;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<1;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=y[e|0]|y[e+1|0]<<8;w[b>>1]=(g<<8|g>>>8)^32768;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<1;break v;case 2:break W;default:break v}}d=x[k+2216>>2];a=cl(k+20|0);f=x[b>>2];b=x[b+20>>2];g=z[a>>1];a=fb-16|0;fb=a;x[a+12>>2]=d>>>1;x[a+8>>2]=f;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=(y[e+1|0]+g|0)+(y[e|0]<<8)|0;w[b>>1]=g;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}fb=a+16|0;f=d<<1;break v}if(!(y[a+2|0]|((g|0)!=16|y[a+1|0]!=3))){X:{switch(d|0){case 0:a=fb-16|0;fb=a;f=x[k+2216>>2];x[a+12>>2]=f;h=x[b>>2]<<1;x[a+8>>2]=h;g=a+8|0;d=x[Gb(g,a+12|0)>>2];x[a+8>>2]=h;x[a+4>>2]=f-d;i=x[Gb(g,a+4|0)>>2];f=x[b+20>>2];j=d>>>1|0;g=j;d=e;while(1){if(g){w[f>>1]=y[d|0]|y[d+1|0]<<8;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+h|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){w[d>>1]=y[f|0]|y[f+1|0]<<8;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=a+16|0;f=b+j<<1;break v;case 1:a=fb-16|0;fb=a;f=x[k+2216>>2];x[a+12>>2]=f;h=x[b>>2]<<1;x[a+8>>2]=h;g=a+8|0;d=x[Gb(g,a+12|0)>>2];x[a+8>>2]=h;x[a+4>>2]=f-d;i=x[Gb(g,a+4|0)>>2];f=x[b+20>>2];j=d>>>1|0;g=j;d=e;while(1){if(g){w[f>>1]=(y[d|0]|y[d+1|0]<<8)^32768;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+h|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){w[d>>1]=(y[f|0]|y[f+1|0]<<8)^32768;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=a+16|0;f=b+j<<1;break v;default:f=0;if((d|0)!=11){break v}break;case 2:break X}}d=x[k+2216>>2];f=z[cl(k+18|0)>>1];i=fb-16|0;fb=i;x[i+12>>2]=d;j=x[b>>2]<<1;x[i+8>>2]=j;g=i+8|0;m=x[Gb(g,i+12|0)>>2];x[i+8>>2]=j;x[i+4>>2]=d-m;t=x[Gb(g,i+4|0)>>2];g=b;h=x[b+20>>2];b=f;G=m>>>1|0;m=G;d=e;while(1){if(m){b=(y[d|0]+b|0)+(y[d+1|0]<<8)|0;w[h>>1]=b;h=h+4|0;d=d+2|0;m=m-1|0;continue}break}d=e+j|0;h=x[g+20>>2]+2|0;b=t>>>1|0;m=b;while(1){if(m){f=(y[d|0]+f|0)+(y[d+1|0]<<8)|0;w[h>>1]=f;h=h+4|0;d=d+2|0;m=m-1|0;continue}break}fb=i+16|0;f=b+G<<1;if(y[a+3|0]!=11){break v}a=x[g+20>>2];b=a+(x[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break v}w[a+2>>1]=z[a+2>>1]+z[a>>1];a=a+4|0;continue}}g=f&255;if(!((g|0)!=16|y[a+1|0]!=3|y[a+2|0]!=1)){f=0;Y:{switch(d|0){case 0:a=fb-16|0;fb=a;f=x[k+2216>>2];x[a+12>>2]=f;h=x[b>>2]<<1;x[a+8>>2]=h;g=a+8|0;d=x[Gb(g,a+12|0)>>2];x[a+8>>2]=h;x[a+4>>2]=f-d;i=x[Gb(g,a+4|0)>>2];f=x[b+20>>2];j=d>>>1|0;g=j;d=e;while(1){if(g){m=y[d|0]|y[d+1|0]<<8;w[f>>1]=m<<8|m>>>8;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+h|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){e=y[f|0]|y[f+1|0]<<8;w[d>>1]=e<<8|e>>>8;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=a+16|0;f=b+j<<1;break v;case 1:a=fb-16|0;fb=a;f=x[k+2216>>2];x[a+12>>2]=f;h=x[b>>2]<<1;x[a+8>>2]=h;g=a+8|0;d=x[Gb(g,a+12|0)>>2];x[a+8>>2]=h;x[a+4>>2]=f-d;i=x[Gb(g,a+4|0)>>2];f=x[b+20>>2];j=d>>>1|0;g=j;d=e;while(1){if(g){m=y[d|0]|y[d+1|0]<<8;w[f>>1]=(m<<8|m>>>8)^32768;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+h|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){e=y[f|0]|y[f+1|0]<<8;w[d>>1]=(e<<8|e>>>8)^32768;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=a+16|0;f=b+j<<1;break v;case 2:break Y;default:break v}}d=x[k+2216>>2];a=z[cl(k+16|0)>>1];f=fb-16|0;fb=f;x[f+12>>2]=d;j=x[b>>2]<<1;x[f+8>>2]=j;h=f+8|0;g=x[Gb(h,f+12|0)>>2];x[f+8>>2]=j;x[f+4>>2]=d-g;m=x[Gb(h,f+4|0)>>2];d=b;i=x[d+20>>2];b=a;t=g>>>1|0;h=t;g=e;while(1){if(h){b=(y[g+1|0]+b|0)+(y[g|0]<<8)|0;w[i>>1]=b;i=i+4|0;g=g+2|0;h=h-1|0;continue}break}g=e+j|0;i=x[d+20>>2]+2|0;b=m>>>1|0;h=b;while(1){if(h){a=(y[g+1|0]+a|0)+(y[g|0]<<8)|0;w[i>>1]=a;i=i+4|0;g=g+2|0;h=h-1|0;continue}break}fb=f+16|0;f=b+t<<1;break v}if(!(y[a+2|0]|((g|0)!=16|y[a+1|0]!=2))){f=0;Z:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>2;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){w[b>>1]=y[e|0]|y[e+1|0]<<8;w[b+2>>1]=y[e+2|0]|y[e+3|0]<<8;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<2;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>2;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){w[b>>1]=(y[e|0]|y[e+1|0]<<8)^32768;w[b+2>>1]=(y[e+2|0]|y[e+3|0]<<8)^32768;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<2;break v;case 2:break Z;default:break v}}d=x[k+2216>>2];a=cl(k+14|0);h=x[b>>2];g=x[b+20>>2];a=z[a>>1];f=fb-16|0;fb=f;x[f+12>>2]=d>>>2;x[f+8>>2]=h;b=a;h=x[Gb(f+12|0,f+8|0)>>2];d=h;while(1){if(d){a=(y[e|0]+a|0)+(y[e+1|0]<<8)|0;w[g>>1]=a;b=(y[e+2|0]+b|0)+(y[e+3|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;e=e+4|0;d=d-1|0;continue}break}fb=f+16|0;f=h<<2;break v}g=f&255;if(!((g|0)!=16|y[a+1|0]!=2|y[a+2|0]!=1)){f=0;_:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>2;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=y[e|0]|y[e+1|0]<<8;w[b>>1]=g<<8|g>>>8;g=y[e+2|0]|y[e+3|0]<<8;w[b+2>>1]=g<<8|g>>>8;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<2;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=x[k+2216>>2]>>>2;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=y[e|0]|y[e+1|0]<<8;w[b>>1]=(g<<8|g>>>8)^32768;g=y[e+2|0]|y[e+3|0]<<8;w[b+2>>1]=(g<<8|g>>>8)^32768;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=a+16|0;f=d<<2;break v;case 2:break _;default:break v}}d=x[k+2216>>2];a=cl(k+12|0);h=x[b>>2];g=x[b+20>>2];a=z[a>>1];f=fb-16|0;fb=f;x[f+12>>2]=d>>>2;x[f+8>>2]=h;b=a;h=x[Gb(f+12|0,f+8|0)>>2];d=h;while(1){if(d){a=(y[e+1|0]+a|0)+(y[e|0]<<8)|0;w[g>>1]=a;b=(y[e+3|0]+b|0)+(y[e+2|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;e=e+4|0;d=d-1|0;continue}break}fb=f+16|0;f=h<<2;break v}if(!(d|y[a+1|0]!=1|(g|0)!=24)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=(d>>>0)/3;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=qd(y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24,16),w[M>>1]=O;f=f+2|0;e=e+3|0;b=b-1|0;continue}break}fb=a+16|0;f=D(d,3);break v}a=fb-16|0;fb=a;x[a+12>>2]=(d>>>0)/3;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=qd(y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24,16),w[M>>1]=O;f=f+2|0;e=e+3|0;b=b-1|0;continue}break}fb=a+16|0;f=D(d,3);break v}g=f&255;if(!(d|y[a+1|0]!=2|(g|0)!=24)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=(d>>>0)/6;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=qd(y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24,16),w[M>>1]=O;M=f,O=qd(y[e+4|0]<<16|y[e+3|0]<<8|y[e+5|0]<<24,16),w[M+2>>1]=O;f=f+4|0;e=e+6|0;b=b-1|0;continue}break}fb=a+16|0;f=D(d,6);break v}a=fb-16|0;fb=a;x[a+12>>2]=(d>>>0)/6;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=qd(y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24,16),w[M>>1]=O;M=f,O=qd(y[e+4|0]<<16|y[e+5|0]<<8|y[e+3|0]<<24,16),w[M+2>>1]=O;f=f+4|0;e=e+6|0;b=b-1|0;continue}break}fb=a+16|0;f=D(d,6);break v}if(!(d|y[a+1|0]!=1|(g|0)!=32)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=d>>>2;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=qd(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),16),w[M>>1]=O;f=f+2|0;e=e+4|0;b=b-1|0;continue}break}fb=a+16|0;f=d<<2;break v}a=fb-16|0;fb=a;x[a+12>>2]=d>>>2;x[a+8>>2]=b;g=x[Gb(a+12|0,a+8|0)>>2];b=g;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);M=f,O=qd(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M>>1]=O;f=f+2|0;e=e+4|0;b=b-1|0;continue}break}fb=a+16|0;f=g<<2;break v}g=f&255;if(!(d|y[a+1|0]!=2|(g|0)!=32)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=qd(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),16),w[M>>1]=O;M=f,O=qd(y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),16),w[M+2>>1]=O;f=f+4|0;e=e+8|0;b=b-1|0;continue}break}fb=a+16|0;f=d<<3;break v}a=fb-16|0;fb=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;g=x[Gb(a+12|0,a+8|0)>>2];b=g;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);M=f,O=qd(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M>>1]=O;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=f,O=qd(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M+2>>1]=O;f=f+4|0;e=e+8|0;b=b-1|0;continue}break}fb=a+16|0;f=g<<3;break v}if(!(d|y[a+1|0]!=1|(g|0)!=64)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=Rc(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),48),w[M>>1]=O;f=f+2|0;e=e+8|0;b=b-1|0;continue}break}fb=a+16|0;f=d<<3;break v}a=fb-16|0;fb=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;h=x[Gb(a+12|0,a+8|0)>>2];b=h;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=f,O=Rc(m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)),i|(j|t),48),w[M>>1]=O;f=f+2|0;e=e+8|0;b=b-1|0;continue}break}fb=a+16|0;f=h<<3;break v}g=f&255;if(!(d|y[a+1|0]!=2|(g|0)!=64)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=d>>>4;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,O=Rc(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),48),w[M>>1]=O;M=f,O=Rc(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24),y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24),48),w[M+2>>1]=O;f=f+4|0;e=e+16|0;b=b-1|0;continue}break}fb=a+16|0;f=d<<4;break v}a=fb-16|0;fb=a;x[a+12>>2]=d>>>4;x[a+8>>2]=b;h=x[Gb(a+12|0,a+8|0)>>2];b=h;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=f,O=Rc(m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)),i|(j|t),48),w[M>>1]=O;d=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);M=f,O=Rc(m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)),i|(j|t),48),w[M+2>>1]=O;f=f+4|0;e=e+16|0;b=b-1|0;continue}break}fb=a+16|0;f=h<<4;break v}if(!(y[a+1|0]!=1|(d|0)!=3|(g|0)!=32)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=d>>>2;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){o=cg((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));o=si(E(Pd(Jg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));$:{if(E(F(o))<E(2147483648)){g=~~o;break $}g=-2147483648}M=f,O=ed(g),w[M>>1]=O;f=f+2|0;e=e+4|0;b=b-1|0;continue}break}fb=a+16|0;f=d<<2;break v}a=fb-16|0;fb=a;x[a+12>>2]=d>>>2;x[a+8>>2]=b;g=x[Gb(a+12|0,a+8|0)>>2];b=g;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);o=cg((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));o=si(E(Pd(Jg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));aa:{if(E(F(o))<E(2147483648)){d=~~o;break aa}d=-2147483648}M=f,O=ed(d),w[M>>1]=O;f=f+2|0;e=e+4|0;b=b-1|0;continue}break}fb=a+16|0;f=g<<2;break v}g=f&255;if(!(y[a+1|0]!=2|(d|0)!=3|(g|0)!=32)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-16|0;fb=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;d=x[Gb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){o=cg((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));o=si(E(Pd(Jg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));ba:{if(E(F(o))<E(2147483648)){g=~~o;break ba}g=-2147483648}M=f,O=ed(g),w[M>>1]=O;o=cg((l(2,y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24)),r()));o=si(E(Pd(Jg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));ca:{if(E(F(o))<E(2147483648)){g=~~o;break ca}g=-2147483648}M=f,O=ed(g),w[M+2>>1]=O;f=f+4|0;e=e+8|0;b=b-1|0;continue}break}fb=a+16|0;f=d<<3;break v}a=fb-16|0;fb=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;g=x[Gb(a+12|0,a+8|0)>>2];b=g;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);o=cg((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));o=si(E(Pd(Jg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));da:{if(E(F(o))<E(2147483648)){d=~~o;break da}d=-2147483648}M=f,O=ed(d),w[M>>1]=O;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);o=cg((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));o=si(E(Pd(Jg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));ea:{if(E(F(o))<E(2147483648)){d=~~o;break ea}d=-2147483648}M=f,O=ed(d),w[M+2>>1]=O;f=f+4|0;e=e+8|0;b=b-1|0;continue}break}fb=a+16|0;f=g<<3;break v}if(!(y[a+1|0]!=1|(d|0)!=3|(g|0)!=64)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-32|0;fb=a;x[a+24>>2]=d>>>3;x[a+16>>2]=b;d=x[Gb(a+24|0,a+16|0)>>2];b=d;while(1){if(b){g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,g|0);s=Ig(+n());M=a,V=zf(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);fa:{if(F(s)<2147483648){g=~~s;break fa}g=-2147483648}M=f,O=ed(g),w[M>>1]=O;f=f+2|0;e=e+8|0;b=b-1|0;continue}break}fb=a+32|0;f=d<<3;break v}a=fb-32|0;fb=a;x[a+24>>2]=d>>>3;x[a+16>>2]=b;h=x[Gb(a+24|0,a+16|0)>>2];b=h;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,i|(j|t));s=Ig(+n());M=a,V=zf(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);ga:{if(F(s)<2147483648){d=~~s;break ga}d=-2147483648}M=f,O=ed(d),w[M>>1]=O;f=f+2|0;e=e+8|0;b=b-1|0;continue}break}fb=a+32|0;f=h<<3;break v}g=f&255;if(!(y[a+1|0]!=2|(d|0)!=3|(g|0)!=64)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=fb-32|0;fb=a;x[a+24>>2]=d>>>4;x[a+16>>2]=b;d=x[Gb(a+24|0,a+16|0)>>2];b=d;while(1){if(b){g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,g|0);s=Ig(+n());M=a,V=zf(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);ha:{if(F(s)<2147483648){g=~~s;break ha}g=-2147483648}M=f,O=ed(g),w[M>>1]=O;g=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);l(0,y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24));l(1,g|0);s=Ig(+n());M=a,V=zf(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);ia:{if(F(s)<2147483648){g=~~s;break ia}g=-2147483648}M=f,O=ed(g),w[M+2>>1]=O;f=f+4|0;e=e+16|0;b=b-1|0;continue}break}fb=a+32|0;f=d<<4;break v}a=fb-32|0;fb=a;x[a+24>>2]=d>>>4;x[a+16>>2]=b;h=x[Gb(a+24|0,a+16|0)>>2];b=h;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,i|(j|t));s=Ig(+n());M=a,V=zf(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);ja:{if(F(s)<2147483648){d=~~s;break ja}d=-2147483648}M=f,O=ed(d),w[M>>1]=O;d=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);l(0,m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,i|(j|t));s=Ig(+n());M=a,V=zf(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);ka:{if(F(s)<2147483648){d=~~s;break ka}d=-2147483648}M=f,O=ed(d),w[M+2>>1]=O;f=f+4|0;e=e+16|0;b=b-1|0;continue}break}fb=a+32|0;f=h<<4;break v}la:{if((g|0)==24){if((d|0)!=15|(y[a+1|0]-1&255)>>>0>1){break la}x[k+48>>2]=-2147483648;d=x[k+2216>>2];ma:{if(!y[a+2|0]){m=k+48|0;f=0;h=fb-16|0;fb=h;M=h,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(h+12|0,(d>>>0)/3|0);a=e;g=x[h+12>>2];i=g;while(1){if(i){j=y[a+1|0]<<16|y[a|0]<<8|y[a+2|0]<<24;na:{oa:{pa:{if((j|0)>=0){d=j;break pa}d=-2147483648;if((j|0)==-2147483648){break oa}d=0-j|0}if(d>>>0<=f>>>0){break na}}f=d}i=i-1|0;a=a+3|0;continue}else{qa:{if(!f){break qa}t=f-1|0;G=f>>>1|0;i=x[b+20>>2];a=g;while(1){if(!a){break qa}j=y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24;d=j&-2147483648|j>>>1;j=G|j<<31;ra:{if((d|0)>0|(d|0)>=0){d=qva(j,d,f,0);j=hb;break ra}j=qva(t-j|0,0-((j>>>0>t>>>0)+d|0)|0,f,0);d=0-j|0;j=0-(hb+((j|0)!=0)|0)|0}M=i,O=qd(Gc(d,j),16),w[M>>1]=O;a=a-1|0;e=e+3|0;i=i+2|0;continue}}}break}if(m){x[m>>2]=f}fb=h+16|0;f=D(g,3);break ma}m=k+48|0;f=0;h=fb-16|0;fb=h;M=h,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(h+12|0,(d>>>0)/3|0);a=e;g=x[h+12>>2];i=g;while(1){if(i){j=y[a+1|0]<<16|y[a+2|0]<<8|y[a|0]<<24;sa:{ta:{ua:{if((j|0)>=0){d=j;break ua}d=-2147483648;if((j|0)==-2147483648){break ta}d=0-j|0}if(d>>>0<=f>>>0){break sa}}f=d}i=i-1|0;a=a+3|0;continue}else{va:{if(!f){break va}t=f-1|0;G=f>>>1|0;i=x[b+20>>2];a=g;while(1){if(!a){break va}j=y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24;d=j&-2147483648|j>>>1;j=G|j<<31;wa:{if((d|0)>0|(d|0)>=0){d=qva(j,d,f,0);j=hb;break wa}j=qva(t-j|0,0-((j>>>0>t>>>0)+d|0)|0,f,0);d=0-j|0;j=0-(hb+((j|0)!=0)|0)|0}M=i,O=qd(Gc(d,j),16),w[M>>1]=O;a=a-1|0;e=e+3|0;i=i+2|0;continue}}}break}if(m){x[m>>2]=f}fb=h+16|0;f=D(g,3)}if(!f){break v}a=x[k+48>>2];if((a|0)==-2147483648){break v}a=ova(z[b+32>>1],0,a,0);e=hb;a=a+1073741824|0;e=a>>>0<1073741824?e+1|0:e;M=b,O=Kd(Bc((e&2147483647)<<1|a>>>31,e>>>31|0),1,64),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break v}g=f&255;if((g|0)==32){if(!((d|0)!=15|(y[a+1|0]-1&255)>>>0>1)){x[k+48>>2]=-2147483648;d=x[k+2216>>2];xa:{if(!y[a+2|0]){m=k+48|0;a=0;h=fb-16|0;fb=h;M=h,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(h+12|0,d>>>2|0);f=e;i=e;g=x[h+12>>2];e=g;while(1){if(e){j=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);ya:{za:{Aa:{if((j|0)>=0){d=j;break Aa}d=-2147483648;if((j|0)==-2147483648){break za}d=0-j|0}if(d>>>0<=a>>>0){break ya}}a=d}e=e-1|0;i=i+4|0;continue}else{Ba:{if(!a){break Ba}t=a-1|0;G=a>>>1|0;i=x[b+20>>2];e=g;while(1){if(!e){break Ba}j=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);d=j&-2147483648|j>>>1;j=G|j<<31;Ca:{if((d|0)>0|(d|0)>=0){d=qva(j,d,a,0);j=hb;break Ca}j=qva(t-j|0,0-((j>>>0>t>>>0)+d|0)|0,a,0);d=0-j|0;j=0-(hb+((j|0)!=0)|0)|0}M=i,O=qd(Gc(d,j),16),w[M>>1]=O;e=e-1|0;f=f+4|0;i=i+2|0;continue}}}break}if(m){x[m>>2]=a}fb=h+16|0;f=g<<2;break xa}m=k+48|0;a=0;h=fb-16|0;fb=h;M=h,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(h+12|0,d>>>2|0);f=e;i=e;g=x[h+12>>2];e=g;while(1){if(e){d=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);j=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);Da:{Ea:{Fa:{if((j|0)>=0){d=j;break Fa}d=-2147483648;if((j|0)==-2147483648){break Ea}d=0-j|0}if(a>>>0>=d>>>0){break Da}}a=d}e=e-1|0;i=i+4|0;continue}else{Ga:{if(!a){break Ga}t=a-1|0;G=a>>>1|0;i=x[b+20>>2];e=g;while(1){if(!e){break Ga}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);d=j&-2147483648|j>>>1;j=G|j<<31;Ha:{if((d|0)>0|(d|0)>=0){d=qva(j,d,a,0);j=hb;break Ha}j=qva(t-j|0,0-((j>>>0>t>>>0)+d|0)|0,a,0);d=0-j|0;j=0-(hb+((j|0)!=0)|0)|0}M=i,O=qd(Gc(d,j),16),w[M>>1]=O;e=e-1|0;f=f+4|0;i=i+2|0;continue}}}break}if(m){x[m>>2]=a}fb=h+16|0;f=g<<2}if(!f){break v}a=x[k+48>>2];if((a|0)==-2147483648){break v}a=ova(z[b+32>>1],0,a,0);e=hb;a=a+1073741824|0;e=a>>>0<1073741824?e+1|0:e;M=b,O=Kd(Bc((e&2147483647)<<1|a>>>31,e>>>31|0),1,64),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break v}if((d|0)!=14|(y[a+1|0]-1&255)>>>0>1){break la}x[k+48>>2]=1065353216;d=x[k+2216>>2];Ia:{if(!y[a+2|0]){h=k+48|0;f=fb-16|0;fb=f;M=f,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(f+12|0,d>>>2|0);g=e;d=x[f+12>>2];a=d;while(1){if(a){q=cg((l(2,y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24)),r()));q=E(F(Jg(q)?q>=E(0)?E(1):E(-1):q));o=o<q?q:o;a=a-1|0;g=g+4|0;continue}else{Ja:{a=o==E(0);if(a){break Ja}I=a?E(1):E(E(1)/o);g=x[b+20>>2];a=d;while(1){if(!a){break Ja}q=cg((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));q=si(E(Pd(E(I*(Jg(q)?q>=E(0)?E(1):E(-1):q)),E(-1))*E(32768)));Ka:{if(E(F(q))<E(2147483648)){j=~~q;break Ka}j=-2147483648}M=g,O=ed(j),w[M>>1]=O;a=a-1|0;e=e+4|0;g=g+2|0;continue}}if(h){B[h>>2]=o}fb=f+16|0;f=d<<2}break}break Ia}i=k+48|0;f=fb-16|0;fb=f;M=f,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(f+12|0,d>>>2|0);g=e;d=x[f+12>>2];a=d;while(1){if(a){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);q=cg((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));q=E(F(Jg(q)?q>=E(0)?E(1):E(-1):q));o=o<q?q:o;a=a-1|0;g=g+4|0;continue}else{La:{a=o==E(0);if(a){break La}I=a?E(1):E(E(1)/o);g=x[b+20>>2];a=d;while(1){if(!a){break La}h=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);q=cg((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));q=si(E(Pd(E(I*(Jg(q)?q>=E(0)?E(1):E(-1):q)),E(-1))*E(32768)));Ma:{if(E(F(q))<E(2147483648)){j=~~q;break Ma}j=-2147483648}M=g,O=ed(j),w[M>>1]=O;a=a-1|0;e=e+4|0;g=g+2|0;continue}}if(i){B[i>>2]=o}fb=f+16|0;f=d<<2}break}}if(!f){break v}o=B[k+48>>2];if(o==E(1)){break v}o=si(BB(E(o*E(z[b+32>>1])),E(1),E(64)));a=65535;Na:{if(o>=E(65535)){break Na}a=0;if(o<=E(0)){break Na}a=~~o>>>0;if(o<E(4294967296)&o>=E(0)){break Na}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break v}if((d|0)!=14|(y[a+1|0]-1&255)>>>0>1|(g|0)!=64){break la}x[k+48>>2]=0;x[k+52>>2]=1072693248;d=x[k+2216>>2];Oa:{if(!y[a+2|0]){h=k+48|0;g=fb-32|0;fb=g;M=g,O=D(x[b>>2],_d(z[b+34>>1])),x[M+4>>2]=O;wc(g+4|0,d>>>3|0);d=e;f=x[g+4>>2];a=f;while(1){if(a){i=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));l(1,i|0);u=Ig(+n());u=F(zf(u)?u>=0?1:-1:u);s=s<u?u:s;a=a-1|0;d=d+8|0;continue}else{Pa:{a=s==0;if(a){break Pa}J=a?1:1/s;d=x[b+20>>2];a=f;while(1){if(!a){break Pa}i=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,i|0);u=Ig(+n());M=g,V=J*(zf(u)?u>=0?1:-1:u),C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;u=Ee(C[Yg(g+24|0,g+16|0,g+8|0)>>3]*32768);Qa:{if(F(u)<2147483648){j=~~u;break Qa}j=-2147483648}M=d,O=ed(j),w[M>>1]=O;a=a-1|0;e=e+8|0;d=d+2|0;continue}}if(h){C[h>>3]=s}fb=g+32|0;f=f<<3}break}break Oa}j=k+48|0;g=fb-32|0;fb=g;M=g,O=D(x[b>>2],_d(z[b+34>>1])),x[M+4>>2]=O;wc(g+4|0,d>>>3|0);d=e;f=x[g+4>>2];a=f;while(1){if(a){h=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);m=h<<24|(h&65280)<<8;i=h&16711680;t=i>>>8|0;G=h&-16777216;K=G>>>24|0;G=G<<8|i<<24;i=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,G|(((i&255)<<24|h>>>8)&-16777216|((i&16777215)<<8|h>>>24)&16711680|(i>>>8&65280|i>>>24)));l(1,m|(t|K));u=Ig(+n());u=F(zf(u)?u>=0?1:-1:u);s=s<u?u:s;a=a-1|0;d=d+8|0;continue}else{Ra:{a=s==0;if(a){break Ra}J=a?1:1/s;d=x[b+20>>2];a=f;while(1){if(!a){break Ra}h=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);m=h<<24|(h&65280)<<8;i=h&16711680;t=i>>>8|0;G=h&-16777216;K=G>>>24|0;G=G<<8|i<<24;i=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,G|(((i&255)<<24|h>>>8)&-16777216|((i&16777215)<<8|h>>>24)&16711680|(i>>>8&65280|i>>>24)));l(1,m|(t|K));u=Ig(+n());M=g,V=J*(zf(u)?u>=0?1:-1:u),C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;u=Ee(C[Yg(g+24|0,g+16|0,g+8|0)>>3]*32768);Sa:{if(F(u)<2147483648){h=~~u;break Sa}h=-2147483648}M=d,O=ed(h),w[M>>1]=O;a=a-1|0;e=e+8|0;d=d+2|0;continue}}if(j){C[j>>3]=s}fb=g+32|0;f=f<<3}break}}if(!f){break v}s=C[k+48>>3];if(s==1){break v}M=b,O=HD(Uv(s*+z[b+32>>1],1,64)),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break v}Ta:{Ua:{Va:{Wa:{g=(f&255)!=32;Xa:{if(!(g|(y[a+1|0]!=1|(d|0)!=12))){o=E(30517578125e-15);f=x[k+2216>>2];if(!y[a+2|0]){break Xa}break Ta}if(!(y[a+1|0]!=2|(d|0)!=12|g)){o=E(30517578125e-15);f=x[k+2216>>2];if(!y[a+2|0]){break Va}break Ua}g=(f&255)!=32;if(g|(y[a+1|0]!=1|(d|0)!=13)){break Wa}o=E(1.1920928955078125e-7);f=x[k+2216>>2];if(y[a+2|0]){break Ta}}d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=f>>>2;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){q=cg((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));q=si(E(Pd(E((Jg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));Ya:{if(E(F(q))<E(2147483648)){g=~~q;break Ya}g=-2147483648}M=b,O=ed(g),w[M>>1]=O;b=b+2|0;e=e+4|0;f=f-1|0;continue}break}fb=a+16|0;f=d<<2;break v}f=0;if(y[a+1|0]!=2|(d|0)!=13|g){break v}o=E(1.1920928955078125e-7);f=x[k+2216>>2];if(y[a+2|0]){break Ua}}d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=f>>>3;x[a+8>>2]=d;d=x[Gb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){q=cg((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));q=si(E(Pd(E((Jg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));Za:{if(E(F(q))<E(2147483648)){g=~~q;break Za}g=-2147483648}M=b,O=ed(g),w[M>>1]=O;q=cg((l(2,y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24)),r()));q=si(E(Pd(E((Jg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));_a:{if(E(F(q))<E(2147483648)){g=~~q;break _a}g=-2147483648}M=b,O=ed(g),w[M+2>>1]=O;b=b+4|0;e=e+8|0;f=f-1|0;continue}break}fb=a+16|0;f=d<<3;break v}d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=f>>>3;x[a+8>>2]=d;g=x[Gb(a+12|0,a+8|0)>>2];f=g;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);q=cg((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));q=si(E(Pd(E((Jg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));$a:{if(E(F(q))<E(2147483648)){d=~~q;break $a}d=-2147483648}M=b,O=ed(d),w[M>>1]=O;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);q=cg((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));q=si(E(Pd(E((Jg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));ab:{if(E(F(q))<E(2147483648)){d=~~q;break ab}d=-2147483648}M=b,O=ed(d),w[M+2>>1]=O;b=b+4|0;e=e+8|0;f=f-1|0;continue}break}fb=a+16|0;f=g<<3;break v}d=x[b>>2];b=x[b+20>>2];a=fb-16|0;fb=a;x[a+12>>2]=f>>>2;x[a+8>>2]=d;g=x[Gb(a+12|0,a+8|0)>>2];f=g;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);q=cg((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));q=si(E(Pd(E((Jg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));bb:{if(E(F(q))<E(2147483648)){d=~~q;break bb}d=-2147483648}M=b,O=ed(d),w[M>>1]=O;b=b+2|0;e=e+4|0;f=f-1|0;continue}break}fb=a+16|0;f=g<<2;break v}a=T(28848)|0}if((gb|0)!=($(28848)|0)){break d}Y(a|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break w}}ub(e);break v}a=N()|0;break d}x[31725]=0;P(151,c|0,f+L|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break f}}Kc(H)}fb=k+2240|0;return f|0}a=N()|0;break a}a=N()|0}ub(e);break a}a=N()|0;break a}a=N()|0}Kc(H);Q(a|0);p()}function Osa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0;d=fb-608|0;fb=d;xc(b);f=fb-16|0;fb=f;h=d+416|0;nw(f+8|0,h);j=x[f+12>>2];g=b;kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(j|0)){Vb(g,x[f+12>>2])}fb=f+16|0;b=(b|0)==(j|0);if(!b){WZ(h)}a:{b:{c:{if(!b){break c}if(!YZ(d+416|0)){break c}if(!Mb(x[g>>2],x[g+8>>2],Bc(XZ(d+416|0),hb))){break c}if(!c){e=1;break c}Bd(a,32);v[d+415|0]=0;j=Fb(d+400|0);d:{e:{f:{g:{h:{i:{if((y[d+416|0]|y[d+417|0]<<8|(y[d+418|0]<<16|y[d+419|0]<<24))==778924148){x[31725]=0;O(419,a|0,16777216);b=x[31725];x[31725]=0;if((b|0)==1){break b}b=x[g>>2];x[31725]=0;b=R(156,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;P(151,g|0,b-4|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}x[31725]=0;t=R(153,g|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break i}break b}j:{k:{l:{m:{n:{o:{if(((y[d+456|0]|y[d+457|0]<<8)-2185&65535)>>>0>1910){break o}b=x[g>>2];x[31725]=0;b=R(156,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}x[31725]=0;P(151,g|0,b-4|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}x[31725]=0;t=R(153,g|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}if(t>>>0<256){break o}b=x[g>>2];x[31725]=0;b=R(156,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}if(b>>>0<=t>>>0){break o}x[31725]=0;b=P(151,g|0,t|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}if(!b){break o}x[31725]=0;b=R(420,g|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}if(!b){break o}x[31725]=0;O(419,a|0,16777216);b=x[31725];x[31725]=0;if((b|0)==1){break b}b=y[d+456|0]|y[d+457|0]<<8;if(b>>>0>=4096){x[31725]=0;c=P(1,d+160|0,16528)|0;b=x[31725];x[31725]=0;if((b|0)==1){break h}a=x[a+1298472>>2];x[31725]=0;S(387,a|0,1,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(c);break d}b=N()|0;tb(c);break a}if(b>>>0<2194){break o}x[31725]=0;e=P(1,d+388|0,16057)|0;b=x[31725];x[31725]=0;if((b|0)==1){break n}b=x[a+1298472>>2];x[31725]=0;S(387,b|0,4,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break m}tb(e)}if(x[a+480180>>2]!=32){break i}b=y[d+456|0]|y[d+457|0]<<8;if((b&61440)!=20480){break j}b=b&4095;e=b<<16;if((y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))!=1414548815){break l}v[d+415|0]=1;break k}b=N()|0;break a}b=N()|0;tb(e);break a}if(b>>>0<297){break k}e=y[d+476|0]|y[d+477|0]<<8|e}x[a+1074308>>2]=e;break i}e=y[d+458|0]|y[d+459|0]<<8;if(!((e|0)!=2184&(b|0)!=2184)){v[d+415|0]=1;x[a+1074308>>2]=18284544;break i}if((b|0)!=768){if((b|0)!=532|(e|0)!=514|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))){break i}x[a+1074308>>2]=17367040;x[31725]=0;b=P(1,d+376|0,14700)|0;e=x[31725];x[31725]=0;if((e|0)!=1){Ab(j,b);tb(b);v[d+415|0]=1;break i}b=N()|0;break a}if(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)|(e|0)!=768|((y[d+448|0]|y[d+449|0]<<8)!=256|y[d+468|0]!=128)){break i}if(y[d+469|0]){break i}x[a+1074308>>2]=18285088;v[d+415|0]=1}b=y[d+460|0]|y[d+461|0]<<8;e=b>>>2|0;x[a+480208>>2]=b<<3&32768|(e&8|(e&4|(x[a+480208>>2]&-32797|b<<1&16)));b=d+280|0;as(b,d+420|0);x[31725]=0;O(220,d+160|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break g}b=d+160|0;Ab(a+1298308|0,b);tb(b);if(!(!(y[d+462|0]&4)|x[a+1074308>>2]-18285314>>>0>4276681982)){x[a+480216>>2]=y[d+446|0];x[a+480220>>2]=y[d+447|0]}b=y[d+464|0];x[a+480200>>2]=b>>>0>128?256:b<<1;b=y[d+466|0];if(b){x[a+480196>>2]=b}v[d+160|0]=31;v[d+280|0]=y[d+467|0];b=d+160|0;e=d+280|0;M=a,T=D(y[ef(b,e)|0],1e4),x[M+480204>>2]=T;v[d+160|0]=y[d+465|0];v[d+280|0]=128;M=a,T=y[Rb(b,e)|0],x[M+480228>>2]=T;e=0;while(1){if((e|0)==64){p:{x[31725]=0;P(151,g|0,192)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}if(x[a+480180>>2]==16777216&((y[d+456|0]|y[d+457|0]<<8)-2187&65535)>>>0<=2){break p}b=y[a+484376|0];e=x[a+484360>>2];x[31725]=0;aa(350,Xb(e,b)|0,g|0,y[d+448|0]|y[d+449|0]<<8,255,254);b=x[31725];x[31725]=0;if((b|0)==1){break b}break e}}else{h=(d+416|0)+e|0;i=h- -64|0;q:{if(y[i|0]==255){break q}f=(e<<5)+a|0;b=f+480280|0;Xe(b);M=f+480286|0,T=Kd(y[h+128|0],0,64),w[M>>1]=T;h=v[i|0];if((h|0)<0){x[b>>2]=x[b>>2]|1024}h=h&127;if(h>>>0<=64){w[f+480284>>1]=h<<2;break q}if((h|0)!=100){break q}x[b>>2]=x[b>>2]|256}e=e+1|0;continue}break}e=0;x[31725]=0;b=R(191,g|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break f}if(b){break d}x[31725]=0;b=R(153,g|0)|0;f=x[31725];x[31725]=0;r:{if((f|0)==1){break r}if(b>>>0>4e3){break d}f=y[a+484376|0];h=x[a+484360>>2];x[31725]=0;b=U(421,Xb(h,f)|0,g|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break r}if(!b){break d}break e}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}r=Nb(d+364|0);o=Nb(d+352|0);e=0;n=Nb(d+340|0);x[31725]=0;b=U(422,g|0,r|0,y[d+450|0]|y[d+451|0]<<8)|0;f=x[31725];x[31725]=0;s:{t:{u:{if((f|0)==1){break u}if(!b){break s}x[31725]=0;b=U(422,g|0,o|0,y[d+452|0]|y[d+453|0]<<8)|0;f=x[31725];x[31725]=0;if((f|0)==1){break u}if(!b){break s}x[31725]=0;b=U(422,g|0,n|0,y[d+454|0]|y[d+455|0]<<8)|0;f=x[31725];x[31725]=0;if((f|0)==1){break u}if(!b){break s}x[d+336>>2]=-1;M=d,T=wb(x[r>>2]),x[M+160>>2]=T;f=wb(x[r+4>>2]);b=x[d+336>>2];while(1){e=x[d+160>>2];if(Ib(e,f)){e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|b>>>0<=e>>>0)){x[d+336>>2]=e;b=e}Je(d+160|0);continue}else{M=d,T=wb(x[o>>2]),x[M+160>>2]=T;f=wb(x[o+4>>2]);b=x[d+336>>2];while(1){e=x[d+160>>2];if(Ib(e,f)){e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|b>>>0<=e>>>0)){x[d+336>>2]=e;b=e}Je(d+160|0);continue}else{M=d,T=wb(x[n>>2]),x[M+160>>2]=T;f=wb(x[n+4>>2]);b=x[d+336>>2];v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{while(1){e=x[d+160>>2];if(Ib(e,f)){e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|b>>>0<=e>>>0)){x[d+336>>2]=e;b=e}Je(d+160|0);continue}else{if(v[d+462|0]&1){x[d+160>>2]=y[d+472|0]|y[d+473|0]<<8|(y[d+474|0]<<16|y[d+475|0]<<24);b=x[Gb(d+336|0,d+160|0)>>2];x[d+336>>2]=b}e=0;if((y[d+458|0]|y[d+459|0]<<8)!=532){break D}f=y[d+456|0]|y[d+457|0]<<8;if(y[d+447|0]|(f?(f|0)!=532:0)|(y[d+446|0]|y[d+469|0])){break D}if(y[d+460|0]&192|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))){break D}if(y[d+450|0]|y[d+451|0]<<8){break E}f=y[d+452|0]|y[d+453|0]<<8;if(!f){break E}if((x[g+8>>2]+(oc(x[o>>2],x[o+4>>2])<<2)|0)+2>>>0>b>>>0){break E}}break}while(1){if((e&65535)>>>0<(f&65535)>>>0){x[31725]=0;b=R(153,g|0)|0;f=x[31725];x[31725]=0;F:{if((f|0)!=1){if(!b){break F}Gh(g,((e&65535)<<2)+4|0);break E}b=N()|0;break t}e=e+1|0;f=y[d+452|0]|y[d+453|0]<<8;continue}break}x[31725]=0;b=P(1,d+324|0,14973)|0;e=x[31725];x[31725]=0;if((e|0)==1){break C}Ab(j,b);tb(b)}e=1;if(y[d+456|0]|y[d+457|0]<<8){break D}x[31725]=0;b=P(1,d+312|0,15480)|0;f=x[31725];x[31725]=0;if((f|0)==1){break B}Ab(j,b);tb(b)}b=y[d+462|0]|y[d+463|0]<<8;G:{if(b&2){x[31725]=0;f=R(191,g|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break w}b=x[g+8>>2];h=x[g>>2];x[31725]=0;i=b;b=f<<3;h=U(152,h|0,i|0,b|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break w}if(!(!h|A[d+336>>2]<b+x[g+8>>2]>>>0)){x[31725]=0;O(423,a+1298412|0,f|0);b=x[31725];x[31725]=0;if((b|0)==1){break w}M=d,T=wb(x[a+1298412>>2]),x[M+280>>2]=T;h=wb(x[a+1298416>>2]);H:{I:{while(1){b=x[d+280>>2];if(!Ib(b,h)){if(!(!f&e)){break G}if(!(y[d+462|0]&4)){break H}x[31725]=0;b=P(1,d+300|0,15513)|0;e=x[31725];x[31725]=0;if((e|0)==1){break I}Ab(j,b);tb(b);break G}x[31725]=0;O(424,g|0,d+160|0);i=x[31725];x[31725]=0;if((i|0)!=1){x[b>>2]=0;x[b+4>>2]=0;x[b+24>>2]=0;x[b+28>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b+16>>2]=0;i=y[d+160|0]|y[d+161|0]<<8;if(i|(y[d+162|0]|y[d+163|0]<<8)){x[b>>2]=((i&65024)>>>9|0)+1980;M=b,T=Yb((y[d+160|0]|y[d+161|0]<<8)>>>5&15,1,12),x[M+4>>2]=T;M=b,T=Yb((y[d+160|0]|y[d+161|0]<<8)&31,1,31),x[M+8>>2]=T;M=b,T=Yb((y[d+162|0]|y[d+163|0]<<8)>>>11|0,0,23),x[M+12>>2]=T;M=b,T=Yb((y[d+162|0]|y[d+163|0]<<8)>>>5&63,0,59),x[M+16>>2]=T;i=Yb((y[d+162|0]|y[d+163|0]<<8)<<1&62,0,59);x[b+24>>2]=i;x[b+28>>2]=i>>31}x[b+32>>2]=y[d+164|0]|y[d+165|0]<<8|(y[d+166|0]<<16|y[d+167|0]<<24);x[d+280>>2]=x[d+280>>2]+40;continue}break}b=N()|0;break t}b=N()|0;break t}x[31725]=0;b=P(1,d+300|0,14995)|0;e=x[31725];x[31725]=0;if((e|0)!=1){Ab(j,b);tb(b);break G}b=N()|0;break t}Gh(g,2);break G}if(e^1|b>>>0>1){break G}x[31725]=0;b=R(191,g|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break v}if(!b){x[31725]=0;b=P(1,d+300|0,14973)|0;e=x[31725];x[31725]=0;if((e|0)!=1){Ab(j,b);tb(b);break G}b=N()|0;break t}Gh(g,2)}J:{if(!(y[d+460|0]&128|y[d+462|0]&8)){break J}x[31725]=0;b=a+901404|0;e=P(425,g|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break A}if(!e){break J}zD(b)}if((y[d+456|0]|y[d+457|0]<<8)>>>0<=531){sr(a+901404|0)}x[31725]=0;u=R(170,d+280|0)|0;b=x[31725];x[31725]=0;K:{L:{M:{if((b|0)!=1){x[31725]=0;e=P(414,g|0,13890)|0;b=x[31725];x[31725]=0;if((b|0)==1){break M}if(e){x[31725]=0;b=R(153,g|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break L}x[31725]=0;S(187,d+260|0,g|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break L}b=d+260|0;f=ic(d+160|0,b);hd(u,f);ub(f);ub(b)}w[a+480188>>1]=1;x[31725]=0;b=P(414,g|0,13895)|0;f=x[31725];x[31725]=0;if((f|0)==1){break M}if(!b){break y}x[31725]=0;b=R(153,g|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;S(187,d+260|0,g|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break K}}b=N()|0;break x}b=N()|0;break t}b=N()|0;break x}b=N()|0;break x}b=d+260|0;f=ic(d+160|0,b);ub(b);b=x[f>>2];x[31725]=0;b=R(156,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break z}w[d+260>>1]=(b>>>0)/20;b=z[Nc(25012,d+260|0)>>1];w[a+480188>>1]=b;e=0;while(1){if((b|0)==(e|0)){ub(f);e=1;break y}x[31725]=0;S(426,f|0,((e<<5)+a|0)+480289|0,20);h=x[31725];x[31725]=0;if((h|0)!=1){e=e+1|0;continue}break}break z}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;ub(f);break x}N:{O:{P:{Q:{R:{S:{T:{U:{V:{b=x[d+336>>2];f=x[g+8>>2];W:{if(b>>>0>=f>>>0){b=b-f|0;break W}x[31725]=0;b=R(204,g|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break V}}x[31725]=0;S(187,d+160|0,g|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break V}b=d+160|0;B=ic(d+260|0,b);ub(b);x[31725]=0;S(427,d+258|0,a|0,B|0);b=x[31725];x[31725]=0;if((b|0)==1){break U}C=Jc(d+258|0);E=y[d+258|0]!=0|e;if((y[d+456|0]|y[d+457|0]<<8)!=535|(y[d+458|0]|y[d+459|0]<<8)!=512|(y[C|0]|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)))){break Q}X:{if(E){break X}e=Xb(x[a+484360>>2],y[a+484376|0]);b=x[e+4>>2];if(!lc(x[e>>2],b)){if(z[On(b)>>1]==65535){break X}}if(!gu(d+480|0,255,64)){break S}}x[a+1074308>>2]=18219008;x[31725]=0;b=P(1,d+244|0,14830)|0;e=x[31725];x[31725]=0;if((e|0)==1){break T}break R}b=N()|0;break x}b=N()|0;break N}b=N()|0;break N}x[a+1074308>>2]=18284544;x[31725]=0;b=P(1,d+244|0,16879)|0;e=x[31725];x[31725]=0;if((e|0)==1){break P}}Ab(j,b);tb(b);v[d+415|0]=1}Y:{if(!(v[d+462|0]&1)|!(y[d+470|0]|y[d+471|0]<<8)){break Y}x[31725]=0;b=P(151,g|0,y[d+472|0]|y[d+473|0]<<8|(y[d+474|0]<<16|y[d+475|0]<<24))|0;e=x[31725];x[31725]=0;if((e|0)==1){break O}if(!b){break Y}x[31725]=0;V(338,a+1298332|0,g|0,y[d+470|0]|y[d+471|0]<<8,4);b=x[31725];x[31725]=0;if((b|0)==1){break O}}w[a+480192>>1]=0;b=0;if(y[d+460|0]&4){w[d+160>>1]=y[d+450|0]|y[d+451|0]<<8;w[d+100>>1]=255;b=z[Nc(d+160|0,d+100|0)>>1];w[a+480192>>1]=b}e=0;Z:{while(1){if((b&65535)>>>0<=e>>>0){x[d+240>>2]=0;e=y[d+452|0]|y[d+453|0]<<8;if(e){b=yb(x[o>>2],e-1|0);x[d+240>>2]=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))+80}w[d+160>>1]=e;w[d+100>>1]=3999;b=z[Nc(d+160|0,d+100|0)>>1];w[a+480190>>1]=b;m=c&2;s=d+180|0;e=0;while(1){_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{if((b&65535)>>>0>e>>>0){b=yb(x[o>>2],e);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!b){break $}x[31725]=0;b=P(151,g|0,b|0)|0;f=x[31725];x[31725]=0;ha:{ia:{ja:{ka:{la:{if((f|0)==1){break la}if(!b){break $}x[31725]=0;b=P(428,g|0,d+160|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break la}if(!b){break $}x[31725]=0;b=e+1|0;f=D(b,104)+a|0;i=f+484380|0;h=P(429,d+160|0,i|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break ka}k=d+148|0;as(k,s);x[31725]=0;O(220,d+100|0,k|0);k=x[31725];x[31725]=0;if((k|0)==1){break ja}k=d+100|0;zc(((b<<5)+a|0)+946304|0,k);tb(k);x[31725]=0;h=P(151,g|0,h|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break ka}if(!h){break $}f=z[f+484414>>1];if(!(f&512)){break ia}x[31725]=0;b=P(430,g|0,d+100|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ga}if(!b){break ha}x[d+16>>2]=y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24);b=y[d+104|0]|y[d+105|0]<<8|(y[d+106|0]<<16|y[d+107|0]<<24);x[d+8>>2]=y[d+100|0]|y[d+101|0]<<8|(y[d+102|0]<<16|y[d+103|0]<<24);x[d+12>>2]=b;_k(i,1,d+8|0);break ha}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}if(!(f&16384)){q=y[d+456|0]|y[d+457|0]<<8;h=y[d+178|0];k=h&2;b=y[d+206|0];f=Xc(d+100|0,k?16:8,1,0,(b^-1)&1);if(!(!(h&4)|q>>>0<532)){Dp(f,3)}ma:{na:{if(h&8){h=b&4?5:4;break na}if(!k){h=10;if((b|0)==255){break na}}if(b&2){v[f+2|0]=1}if(b&4){yg(f,2)}if(!(b&8)){break ma}h=9;if(!k){break ma}}yg(f,h)}if(m){b=0;x[31725]=0;U(217,d+100|0,i|0,g|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break ca}break _}b=1;f=y[d+103|0];if(f>>>0>17){break ba}h=1<<f;if(!(h&63503)){if(!(h&198144)){break ba}break da}if(y[d+100|0]){break da}break ca}x[31725]=0;O(431,g|0,d+88|0);f=x[31725];x[31725]=0;if((f|0)==1){break ea}h=x[d+88>>2];if(!(!m|!h)){f=Fb(d+100|0);x[31725]=0;S(272,g|0,f|0,h|0);h=x[31725];x[31725]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((h|0)!=1){x[31725]=0;O(385,d+136|0,16450);h=x[31725];x[31725]=0;if((h|0)==1){break ua}x[d+76>>2]=b;x[31725]=0;S(260,d+124|0,0,f|0);b=x[31725];x[31725]=0;if((b|0)==1){break ta}x[31725]=0;V(432,d+148|0,d+136|0,d+76|0,d+124|0);b=x[31725];x[31725]=0;if((b|0)==1){break sa}b=x[a+1298472>>2];x[31725]=0;S(387,b|0,2,d+148|0);b=x[31725];x[31725]=0;if((b|0)==1){break ra}tb(d+148|0);tb(d+124|0);Eb(d+136|0);tb(f);break ha}b=N()|0;break oa}b=N()|0;break oa}b=N()|0;break pa}b=N()|0;break qa}b=N()|0;tb(d+148|0)}tb(d+124|0)}Eb(d+136|0)}tb(f);break N}x[31725]=0;P(185,g|0,h|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break ea}}b=0;break aa}w[d+160>>1]=1;w[d+100>>1]=b;M=a,T=z[qe(d+160|0,d+100|0)>>1],w[M+480190>>1]=T;if(!((y[d+456|0]|y[d+457|0]<<8)==516&l)|(y[d+458|0]|y[d+459|0]<<8)!=512|(y[d+462|0]|y[d+463|0]<<8|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)))){break fa}if(((y[d+460|0]|y[d+461|0]<<8)&65527)!=21|y[d+464|0]!=128|(y[d+465|0]!=48|y[d+468|0]!=128)){break fa}if(y[d+469|0]|(y[d+470|0]|y[d+471|0]<<8)){break fa}b=d+544|0;f=d+480|0;e=1;while(1)if((b|0)==(f|0)){f=d+608|0;while(1)if((b|0)==(f|0)){b=20;while(1){if((b|0)==26){va:{if(!(e&1)){break fa}x[31725]=0;b=P(1,d+148|0,9879)|0;e=x[31725];x[31725]=0;if((e|0)==1){break va}Ab(j,b);tb(b);break fa}}else{e=!y[(b+d|0)+420|0]&e;b=b+1|0;continue}break}b=N()|0;break N}else{e=y[b|0]==64&e;b=b+1|0;continue}}else{e=(y[f|0]&127)==32&e;f=f+1|0;continue}}b=N()|0;break N}x[a+480260>>2]=0;x[a+480264>>2]=2147483647;b=oc(x[n>>2],x[n+4>>2]);w[d+160>>1]=b;s=z[Nc(d+160|0,x[a+8>>2]+10|0)>>1];w[d+122>>1]=s;wa:{xa:{ya:{za:{if((b|0)!=(s|0)){x[31725]=0;W(433,d+100|0);b=x[31725];x[31725]=0;if((b|0)==1){break wa}b=x[n+4>>2];e=x[n>>2];x[31725]=0;M=d,T=oc(e,b),x[M+136>>2]=T;V(434,d+160|0,d+100|0,d+136|0,d+122|0);b=x[31725];x[31725]=0;if((b|0)==1){break ya}b=x[a+1298472>>2];x[31725]=0;S(387,b|0,2,d+160|0);b=x[31725];x[31725]=0;if((b|0)==1){break za}tb(d+160|0);Eb(d+100|0)}if(!(c&1)){w[d+122>>1]=0;s=0}h=0;Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{while(1){Ra:{if((h|0)==(s|0)){b=x[d+240>>2];if(!b){break Oa}x[31725]=0;P(151,g|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Qa}if(!q){break Oa}while(1){Sa:{b=x[g+8>>2];c=x[g>>2];x[31725]=0;b=U(152,c|0,b|0,4)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Sa}if(!b){break Oa}x[31725]=0;b=P(414,g|0,13869)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Sa}Ta:{if(!b){x[31725]=0;b=P(414,g|0,13874)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Sa}if(!b){break Ta}}x[31725]=0;b=R(153,g|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Pa}Gh(g,8);if(b&-2139062144){break Ta}if(b&1616928864){break Oa}}x[31725]=0;b=R(191,g|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Sa}x[31725]=0;P(185,g|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}b=N()|0;break N}Ua:{b=yb(x[n>>2],h);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);Va:{if(!b){break Va}x[31725]=0;b=P(151,g|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Na}if(!b){break Va}x[31725]=0;b=R(191,g|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Aa}x[31725]=0;m=R(191,g|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ba}if((m-1025&65535)>>>0<64512){break Va}x[31725]=0;c=P(185,g|0,4)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ba}if(!c){break Va}x[31725]=0;S(187,d+100|0,g|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break Ca}b=d+100|0;f=ic(d+160|0,b);ub(b);b=z[a+480188>>1];l=0;x[31725]=0;i=P(435,d+136|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Ea}Wa:{while(1){if(l>>>0>=m>>>0){break Wa}b=x[f>>2];x[31725]=0;b=U(152,b|0,x[d+168>>2],1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ua}if(!b){break Wa}x[31725]=0;b=R(199,f|0)|0;c=x[31725];x[31725]=0;Xa:{if((c|0)!=1){c=b<<24>>24;if(c){break Xa}l=l+1|0;continue}break Ra}Ya:{b=c&127;k=b?b-1|0:0;b=k&65535;if(Sc(x[i>>2],x[d+140>>2])>>>0>b>>>0){break Ya}x[31725]=0;v[d+100|0]=0;S(436,i|0,b+1|0,d+100|0);e=x[31725];x[31725]=0;if((e|0)!=1){break Ya}break Ra}Za:{if((c|0)<0){x[31725]=0;c=R(199,f|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Za}M=xb(x[i>>2],b),T=c,v[M|0]=T}e=xb(x[i>>2],b);c=y[e|0];if(!(!(c&15)|b>>>0<z[a+480188>>1])){w[a+480188>>1]=k+1;c=y[e|0]}if(c&1){x[31725]=0;P(185,f|0,1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Za}e=xb(x[i>>2],b)}if(y[e|0]&2){x[31725]=0;P(185,f|0,1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Za}e=xb(x[i>>2],b)}if(y[e|0]&4){x[31725]=0;P(185,f|0,1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Za}e=xb(x[i>>2],b)}if(!(y[e|0]&8)){continue}x[31725]=0;P(185,f|0,2)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break Ra}x[d+100>>2]=x[g+8>>2];M=d,T=x[ad(d+240|0,d+100|0)>>2],x[M+240>>2]=T;dc(i);ub(f)}h=h+1|0;continue}}break}b=N()|0;dc(i);break Da}b=N()|0;break N}b=N()|0;break N}x[31725]=0;F=P(437,a|0,g|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){b=y[d+415|0]|F;v[d+415|0]=b;if(!(y[C|0]|!(b&255))){Qv(a+1074312|0);v[a+1074368|0]=0}x[31725]=0;H=ba(438,a|0,g|0,0,d+415|0)|0;b=x[31725];x[31725]=0;_a:{if((b|0)==1){break _a}x[31725]=0;q=a+484344|0;O(225,q|0,s|0);b=x[31725];x[31725]=0;if((b|0)==1){break _a}L=a+480183|0;h=0;while(1){$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{if((h|0)!=(s|0)){b=yb(x[n>>2],h);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(b){x[31725]=0;b=P(151,g|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break nb}if(b){break mb}}x[31725]=0;b=U(198,q|0,h&65535,64)|0;c=x[31725];x[31725]=0;if((c|0)==1){break nb}if(b){break ob}w[d+64>>1]=h;x[31725]=0;W(439,d+100|0);b=x[31725];x[31725]=0;if((b|0)==1){break sb}x[31725]=0;S(440,d+160|0,d+100|0,d- -64|0);b=x[31725];x[31725]=0;if((b|0)==1){break rb}b=x[a+1298472>>2];x[31725]=0;S(387,b|0,2,d+160|0);b=x[31725];x[31725]=0;if((b|0)==1){break qb}tb(d+160|0);Eb(d+100|0)}if(!x[a+1074308>>2]){e=y[d+456|0]|y[d+457|0]<<8;if((e|0)!=2184){break kb}x[a+1074308>>2]=18284544}if(!Ad(x[j+4>>2],y[j+11|0])){break lb}x[31725]=0;c=P(1,d+100|0,18237)|0;b=x[31725];x[31725]=0;if((b|0)==1){break bb}b=x[a+1074308>>2];x[31725]=0;O(136,d+76|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break db}x[31725]=0;S(2,d+160|0,c|0,d+76|0);b=x[31725];x[31725]=0;if((b|0)==1){break eb}e=d+160|0;b=Ab(j,e);tb(e);tb(d+76|0);tb(c);e=x[a+1074308>>2];if((y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))==1414548815){break jb}if((e|0)!=18284544){break ib}e=18284544;if(!(E|H|F)){break hb}break gb}b=N()|0;break N}b=N()|0;break pb}b=N()|0;tb(d+160|0)}Eb(d+100|0);break N}b=x[q>>2];x[31725]=0;O(441,Wb(b,h)|0,u|0);b=x[31725];x[31725]=0;if((b|0)!=1){break $a}}b=N()|0;break N}x[31725]=0;b=R(191,g|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Fa}x[31725]=0;I=R(191,g|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ga}x[31725]=0;c=P(185,g|0,4)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ga}if(!c){break $a}x[31725]=0;c=U(198,q|0,h&65535,I|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ga}if(!c){break $a}x[31725]=0;S(187,d+100|0,g|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break Ha}b=d+100|0;m=ic(d+160|0,b);ub(b);b=x[q>>2];x[31725]=0;O(441,Wb(b,h)|0,u|0);b=x[31725];x[31725]=0;if((b|0)==1){break Ja}b=z[a+480188>>1];x[31725]=0;k=P(435,d+124|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Ka}b=z[a+480188>>1];w[d+104>>1]=0;x[31725]=0;x[d+100>>2]=0;l=U(442,d+88|0,b|0,d+100|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Ma}M=d,T=wb(x[Wb(x[q>>2],h)>>2]),x[M+76>>2]=T;G=0;while(1){tb:{ub:{vb:{wb:{if(G>>>0>=I>>>0){break wb}b=x[m>>2];x[31725]=0;b=U(152,b|0,x[d+168>>2],1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ab}if(!b){break wb}x[31725]=0;b=R(199,m|0)|0;c=x[31725];x[31725]=0;xb:{if((c|0)!=1){b=b<<24>>24;if(b){break xb}K_(d+76|0,z[a+480188>>1]);G=G+1|0;continue}break ab}yb:{c=b&127;i=c?c-1&65535:0;if(Sc(x[k>>2],x[d+128>>2])>>>0>i>>>0){break yb}x[31725]=0;v[d+100|0]=0;c=i+1|0;S(436,k|0,c|0,d+100|0);e=x[31725];x[31725]=0;if((e|0)==1){break ab}w[d+104>>1]=0;x[31725]=0;x[d+100>>2]=0;S(443,l|0,c|0,d+100|0);c=x[31725];x[31725]=0;if((c|0)!=1){break yb}break ab}if((b|0)<0){x[31725]=0;b=R(199,m|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ab}M=xb(x[k>>2],i),T=b,v[M|0]=T}w[d+104>>1]=0;x[d+100>>2]=0;b=d+100|0;if(i>>>0<z[a+480188>>1]){b=Wc(x[d+76>>2],i)}f=xb(x[k>>2],i);e=y[f|0];if(e&16){M=b,T=y[Wc(x[l>>2],i)|0],v[M|0]=T;e=y[f|0]}if(e&32){M=b,T=y[Wc(x[l>>2],i)+1|0],v[M+1|0]=T;e=y[f|0]}if(e&64){c=Wc(x[l>>2],i);v[b+2|0]=y[c+2|0];v[b+4|0]=y[c+4|0];e=y[f|0]}if(e<<24>>24<0){c=Wc(x[l>>2],i);v[b+3|0]=y[c+3|0];v[b+5|0]=y[c+5|0];e=y[f|0]}if(e&1){x[31725]=0;c=R(199,m|0)|0;e=x[31725];x[31725]=0;zb:{Ab:{if((e|0)!=1){c=c<<24>>24;c=(((c^-1)&128)>>>7|0)+c|0;if(!(v[L|0]&1)){break Ab}e=c;break zb}break ab}e=253;if((c-121&255)>>>0<132){break zb}e=(c&255)!=253?c:0}v[b|0]=e;M=Wc(x[l>>2],i),T=e,v[M|0]=T;f=xb(x[k>>2],i)}if(y[f|0]&2){x[31725]=0;c=R(199,m|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break ab}v[b+1|0]=c;M=Wc(x[l>>2],i),T=c,v[M+1|0]=T;f=xb(x[k>>2],i)}if(!(y[f|0]&4)){break tb}x[31725]=0;f=R(199,m|0)|0;c=x[31725];x[31725]=0;Bb:{Cb:{if((c|0)!=1){if(f>>>0>64){break Cb}v[b+4|0]=f;e=1;break Bb}break ab}if(f<<24>>24<=-64){e=2;v[b+2|0]=2;f=f^-128;v[b+4|0]=f;break ub}if(f>>>0<=74){e=5;v[b+2|0]=5;f=f-65|0;v[b+4|0]=f;break ub}if(f>>>0<=84){e=6;v[b+2|0]=6;f=f-75|0;v[b+4|0]=f;break ub}if(f>>>0<=94){e=3;v[b+2|0]=3;f=f-85|0;v[b+4|0]=f;break ub}if(f>>>0<=104){e=4;v[b+2|0]=4;f=f-95|0;v[b+4|0]=f;break ub}if(f>>>0<=114){e=13;v[b+2|0]=13;f=f-105|0;v[b+4|0]=f;break ub}if(f>>>0<=124){e=12;v[b+2|0]=12;f=f-115|0;v[b+4|0]=f;break ub}c=f+63|0;if((c&255)>>>0<=9){v[b+4|0]=c;e=11;v[b+2|0]=11;f=c;break ub}c=f+53|0;J=c&255;if(J>>>0<=9){v[b+4|0]=c;e=8;v[b+2|0]=8;if(!J){f=0;break ub}if(x[a+1074308>>2]-1>>>0>18285139){break vb}e=7;v[b+2|0]=7;break vb}f=f+33|0;if((f&255)>>>0>=10){f=y[b+4|0];e=y[b+2|0];break ub}v[b+4|0]=f;e=15}v[b+2|0]=e;break ub}Sk(l);dc(k);ub(m);break $a}f=c}c=Wc(x[l>>2],i);v[c+4|0]=f;v[c+2|0]=e;f=xb(x[k>>2],i)}if(!(y[f|0]&8)){continue}x[31725]=0;O(200,d+52|0,m|0);c=x[31725];x[31725]=0;if((c|0)!=1){xD(b,y[d+52|0],y[Jc(d+52|0)|0],1);c=Wc(x[l>>2],i);v[c+3|0]=y[b+3|0];v[c+5|0]=y[b+5|0];continue}break}break ab}e=y[d+456|0]|y[d+457|0]<<8}Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{b=e&65535;switch(b>>>12|0){case 13:break Ib;case 7:break Jb;case 6:break Kb;case 4:break Lb;case 1:break Nb;case 0:break Ob;default:break fb}}if(y[C|0]){x[31725]=0;b=P(1,d+160|0,8340)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Ab(j,b);tb(b);break fb}b=N()|0;break N}Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{c=e&65535;if((c|0)!=532){break Xb}b=y[d+458|0]|y[d+459|0]<<8;if((b|0)!=512){break Wb}if(y[d+462|0]|y[d+463|0]<<8|(y[d+460|0]|y[d+461|0]<<8)!=9|(y[d+447|0]|y[d+446|0])){break Xb}if(y[d+450|0]|y[d+451|0]<<8|((y[d+454|0]|y[d+455|0]<<8)+1|0)!=(y[d+448|0]|y[d+449|0]<<8)|(y[d+464|0]!=128|y[d+465|0]!=100)){break Xb}if(y[d+466|0]!=1|y[d+468|0]!=128|(y[d+469|0]|(y[d+470|0]|y[d+471|0]<<8))){break Xb}if(y[d+472|0]|y[d+473|0]<<8|(y[d+474|0]<<16|y[d+475|0]<<24)|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))){break Xb}x[31725]=0;b=P(1,d+160|0,9860)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Ab(j,b);tb(b);break fb}b=N()|0;break N}Yb:{if((c|0)!=514|(y[d+458|0]|y[d+459|0]<<8)!=512|(y[d+447|0]|y[d+446|0])){break Yb}if(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)){break Yb}b=x[n>>2];if(lc(b,x[n+4>>2])){break Ub}c=x[o>>2];if(lc(c,x[o+4>>2])){break Ub}b=yb(b,0);f=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!f){break Ub}b=yb(c,0);if(f>>>0>=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0){break Ub}x[a+1074308>>2]=16777376;x[31725]=0;b=P(1,d+160|0,13471)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Ab(j,b);tb(b);v[d+415|0]=1;break fb}b=N()|0;break N}if((e&65535)!=532){break Vb}b=y[d+458|0]|y[d+459|0]<<8;if((b|0)!=512){break Wb}e=532;if(y[d+447|0]|y[d+446|0]){break Eb}b=512;if(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)){break Db}Zb:{if(y[d+462|0]&6){_b:{c=x[r>>2];if(oc(c,x[r+4>>2])>>>0<2){break _b}b=yb(c,1);e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);b=yb(c,0);if((e-(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|0)!=557){break _b}x[a+1074308>>2]=16777394;x[31725]=0;c=P(1,d+160|0,15199)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break Zb}b=N()|0;break N}x[a+1074308>>2]=16777393;x[31725]=0;c=P(1,d+160|0,13361)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break Zb}b=N()|0;break N}x[a+1074308>>2]=16777381;x[31725]=0;c=P(1,d+160|0,14911)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Hb}}Ab(j,c);tb(c);v[d+415|0]=1;break fb}e=532;if((b|0)!=532){break Tb}if((y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))==1229080643){x[31725]=0;b=P(1,d+160|0,8378)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Ab(j,b);tb(b);b=38;break Mb}b=N()|0;break N}if(y[d+469|0]|(y[d+462|0]|y[d+463|0]<<8)>>>0>1|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)|((y[d+460|0]|y[d+461|0]<<8)&4294)!=4)){break Ub}if(!z[a+480190>>1]){break Ub}x[31725]=0;e=P(36,d+100|0,13604)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Rb}b=fb-32|0;fb=b;c=fb-16|0;fb=c;Pw(c+8|0,a+484527|0);BZ(b+24|0,x[c+8>>2],x[c+12>>2]);fb=c+16|0;ee(b+16|0,e);c=x[b+20>>2];x[b+8>>2]=x[b+16>>2];x[b+12>>2]=c;c=Ic(x[b+24>>2],x[b+28>>2],b+8|0);fb=b+32|0;tb(e);if(c){break Sb}e=y[d+456|0]|y[d+457|0]<<8}if(e&65535){break Ub}if(Ad(x[j+4>>2],y[j+11|0])){break Pb}}b=y[d+458|0]|y[d+459|0]<<8}if((b&65535)>>>0>767){break fb}break Db}x[31725]=0;b=P(1,d+160|0,8404)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Qb}Ab(j,b);tb(b);break fb}b=N()|0;break N}b=N()|0;break N}x[31725]=0;b=P(1,d+160|0,9750)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Ab(j,b);tb(b);break fb}b=N()|0;break N}c=y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24);x[31725]=0;S(444,d+160|0,b|0,y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24));e=x[31725];x[31725]=0;$b:{ac:{bc:{cc:{dc:{ec:{fc:{gc:{hc:{if((e|0)!=1){e=d+160|0;Ab(j,e);tb(e);c=(b|0)==8191?c:b-4176|0;if((c|0)>1915){break hc}b=x[a+480208>>2];if(!(b&16)){break gc}x[31725]=0;P(269,a+1074312|0,7)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break fc}break Fb}b=N()|0;break N}if(c>>>0>4200){break dc}b=x[a+480208>>2]}if(!(b&16)){x[31725]=0;P(269,a+1074312|0,7)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Fb}}if((c|0)>2385){break ec}}x[31725]=0;P(269,a+1074312|0,38)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Fb}}x[31725]=0;b=P(269,a+1074312|0,102)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Fb}x[31725]=0;P(269,b|0,48)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Fb}break cc}if(c>>>0>4383){break bc}}x[31725]=0;b=U(268,a+1074312|0,116,1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Fb}x[31725]=0;P(269,b|0,115)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Fb}break ac}if(c>>>0>4563){break $b}}x[31725]=0;b=P(269,a+1074312|0,43)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Fb}x[31725]=0;b=P(269,b|0,42)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Fb}x[31725]=0;P(269,b|0,87)|0;c=x[31725];x[31725]=0;b=120;if((c|0)==1){break Fb}break Mb}b=120;if(c>>>0>4876){break fb}}x[31725]=0;P(269,a+1074312|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Fb}break fb}x[31725]=0;W(445,d+100|0);b=x[31725];x[31725]=0;ic:{jc:{kc:{if((b|0)!=1){b=y[d+456|0]|y[d+457|0]<<8;x[d+64>>2]=b>>>8&15;x[31725]=0;x[d+52>>2]=b&255;O(446,d+76|0,d+52|0);b=x[31725];x[31725]=0;if((b|0)==1){break kc}x[31725]=0;V(432,d+160|0,d+100|0,d- -64|0,d+76|0);b=x[31725];x[31725]=0;if((b|0)==1){break jc}b=d+160|0;Ab(j,b);tb(b);tb(d+76|0);Eb(d+100|0);break fb}b=N()|0;break N}b=N()|0;break ic}b=N()|0;tb(d+76|0)}Eb(d+100|0);break N}x[31725]=0;b=P(1,d+160|0,8340)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Ab(j,b);tb(b);break fb}b=N()|0;break N}if(!((b|0)!=32767|(y[d+458|0]|y[d+459|0]<<8)!=533)){x[31725]=0;b=P(1,d+160|0,5042)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Ab(j,b);tb(b);break fb}b=N()|0;break N}x[31725]=0;O(133,d+100|0,4150);b=x[31725];x[31725]=0;lc:{if((b|0)!=1){b=y[d+456|0]|y[d+457|0]<<8;x[d+76>>2]=b>>>8&15;x[d+64>>2]=b>>>4&15;x[31725]=0;x[d+52>>2]=b&15;aa(134,d+160|0,d+100|0,d+76|0,d- -64|0,d+52|0);b=x[31725];x[31725]=0;if((b|0)==1){break lc}b=d+160|0;Ab(j,b);tb(b);Eb(d+100|0);break fb}b=N()|0;break N}b=N()|0;Eb(d+100|0);break N}x[31725]=0;b=P(1,d+160|0,6123)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Gb}Ab(j,b);tb(b);break fb}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=512}if(!Ad(x[j+4>>2],y[j+11|0])){break fb}mc:{nc:{oc:{pc:{qc:{if((b&65535)>>>0>=533){x[31725]=0;b=P(1,d+76|0,14943)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Ab(j,b);tb(b);break qc}b=N()|0;break N}if((e&65535)>>>0>=533){x[31725]=0;O(447,d+76|0,4015);b=x[31725];x[31725]=0;rc:{if((b|0)!=1){x[31725]=0;x[d+64>>2]=(y[d+456|0]|y[d+457|0]<<8)-532;S(448,d+160|0,d+76|0,d- -64|0);b=x[31725];x[31725]=0;if((b|0)==1){break rc}b=d+160|0;Ab(j,b);tb(b);Eb(d+76|0);break qc}b=N()|0;break N}b=N()|0;Eb(d+76|0);break N}x[31725]=0;O(270,d+76|0,4314);b=x[31725];x[31725]=0;if((b|0)==1){break pc}b=y[d+456|0]|y[d+457|0]<<8;x[d+52>>2]=b>>>8&15;x[31725]=0;x[d+40>>2]=b&255;O(446,d- -64|0,d+40|0);b=x[31725];x[31725]=0;if((b|0)==1){break oc}x[31725]=0;V(432,d+160|0,d+76|0,d+52|0,d- -64|0);b=x[31725];x[31725]=0;if((b|0)==1){break nc}b=d+160|0;Ab(j,b);tb(b);tb(d- -64|0);Eb(d+76|0)}if(!lc(x[a+1298412>>2],x[a+1298416>>2])){break fb}b=y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24);if(!b){break fb}b=GF(y[d+456|0]|y[d+457|0]<<8,b);c=rp(d+160|0);x[c+32>>2]=b;x[31725]=0;O(449,a+1298412|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break fb}b=N()|0;break N}b=N()|0;break N}b=N()|0;break mc}b=N()|0;tb(d- -64|0)}Eb(d+76|0);break N}if(!((e|0)!=18284544|H|E|F)){break hb}break gb}if(((y[d+456|0]|y[d+457|0]<<8)&61440)!=20480){break gb}}x[31725]=0;c=P(1,d+160|0,16891)|0;e=x[31725];x[31725]=0;sc:{if((e|0)!=1){x[31725]=0;P(76,b|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break sc}tb(c);break fb}b=N()|0;break N}b=N()|0;tb(c);break N}if(!YG(e)){break fb}x[31725]=0;c=P(1,d+160|0,17127)|0;e=x[31725];x[31725]=0;tc:{if((e|0)!=1){x[31725]=0;P(76,b|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break tc}tb(c);break fb}b=N()|0;break N}b=N()|0;tb(c);break N}uc:{vc:{wc:{xc:{yc:{zc:{Ac:{Bc:{Cc:{if(K&1){x[31725]=0;c=P(1,d- -64|0,17141)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Cc}x[31725]=0;P(76,j|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Bc}tb(c)}e=x[a+480180>>2];if(!((e|0)!=16777216|(y[d+456|0]|y[d+457|0]<<8)>>>0<2186)){x[31725]=0;b=P(151,g|0,t|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break _a}if(b){x[31725]=0;S(450,a|0,g|0,y[d+456|0]|y[d+457|0]<<8);b=x[31725];x[31725]=0;if((b|0)==1){break _a}}e=x[a+480180>>2]}if((e|0)!=16777216){break Ac}x[31725]=0;P(1,d+52|0,13852)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break zc}b=N()|0;break N}b=N()|0;break N}b=N()|0;tb(c);break N}x[31725]=0;O(270,d+40|0,4314);b=x[31725];x[31725]=0;if((b|0)==1){break yc}b=y[d+458|0]|y[d+459|0]<<8;x[d+36>>2]=b>>>8;x[31725]=0;x[d+20>>2]=b&255;O(446,d+24|0,d+20|0);b=x[31725];x[31725]=0;if((b|0)==1){break xc}x[31725]=0;V(432,d+52|0,d+40|0,d+36|0,d+24|0);b=x[31725];x[31725]=0;if((b|0)==1){break wc}}b=d+52|0;Ab(a+1298344|0,b);tb(b);if((e|0)!=16777216){tb(d+24|0);Eb(d+40|0)}b=x[a+480180>>2];x[31725]=0;b=P(1,d+52|0,((b|0)==16777216?10124:6127)|0)|0;c=x[31725];x[31725]=0;e=1;if((c|0)==1){break uc}Ab(a+1298356|0,b);tb(b);Ab(a+1298368|0,j);M=a+1298404|0,T=x[Fc(d+36|0,x[a+1074308>>2]?22:4)>>2],x[M>>2]=T;x[a+1298408>>2]=0;ub(B);ub(u);break s}b=N()|0;break N}b=N()|0;break vc}b=N()|0;tb(d+24|0)}Eb(d+40|0);break N}b=N()|0;break N}b=N()|0;tb(d+76|0);break cb}b=N()|0}tb(c);break N}b=N()|0;break N}b=N()|0;Sk(l);break La}h=h+1|0;continue}}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}dc(k);break Ia}b=N()|0;break Ia}b=N()|0}ub(m);break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}ub(f);break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;tb(d+160|0);break xa}b=N()|0}Eb(d+100|0);break N}b=N()|0;break N}b=N()|0;break N}b=0;f=wD(d+100|0,x[i>>2]);x[31725]=0;P(185,g|0,f|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break _}}f=y[d+103|0];if(!x[i>>2]|(f|0)!=1){break ba}l=1;break aa}K=(f|0)==10|K}x[d+100>>2]=x[g+8>>2];M=d,T=x[ad(d+240|0,d+100|0)>>2],x[M+240>>2]=T;q=(b|0)!=0}e=e+1|0;b=z[a+480190>>1];continue}break}b=N()|0;break N}Dc:{b=yb(x[r>>2],e);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);Ec:{if(!b){break Ec}x[31725]=0;b=P(151,g|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Dc}if(!b){break Ec}b=x[g+8>>2];f=x[g>>2];x[31725]=0;b=U(152,f|0,b|0,554)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Dc}if(!b){break Ec}x[31725]=0;b=U(253,a|0,e+1&65535,0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Z}if(!b){break Ec}x[31725]=0;V(451,a|0,g|0,b|0,y[d+458|0]|y[d+459|0]<<8);f=x[31725];x[31725]=0;if((f|0)==1){break Z}v[b+33|0]=y[d+469|0]}e=e+1|0;b=z[a+480192>>1];continue}break}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}ub(B)}ub(u);break t}b=N()|0;break t}b=N()|0;break t}}}}}b=N()|0}uc(n);uc(o);uc(r);break a}uc(n);uc(o);uc(r)}tb(j)}fb=d+608|0;return e|0}b=N()|0}tb(j);Q(b|0);p()}function pra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0;d=fb-1712|0;fb=d;xc(b);a:{if(!Ci(b,d+1704|0)){break a}if(!JY(d+1704|0)){break a}if(!c){i=1;break a}n=y[d+1707|0];v[d+1703|0]=n;x[d+1696>>2]=-1;x[d+1692>>2]=1048576;if(n>>>0>=5){h=Pg(b);x[d+1696>>2]=h;if(!Mb(x[b>>2],x[b+8>>2],h)){break a}x[d+288>>2]=134217727;M=d,T=x[Gb(d+288|0,d+1696|0)>>2]<<5,x[M+1692>>2]=T}C=Nb(d+1680|0);x[d+288>>2]=y[d+1708|0]|y[d+1709|0]<<8|(y[d+1710|0]<<16|y[d+1711|0]<<24);h=x[Gb(d+1692|0,d+288|0)>>2];x[31725]=0;O(554,C|0,h|0);h=x[31725];x[31725]=0;b:{c:{d:{e:{f:{if((h|0)!=1){x[31725]=0;h=U(555,b|0,C|0,y[d+1708|0]|y[d+1709|0]<<8|(y[d+1710|0]<<16|y[d+1711|0]<<24))|0;f=x[31725];x[31725]=0;g:{if((f|0)==1){break g}if(!h){break b}if(n>>>0>=5){x[31725]=0;P(151,b|0,x[d+1696>>2]+12|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break g}}x[31725]=0;O(248,a|0,0);h=x[31725];x[31725]=0;if((h|0)==1){break g}gg(a);oe(d+1648|0,x[C>>2],x[C+4>>2]);h=Nd(d+1640|0);x[31725]=0;f=x[h+4>>2];x[d+88>>2]=x[h>>2];x[d+92>>2]=f;m=jg(556,d+1660|0,x[d+1648>>2],x[d+1652>>2],d+88|0);h=x[31725];x[31725]=0;h:{i:{j:{if((h|0)!=1){x[31725]=0;S(360,m|0,a+1298308|0,-1);h=x[31725];x[31725]=0;if((h|0)==1){break j}x[31725]=0;S(360,m|0,a+1298332|0,-1);h=x[31725];x[31725]=0;if((h|0)==1){break j}x[31725]=0;h=P(557,m|0,d+1218|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break f}if(!h){break c}h=v[d+1218|0];if((h|0)<=0|(y[d+1227|0]|y[d+1228|0]<<8)>>>0>255|(y[d+1229|0]|y[d+1230|0]<<8)>>>0>3999){break c}w[a+480188>>1]=h&255;bf(Xb(x[a+484360>>2],y[a+484376|0]),y[d+1221|0]|y[d+1222|0]<<8);w[a+480192>>1]=y[d+1227|0]|y[d+1228|0]<<8;w[a+480190>>1]=y[d+1229|0]|y[d+1230|0]<<8;h=y[d+1231|0];x[a+480196>>2]=h?h:6;h=y[d+1232|0];x[a+480204>>2]=D(h?h:125,1e4);f=y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24);h=32;k:{if(f&256){break k}h=2;if(f&2){break k}h=1;if(f&128){break k}h=f&8?16:4}x[31725]=0;O(419,a|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break f}e=x[a+480208>>2];f=e|16777216;x[a+480208>>2]=f;h=y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24);if(h&1){f=e|16777232;x[a+480208>>2]=f}j=x[a+480180>>2];i=(j|0)==32;e=i&!(h&1024);k=(j|0)==2;g=k&h>>>4;s=h&2097152;k=k&h>>>2;i=i&!(h&2048);if(e|(s|k|(i|g))){f=g?f|65536:f;f=k?f|2:f;f=i?f|4:f;x[a+480208>>2]=s>>>6|(e?f|8:f)}if(h&524288){x[31725]=0;U(268,a+1074312|0,5,1)|0;h=x[31725];x[31725]=0;if((h|0)==1){break f}j=x[a+480180>>2]}if((j|0)==2){break i}if((j|0)!=32){break h}v[d+288|0]=y[d+1237|0];v[d+220|0]=128;M=a,T=y[Rb(d+288|0,d+220|0)|0]<<1,x[M+480200>>2]=T;break h}e=N()|0;break d}e=N()|0;break e}v[d+288|0]=y[d+1237|0];v[d+220|0]=64;M=a,T=y[Rb(d+288|0,d+220|0)|0]<<2,x[M+480200>>2]=T}E=a+480188|0;h=v[d+1239|0];l:{if((h|0)<0){h=h+52|0;break l}G=xt(+(h|0)*3.1/20);m:{if(G<4294967296&G>=0){h=~~G>>>0;break m}h=0}h=h+51|0}x[a+480228>>2]=h;w[d+288>>1]=64;e=z[Nc(E,d+288|0)>>1];f=0;g=(j|0)!=32;k=(j|0)==4;i=0;while(1)if((e|0)==(i|0)){i=0;k=0;while(1){if((f|0)!=16){k=y[(d+f|0)+1368|0]!=0|k;f=f+1|0;continue}break}while(1){if((i|0)!=128){k=y[((i<<1)+d|0)+1385|0]!=0|k;i=i+1|0;continue}break}n:{if(!(k&1)){break n}h=a+901692|0;i=0;while(1){if((i|0)==16){h=a+902204|0;i=0;while(1){if((i|0)!=128){f=(d+1218|0)+(i<<1)|0;o:{if(y[f+167|0]){x[31725]=0;W(558,d+220|0);e=x[31725];x[31725]=0;p:{q:{r:{s:{t:{if((e|0)!=1){e=y[f+167|0];x[31725]=0;x[d+244>>2]=e-1;O(559,d+1164|0,d+244|0);e=x[31725];x[31725]=0;if((e|0)==1){break t}f=y[f+166|0];x[31725]=0;v[d+192|0]=f;O(560,d+1144|0,d+192|0);f=x[31725];x[31725]=0;if((f|0)==1){break s}x[31725]=0;V(561,d+288|0,d+220|0,d+1164|0,d+1144|0);f=x[31725];x[31725]=0;if((f|0)==1){break r}f=d+288|0;ee(d+1192|0,f);sf(Oe(h,i),x[d+1192>>2],x[d+1196>>2]);tb(f);tb(d+1144|0);tb(d+1164|0);Eb(d+220|0);break o}e=N()|0;break e}e=N()|0;break p}e=N()|0;break q}e=N()|0;tb(d+1144|0)}tb(d+1164|0)}Eb(d+220|0);break e}f=qc(d+1184|0,22255);sf(Oe(h,i),x[f>>2],x[d+1188>>2])}i=i+1|0;continue}break}j=x[a+480180>>2];break n}f=(d+i|0)+1368|0;u:{if(y[f|0]){x[31725]=0;W(562,d+220|0);e=x[31725];x[31725]=0;v:{w:{x:{if((e|0)!=1){f=y[f|0];x[31725]=0;x[d+1144>>2]=f-1;O(559,d+1164|0,d+1144|0);f=x[31725];x[31725]=0;if((f|0)==1){break x}x[31725]=0;S(292,d+288|0,d+220|0,d+1164|0);f=x[31725];x[31725]=0;if((f|0)==1){break w}f=d+288|0;ee(d+1208|0,f);sf(Oe(h,i),x[d+1208>>2],x[d+1212>>2]);tb(f);tb(d+1164|0);Eb(d+220|0);break u}e=N()|0;break e}e=N()|0;break v}e=N()|0;tb(d+1164|0)}Eb(d+220|0);break e}f=qc(d+1200|0,22255);sf(Oe(h,i),x[f>>2],x[d+1204>>2])}i=i+1|0;continue}}h=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;f=Xb(f,h);h=j&5;aa(350,f|0,m|0,y[d+1219|0]|y[d+1220|0]<<8,(h?65535:255)|0,(h?65535:254)|0);h=x[31725];x[31725]=0;if((h|0)!=1){x[31725]=0;S(187,d+288|0,m|0,D(y[d+1218|0],y[d+1223|0]|y[d+1224|0]<<8)<<1);h=x[31725];x[31725]=0;if((h|0)!=1){h=d+288|0;H=ic(d+1164|0,h);ub(h);x[31725]=0;S(187,h|0,m|0,(y[d+1223|0]|y[d+1224|0]<<8)<<1);h=x[31725];x[31725]=0;y:{if((h|0)!=1){h=d+288|0;I=ic(d+1144|0,h);ub(h);x[31725]=0;s=P(216,d+1132|0,y[d+1225|0]|y[d+1226|0]<<8)|0;h=x[31725];x[31725]=0;z:{if((h|0)!=1){M=d,T=wb(x[s>>2]),x[M+244>>2]=T;h=wb(x[s+4>>2]);A:{B:{C:{while(1){f=x[d+244>>2];if(!Ib(f,h)){h=x[a+480180>>2];t=c&1;if(!t){break B}x[31725]=0;O(225,a+484344|0,y[d+1223|0]|y[d+1224|0]<<8);f=x[31725];x[31725]=0;if((f|0)!=1){break B}e=N()|0;break A}x[31725]=0;e=R(153,m|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){x[31725]=0;S(187,d+220|0,m|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break C}g=f;f=d+220|0;e=ic(d+288|0,f);hd(g,e);ub(e);ub(f);Sf(d+244|0);continue}break}e=N()|0;break A}e=N()|0;break A}r=(h|0)==16?14:(h|0)==32?1:13;J=a+484344|0;j=1;while(1){D:{E:{F:{G:{H:{I:{if((y[d+1223|0]|y[d+1224|0]<<8)>>>0<=q>>>0){switch(x[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}x[31725]=0;h=R(191,I|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break H}x[d+220>>2]=h;if(!t){break D}x[31725]=0;f=U(198,J|0,q&65535,h|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break H}h=0;if(!f){break D}while(1){e=h&65535;if(e>>>0>=y[d+1218|0]){break D}x[31725]=0;f=R(191,H|0)|0;g=x[31725];x[31725]=0;J:{if((g|0)!=1){g=x[s>>2];if(Uf(g,x[s+4>>2])>>>0<=f>>>0){break J}l=eh(g,f);xc(l);f=0;g=Wb(x[J>>2],q);i=jd(x[g>>2],x[x[g+48>>2]+12>>2],0,e);K:while(1){if(A[d+220>>2]<=f>>>0){break J}x[31725]=0;e=R(199,l|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){if(!e){break J}u=e>>>4|0;B=e&15;k=0;g=ch(d+288|0);while(1){L:{M:{N:{if(B>>>0>(k&255)>>>0){x[31725]=0;O(200,d+244|0,l|0);e=x[31725];x[31725]=0;if((e|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{e=y[xb(d+244|0,0)|0];switch(e-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(e-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}e=y[xb(d+244|0,1)|0];fa:{if(e>>>0<=119){e=e+r|0;break fa}ga:{switch(e-254|0){case 1:e=255;break fa;case 0:e=254;break fa;default:break ga}}e=253}v[g|0]=e;j=KD(e)&j;break L}M=d,T=y[xb(d+244|0,1)|0]+1|0,v[M+289|0]=T;break L}ha:{if(y[d+290|0]){break ha}e=x[a+480180>>2];if((e|0)!=32){if((e|0)!=4){break ha}e=y[xb(d+244|0,1)|0];if(e&15){break ha}v[d+290|0]=11;v[d+292|0]=e>>>4;break L}o=y[xb(d+244|0,1)|0];e=0;while(1){if((e|0)==10){break ha}if((o|0)==y[e+42208|0]){v[d+292|0]=e;v[d+290|0]=11;break L}else{e=e+1|0;continue}}}M=d,T=y[xb(d+244|0,1)|0],v[M+293|0]=T;v[d+291|0]=4;break L}e=xb(d+244|0,1);ia:{if(y[d+290|0]){break ia}o=y[e|0];if(x[a+480180>>2]!=32|o>>>0>9){break ia}v[d+292|0]=o;v[d+290|0]=8;break L}v[d+293|0]=y[e|0];v[d+291|0]=5;break L}ja:{if(y[d+290|0]){break ja}ka:{e=x[a+480180>>2];if((e|0)!=4){if((e|0)!=32){break ja}e=xb(d+244|0,1);o=y[e|0];if((o|0)!=255){break ka}v[d+292|0]=64;v[d+290|0]=2;break L}e=xb(d+244|0,1);if(y[e|0]&15){break ja}break M}if(!(o&3)){break M}}M=d,T=y[xb(d+244|0,1)|0],v[M+293|0]=T;v[d+291|0]=9;break L}o=y[d+290|0];e=xb(d+244|0,1);la:{if(o|x[a+480180>>2]==1){break la}o=y[e|0];if(o>>>0>64){break la}v[d+292|0]=o;v[d+290|0]=1;break L}v[d+293|0]=y[e|0];v[d+291|0]=13;break L}e=y[xb(d+244|0,1)|0];v[d+293|0]=e;v[d+291|0]=14;if(x[a+480180>>2]==32){break L}v[d+293|0]=D((e&240)>>>4|0,10)+(e&15);break L}e=y[xb(d+244|0,1)|0];v[d+293|0]=e;v[d+291|0]=e>>>0<32?16:17;break L}o=y[xb(d+244|0,1)|0];if(o>>>0>=16){v[d+292|0]=o>>>4;v[d+290|0]=(e|0)==20?3:5;break L}v[d+292|0]=o&15;v[d+290|0]=(e|0)==20?4:6;break L}e=y[xb(d+244|0,1)|0];if(e>>>0>=16){v[d+290|0]=10;v[d+292|0]=e>>>4;break L}v[d+290|0]=9;v[d+292|0]=e&15;break L}e=y[xb(d+244|0,1)|0];v[d+291|0]=28;v[d+293|0]=e|16;break L}e=y[xb(d+244|0,1)|0];v[d+291|0]=28;v[d+293|0]=e|32;break L}M=d,T=y[xb(d+244|0,1)|0],v[M+292|0]=T;v[d+290|0]=(e|0)==31?7:8;break L}e=y[d+291|0];v[d+291|0]=(e|0)==4?6:(e|0)==5?7:11;M=d,T=y[xb(d+244|0,1)|0],v[M+293|0]=T;break L}e=xb(d+244|0,1);v[d+292|0]=y[e|0]%10;e=y[e|0];if(e>>>0<=9){v[d+290|0]=5;break L}if(e>>>0<=19){v[d+290|0]=6;break L}if(e>>>0<=29){v[d+290|0]=3;break L}if(e>>>0>39){break L}v[d+290|0]=4;break L}M=d,T=y[xb(d+244|0,1)|0],v[M+292|0]=T;v[d+290|0]=(e|0)==49?13:12;break L}e=y[xb(d+244|0,1)|0]+33|0;if((e&255)>>>0>9){break L}v[d+290|0]=15;v[d+292|0]=e;break L}if(e>>>0>57){break L}M=d,T=y[xb(d+244|0,1)|0],v[M+293|0]=T;v[d+291|0]=y[e+25184|0];break L}x[d+244>>2]=f+u;e=x[Gb(d+244|0,d+220|0)>>2];e=e>>>0<f>>>0?f:e;while(1){if((e|0)!=(f|0)){k=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[i|0]=k;v[i+1|0]=k>>>8;v[i+2|0]=k>>>16;v[i+3|0]=k>>>24;k=y[g+4|0]|y[g+5|0]<<8;v[i+4|0]=k;v[i+5|0]=k>>>8;f=f+1|0;i=D(y[d+1218|0],6)+i|0;continue}break}f=e;continue K}e=N()|0;break A}e=y[e|0];v[d+290|0]=2;v[d+292|0]=e>>>2}k=k+1|0;continue}}break}e=N()|0;break A}e=N()|0;break A}h=h+1|0;continue}}i=z[a+480192>>1];h=0;break E}e=N()|0;break A}if(!(z[E>>1]==4&j)){break F}x[a+480208>>2]=x[a+480208>>2]|8454144}i=0;h=!((y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24))&512)}x[31725]=0;o=P(563,d+1120|0,i|0)|0;f=x[31725];x[31725]=0;ma:{na:{oa:{pa:{qa:{if((f|0)!=1){i=n>>>0<5;k=1;ra:{while(1){g=k&65535;if(g>>>0>z[a+480192>>1]){break ra}sa:{ta:{ua:{va:{if(!h){x[31725]=0;e=U(253,a|0,g|0,0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break va}if(e){break ua}}while(1){x[31725]=0;f=R(199,m|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break na}if(f){continue}break}if(!i){while(1){x[31725]=0;f=R(199,m|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){e=N()|0;break ma}if(f){continue}break}}x[31725]=0;P(185,m|0,826)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break ta}}e=N()|0;break ma}f=Fb(d+220|0);x[31725]=0;S(360,m|0,f|0,-1);j=x[31725];x[31725]=0;if((j|0)==1){break sa}zc(e+492|0,f);if(!i){x[31725]=0;S(360,m|0,f|0,-1);j=x[31725];x[31725]=0;if((j|0)==1){break sa}zc(e+524|0,f)}x[31725]=0;j=P(564,m|0,d+288|0)|0;q=x[31725];x[31725]=0;if((q|0)==1){break oa}if(!j){break qa}j=x[a+480180>>2];x[31725]=0;S(565,d+288|0,e|0,j|0);e=x[31725];x[31725]=0;if((e|0)==1){break oa}if(x[a+480180>>2]==4){e=yb(x[o>>2],g-1|0);g=y[d+1090|0]|y[d+1091|0]<<8|(y[d+1092|0]<<16|y[d+1093|0]<<24);v[e|0]=g;v[e+1|0]=g>>>8;v[e+2|0]=g>>>16;v[e+3|0]=g>>>24}tb(f)}k=k+1|0;continue}break}break oa}if(!h){break pa}w[a+480192>>1]=0;break pa}e=N()|0;break A}tb(f)}h=z[a+480190>>1];x[31725]=0;q=P(566,d+276|0,h|0)|0;h=x[31725];x[31725]=0;if((h|0)!=1){B=y[d+1703|0];L=!(v[d+1233|0]&1)|B>>>0>4;t=c&2;k=1;c=0;while(1){h=c;wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{j=k&65535;if(j>>>0<=z[a+480190>>1]){i=Fb(d+264|0);x[31725]=0;S(360,m|0,i|0,-1);c=x[31725];x[31725]=0;Ra:{Sa:{if((c|0)!=1){zc(((j<<5)+a|0)+946304|0,i);c=B>>>0<5;if(c){break Sa}x[31725]=0;S(360,m|0,i|0,-1);f=x[31725];x[31725]=0;if((f|0)!=1){break Ra}}e=N()|0;break za}tf(i)}x[31725]=0;f=P(567,m|0,d+288|0)|0;e=x[31725];x[31725]=0;Ta:{Ua:{if((e|0)==1){break Ua}if(!f){break Ta}g=x[a+480180>>2];x[31725]=0;e=D(j,104)+a|0;f=e+484380|0;V(568,d+288|0,f|0,g|0,L|0);g=x[31725];x[31725]=0;if((g|0)==1){break Ua}ze(e+484423|0,i);r=0;Va:{if(((y[d+308|0]|y[d+309|0]<<8)&61440)!=28672|c){break Va}x[31725]=0;r=R(569,m|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break Va}e=N()|0;break za}if(!t){break xa}g=y[d+323|0]|y[d+324|0]<<8|(y[d+325|0]<<16|y[d+326|0]<<24);c=y[d+308|0]|y[d+309|0]<<8;n=c&61440;if(!(g|n)){c=Xc(d+220|0,c&1?16:8,c&1024?3:1,0,0);x[31725]=0;U(217,c|0,f|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break xa}e=N()|0;break za}if((g|0)<0){c=g+j|0;if((c|0)<=0){break xa}HY(f,(D(c,104)+a|0)+484380|0);break xa}if((g|0)<=0){break xa}if(c&1){l=e+484414|0;w[l>>1]=z[l>>1]|1}if(c&1024){l=e+484414|0;w[l>>1]=z[l>>1]|64}x[31725]=0;S(187,d+220|0,b|0,g|0);g=x[31725];x[31725]=0;Wa:{Xa:{Ya:{Za:{_a:{$a:{if((g|0)!=1){l=d+220|0;g=ic(d+244|0,l);ub(l);l=_d(z[f+34>>1]);K=(n|0)==16384;if(!K&(n|0)!=8192){break Za}u=x[g>>2];x[31725]=0;u=R(156,u|0)|0;F=x[31725];x[31725]=0;if((F|0)==1){break Wa}F=4/(l>>>0)|0;ova(F,0,u,0);wc(f,hb?-1:D(F,u));if((n|0)==8192){break $a}if(!K){break Za}if(!Fh(f)){break Ya}c=x[e+484400>>2];f=x[f>>2];if(!(v[d+308|0]&1)){break _a}x[31725]=0;V(570,g|0,c|0,f|0,l|0);f=x[31725];x[31725]=0;c=h;if((f|0)==1){break Ba}break Xa}e=N()|0;break za}if(!Fh(f)){break Ya}c=x[e+484400>>2];f=x[f>>2];if(v[d+308|0]&1){x[31725]=0;V(571,g|0,c|0,f|0,l|0);f=x[31725];x[31725]=0;c=h;if((f|0)!=1){break Xa}break Ba}x[31725]=0;V(572,g|0,c|0,f|0,l|0);f=x[31725];x[31725]=0;c=h;if((f|0)==1){break Ba}break Xa}x[31725]=0;V(573,g|0,c|0,f|0,l|0);f=x[31725];x[31725]=0;c=h;if((f|0)==1){break Ba}break Xa}if((c&45056)==12288){c=GY(d+220|0,g,y[d+327|0]|y[d+328|0]<<8,r);M=hd(wf(x[q>>2],j-1|0),c),T=x[c+20>>2],x[M+20>>2]=T;ub(c);break Ya}if((n|0)!=32768){c=1;if((n|0)!=4096){break Xa}n=Ge(d+220|0,g);x[31725]=0;c=P(574,d+214|0,g|0)|0;l=x[31725];x[31725]=0;if((l|0)!=1){ab:{bb:{if(!y[d+219|0]){break bb}r=y[d+327|0]|y[d+328|0]<<8;l=z[d+216>>1]<<1;if(r>>>0<(l&65535)>>>0){break bb}l=r-l|0;v[d+327|0]=l;v[d+328|0]=l>>>8;c=z[c>>1];x[31725]=0;P(151,g|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ab}x[31725]=0;c=R(204,g|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break ab}x[31725]=0;S(187,d+172|0,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break ab}c=d+172|0;l=ic(d+192|0,c);hd(n,l);ub(l);ub(c)}x[31725]=0;j=U(575,a|0,j|0,n|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ab}c=1;if(j){c=y[d+327|0]|y[d+328|0]<<8;cb:{if(!c){break cb}j=z[f+34>>1];l=Xk(x[f>>2],j);if(l>>>0<=c>>>0){break cb}j=el(j);e=x[e+484400>>2];nl(e,c+e|0,l-c|0);x[f>>2]=x[f>>2]-((c>>>0)/(j>>>0)|0)}wc(f,y[d+296|0]|y[d+297|0]<<8|(y[d+298|0]<<16|y[d+299|0]<<24));c=h}ub(n);break Xa}}e=N()|0;ub(n);break Aa}x[31725]=0;c=P(430,g|0,d+220|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Qa}if(!c){break Ya}x[d+80>>2]=y[d+228|0]|y[d+229|0]<<8|(y[d+230|0]<<16|y[d+231|0]<<24);c=y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24);x[d+72>>2]=y[d+220|0]|y[d+221|0]<<8|(y[d+222|0]<<16|y[d+223|0]<<24);x[d+76>>2]=c;_k(f,1,d+72|0)}c=h}ub(g);break wa}e=N()|0;break Aa}e=N()|0;break za}tb(i)}db:{if(!t){break db}n=1;while(1){c=n&65535;if(c>>>0>z[a+480190>>1]){break db}b=wf(x[q>>2],c-1|0);f=x[b>>2];x[31725]=0;f=R(174,f|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Pa}eb:{fb:{if(!f){break fb}f=c+w[b+22>>1]|0;f=((f|0)>0?f:n)&65535;k=z[b+20>>1];g=(f|0)!=(c|0)&(f|0)!=0&f>>>0<=z[a+480190>>1]&(k|0)!=0;gb:{if(g){f=wf(x[q>>2],f-1|0);break gb}f=x[b>>2];x[31725]=0;k=R(156,f|0)|0;e=x[31725];x[31725]=0;f=b;if((e|0)==1){break Oa}}xc(f);hb:{if(g){e=x[f+8>>2];i=x[f>>2];j=z[b+20>>1];x[31725]=0;e=U(152,i|0,e|0,j|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break Oa}if(!e){break fb}x[d+220>>2]=0;x[d+244>>2]=0;x[31725]=0;S(188,d+288|0,f|0,k|0);e=x[31725];x[31725]=0;ib:{if((e|0)!=1){j=ZC($e(d+288|0),vh(x[d+288>>2]),d+220|0,d+244|0);x[31725]=0;P(185,f|0,x[d+220>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break ib}Kc(d+288|0);break hb}e=N()|0;break ya}e=N()|0;Kc(d+288|0);break ya}j=0;x[d+220>>2]=0;x[d+244>>2]=0}x[31725]=0;O(576,d+288|0,b|0);f=x[31725];x[31725]=0;jb:{kb:{if((f|0)!=1){e=$e(d+288|0);k=x[d+288>>2];if(!g){j=ZC(e,vh(k),d+220|0,d+244|0);x[31725]=0;f=x[d+220>>2];P(185,b|0,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break eb}k=k-f|0;e=e+f|0}if(j){break kb}h=1;break jb}e=N()|0;break ya}c=D(c,104)+a|0;l=c+484380|0;Fh(l);u=c+484400|0;f=0;i=x[d+244>>2];while(1){lb:{if(!k|(i|0)!=1?i:0){break lb}c=x[l>>2];if(c>>>0<=f>>>0){break lb}if(!je(c,x[l+20>>2])){break lb}x[d+192>>2]=0;x[d+172>>2]=0;i=FY(j,e,vh(k),d+192|0,d+264|0,d+172|0);x[31725]=0;x[d+220>>2]=i;P(185,b|0,i|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ca}Bi(d+172|0,vh(x[l>>2]-f|0));c=x[d+172>>2];mb:{if((c|0)<=0){break mb}g=x[d+192>>2];B=z[l+34>>1];if((_d(B)|0)!=(g|0)){break mb}t=D(f,g);r=x[u>>2];if(B&1){x[d+168>>2]=c;x[d+156>>2]=c;x[d- -64>>2]=c;x[d+48>>2]=c;x[d+152>>2]=g;x[d+148>>2]=x[d+264>>2];x[d+164>>2]=g;x[d+160>>2]=r+(t<<1);x[31725]=0;g=x[d+152>>2];x[d+40>>2]=x[d+148>>2];x[d+44>>2]=g;g=x[d+164>>2];x[d+56>>2]=x[d+160>>2];x[d+60>>2]=g;O(577,d+56|0,d+40|0);g=x[31725];x[31725]=0;if((g|0)!=1){break mb}break Ca}x[d+144>>2]=c;x[d+132>>2]=c;x[d+32>>2]=c;x[d+16>>2]=c;x[d+128>>2]=g;x[d+124>>2]=x[d+264>>2];x[d+140>>2]=g;x[d+136>>2]=r+t;x[31725]=0;g=x[d+128>>2];x[d+8>>2]=x[d+124>>2];x[d+12>>2]=g;g=x[d+140>>2];x[d+24>>2]=x[d+136>>2];x[d+28>>2]=g;O(578,d+24|0,d+8|0);g=x[31725];x[31725]=0;if((g|0)==1){break Ca}}k=k-i|0;e=e+i|0;i=EY(j);x[d+244>>2]=i;f=c+f|0;continue}break}DY(j)}Kc(d+288|0)}n=n+1|0;continue}break}break Ca}nb:{if(x[a+480180>>2]!=4){break nb}i=0;while(1){if(z[a+480192>>1]<=i>>>0){break nb}b=yb(x[o>>2],i);c=y[b+3|0];f=y[b+2|0];e=y[b+1|0];b=y[b|0];x[31725]=0;i=i+1|0;ja(402,a|0,i&65535,b|0,e|0,f|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){continue}break}e=N()|0;break ya}if(!(y[d+1235|0]&16)){break Ka}b=x[m+8>>2];c=x[m>>2];x[31725]=0;b=U(152,c|0,b|0,1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ma}if(!b){break Ka}i=0;x[31725]=0;b=R(199,m|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Na}if(!(b&1)){break La}while(1){if(z[E>>1]<=i>>>0){break La}x[31725]=0;b=R(153,m|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){v[((i<<5)+a|0)+480288|0]=b;i=i+1|0;continue}break}e=N()|0;break ya}e=N()|0;break Aa}e=N()|0;break ya}e=N()|0;break ya}e=N()|0;break ya}e=N()|0;break ya}f=a+906300|0;while(1){b=x[m+8>>2];c=x[m>>2];x[31725]=0;b=U(152,c|0,b|0,1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Da}if(!b){break Ka}x[31725]=0;b=R(199,m|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ia}if(!b){break Ka}x[31725]=0;c=R(153,m|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ja}x[31725]=0;S(187,d+220|0,m|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break Ja}e=d+220|0;c=ic(d+288|0,e);ub(e);ob:{if(b>>>0<=250){b=vd(f,b-1|0);x[31725]=0;O(452,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break ob}}ub(c);continue}break}e=N()|0;ub(c);break ya}k=a+901404|0;c=Fb(d+192|0);f=0;j=0;while(1){b=x[m+8>>2];e=x[m>>2];x[31725]=0;b=U(152,e|0,b|0,8)|0;e=x[31725];x[31725]=0;pb:{qb:{rb:{sb:{tb:{if((e|0)!=1){if(b){x[31725]=0;e=R(153,m|0)|0;b=x[31725];x[31725]=0;ub:{vb:{wb:{xb:{yb:{zb:{Ab:{Bb:{if((b|0)!=1){x[31725]=0;b=R(153,m|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Bb}x[31725]=0;S(187,d+288|0,m|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break Ab}g=d+288|0;b=ic(d+220|0,g);ub(g);if((e|0)==1229211981){break xb}if((e|0)==1229476432){break yb}if((e|0)==1397900630){break zb}if((e|0)!=1414548815){break pb}x[31725]=0;e=P(414,b|0,13890)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ha}if(!e){break qb}x[31725]=0;e=R(153,b|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){x[31725]=0;S(187,d+288|0,b|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){break wb}}e=N()|0;break Ga}e=N()|0;break Ea}e=N()|0;break Ea}e=N()|0;break Ea}Cb:{Db:{Eb:{e=x[a+480180>>2];switch(e-2|0){case 1:break pb;case 0:break vb;case 2:break Db;default:break Eb}}if((e|0)==16){break Cb}if((e|0)!=32){break pb}x[31725]=0;f=R(191,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ha}x[31725]=0;j=R(191,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break pb}break Ha}e=Fc(d+120|0,4);x[d+288>>2]=32;g=x[b>>2];x[31725]=0;g=R(156,g|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){x[d+244>>2]=g;e=x[e>>2];g=x[Gb(d+288|0,d+244|0)>>2];x[31725]=0;V(579,b|0,c|0,e|0,g|0);e=x[31725];x[31725]=0;if((e|0)!=1){break pb}}e=N()|0;break Ga}x[31725]=0;e=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break ub}x[31725]=0;O(580,d+244|0,4211);g=x[31725];x[31725]=0;Fb:{if((g|0)!=1){x[d+264>>2]=e>>>4;x[31725]=0;x[d+104>>2]=e&15;V(309,d+288|0,d+244|0,d+264|0,d+104|0);e=x[31725];x[31725]=0;if((e|0)==1){break Fb}e=d+288|0;Ab(c,e);tb(e);Eb(d+244|0);break pb}e=N()|0;break Ga}e=N()|0;Eb(d+244|0);break Ga}x[31725]=0;e=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ha}x[a+480216>>2]=e;x[31725]=0;e=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ha}x[a+480220>>2]=e;break pb}x[31725]=0;P(425,b|0,k|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ha}zD(k);break pb}e=d+288|0;g=ic(d+244|0,e);ub(e);e=x[g>>2];x[31725]=0;e=R(156,e|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break rb}w[d+288>>1]=e>>>5;M=d,T=gk(x[a+484344>>2],x[a+484348>>2]),w[M+264>>1]=T;e=z[Nc(d+288|0,d+264|0)>>1];i=0;while(1){if((e|0)==(i|0)){ub(g);break qb}x[31725]=0;O(581,g|0,d+288|0);n=x[31725];x[31725]=0;Gb:{if((n|0)==1){break Gb}n=x[J>>2];x[31725]=0;O(582,Wb(n,i)|0,d+288|0);n=x[31725];x[31725]=0;if((n|0)==1){break Gb}i=i+1|0;continue}break}break rb}x[31725]=0;f=R(191,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ha}break pb}e=N()|0;break Ga}b=x[a+480180>>2];Hb:{Ib:{Jb:{if((b|0)!=32){break Jb}e=f&65535;if(e>>>0<256){break Jb}if(e>>>0<532){break Ib}}b=(b|0)!=2;Kb:{if(b){break Kb}e=f&65535;if(e>>>0<12544){break Kb}if(e>>>0<12820){break Ib}}if(b){break Hb}b=f&65535;if(b>>>0<4864|b>>>0>4895){break Hb}}sr(k)}i=1;Lb:{if(!(v[d+1235|0]&1)){break Lb}f=x[a+1074308>>2];if(!f){while(1){b=i&65535;if(b>>>0<=z[a+480192>>1]){b=x[((b<<2)+a|0)+900380>>2];if(b){f=x[a+480180>>2];x[31725]=0;O(583,_h(b,2)|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break tb}v[b+19|0]=y[b+19|0]+3>>>2}i=i+1|0;continue}break}f=x[a+1074308>>2]}if(f>>>0<=18350079){x[31725]=0;b=P(269,a+1074312|0,27)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Fa}x[31725]=0;P(269,b|0,57)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Fa}f=x[a+1074308>>2]}if(f>>>0<=19070975){x[31725]=0;P(269,a+1074312|0,73)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Fa}f=x[a+1074308>>2]}if(f>>>0>19267583){break Lb}x[31725]=0;P(269,a+1074312|0,50)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Fa}}Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{if(Ad(x[c+4>>2],y[c+11|0])){x[31725]=0;W(584,d+220|0);b=x[31725];x[31725]=0;_b:{if((b|0)!=1){x[31725]=0;S(552,d+288|0,d+220|0,d+1703|0);b=x[31725];x[31725]=0;if((b|0)==1){break _b}break Zb}e=N()|0;break Ea}e=N()|0;Eb(d+220|0);break Ea}x[31725]=0;W(585,d+220|0);b=x[31725];x[31725]=0;if((b|0)==1){break Yb}x[31725]=0;V(586,d+288|0,d+220|0,d+1703|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break Xb}}b=d+288|0;Ab(c,b);tb(b);b=d+220|0;Eb(b);x[31725]=0;O(551,b|0,3977);b=x[31725];x[31725]=0;if((b|0)==1){break Vb}x[31725]=0;S(552,d+288|0,d+220|0,d+1703|0);b=x[31725];x[31725]=0;if((b|0)==1){break Ub}b=d+288|0;Ab(a+1298344|0,b);tb(b);Eb(d+220|0);x[31725]=0;b=P(1,b|0,14991)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Tb}Ab(a+1298356|0,b);tb(b);b=x[a+480180>>2];switch(b-1|0){case 2:break sb;case 1:break Pb;case 3:break Qb;case 0:break Rb;default:break Wb}}e=N()|0;break Ea}e=N()|0;Eb(d+220|0);break Ea}if((b|0)==16){break Sb}if((b|0)==32){break Ob}if((b|0)!=16777216){break sb}x[31725]=0;b=P(1,d+220|0,10124)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Nb}Ab(a+1298392|0,b);tb(b);x[31725]=0;b=P(1,d+244|0,13852)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Mb}Ab(a+1298380|0,b);tb(b);break sb}e=N()|0;break Ea}e=N()|0;Eb(d+220|0);break Ea}e=N()|0;break Ea}x[31725]=0;b=P(1,d+220|0,10129)|0;f=x[31725];x[31725]=0;$b:{if((f|0)!=1){Ab(a+1298392|0,b);tb(b);x[31725]=0;b=P(1,d+244|0,8365)|0;f=x[31725];x[31725]=0;if((f|0)==1){break $b}Ab(a+1298380|0,b);tb(b);break sb}e=N()|0;break Ea}e=N()|0;break Ea}x[31725]=0;b=P(1,d+220|0,12386)|0;f=x[31725];x[31725]=0;ac:{if((f|0)!=1){Ab(a+1298392|0,b);tb(b);x[31725]=0;b=P(1,d+244|0,14248)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ac}Ab(a+1298380|0,b);tb(b);break sb}e=N()|0;break Ea}e=N()|0;break Ea}x[31725]=0;b=P(1,d+220|0,10102)|0;f=x[31725];x[31725]=0;bc:{if((f|0)!=1){Ab(a+1298392|0,b);tb(b);x[31725]=0;b=P(1,d+244|0,15285)|0;f=x[31725];x[31725]=0;if((f|0)==1){break bc}Ab(a+1298380|0,b);tb(b);break sb}e=N()|0;break Ea}e=N()|0;break Ea}x[31725]=0;b=P(1,d+220|0,10474)|0;f=x[31725];x[31725]=0;cc:{if((f|0)!=1){Ab(a+1298392|0,b);tb(b);x[31725]=0;b=P(1,d+244|0,15026)|0;f=x[31725];x[31725]=0;if((f|0)==1){break cc}Ab(a+1298380|0,b);tb(b);break sb}e=N()|0;break Ea}e=N()|0;break Ea}x[31725]=0;b=P(1,d+220|0,6127)|0;f=x[31725];x[31725]=0;dc:{ec:{fc:{gc:{hc:{if((f|0)!=1){Ab(a+1298392|0,b);tb(b);if(!(j&65535)){break dc}x[31725]=0;O(270,d+264|0,4314);b=x[31725];x[31725]=0;if((b|0)==1){break hc}x[d+116>>2]=(j&65280)>>>8;x[31725]=0;x[d+100>>2]=j&255;O(446,d+104|0,d+100|0);b=x[31725];x[31725]=0;if((b|0)==1){break gc}x[31725]=0;V(432,d+244|0,d+264|0,d+116|0,d+104|0);b=x[31725];x[31725]=0;if((b|0)==1){break fc}b=d+244|0;Ab(a+1298380|0,b);tb(b);tb(d+104|0);Eb(d+264|0);break sb}e=N()|0;break Ea}e=N()|0;break Ea}e=N()|0;break ec}e=N()|0;tb(d+104|0)}Eb(d+264|0);break Ea}x[31725]=0;b=P(1,d+244|0,8557)|0;f=x[31725];x[31725]=0;if((f|0)!=1){Ab(a+1298380|0,b);tb(b);break sb}e=N()|0;break Ea}e=N()|0;break Ea}e=N()|0;break Ea}e=N()|0;break Ea}e=N()|0;break Ea}Ab(a+1298368|0,c);ic:{if(x[a+1074308>>2]){M=a,T=x[Fc(d+264|0,22)>>2],x[M+1298404>>2]=T;break ic}if(x[a+480180>>2]==1){M=a,T=x[Fc(d+264|0,28)>>2],x[M+1298404>>2]=T;break ic}M=a,T=x[Fc(d+264|0,4)>>2],x[M+1298404>>2]=T}i=1;jc:{kc:{if(h&1){x[31725]=0;b=P(1,d+264|0,16662)|0;h=x[31725];x[31725]=0;if((h|0)==1){break kc}a=x[a+1298472>>2];x[31725]=0;S(387,a|0,2,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break jc}tb(b)}tb(c);CY(q);uc(o);Qc(s);ub(I);ub(H);break c}e=N()|0;break Ea}e=N()|0;tb(b);break Ea}e=N()|0;ub(g);break Ga}x[31725]=0;e=P(414,b|0,13895)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ha}lc:{if(!e){break lc}x[31725]=0;e=R(153,b|0)|0;g=x[31725];x[31725]=0;mc:{if((g|0)!=1){x[31725]=0;S(187,d+244|0,b|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){break mc}}e=N()|0;break Ga}e=d+244|0;g=ic(d+288|0,e);ub(e);e=x[g>>2];x[31725]=0;e=R(156,e|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){w[d+244>>1]=(e>>>0)/20;w[d+264>>1]=z[E>>1];e=z[Nc(d+244|0,d+264|0)>>1];i=0;while(1){if((e|0)==(i|0)){ub(g);break lc}x[31725]=0;S(426,g|0,((i<<5)+a|0)+480289|0,20);n=x[31725];x[31725]=0;if((n|0)!=1){i=i+1|0;continue}break}}e=N()|0;ub(g);break Ga}x[31725]=0;P(437,a|0,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ha}x[31725]=0;ba(438,a|0,b|0,1,0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ha}if((f-2186&65535)>>>0<=117){x[a+480180>>2]=16777216;x[31725]=0;S(450,a|0,b|0,f&65535);e=x[31725];x[31725]=0;if((e|0)==1){break Ha}}if(!x[a+1074308>>2]){break pb}x[31725]=0;g=P(1,d+172|0,18237)|0;e=x[31725];x[31725]=0;nc:{oc:{pc:{if((e|0)!=1){e=x[a+1074308>>2];x[31725]=0;O(136,d+244|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break pc}x[31725]=0;S(2,d+288|0,g|0,d+244|0);e=x[31725];x[31725]=0;if((e|0)==1){break oc}e=d+288|0;Ab(c,e);tb(e);tb(d+244|0);tb(g);break pb}e=N()|0;break Ga}e=N()|0;break nc}e=N()|0;tb(d+244|0)}tb(g);break Ga}ub(b);continue}}e=N()|0;break ya}e=N()|0;break ya}e=N()|0}ub(b);break Ea}e=N()|0}tb(c);break ya}e=N()|0;break ya}e=N()|0;Kc(d+288|0);break ya}e=N()|0}ub(g)}tb(i)}CY(q);break ma}c=h}tb(i);k=k+1|0;continue}}e=N()|0;break ma}e=N()|0;tb(f);break ma}e=N()|0}uc(o);break A}q=q+1|0;continue}}Qc(s);break z}e=N()|0}ub(I);break y}e=N()|0}ub(H);break e}e=N()|0;break e}e=N()|0;break e}else{qc:{rc:{if(!g){v[d+288|0]=y[(d+i|0)+1240|0];v[d+220|0]=64;M=((i<<5)+a|0)+480286|0,T=y[Rb(d+288|0,d+220|0)|0],w[M>>1]=T;break rc}if(k){break qc}}sc:{h=y[(d+i|0)+1304|0];if((h|0)!=255){if((h|0)!=127){break sc}x[((i<<5)+a|0)+480280>>2]=256;break qc}w[((i<<5)+a|0)+480284>>1]=256;break qc}w[((i<<5)+a|0)+480284>>1]=h}i=i+1|0;continue}}e=N()|0;break d}e=N()|0;break d}e=N()|0}ub(m)}dc(C);Q(e|0);p()}ub(m)}dc(C)}fb=d+1712|0;return i|0}function Bra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;e=fb-944|0;fb=e;xc(b);a:{if(!UY(b,e+892|0)){break a}if(!YY(e+892|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(XY(e+892|0),hb))){break a}if(!c){d=1;break a}Bd(a,8);gg(a);l=y[e+895|0]-48|0;v[e+891|0]=l;cd(b,$b(y[e+900|0]|y[e+901|0]<<8|(y[e+902|0]<<16|y[e+903|0]<<24)));f=e+584|0;fe(f,b,504);L=ic(e+868|0,f);ub(f);x[31725]=0;O(525,b|0,f|0);f=x[31725];x[31725]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(y[e+867|0]>63){break b}if(Bb(z[e+584>>1])<<16>>16<0){break b}Tb(e+504|0,0,80);h:{f=$b(y[e+924|0]|y[e+925|0]<<8|(y[e+926|0]<<16|y[e+927|0]<<24));if(!f){break h}x[31725]=0;f=P(151,b|0,f|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){if(!f){break h}x[31725]=0;O(526,b|0,e+504|0);f=x[31725];x[31725]=0;if((f|0)!=1){break h}}h=N()|0;break e}x[31725]=0;S(527,e+500|0,b|0,l&255);f=x[31725];x[31725]=0;if((f|0)!=1){X=af(e+500|0);f=z[e+500>>1];if((f-128&65535)>>>0<65409){break b}w[a+480188>>1]=f;H=Nb(e+488|0);f=$b(y[e+916|0]|y[e+917|0]<<8|(y[e+918|0]<<16|y[e+919|0]<<24));i:{if(f){x[31725]=0;P(151,b|0,f|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break g}x[31725]=0;S(528,b|0,H|0,y[e+867|0]);f=x[31725];x[31725]=0;if((f|0)==1){break g}g=y[e+867|0];break i}g=y[e+867|0];if(g){break c}}F=a+480188|0;g=g&255;w[a+480192>>1]=g;w[a+480190>>1]=g;Y=(l&255)>>>0<2|v[e+848|0]>=0;B=!Y;u=c&2;m=1;s=1;while(1){j:{k:{l:{m:{n:{o:{d=s&65535;if(d>>>0<=(g&65535)>>>0){x[31725]=0;o=m&65535;f=U(253,a|0,d|0,o|0)|0;g=x[31725];x[31725]=0;p:{if((g|0)!=1){if(f){break p}break d}h=N()|0;break f}f=x[((d<<2)+a|0)+900380>>2];w[e+92>>1]=0;x[e+88>>2]=0;x[31725]=0;k=R(170,e+468|0)|0;g=x[31725];x[31725]=0;q:{if((g|0)!=1){d=yb(x[H>>2],d-1|0);d=$b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));r:{if(!d){break r}x[31725]=0;d=P(151,b|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break k}if(!d){break r}x[31725]=0;O(529,b|0,e+88|0);d=x[31725];x[31725]=0;if((d|0)==1){break k}d=x[e+88>>2];g=w[e+92>>1];x[31725]=0;j=$b(d);d=xe(g);S(187,e+128|0,b|0,j<<(d>>>5&1&(d|0)>0));d=x[31725];x[31725]=0;if((d|0)==1){break k}d=e+128|0;g=ic(e+188|0,d);hd(k,g);ub(g);ub(d)}g=xe(w[e+92>>1]);d=g&15;if((g|0)>=0){break q}Kv(f,0);$=1;break o}h=N()|0;break f}if(d>>>0>6){break o}l=y[d+25062|0];if(!d){break m}w[a+480190>>1]=(z[a+480190>>1]+l|0)-1;i=f+108|0;t=f+236|0;q=l-2|0;h=4;s:while(1){j=1;if((h|0)==10){break n}j=D(h,12);d=(q<<3)+h|0;n=y[d+25068|0]+m|0;r=y[d+25116|0];d=0;while(1)if((d|0)==12){h=h+1|0;continue s}else{A=d+j|0;ia=_b(t,A),ja=n,w[ia>>1]=ja;A=xb(i,A);v[A|0]=r+y[A|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{f=$b(x[e+508>>2]);if(!f){break D}if(!Bb(z[e+512>>1])){break D}x[31725]=0;f=P(151,b|0,f|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break C}if(!f){break D}ia=e,ja=Bb(z[e+512>>1]),w[ia+188>>1]=ja;w[e+128>>1]=y[e+867|0];k=z[Nc(e+188|0,e+128|0)>>1];f=e+136|0;i=e+132|0;l=Bb(z[e+514>>1]);m=l>>>0<5;s=l>>>0<19;o=l>>>0<21;q=l>>>0<15;B=l>>>0<6;g=0;while(1){if((g|0)==(k|0)){break D}x[31725]=0;S(530,b|0,e+188|0,l|0);d=x[31725];x[31725]=0;E:{F:{G:{if((d|0)!=1){g=g+1|0;d=x[((g<<2)+a|0)+900380>>2];j=y[e+188|0];if(j){t=fm(e+128|0,0,64);fm(i,j-1&65535,64);h=y[e+189|0];if(h){h=64/(h>>>0)|0}else{h=0}fm(f,h+j|0,0);x[31725]=0;j=d+48|0;S(531,j|0,t|0,3);h=x[31725];x[31725]=0;if((h|0)==1){break G}if(y[e+188|0]==1){h=x[vb(e+464|0,wb(x[j>>2]))>>2];t=wb(x[j>>2]);h=x[j>>2]+(Iv(h,t)<<2)|0;Ih(j,Wg(h+4|0,x[j+4>>2],h));wb(h)}j=y[e+189|0];x[d>>2]=j?j<<9:32767;v[d+60|0]=y[d+60|0]|1;t=1}H:{if(m){break H}j=y[e+192|0];if(j){ia=xb(d+108|0,24),ja=j+24|0,v[ia|0]=ja;t=1}if(s){break H}x[d+4>>2]=y[e+206|0]+1>>>1;if(o){break H}w[d+28>>1]=y[e+208|0]|y[e+209|0]<<8}d=D(z[_b(d+236|0,61)>>1],104)+a|0;v[d+484417|0]=y[e+191|0]<<4;if(q){break F}j=$b(y[e+198|0]|y[e+199|0]<<8|(y[e+200|0]<<16|y[e+201|0]<<24));x[d+484384>>2]=j;ia=d+484388|0,ja=$b(y[e+202|0]|y[e+203|0]<<8|(y[e+204|0]<<16|y[e+205|0]<<24))+j|0,x[ia>>2]=ja;break E}h=N()|0;break f}h=N()|0;break f}if(B){continue}}j=d+484414|0;h=j;n=z[j>>1]&65529;j=y[e+193|0];w[h>>1]=n|j<<1&2|j>>>1&4;if(!(j&4)){continue}w[d+484412>>1]=0;continue}}I:{f=$b(x[e+524>>2]);if(!f){break I}if(!Bb(z[e+528>>1])){break I}x[31725]=0;f=P(151,b|0,f|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break C}if(!f){break I}ia=e,ja=Bb(z[e+528>>1]),w[ia+188>>1]=ja;w[e+128>>1]=y[e+867|0];j=z[Nc(e+188|0,e+128|0)>>1];h=Bb(z[e+530>>1]);d=0;J:while(1){if((d|0)==(j|0)){break I}x[31725]=0;S(532,b|0,e+188|0,h|0);f=x[31725];x[31725]=0;if((f|0)==1){break t}f=e+88|0;R_(f,e+188|0);x[31725]=0;O(220,e+128|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break u}d=d+1|0;l=((d<<2)+a|0)+900380|0;f=e+128|0;zc(x[l>>2]+492|0,f);tb(f);g=x[l>>2];x[31725]=0;O(391,f|0,g|0);f=x[31725];x[31725]=0;if((f|0)==1){break v}ia=e,ja=$i(x[e+128>>2]),x[ia+88>>2]=ja;k=Rf(e+128|0);while(1){f=x[e+88>>2];if(Ib(f,k)){g=(z[jp(f)>>1]<<5)+a|0;i=g+946328|0;f=x[l>>2];m=x[f+520>>2];x[i>>2]=x[f+516>>2];x[i+4>>2]=m;m=x[f+512>>2];i=g+946320|0;x[i>>2]=x[f+508>>2];x[i+4>>2]=m;m=x[f+504>>2];i=g+946312|0;x[i>>2]=x[f+500>>2];x[i+4>>2]=m;i=x[f+496>>2];g=g+946304|0;x[g>>2]=x[f+492>>2];x[g+4>>2]=i;ah(e+88|0);continue}else{Tv(e+128|0);continue J}}}}sr(a+901404|0);f=qc(e+456|0,4940);sf(Oe(a+901692|0,0),x[f>>2],x[f+4>>2]);xc(b);aa=c&1;q=a+484344|0;B=a+1298332|0;Z=a+1298308|0;M=a+484360|0;l=0;m=0;while(1){K:{c=l&255;if(c>>>0>=y[X|0]){break K}x[31725]=0;V(533,b|0,e+892|0,e+504|0,e+584|0);f=x[31725];x[31725]=0;L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((f|0)==1){break X}Y:{if(!c){d=0;break Y}x[31725]=0;c=R(276,M|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break X}d=l;if((c|0)==255){break d}}k=Xj(x[M>>2],d&255);s=qg(e+444|0);lj(k);if(y[e+891|0]<=1){c=Bb(z[e+586>>1]);if(c>>>0>256){break Q}f=e+188|0;SY(f,e+584|0);x[31725]=0;S(534,k|0,f|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break W}ia=e,ja=wb(x[k>>2]),x[ia+188>>2]=ja;f=wb(x[k+4>>2]);while(1){c=x[e+188>>2];if(Ib(c,f)){w[c>>1]=z[c>>1]+m;Md(e+188|0);continue}break}Yh(a,1);w[e+188>>1]=16;c=z[Nc(F,e+188|0)>>1];d=0;while(1)if((c|0)==(d|0)){c=32;break M}else{v[e+188|0]=y[(d+e|0)+850|0];v[e+128|0]=64;ia=((d<<5)+a|0)+480286|0,ja=y[Rb(e+188|0,e+128|0)|0],w[ia>>1]=ja;d=d+1|0;continue}}SY(e+188|0,e+584|0);c=Bb(z[e+200>>1]);if(!c|c>>>0>64|z[F>>1]>64){break Q}j=$b(x[e+208>>2]);c=Bb(z[e+212>>1]);if(c){w[e+128>>1]=c;w[e+88>>1]=800;c=Bc(((z[Nc(e+128|0,e+88|0)>>1]<<5)+50>>>0)/100|0,0)}else{c=32}f=x[e+196>>2];x[31725]=0;f=P(151,b|0,$b(f)|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break V}d=0;Z:{if(!f){break Z}while(1){if(z[F>>1]<=d>>>0){break Z}x[31725]=0;f=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){v[e+128|0]=f;v[e+88|0]=64;ia=((d<<5)+a|0)+480286|0,ja=y[Rb(e+128|0,e+88|0)|0],w[ia>>1]=ja;d=d+1|0;continue}break}h=N()|0;break w}_:{$:{f=$b(x[e+204>>2]);if(!f){break $}x[31725]=0;f=P(151,b|0,f|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break V}d=0;if(!f){break $}while(1){if(z[F>>1]<=d>>>0){break _}x[31725]=0;f=R(535,b|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){ia=((d<<5)+a|0)+480284|0,ja=(Yb(f,-16,16)<<3)+128|0,w[ia>>1]=ja;d=d+1|0;continue}break}h=N()|0;break w}Yh(a,1)}f=Nb(e+176|0);d=x[e+192>>2];x[31725]=0;h=P(151,b|0,$b(d)|0)|0;d=x[31725];x[31725]=0;aa:{if((d|0)==1){break aa}g=33;d=0;if(!h){break N}h=z[e+586>>1];i=x[b+8>>2];o=x[b>>2];x[31725]=0;h=U(152,o|0,i|0,Bb(h)<<1)|0;i=x[31725];x[31725]=0;if((i|0)==1){break aa}if(!h){break N}h=z[e+586>>1];x[31725]=0;h=U(536,b|0,f|0,Bb(h)|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break aa}if(!h){break N}ia=e,ja=wb(x[f>>2]),x[ia+172>>2]=ja;o=wb(x[e+180>>2]);u=x[e+188>>2];n=z[e+202>>1];while(1){d=x[e+172>>2];if(!Ib(d,o)){g=0;d=1;break N}d=Bb(y[d|0]|y[d+1|0]<<8);ba:{if(Bb(n)>>>0<d>>>0){break ba}x[31725]=0;P(151,b|0,$b(u)+(d<<2)|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break U}x[31725]=0;d=R(283,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break U}x[31725]=0;d=P(151,b|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break U}if(!d){break ba}d=x[b+8>>2];g=x[b>>2];x[31725]=0;d=U(152,g|0,d|0,42)|0;g=x[31725];x[31725]=0;if((g|0)==1){break U}if(!d){break ba}x[31725]=0;O(537,b|0,e+128|0);d=x[31725];x[31725]=0;ca:{if((d|0)!=1){if(lc(x[k>>2],x[k+4>>2])){break ca}x[31725]=0;O(538,k|0,65534);d=x[31725];x[31725]=0;if((d|0)!=1){break ca}}h=N()|0;break O}d=Bb(y[e+168|0]|y[e+169|0]<<8);x[e+124>>2]=d;g=x[b+8>>2];h=x[b>>2];x[31725]=0;d=U(152,h|0,g|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break T}if(!d){x[31725]=0;d=R(204,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break T}wc(e+124|0,d)}wc(e+124|0,65534);g=x[k+4>>2];h=x[k>>2];d=0;x[31725]=0;i=x[e+124>>2];r=Zc(h,g);O(539,k|0,i+r|0);g=x[31725];x[31725]=0;if((g|0)==1){break P}while(1){da:{if((d|0)==(i|0)){if(y[e+128|0]){Mn(e+88|0,e+128|0);x[31725]=0;S(540,e+112|0,x[e+88>>2],x[e+92>>2]);d=x[31725];x[31725]=0;if((d|0)==1){break S}d=e+112|0;wp(k,d);tb(d)}d=$b(y[e+160|0]|y[e+161|0]<<8|(y[e+162|0]<<16|y[e+163|0]<<24));if(!d){break ba}x[31725]=0;d=P(151,b|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){break da}break P}x[31725]=0;g=R(275,b|0)|0;h=x[31725];x[31725]=0;ea:{if((h|0)!=1){g=g<<16>>16;if((g|0)<0){break ea}x[31725]=0;O(538,k|0,g+m&65535);g=x[31725];x[31725]=0;if((g|0)!=1){break ea}}h=N()|0;break O}d=d+1|0;continue}break}if(!d){break ba}while(1){fa:{x[31725]=0;d=P(541,b|0,e+108|0)|0;g=x[31725];x[31725]=0;ga:{ha:{ia:{ja:{if((g|0)!=1){if(!d){break ba}x[31725]=0;S(187,e+68|0,b|0,y[e+111|0]);d=x[31725];x[31725]=0;if((d|0)==1){break ja}d=e+68|0;g=ic(e+88|0,d);ub(d);h=Bb(z[e+108>>1]);d=lm(h+r|0);w[e+68>>1]=d;if((h|0)==65535){break fa}h=x[k>>2];if(Zc(h,x[k+4>>2])>>>0<=d>>>0){break fa}i=65535;switch(y[e+110|0]-1|0){case 0:break ha;case 1:break ia;default:break ga}}h=N()|0;break O}h=N()|0;break O}x[31725]=0;d=R(275,g|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break R}x[31725]=0;h=P(542,s|0,e+68|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break R}w[h>>1]=d;h=x[k>>2];i=65534;d=z[e+68>>1]}ia=_b(h,d),ja=i,w[ia>>1]=ja}ub(g);continue}break}ub(g)}Md(e+172|0);continue}}h=N()|0;break O}h=N()|0;break f}h=N()|0;break w}h=N()|0;break w}h=N()|0;break O}h=N()|0;break O}h=N()|0;break O}h=N()|0;ub(g);break O}cD(s);break d}h=N()|0}md(f);break w}md(f);if(!d){break L}c=c>>>(j>>>1&1)|0}j=Bb(z[e+844>>1]);g=y[e+847|0];_=g&64;f=y[e+848|0];T=f&32;I=(f&31)+1|0;ia=a,ja=PY(j,_>>>6|0,T>>>5|0,I),x[ia+480204>>2]=ja;ia=a,ja=Kd(y[e+849|0],1,32),x[ia+480196>>2]=ja;if(T){x[a+480216>>2]=I;x[a+480220>>2]=I<<2}f=y[e+866|0];if(f){v[e+188|0]=f;v[e+128|0]=64;ia=a,ja=y[Rb(e+188|0,e+128|0)|0]<<2,x[ia+480200>>2]=ja}x[a+480228>>2]=c;x[a+480232>>2]=c;x[a+480208>>2]=x[a+480208>>2]&-3|(g^-1)>>>4&2;ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{c=$b(x[e+548>>2]);ua:{if(!c){break ua}x[31725]=0;c=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ta}if(!c){break ua}c=x[e+552>>2];x[31725]=0;S(272,b|0,Z|0,$b(c)|0);c=x[31725];x[31725]=0;if((c|0)==1){break ta}if(y[X|0]<2){break ua}x[31725]=0;S(260,e+56|0,28,Z|0);c=x[31725];x[31725]=0;if((c|0)==1){break ta}c=e+56|0;wp(k,c);tb(c)}va:{if($b(x[e+520>>2])>>>0<2){break va}c=x[e+516>>2];x[31725]=0;c=P(151,b|0,$b(c)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ta}if(!c){break va}c=x[e+520>>2];x[31725]=0;V(338,B|0,b|0,$b(c)-1|0,4);c=x[31725];x[31725]=0;if((c|0)==1){break ta}}c=$b(x[e+560>>2]);if(!c){break ka}x[31725]=0;c=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ta}if(!c){break ka}c=x[b+8>>2];f=x[b>>2];x[31725]=0;c=U(152,f|0,c|0,12)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ta}if(!c){break ka}x[31725]=0;P(185,b|0,6)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ta}x[31725]=0;c=R(275,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ta}if((c|0)!=1){break ka}x[31725]=0;c=R(283,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ra}if(!c){break ka}f=x[b+8>>2];d=x[b>>2];x[31725]=0;f=U(152,d|0,f|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break ra}if(f){break sa}break ka}h=N()|0;break w}f=_G(e+188|0,B);x[31725]=0;V(338,B|0,b|0,c|0,4);c=x[31725];x[31725]=0;if((c|0)==1){break ma}if(!Ad(x[e+192>>2],y[e+199|0])){x[31725]=0;c=U(543,e+32|0,2,13)|0;d=x[31725];x[31725]=0;if((d|0)==1){break qa}x[31725]=0;S(544,e+128|0,f|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break pa}x[31725]=0;S(545,e+44|0,e+128|0,B|0);d=x[31725];x[31725]=0;if((d|0)==1){break oa}d=e+44|0;Ab(B,d);tb(d);tb(e+128|0);tb(c)}tb(f);break ka}h=N()|0;break w}h=N()|0;break la}h=N()|0;break na}h=N()|0;tb(e+128|0)}tb(c);break la}h=N()|0}tb(f);break w}wa:{J=y[e+891|0];if(J>>>0<2){break wa}h=0;if(!$b(x[e+572>>2])){break wa}while(1){if(z[F>>1]<=h>>>0){break wa}c=x[e+572>>2];x[31725]=0;c=P(151,b|0,$b(c)+(h<<2)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break x}xa:{if(!c){break xa}x[31725]=0;c=R(283,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break x}x[31725]=0;c=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break x}i=0;d=0;if(!c){break xa}while(1){ya:{c=x[b+8>>2];f=x[b>>2];x[31725]=0;c=U(152,f|0,c|0,8)|0;f=x[31725];x[31725]=0;za:{Aa:{Ba:{if((f|0)!=1){if(!c){break ya}x[31725]=0;O(546,b|0,e+188|0);c=x[31725];x[31725]=0;if((c|0)==1){break Ba}c=$b(x[e+188>>2]);if(!c){break ya}switch((c&536870911)-1|0){case 1:break za;case 0:break Aa;default:continue}}h=N()|0;break w}h=N()|0;break w}i=$b(x[e+192>>2]);continue}d=$b(x[e+192>>2]);continue}break}if(!i|!d){break xa}x[31725]=0;c=P(151,b|0,i|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break y}if(!c){break xa}x[31725]=0;S(426,b|0,((h<<5)+a|0)+480289|0,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break y}}h=h+1|0;continue}}ia=e,ja=Bb(z[e+584>>1]),w[ia+172>>1]=ja;Gf(e+172|0,(m^-1)&65535);x[31725]=0;u=z[e+172>>1];O(225,q|0,u+m&65535);c=x[31725];x[31725]=0;Ca:{if((c|0)==1){break Ca}ba=g&16;ca=m&65535;n=0;Da:{Ea:{while(1){if((n|0)==(u|0)){ia=e,ja=$i(x[s>>2]),x[ia+128>>2]=ja;g=Rf(s);while(1){Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{c=x[e+128>>2];if(!Zg(c,g)){c=$b(x[e+504>>2]);if(c){break Ka}g=31;break Ja}c=jp(c);f=af(c);d=z[c>>1];if(!d){d=0;break Ia}j=d-1&65535;if(!cj(k,j)){break Ia}x[31725]=0;d=P(370,k|0,j|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Fa}break Ha}x[31725]=0;c=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ca}g=c?0:31}m=m+u|0;break L}if(z[f>>1]==(d+1|0)){break Ga}x[31725]=0;d=P(369,q|0,1)|0;j=x[31725];x[31725]=0;if((j|0)==1){break Fa}if((d|0)==65535){break Ga}ia=_b(x[k>>2],z[c>>1]),ja=d,w[ia>>1]=ja}c=Wb(x[q>>2],d);ye(c,Gn(Ye(Ne(e+188|0,12,$v(z[f>>1])),x[c+12>>2]-1|0)));u=(u&65535)>>>0>d>>>0?u:d+1|0}ah(e+128|0);continue}break}h=N()|0;break w}La:{Ma:{if(!aa){break Ma}c=y[e+908|0]|y[e+909|0]<<8|(y[e+910|0]<<16|y[e+911|0]<<24);x[31725]=0;c=P(151,b|0,$b(c)+(n<<2)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ea}if(!c){break Ma}x[31725]=0;c=R(283,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ea}x[31725]=0;c=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break Ea}if(!c){break Ma}A=Fb(e+68|0);x[31725]=0;c=v[e+846|0];K=R(170,e+12|0)|0;f=x[31725];x[31725]=0;Na:{Oa:{if((f|0)!=1){j=c+48|0;if(J){break Oa}x[31725]=0;O(547,b|0,e+188|0);c=x[31725];x[31725]=0;if((c|0)==1){break La}w[e+124>>1]=y[e+188|0];r=y[e+189|0]+1|0;break Na}h=N()|0;break z}x[31725]=0;O(548,b|0,e+176|0);f=x[31725];x[31725]=0;Pa:{Qa:{if((f|0)!=1){f=Bb(z[e+176>>1]);w[e+124>>1]=f;r=Bb(z[e+178>>1])+1|0;d=$b(z[e+180>>1]|z[e+182>>1]<<16);if(!d){break Pa}g=x[b+8>>2];x[31725]=0;P(151,b|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break A}x[31725]=0;O(549,b|0,e+188|0);d=x[31725];x[31725]=0;if((d|0)==1){break A}d=y[e+192|0]|y[e+193|0]<<8|(y[e+194|0]<<16|y[e+195|0]<<24);x[31725]=0;d=P(151,b|0,$b(d)|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}if(!d){break Qa}d=y[e+196|0]|y[e+197|0]<<8|(y[e+198|0]<<16|y[e+199|0]<<24);x[31725]=0;S(272,b|0,A|0,$b(d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){break Qa}break A}break A}d=$b(y[e+204|0]|y[e+205|0]<<8|(y[e+206|0]<<16|y[e+207|0]<<24));Ra:{if(!d){break Ra}x[31725]=0;d=P(151,b|0,d|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}if(!d){break Ra}x[31725]=0;d=R(283,b|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}x[31725]=0;d=P(151,b|0,d|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}if(!d){break Ra}x[31725]=0;S(187,e+88|0,b|0,D(f,r)|0);f=x[31725];x[31725]=0;if((f|0)==1){break A}f=e+88|0;d=ic(e+128|0,f);hd(K,d);ub(d);ub(f)}x[31725]=0;P(151,b|0,g|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break A}}j=J>>>0>2?c+24|0:j}x[31725]=0;c=n+ca|0;f=U(198,q|0,c&65535,r|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break A}Sa:{if(!f){break Sa}f=x[q>>2];x[31725]=0;o=Wb(f,c);O(285,o|0,A|0);c=x[31725];x[31725]=0;if((c|0)==1){break Da}Gf(e+124|0,z[F>>1]);da=r-1|0;c=0;ea=z[e+124>>1];Ta:while(1){if((c|0)==(r|0)){break Sa}f=c+1|0;fa=c-1|0;h=0;d=jd(x[o>>2],x[x[o+48>>2]+12>>2],c,0);while(1){G=h&65535;if(ea>>>0<=G>>>0){c=f;continue Ta}vD(e+128|0,y[d+3|0],d+5|0);Ua:{if(!J){x[31725]=0;O(550,e+188|0,b|0);g=x[31725];x[31725]=0;if((g|0)!=1){g=y[e+188|0];i=e+188|0;C=Jc(i);v[d+1|0]=g>>>3&16|y[C|0]>>>4|g>>>1&32;C=y[C|0];ia=d,ja=y[af(i)|0],v[ia+5|0]=ja;g=g&63;g=g?g+j|0:0;i=C&15;break Ua}break A}x[31725]=0;O(359,e+188|0,b|0);g=x[31725];x[31725]=0;Va:{Wa:{if((g|0)!=1){g=e+188|0;i=Jc(g);C=af(g);W=fj(g);x[31725]=0;g=R(199,K|0)|0;E=x[31725];x[31725]=0;if((E|0)==1){break A}v[d+4|0]=g;E=y[e+188|0];g=E&127;if(!g){break Wa}g=g+j|0;break Va}break A}g=0;if((E|0)!=128){break Va}v[d|0]=254}v[d+1|0]=y[i|0]&63;i=y[C|0];v[d+5|0]=y[W|0]}if(g-1>>>0<=119){v[d|0]=g}W=(g|0)>84;C=e+188|0;E=(_|0)!=0;ga=(T|0)!=0;ha=(ba|0)!=0;g=fb-16|0;fb=g;v[d+3|0]=0;Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{i=i&255;switch(i-4|0){case 4:case 10:break Ya;case 42:break _a;case 37:break $a;case 28:break ab;case 27:break bb;case 26:break cb;case 25:break db;case 24:break eb;case 23:break fb;case 22:break gb;case 21:break hb;case 20:break ib;case 18:break jb;case 17:break kb;case 16:break lb;case 14:break mb;case 13:break nb;case 12:break ob;case 11:break pb;case 9:break qb;case 8:break rb;case 5:break sb;case 0:break tb;default:break Za}}v[d+3|0]=5;i=y[d+5|0];v[g+15|0]=i>>>3;v[g+14|0]=15;E=y[Rb(g+15|0,g+14|0)|0];v[g+13|0]=i<<1&30;v[g+12|0]=15;ia=d,ja=y[Rb(g+13|0,g+12|0)|0]|E<<4,v[ia+5|0]=ja;break Ya}if((y[d+5|0]-1&255)>>>0>19){break Ya}v[d+3|0]=16;break Ya}v[d+3|0]=13;i=y[d+5|0];ub:{if(!ha){if(i>>>0>152){break ub}v[d+5|0]=D((i&240)>>>4|0,10)+(i&15);break Ya}v[d+5|0]=(i&127)+1>>>1;break Ya}v[d+3|0]=0;break Ya}v[d+3|0]=11;break Ya}i=y[d+5|0];if(!i){v[d+3|0]=14;break Ya}if(i>>>0>240){break Ya}v[d+3|0]=17;if(i>>>0<=2){v[d+5|0]=112;break Ya}i=HD(+(PY(i,E,ga,I)>>>0)/1e4);if(i>>>0<=255){v[d+5|0]=i;break Ya}v[d+5|0]=i>>>8;v[g+11|0]=i;de(C,34,g+11|0);break Xa}v[d+3|0]=31;v[d+5|0]=y[d+5|0]|128;break Ya}v[d+3|0]=19;v[g+10|0]=15;ia=d,ja=y[Rb(d+5|0,g+10|0)|0]|16,v[ia+5|0]=ja;break Ya}v[d+3|0]=19;v[g+9|0]=15;ia=d,ja=y[Rb(d+5|0,g+9|0)|0]|32,v[ia+5|0]=ja;break Ya}v[d+3|0]=5;i=y[d+5|0];v[g+8|0]=(i>>>4|0)+1;v[g+7|0]=15;ia=d,ja=i&15|y[Rb(g+8|0,g+7|0)|0]<<4,v[ia+5|0]=ja;break Ya}v[d+3|0]=19;v[d+5|0]=y[d+5|0]&15|80;break Ya}v[d+3|0]=19;v[g+6|0]=15;ia=d,ja=y[Rb(d+5|0,g+6|0)|0]|96,v[ia+5|0]=ja;break Ya}v[d+3|0]=19;v[g+5|0]=15;ia=d,ja=y[Rb(d+5|0,g+5|0)|0]|192,v[ia+5|0]=ja;break Ya}v[d+3|0]=10;break Ya}v[d+3|0]=19;v[g+4|0]=15;ia=d,ja=y[Rb(d+5|0,g+4|0)|0]|160,v[ia+5|0]=ja;break Ya}v[d+3|0]=19;v[g+3|0]=15;ia=d,ja=y[Rb(d+5|0,g+3|0)|0]|176,v[ia+5|0]=ja;break Ya}i=y[d+5|0]-1<<24>>24;if((i|0)<0){break Ya}v[d+5|0]=i;v[d+3|0]=31;break Ya}v[d+3|0]=14;break Ya}v[d+3|0]=19;v[g+2|0]=15;ia=d,ja=y[Rb(d+5|0,g+2|0)|0]|224,v[ia+5|0]=ja;break Ya}i=y[d+5|0];if(i>>>0>=16){v[d+3|0]=19;v[d+5|0]=i>>>4|208;break Ya}if(!i){break Ya}v[d+3|0]=19;v[d+5|0]=i|144;break Ya}if(y[d+5|0]|y[d+4|0]){break Ya}if(!Tc(y[d|0])){break Ya}v[d+5|0]=159;v[d+3|0]=20;break Ya}i=y[d+4|0];if(!i){break Ya}v[d+3|0]=44;ia=d,ja=zi(Bc(((y[d+5|0]<<8&65280)>>>0)/(i>>>0)|0,0)),v[ia+5|0]=ja;break Ya}i=y[d+5|0];if((i+16&255)>>>0>32){break Ya}v[d+3|0]=9;ia=d,ja=bh(((i^128)<<3)-896|0),v[ia+5|0]=ja;break Ya}if(i>>>0>15){break Ya}Bf(d,i,y[d+5|0])}v[g+1|0]=0;vD(C,0,g+1|0)}fb=g+16|0;vb:{if(y[e+128|0]!=34){break vb}if(!y[d+3|0]){g=z[e+128>>1];v[d+3|0]=g;v[d+5|0]=g>>>8;break vb}if(!c){break vb}ia=jd(x[o>>2],x[x[o+48>>2]+12>>2],fa,G),ja=255,v[ia+5|0]=ja}g=W&Y;wb:{if(!y[e+188|0]){break wb}if(c>>>0<da>>>0){i=jd(x[o>>2],x[x[o+48>>2]+12>>2],f,G);G=z[e+188>>1];v[i+3|0]=G;v[i+5|0]=G>>>8;break wb}v[d+5|0]=255}t=g|t;d=d+6|0;h=h+1|0;continue}}}ub(K);tb(A)}n=n+1|0;continue}break}break A}h=N()|0;break w}break A}h=N()|0;break w}cD(s);d=0;xb:{switch(g-31|0){default:if(g){break c}break;case 2:break xb;case 1:break c;case 0:break K}}l=l+1|0;continue}break}ek(M,0);d=1;if(t&1){break B}while(1){b=d&65535;if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=0;break B}b=((b<<2)+a|0)+900380|0;c=x[b>>2];if(c){Db(Jv(c))}x[b>>2]=0;d=d+1|0;continue}}h=N()|0;break f}yb:{if(!$){break yb}x[31725]=0;b=P(1,e+188|0,16403)|0;c=x[31725];x[31725]=0;zb:{if((c|0)!=1){c=x[a+1298472>>2];x[31725]=0;S(387,c|0,2,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break zb}tb(b);break yb}h=N()|0;break f}h=N()|0;tb(b);break f}g=22255;Ab:{Bb:{switch(y[e+891|0]){case 0:g=z[F>>1]>4?17291:17277;break Ab;case 1:g=17259;break Ab;case 2:g=17241;break Ab;case 3:break Bb;default:break Ab}}g=17214}x[31725]=0;O(551,e+88|0,16813);b=x[31725];x[31725]=0;Cb:{Db:{Eb:{if((b|0)!=1){x[31725]=0;S(552,e+128|0,e+88|0,e+891|0);b=x[31725];x[31725]=0;if((b|0)==1){break Eb}b=e+128|0;Ab(a+1298344|0,b);tb(b);Eb(e+88|0);x[31725]=0;b=P(1,b|0,12706)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Db}Ab(a+1298356|0,b);tb(b);x[31725]=0;O(132,a+1298368|0,g|0);b=x[31725];x[31725]=0;if((b|0)==1){break Cb}ia=a+1298404|0,ja=x[Fc(e+88|0,28)>>2],x[ia>>2]=ja;d=1;break c}h=N()|0;break f}h=N()|0;Eb(e+88|0);break f}h=N()|0;break f}h=N()|0;break f}h=N()|0;ub(K)}tb(A);break w}h=N()|0;break w}h=N()|0}cD(s);break f}h=N()|0;break f}h=N()|0;break f}h=N()|0;break f}l=1;if((d|0)!=7){break m}d=f+108|0;j=NC(d);while(1){if((d|0)!=(j|0)){ia=d,ja=km(y[d|0]-24|0),v[ia|0]=ja;d=d+1|0;continue}break}j=0}t=1;break l}j=0;Fb:{if(B|(g|0)<0){break Fb}i=f+108|0;h=7;Gb:while(1){if((h|0)==10){break Fb}q=D(h,12);n=D(h,-12)+72|0;d=0;while(1)if((d|0)==12){h=h+1|0;continue Gb}else{r=xb(i,d+q|0);v[r|0]=n+y[r|0];d=d+1|0;continue}}}}x[31725]=0;O(553,L|0,e+188|0);d=x[31725];x[31725]=0;if((d|0)!=1){Hb:{d=y[e+192|0];if((d-1&255)>>>0<=15){v[f+31|0]=d;t=1}d=y[e+193|0];if(d-1<<24>>24>=0){v[f+30|0]=d}d=0;Ib:{while(1){if((d|0)==(l|0)){if(!u){break j}if((g|0)>=0){break Ib}break j}x[31725]=0;f=D(d+o|0,104)+a|0;O(281,f+484380|0,8);h=x[31725];x[31725]=0;if((h|0)!=1){v[e+128|0]=y[e+194|0];v[e+68|0]=64;ia=f+484410|0,ja=y[Rb(e+128|0,e+68|0)|0]<<2,w[ia>>1]=ja;v[f+484416|0]=y[e+195|0];d=d+1|0;continue}break}break k}f=Xc(e+128|0,8,1,1,0);q=Bb(z[e+190>>1]);h=Bb(z[e+188>>1]);d=x[k>>2];x[31725]=0;g=R(156,d|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){d=xe(w[e+92>>1]);if(d&16){fd(f,16);g=g>>>1|0}if(d&32){Dp(f,3);g=g>>>1|0}if(d&64){yg(f,2)}g=j?(g>>>0)/((-1<<l^-1)>>>0)|0:g;i=h+q|0;d=0;while(1){if((d|0)==(l|0)){break j}j=D(d+o|0,104)+a|0;n=j+484380|0;x[n>>2]=g;x[31725]=0;U(217,f|0,n|0,k|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break Hb}h=h<<1;i=i<<1;if(q>>>0>=2){x[j+484388>>2]=i;x[j+484384>>2]=h;j=j+484414|0;w[j>>1]=z[j>>1]|2}d=d+1|0;g=g<<1;continue}}}}}h=N()|0;ub(k);break f}ub(k);s=s+1|0;m=l+m|0;g=z[a+480192>>1];continue}}h=N()|0;break e}h=N()|0;break e}h=N()|0}uc(H)}ub(L);Q(h|0);p()}d=0}uc(H)}ub(L)}fb=e+944|0;return d|0}function epa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=E(0),F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=E(0),ea=0,fa=0,ga=0,ia=0,ja=0;e=fb-608|0;fb=e;xc(b);a:{b:{c:{if(!Ci(b,e+600|0)){break c}if(!EW(e+600|0)){break c}if((vp(b)|0)>=0){break c}if(!c){d=1;break c}Bd(a,16777216);x[a+480208>>2]=x[a+480208>>2]|1681e4;yr(e+256|0,32);f=x[e+268>>2];d=a+1074320|0;x[d>>2]=x[e+264>>2];x[d+4>>2]=f;d=x[e+260>>2];x[a+1074312>>2]=x[e+256>>2];x[a+1074316>>2]=d;dg(a+1074312|0,38);q=Nb(e+588|0);r=Nb(e+576|0);t=Nb(e+564|0);l=Nb(e+552|0);Gh(b,4);i=a+480190|0;K=c&1;H=a+1298332|0;s=2500;I=!(c&2);d:{e:{f:{while(1){c=x[b+8>>2];d=x[b>>2];x[31725]=0;c=U(152,d|0,c|0,4)|0;d=x[31725];x[31725]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){x[31725]=0;c=R(713,b|0)|0;d=x[31725];x[31725]=0;o:{if((d|0)==1){break o}m=4;d=0;p:{q:{r:{switch(c+21|0){case 20:x[31725]=0;c=R(283,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){d=c&65535;if(z[a+480188>>1]|d-1>>>0>126){continue}w[a+480188>>1]=c;ia=a,ja=Yb(512/(d>>>0)|0,16,128),x[ia+480228>>2]=ja;continue}c=N()|0;break a;case 19:x[31725]=0;M=R(283,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break o}if(M>>>0<=1024){continue}break m;case 16:x[31725]=0;c=R(283,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){if((c&65535)==4){continue}break m}c=N()|0;break a;case 15:x[31725]=0;c=R(283,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[e+256>>2]=c;x[e+152>>2]=800;ia=a,ja=_e(+A[Gb(e+256|0,e+152|0)>>2]*1.24*1e4),x[ia+480204>>2]=ja;continue}c=N()|0;break a;case 31:x[31725]=0;c=R(283,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break o}Z=1;s=Kd(c,0,1e4);continue;case 32:case 33:x[31725]=0;c=R(283,b|0)|0;d=x[31725];x[31725]=0;s:{t:{if((d|0)!=1){Z=1;if(!c){continue}x[31725]=0;d=P(1,e+540|0,12615)|0;c=x[31725];x[31725]=0;if((c|0)==1){break t}c=x[a+1298472>>2];x[31725]=0;S(387,c|0,2,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break s}tb(d);continue}c=N()|0;break a}c=N()|0;break a}c=N()|0;tb(d);break a;case 14:x[31725]=0;P(185,b|0,4)|0;c=x[31725];x[31725]=0;if((c|0)==1){break o}g=!z[i>>1]|g;continue;case 11:if(!K){break q}if(!lc(x[q>>2],x[q+4>>2])){break q}x[31725]=0;O(714,e+256|0,b|0);c=x[31725];x[31725]=0;if((c|0)!=1){if(x[q>>2]){kY(q);c=x[q>>2];cp(q);Db(c);ia=zb(q),ja=0,x[ia>>2]=ja;x[q>>2]=0;x[q+4>>2]=0}c=e+256|0;x[q>>2]=x[c>>2];x[q+4>>2]=x[c+4>>2];d=zb(c);ia=zb(q),ja=x[d>>2],x[ia>>2]=ja;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Yi(c);continue}c=N()|0;break a;case 3:case 4:case 10:f=Th(x[l>>2],x[l+4>>2]);d=z[i>>1];if(f>>>0<=d>>>0){continue}if((g|I)&1){break q}if(!vi(d)){break q}d=d+1|0;w[i>>1]=d;u=Nb(e+528|0);x[31725]=0;n=R(170,e+508|0)|0;g=x[31725];x[31725]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}x[31725]=0;c=R(283,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break u}x[31725]=0;S(187,e+152|0,b|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break u}c=e+152|0;g=ic(e+256|0,c);hd(n,g);ub(g);break g}c=N()|0;break d}x[31725]=0;O(715,e+256|0,b|0);c=x[31725];x[31725]=0;x:{if((c|0)!=1){c=e+256|0;g=Fn(u,c);dc(c);oe(e+480|0,x[g>>2],x[e+532>>2]);c=Nd(e+472|0);x[31725]=0;g=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=g;c=jg(329,e+488|0,x[e+480>>2],x[e+484>>2],e+16|0);g=x[31725];x[31725]=0;if((g|0)==1){break x}hd(n,c);break g}c=N()|0;break e}c=N()|0;break e}x[31725]=0;O(716,e+256|0,b|0);c=x[31725];x[31725]=0;y:{if((c|0)!=1){c=e+256|0;g=Fn(u,c);dc(c);oe(e+440|0,x[g>>2],x[e+532>>2]);c=Nd(e+432|0);x[31725]=0;g=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=g;c=jg(329,e+452|0,x[e+440>>2],x[e+444>>2],e+8|0);g=x[31725];x[31725]=0;if((g|0)==1){break y}hd(n,c);break g}c=N()|0;break e}c=N()|0;break e}c=N()|0;break e;case 9:c=z[i>>1];if(!vi(c)){continue}w[i>>1]=c+1;continue;case 8:if(!K){break q}if(!lc(x[t>>2],x[t+4>>2])){break q}x[31725]=0;O(717,e+256|0,b|0);c=x[31725];x[31725]=0;if((c|0)!=1){c=e+256|0;DW(t,c);uc(c);continue}c=N()|0;break a;case 7:if(!lc(x[l>>2],x[l+4>>2])){break q}x[31725]=0;O(718,e+256|0,b|0);c=x[31725];x[31725]=0;if((c|0)!=1){if(x[l>>2]){ZV(l);c=x[l>>2];lC(l);Db(c);ia=zb(l),ja=0,x[ia>>2]=ja;x[l>>2]=0;x[l+4>>2]=0}c=e+256|0;x[l>>2]=x[c>>2];x[l+4>>2]=x[c+4>>2];d=zb(c);ia=zb(l),ja=x[d>>2],x[ia>>2]=ja;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;tv(c);continue}c=N()|0;break a;case 6:if(!K){break q}if(!lc(x[r>>2],x[r+4>>2])){break q}x[31725]=0;O(719,e+256|0,b|0);c=x[31725];x[31725]=0;if((c|0)!=1){if(x[r>>2]){cW(r);c=x[r>>2];iv(r);Db(c);ia=zb(r),ja=0,x[ia>>2]=ja;x[r>>2]=0;x[r+4>>2]=0}c=e+256|0;x[r>>2]=x[c>>2];x[r+4>>2]=x[c+4>>2];d=zb(c);ia=zb(r),ja=x[d>>2],x[ia>>2]=ja;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;rn(c);continue}c=N()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}x[31725]=0;O(720,e+256|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break n}z:{c=x[e+256>>2];d=x[e+260>>2];if(lc(c,d)){break z}x[31725]=0;V(345,H|0,c|0,Sc(c,d)|0,1);c=x[31725];x[31725]=0;if((c|0)!=1){break z}c=N()|0;dc(e+256|0);break a}dc(e+256|0);continue}x[31725]=0;m=R(283,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break o}}x[31725]=0;P(185,b|0,m|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}}c=N()|0;break a}d=0;if(!z[a+480188>>1]|!M){break m}b=x[l>>2];c=x[l+4>>2];if(lc(b,c)){break m}if(K){if(lc(x[q>>2],x[q+4>>2])){break m}if(lc(x[t>>2],x[t+4>>2])){break m}if(lc(x[r>>2],x[r+4>>2])){break m}}b=Th(b,c);if(b>>>0>=256){x[31725]=0;O(721,l|0,255);b=x[31725];x[31725]=0;if((b|0)==1){break b}b=Th(x[l>>2],x[l+4>>2])}w[a+480192>>1]=b;m=a+480192|0;ia=a,ja=z[qe(i,m)>>1],w[ia+480190>>1]=ja;if(g&1){x[31725]=0;b=P(1,e+528|0,16492)|0;c=x[31725];x[31725]=0;if((c|0)==1){break h}c=x[a+1298472>>2];x[31725]=0;S(387,c|0,2,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break i}tb(b)}g=0;A:while(1){if((g|0)!=2){d=1;while(1){h=d&65535;if(h>>>0>z[m>>1]){g=g+1|0;continue A}B:{f=pn(x[l>>2],h-1|0);if(!y[f|0]|v[f+128|0]<0){break B}if((ov(f)|0)==((g|0)!=1|0)){break B}C:{D:{E:{c=0;F:{if(!ov(f)){break F}if(Bb(y[f+6|0]|y[f+7|0]<<8)){break F}if(Bb(y[f+14|0]|y[f+15|0]<<8)>>>0>20){break F}c=(Bb(y[f+18|0]|y[f+19|0]<<8)|0)==4}G:{H:{if(c){c=y[f+23|0];b=y[f+140|0];x[31725]=0;b=ha(722,f|0,a|0,(b&2)>>>1|0,(D(h,104)+a|0)+484380|0,s&65535)|0;k=x[31725];x[31725]=0;I:{J:{if((k|0)!=1){if(!b){break I}x[31725]=0;b=P(36,e+384|0,10755)|0;k=x[31725];x[31725]=0;if((k|0)==1){break J}zc(((h<<5)+a|0)+946304|0,b);tb(b);k=x[l>>2];b=d;if(Th(k,x[l+4>>2])>>>0<=c>>>0){break G}ia=f,ja=y[f+143|0]+y[pn(k,c)+143|0]|0,v[ia+143|0]=ja;break H}c=N()|0;break a}c=N()|0;break a}b=c+1|0;break G}c=0;K:{if(!ov(f)){break K}if((Bb(y[f+6|0]|y[f+7|0]<<8)|0)!=1){break K}if((Bb(y[f+14|0]|y[f+15|0]<<8)|0)!=2){break K}c=(Bb(y[f+18|0]|y[f+19|0]<<8)|0)==10}b=d;if(!c){break G}uW(e+256|0,f);b=Bb(y[e+276|0]|y[e+277|0]<<8);if(b>>>0>=z[i>>1]){break H}x[31725]=0;c=R(711,e+152|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break E}k=y[e+292|0]|y[e+293|0]<<8;n=z[a+480190>>1];x[31725]=0;o=D(b,104);b=a+484380|0;k=Bb(k);b=ba(723,e+256|0,(o+b|0)+104|0,(k>>>0<n>>>0?(b+D(k,104)|0)+104|0:c)|0,b+D(h,104)|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break D}if(!b){break H}x[31725]=0;b=P(36,e+140|0,11253)|0;c=x[31725];x[31725]=0;if((c|0)==1){break C}zc(((h<<5)+a|0)+946304|0,b);tb(b);v[f+139|0]=y[f+139|0]+12}b=d}x[31725]=0;b=b&65535;c=U(253,a|0,h|0,b|0)|0;h=x[31725];x[31725]=0;if((h|0)!=1){if(!c|b>>>0>z[i>>1]){break B}x[31725]=0;V(724,f|0,c|0,(D(b,104)+a|0)+484380|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break B}}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}d=d+1|0;continue}}break}I=qg(e+128|0);u=qg(e+116|0);b=oc(x[t>>2],x[t+4>>2]);_=D(z[a+480188>>1],M);$=lm((b>>>0)/(_>>>0)|0);x[31725]=0;X=a+484344|0;O(225,X|0,$|0);b=x[31725];x[31725]=0;if((b|0)==1){break k}lj(Xb(x[a+484360>>2],y[a+484376|0]));b=z[a+480188>>1];x[31725]=0;F=P(725,e+104|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}ia=e,ja=wb(x[r>>2]),x[ia+52>>2]=ja;ea=a+902204|0;fa=wb(x[r+4>>2]);while(1){L:{M:{N:{n=x[e+52>>2];if(!Ib(n,fa)){break N}b=xe((y[n+6|0]|y[n+7|0]<<8)<<16>>16);if((b|0)==1){break L}if((b&65535)==65535){break N}g=Bb(y[n|0]|y[n+1|0]<<8);b=x[q>>2];f=x[q+4>>2];c=Lg(b,f);if(g>>>0>=c>>>0){break L}d=Bb(y[n+2|0]|y[n+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(Lg(b,f)<<5)|0;x[e+256>>2]=b;x[e+260>>2]=c-b>>5;b=x[e+256>>2];gc(e+76|0,b+(Bb(y[n|0]|y[n+1|0]<<8)<<5)|0,Bb(y[n+2|0]|y[n+3|0]<<8));O:{G=Xb(x[a+484360>>2],y[a+484376|0]);if(lc(x[G>>2],x[G+4>>2])){break O}x[31725]=0;O(538,G|0,65534);b=x[31725];x[31725]=0;if((b|0)!=1){break O}break M}ia=e,ja=wb(x[e+76>>2]),x[ia+40>>2]=ja;b=fb-16|0;fb=b;ga=x[vb(b+12|0,x[e+76>>2]+(x[e+80>>2]<<5)|0)>>2];fb=b+16|0;while(1){i=x[e+40>>2];if(!Ib(i,ga)){break L}b=xe(xe((y[n+8|0]|y[n+9|0]<<8)<<16>>16)+xe((y[i+16|0]|y[i+17|0]<<8)<<16>>16)<<16>>16);v[i+16|0]=b;v[i+17|0]=b>>>8;b=ce(I);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!kv(i,d)){c=1;if(!kv(d,i)){break P}b=b+4|0}b=x[b>>2];continue}break}Q:{R:{S:{if(c){x[31725]=0;b=P(726,I|0,i|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break M}H=z[b>>1];break S}H=0;if(!K){break S}b=y[i+12|0]|y[i+13|0]<<8;x[31725]=0;H=P(369,X|0,Bb(b)|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break M}if((H|0)==65535){break L}x[31725]=0;b=P(726,I|0,i|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break M}w[b>>1]=H;if(Bb(y[i+8|0]|y[i+9|0]<<8)>>>0>=$>>>0){break R}if(Bb(y[i+10|0]|y[i+11|0]<<8)>>>0>=M>>>0){break R}k=Bb(y[i+14|0]|y[i+15|0]<<8);c=Mk(wb(x[t>>2]),D(Bb(y[i+8|0]|y[i+9|0]<<8),_));b=z[a+480188>>1];ia=e,ja=Mk(c,D(b,Bb(y[i+10|0]|y[i+11|0]<<8))),x[ia+28>>2]=ja;T=0;x[e+100>>2]=0;o=ch(e- -64|0);T:while(1){U:{d=Bb(y[i+12|0]|y[i+13|0]<<8);c=Wb(x[X>>2],H);if(d>>>0<=T>>>0){break U}m=0;Y=jd(x[c>>2],x[x[c+48>>2]+12>>2],T,0);c=0;while(1){if((b&65535)>>>0<=m>>>0){T=T+1|0;continue T}b=wb(x[t+4>>2]);d=x[e+28>>2];h=Ib(d,b)?d:e+100|0;b=wb(x[t+4>>2]);if(Ib(x[e+28>>2],b)){BW(e+28|0)}d=Y+D(m,6)|0;g=y[h+1|0];b=(g>>>0>=85?-1:g+25|0)<<24>>24;s=0;f=x[l>>2];L=Th(f,x[l+4>>2]);J=y[h+3|0];V:{if(L>>>0<=J>>>0){break V}s=J+1|0;if(v[pn(f,J)+142|0]&1|(b|0)<0){break V}b=km(xe((y[i+16|0]|y[i+17|0]<<8)<<16>>16)+b<<24>>24)}W:{if(!y[d|0]|!(y[h|0]|(g|0)!=255|J|y[h+2|0])){break W}g=y[d+1|0];if(!g|g>>>0>L>>>0){break W}if(y[pn(f,g-1|0)+132|0]!=2){break W}ap(d)}f=qv(x[F>>2],m);X:{Y:{if(!(c&1)){g=y[h|0];break Y}c=y[o|0]|y[o+1|0]<<8|(y[o+2|0]<<16|y[o+3|0]<<24);v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;c=y[o+4|0]|y[o+5|0]<<8;v[d+4|0]=c;v[d+5|0]=c>>>8;Z:{if(y[d+3|0]){break Z}g=y[f+21|0];c=y[qv(x[F>>2],m-1|0)+21|0];if((g|0)==(c|0)){break Z}v[d+3|0]=21;v[f+21|0]=c;v[d+5|0]=c}c=0;g=y[h|0];if(!(g-24>>>0<2|(g|0)==9|!g&(y[h+2|0]+7&255)>>>0<2)){break X}}_:{$:{aa:{ba:{ca:{da:{switch(g|0){case 5:c=y[f+17|0];break ca;case 0:ea:{c=y[h+2|0];if(c>>>0>=201){g=0;fa:{switch(c-242|0){case 11:v[d+4|0]=1;v[d+2|0]=14;v[f+16|0]=0;break $;case 9:if(!y[d|0]){v[d|0]=y[f+17|0]}v[d+4|0]=1;v[d+2|0]=15;break $;case 8:if((k&255)>>>0<2){break $}k=k-1|0;break aa;case 7:if((k&255)==255){k=255;break $}k=k+1|0;break aa;case 6:v[f+17|0]=b;if(y[f+18|0]!=(s&255)){break $}v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;w[f+32>>1]=0;x[f+8>>2]=0;break $;case 5:v[d+5|0]=242;v[d+3|0]=2;break $;case 4:v[d+5|0]=242;v[d+3|0]=3;break $;case 3:v[d+5|0]=244;v[d+3|0]=2;break $;case 2:v[d+5|0]=244;v[d+3|0]=3;break $;case 1:v[d+5|0]=248;v[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}v[d+5|0]=248;v[d+3|0]=3;break $}g=0;L=v[h+1|0];if((L|0)<0&c>>>0>99){break $}if((L|0)>=0){v[f+17|0]=b;v[d|0]=b;v[f+18|0]=s;v[d+1|0]=s;w[f+32>>1]=0;x[f+8>>2]=0;c=y[h+2|0]}b=c&255;if(!b){break $}ia=f,ja=gm(+(b>>>0)*.64),v[ia+19|0]=ja;j=B[f>>2];x[f>>2]=0;g=j!=E(0);break $}v[d+4|0]=0;v[d+2|0]=14;v[f+16|0]=1;break $;case 1:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(.0333000011742115);break _;case 2:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(-.0333000011742115);break _;case 12:v[e+256|0]=15;v[e+96|0]=y[h+3|0]>>>3;b=y[Rb(e+256|0,e+96|0)|0];v[e+256|0]=15;v[e+96|0]=y[h+2|0]>>>3;ia=f,ja=y[Rb(e+256|0,e+96|0)|0]|b<<4,v[ia+24|0]=ja;break _;case 3:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(.0333000011742115);break _;case 4:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(-.0333000011742115);break _;case 15:if(!y[h+2|0]|(b|0)<0){break _}g=b-y[f+17|0]<<5;c=g>>31;c=(c^g)-c|0;x[e+256>>2]=c;v[f+17|0]=b;x[f+8>>2]=0;v[d|0]=b;v[d+3|0]=4;b=bh((c>>>0)/(y[h+2|0]<<1>>>0)|0);v[d+5|0]=b;v[f+27|0]=b;x[e+96>>2]=D(b,(k&255)-1|0);ia=f,ja=c-x[ud(e+256|0,e+96|0)>>2]|0,w[ia+32>>1]=ja;break _;case 13:v[e+256|0]=15;v[e+96|0]=y[h+3|0]>>>3;b=y[Rb(e+256|0,e+96|0)|0];v[e+256|0]=15;v[e+96|0]=y[h+2|0];ia=f,ja=y[Rb(e+256|0,e+96|0)|0]|b<<4,v[ia+23|0]=ja;break _;case 18:b=y[h+2|0]+y[f+17|0]&255;b=b?b>>>0>=120?120:b:1;v[f+17|0]=b;v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;break ba;case 23:case 24:case 25:b=ce(u);while(1){ga:{c=0;if(!b){break ga}g=b+13|0;if(!mv(h,g)){c=1;if(!mv(g,h)){break ga}b=b+4|0}b=x[b>>2];continue}break};if(c){v[d+3|0]=31;x[31725]=0;b=P(727,u|0,h|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break M}v[d+5|0]=y[b|0];break _}b=x[zb(u)>>2];if(b>>>0>127){break _}x[e+92>>2]=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);c=Oe(ea,b&255);g=x[a+480208>>2];x[31725]=0;x[e+24>>2]=x[e+92>>2];c=U(728,e+24|0,c|0,g|0)|0;g=x[31725];x[31725]=0;ha:{if((g|0)==1){break ha}if(!c){break _}v[d+3|0]=31;x[31725]=0;c=P(727,u|0,h|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break ha}b=b|-128;v[c|0]=b;v[d+5|0]=b;aa=(y[h|0]&254)==24|aa;break _}break M;case 16:if(!y[h+2|0]){break _}v[d+3|0]=15;x[e+256>>2]=15;x[e+96>>2]=y[h+3|0]+1;ia=d,ja=x[ud(e+256|0,e+96|0)>>2],v[ia+5|0]=ja;w[f+30>>1]=D(y[h+2|0],y[h+3|0]+1|0);break _;case 9:v[d+3|0]=16;b=y[h+2|0];k=b?b:4;v[d+5|0]=k;break _;case 19:ia:{b=y[h+1|0];switch(b|0){case 0:case 4:break ia;default:break _}}g=128;g=(b|0)==4?y[h+3|0]:g;v[e+91|0]=g;v[e+256|0]=y[h+2|0];v[e+96|0]=100;b=e+256|0;s=e+96|0;c=y[Rb(b,s)|0];x[e+256>>2]=128;x[e+96>>2]=256-(g&255);g=x[ud(b,s)>>2];v[e+256|0]=128;b=y[Rb(b,e+91|0)|0];g=(D(c,g)|0)/128|0;s=g&255;if((s|0)!=y[f+20|0]){v[f+20|0]=g;v[d+3|0]=21;g=Bc(((D(s,y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=g;v[d+5|0]=g}if(y[h+1|0]!=4|(z[a+480188>>1]-1|0)<=(m|0)){break _}g=m+1|0;h=qv(x[F>>2],g);b=D(b,c)>>>7|0;if(y[h+20|0]==(b&255)){break _}v[h+20|0]=b;b=Y+D(g,6)|0;v[b+3|0]=21;c=Bc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=c;v[b+5|0]=c;break _;case 10:case 11:case 17:case 20:v[d+3|0]=0;break _;case 7:b=y[h+2|0];v[f+25|0]=0;v[f+26|0]=0;v[f+22|0]=b;break _;case 8:v[f+22|0]=y[f+22|0]+y[h+2|0];break _;case 14:v[f+25|0]=y[h+3|0];v[f+26|0]=y[h+2|0];break _;case 6:break da;default:break _}}v[f+18|0]=s;v[f+17|0]=b;v[d+1|0]=s;c=b}v[d|0]=c;if((b|0)>=0){v[f+18|0]=s;v[d+1|0]=s}if(y[h|0]==5){v[d+4|0]=1;v[d+2|0]=11}b=y[f+26|0];c=y[f+22|0];if(!(b|(c|y[h+2|0]))){break ba}if(b){ca=(Xi(+z[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{ca=0}v[d+3|0]=44;ia=d,ja=gm(ca+ +(c+y[h+2|0]|0)),v[ia+5|0]=ja}w[f+32>>1]=0;break _}v[d+5|0]=k;v[d+3|0]=16}b=Bc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!g&y[f+21|0]==(b&255))){v[f+21|0]=b;v[d+5|0]=b;v[d+3|0]=21}if(m&1|v[h+1|0]<=0|(z[a+480188>>1]-1|0)<=(m|0)){break _}b=x[l>>2];if(Th(b,x[l+4>>2])>>>0<=J>>>0){break _}if(y[pn(b,J)+132|0]!=1){break _}g=m+1|0;b=Y+D(g,6)|0;c=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[d+4|0]|y[d+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;v[b+1|0]=y[b+1|0]+1;b=qv(x[F>>2],g);v[b+19|0]=y[f+19|0];B[b>>2]=B[f>>2];B[b+4>>2]=B[f+4>>2];B[b+8>>2]=B[f+8>>2];B[b+12>>2]=B[f+12>>2];w[b+30>>1]=z[f+30>>1]}ja:{if(y[d|0]){v[f+16|0]=0;break ja}c=0;if(y[f+16|0]){break X}}ka:{if(!z[f+30>>1]){break ka}b=k&255;w[e+256>>1]=b;c=f+30|0;ia=c,ja=z[qe(c,e+256|0)>>1]-b|0,w[ia>>1]=ja;if(y[d+3|0]){break ka}v[d+3|0]=15;v[d+5|0]=0}j=B[f>>2];la:{if(j==E(0)){break la}b=k&255;j=E(E(j*E(b>>>0))+B[f+4>>2]);B[f+4>>2]=j;if(y[d+3|0]){break la}ma:{na:{oa:{pa:{if(b>>>0>=2){g=b-1|0;C=E(g|0);if(!(C<=j)){break pa}v[e+256|0]=15;ia=e,ja=Bh(E(j/C)),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+4>>2]=j-E(D(b,g)|0);v[d+3|0]=22;c=b<<4;break ma}if(!(j>=E(1))){break oa}break na}if(j>=E(1)){break na}if(!(j<=E(1-b|0))){break oa}v[e+256|0]=15;ia=e,ja=Bh(E(E(-j)/C)),v[ia+96|0]=ja;c=y[Rb(e+256|0,e+96|0)|0];B[f+4>>2]=j+E(D(g,c)|0);v[d+3|0]=22;break ma}if(!(j<=E(-1))){break la}v[e+256|0]=14;ia=e,ja=Bh(E(-j)),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+4>>2]=j+E(b>>>0);v[d+3|0]=22;c=b|-16;break ma}v[e+256|0]=15;ia=e,ja=Bh(j),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+4>>2]=j-E(b>>>0);v[d+3|0]=22;c=b<<4|15}v[d+5|0]=c}j=B[f+8>>2];qa:{if(j==E(0)){break qa}b=k&255;j=E(E(j*E(b>>>0))+B[f+12>>2]);B[f+12>>2]=j;ra:{if(!y[d+3|0]){sa:{ta:{if(b>>>0>=2){c=b-1|0;C=E(c|0);if(!(C<=j)){break ta}v[e+256|0]=223;ia=e,ja=Bh(E(j/C)),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(D(b,c)|0);v[d+3|0]=2;v[d+5|0]=b;break qa}if(!(j>=E(1))){break sa}break ra}if(j>=E(1)){break ra}if(!(E(1-b|0)>=j)){break sa}v[e+256|0]=223;ia=e,ja=Bh(E(E(-j)/C)),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(D(b,c)|0);v[d+3|0]=3;v[d+5|0]=b;break qa}if(!(j<=E(-1))){break qa}v[e+256|0]=14;ia=e,ja=Bh(E(-j)),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(b>>>0);v[d+3|0]=3;v[d+5|0]=b|240;break qa}if(y[d+2|0]|b>>>0<2){break qa}da=E(j*E(.25));c=b-1|0;C=E(c|0);if(da>=C){v[e+256|0]=9;ia=e,ja=Bh(E(j/C))>>>2|0,v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(D(b,c)<<2);v[d+2|0]=12;v[d+4|0]=b;break qa}if(!(da<=E(1-b|0))){break qa}v[e+256|0]=9;ia=e,ja=Bh(E(E(-j)/C))>>>2|0,v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(D(b,c)<<2);v[d+2|0]=13;v[d+4|0]=b;break qa}v[e+256|0]=15;ia=e,ja=Bh(j),v[ia+96|0]=ja;b=y[Rb(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(b>>>0);v[d+3|0]=2;v[d+5|0]=b|240}ua:{va:{wa:{xa:{ya:{za:{Aa:{b=y[d+3|0];switch(b|0){case 4:break ua;case 0:break Aa;default:break za}}Ba:{b=y[f+23|0];if(!b){b=y[f+24|0];if(b){break Ba}if(!z[f+32>>1]){break ua}c=f+32|0;break ya}v[d+3|0]=5;v[d+5|0]=b;if(!z[f+32>>1]){break ua}break xa}v[d+3|0]=8;v[d+5|0]=b;if(z[f+32>>1]){break xa}break ua}if(!z[f+32>>1]){break ua}c=f+32|0;if(b){break wa}}v[d+3|0]=4;break va}c=f+32|0}v[d+2|0]=11}w[e+256>>1]=D(y[f+27|0],(k&255)-1|0);ia=f,ja=z[f+32>>1]-z[Nc(c,e+256|0)>>1]|0,w[ia+32>>1]=ja}w[f+28>>1]=z[f+28>>1]+D(y[f+25|0],k&255)&1023;c=0;if(m&1){break X}b=y[f+18|0];if(!b){break X}g=x[l>>2];if(Th(g,x[l+4>>2])>>>0<b>>>0){break X}g=pn(g,b-1|0);if(!(y[g+142|0]&4)){break X}b=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[o|0]=b;v[o+1|0]=b>>>8;v[o+2|0]=b>>>16;v[o+3|0]=b>>>24;b=y[d+4|0]|y[d+5|0]<<8;v[o+4|0]=b;v[o+5|0]=b>>>8;c=1;b=y[e+65|0];if(!b|y[g+132|0]!=1){break X}v[e+65|0]=b+1}m=m+1|0;b=z[a+480188>>1];continue}}break}ye(c,Zh(Ye(Ne(e+256|0,16,Bb(y[i+14|0]|y[i+15|0]<<8)&255),0)))}b=mm(x[G>>2],x[G+4>>2]);ia=e,ja=Bb(y[i+4|0]|y[i+5|0]<<8),w[ia+256>>1]=ja;w[e+64>>1]=1;c=z[qe(e+256|0,e- -64|0)>>1];x[31725]=0;V(729,G|0,b|0,c|0,H&65535);b=x[31725];x[31725]=0;if((b|0)==1){break Q}b=xe((y[n+8|0]|y[n+9|0]<<8)<<16>>16);b=xe(xe((y[i+16|0]|y[i+17|0]<<8)<<16>>16)-b<<16>>16);v[i+16|0]=b;v[i+17|0]=b>>>8}er(e+40|0);continue}break}break M}d=aa&1;if(d){g=a+906300|0;b=vd(g,0);x[31725]=0;W(288,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break M}x[b+16>>2]=1299020115;x[b+20>>2]=1869112133;x[b+24>>2]=655376;x[b+28>>2]=0;x[e+256>>2]=0;f=b+48|0;c=e+256|0;s0(b+32|0,f,c);x[31725]=0;c=P(36,c|0,9571)|0;h=x[31725];x[31725]=0;if((h|0)==1){break M}tE(f,c);tb(c);x[31725]=0;c=P(36,e+76|0,9564)|0;f=x[31725];x[31725]=0;if((f|0)==1){break M}mw(b+80|0,c);tb(c);x[31725]=0;b=P(36,e- -64|0,9556)|0;c=x[31725];x[31725]=0;if((c|0)==1){break M}tE(vd(g,1)+48|0,b);tb(b)}b=0;while(1){if(z[a+480188>>1]>b>>>0){ZD(a,b&65535);c=(b<<5)+a|0;v[c+480288|0]=d;w[c+480284>>1]=b<<8&256;b=b+1|0;continue}break}x[31725]=0;b=P(1,e+52|0,12165)|0;c=x[31725];x[31725]=0;Ca:{Da:{Ea:{if((c|0)!=1){Ab(a+1298344|0,b);tb(b);x[31725]=0;b=P(1,e+40|0,12383)|0;c=x[31725];x[31725]=0;if((c|0)==1){break M}Ab(a+1298356|0,b);tb(b);if(Z){break Ea}x[31725]=0;b=P(1,e+28|0,12165)|0;c=x[31725];x[31725]=0;if((c|0)==1){break M}break Da}break M}if(Th(x[l>>2],x[l+4>>2])>>>0<=128){x[31725]=0;b=P(1,e+28|0,9298)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break Da}break M}x[31725]=0;b=P(1,e+28|0,14802)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Ca}}Ab(a+1298368|0,b);tb(b);ia=a+1298404|0,ja=x[Fc(e+100|0,28)>>2],x[ia>>2]=ja;AW(F);oW(u);nW(I);d=1;break m}}c=N()|0;AW(F);break j}$o(e+52|0);continue}}c=N()|0;break a}c=N()|0;break a}tv(l);uc(t);rn(r);Yi(q);break c}c=N()|0;break j}c=N()|0}oW(u);nW(I);break a}c=N()|0;tb(b);break a}c=N()|0;break a}ub(c);x[31725]=0;c=d&65535;d=U(730,a|0,c|0,n|0)|0;g=x[31725];x[31725]=0;Fa:{Ga:{Ha:{Ia:{if((g|0)==1){break Ia}if(d){break Fa}x[31725]=0;d=U(731,a|0,c|0,n|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31725]=0;d=U(732,a|0,c|0,n|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31725]=0;d=P(733,(D(c,104)+a|0)+484380|0,n|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31725]=0;d=P(1,e+420|0,16203)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Ha}g=x[a+1298472>>2];x[31725]=0;S(387,g|0,2,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break Ga}tb(d);break Fa}c=N()|0;break e}c=N()|0;break e}c=N()|0;tb(d);break e}Ja:{Ka:{La:{F=D(c,104)+a|0;if(y[F+484414|0]&64){d=z[i>>1];if(vi(d)){break La}}d=x[l>>2];if(Th(d,x[l+4>>2])>>>0<=c>>>0){break Ka}if(y[pn(d,c)+132|0]!=2){break Ka}c=z[i>>1];if(!vi(c)){break Ka}w[i>>1]=c+1;break Ka}c=d+1|0;w[a+480190>>1]=c;G=D(c&65535,104)+a|0;o=G+484380|0;h=F+484380|0;d=x[h>>2];g=x[h+20>>2];Ma:{if(!je(d,g)){break Ma}f=z[h+34>>1];if((h|0)==(o|0)|(_d(f)|0)!=2){break Ma}c=(h|0)==(o|0);if(!(je(x[o>>2],x[o+20>>2])?c:1)){break Ma}je(x[h>>2],x[h+20>>2]);if(!c){g=nv(d,Qn(f))}f=x[h+20>>2];if(!(f?g:0)){if(!c){aC(g)}break Ma}Na:{Oa:{switch(Qn(z[h+34>>1])-1|0){case 1:d=g;c=f;m=x[h+20>>2];k=x[h>>2];while(1){if(k){w[d>>1]=z[m>>1];w[c>>1]=z[m+2>>1];m=m+4|0;c=c+2|0;d=d+2|0;k=k-1|0;continue}break};break Na;case 0:break Oa;default:break Na}}d=g;c=f;m=x[h+20>>2];k=x[h>>2];while(1){if(k){v[d|0]=y[m|0];v[c|0]=y[m+1|0];m=m+2|0;c=c+1|0;d=d+1|0;k=k-1|0;continue}break}}d=bp(o,h);w[d+34>>1]=z[d+34>>1]&65471;x[o+20>>2]=g;g=bp(h,h);w[g+34>>1]=z[g+34>>1]&65471;x[h+20>>2]=f;f=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(f|0)){h=x[c+104>>2];if(!((h|0)!=(d|0)&(g|0)!=(h|0))){x[c+88>>2]=x[c+88>>2]&-65}c=c+872|0;continue}break}Sj(d,a);Sj(g,a)}x[31725]=0;c=P(36,e+408|0,6320)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Ja}ze(G+484423|0,c);tb(c);x[31725]=0;c=P(36,e+396|0,6223)|0;d=x[31725];x[31725]=0;if((d|0)==1){break f}ze(F+484423|0,c);tb(c)}ub(n);dc(u);g=0;continue}break}c=N()|0;break e}c=N()|0}ub(n)}dc(u);break a}fb=e+608|0;return d|0}c=N()|0}tv(l);uc(t);rn(r);Yi(q);Q(c|0);p()}function Dv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,R=0,T=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,fa=0,ia=0,ka=E(0),la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,xa=0,ya=E(0);i=fb-192|0;fb=i;X=Nb(a);s=i+160|0;v[s+26|0]=0;w[s+24>>1]=0;x[s+16>>2]=0;x[s+20>>2]=-1;x[s+8>>2]=-1;x[s+12>>2]=-1;x[s>>2]=0;x[s+4>>2]=0;ea=x[d+16>>2];a=y[d+6|0];g=x[b+484360>>2];la=(ua=a,va=y[b+484376|0],xa=Qj(g,x[b+484364>>2])>>>0>a>>>0,xa?ua:va);a=la&255;K=Xj(g,a);x[31725]=0;t=P(604,i+128|0,b|0)|0;g=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{if((g|0)!=1){l=x[t+4>>2];x[31725]=0;J=U(605,i+92|0,b|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break f}qa=b+484360|0;$=c&7;k=x[d>>2];a=z[d+4>>1];g=Zc(x[K>>2],x[K+4>>2]);while(1){f=a&65535;if(f>>>0>=g>>>0){break e}if(cj(K,f)){break e}a=a+1|0;k=0;continue}}a=N()|0;break c}a=N()|0;break d}x[d>>2]=k;w[d+4>>1]=a;x[l+52>>2]=k;x[l+48>>2]=k;x[s+16>>2]=k;w[l+74>>1]=a;w[l+72>>1]=a;w[s+24>>1]=a;ma=Nd(i+84|0);g:{if(($|0)!=7){break g}a=fb-16|0;fb=a;g=a+8|0;Jb(g,ma,1);hp(g);fb=a+16|0;if((ea|0)!=2){break g}a=x[K>>2];f=Zc(a,x[K+4>>2]);g=z[d+12>>1];if(f>>>0<=g>>>0){break g}f=x[b+484344>>2];k=x[b+484348>>2];a=z[_b(a,g)>>1];if(!He(f,k,a)){break g}g=Wb(f,a);f=x[d+8>>2];if(A[g+12>>2]<=f>>>0){break g}a=0;n=jd(x[g>>2],x[x[g+48>>2]+12>>2],f,0);g=x[t+8>>2];f=z[b+480188>>1];r=z[b+480192>>1];while(1){if((a|0)==(f|0)){break g}h:{i:{j:{k:{e=y[n|0];switch(e-253|0){case 1:case 2:break i;case 0:break k;default:break j}}if(r){break i}}if(!Tc(e)){break h}if(Rl(y[n+2|0],y[n+3|0])){break h}}ua=Ve(g,a),va=-1,x[ua>>2]=va}n=n+6|0;a=a+1|0;continue}}Y=c&1;if(Y){PT(l+223860|0)}M=l+74|0;L=l+48|0;ra=l+223872|0;R=l+80|0;sa=b+901692|0;ta=b+902204|0;ba=l+44|0;fa=l+223860|0;Z=l+20|0;I=b+1074312|0;na=l+616|0;ca=32768;oa=($|0)!=7;r=0;l:{m:{n:{o:{p:{q:{r:{s:{t:while(1){pa=C[d+8>>3];o(+pa);g=j(1)|0;a=j(0)|0;h=x[d+16>>2];f=a;u:{v:{w:{x:{while(1){OT(i+24|0,x[b+480180>>2],z[b+480188>>1],l,G&1);q=y[i+24|0];if((h|0)==3&C[t+24>>3]>=pa){break x}a=65535;e=x[K>>2];m=Zc(e,x[K+4>>2]);k=z[l+72>>1];if(m>>>0>k>>>0){a=z[_b(e,k)>>1]}w[l+70>>1]=a;m=x[b+484344>>2];e=x[b+484348>>2];n=a&65535;if(!(He(m,e,n)|(h|0)!=2|(n|0)==65535)&(k|0)==(g&65535)){break x}y:{while(1){H=gk(m,e);u=x[K>>2];while(1){k=a&65535;if(k>>>0<H>>>0){break y}a=z[l+72>>1];z:{A:{if((k|0)!=65535){k=Zc(u,x[K+4>>2]);if(a>>>0<k>>>0){break A}}n=z[K+28>>1];if((a|0)==(n|0)){break y}k=Zc(u,x[K+4>>2]);break z}n=a+1|0}w[l+72>>1]=n;a=65535;F=k;k=n&65535;if(F>>>0>k>>>0){a=z[_b(u,k)>>1]}w[l+74>>1]=n;w[l+70>>1]=a;if(He(m,e,a&65535)){continue}break}a=Oq(i+24|0,na);x[31725]=0;a=ha(606,J|0,n&65535,0,a|0,(q|0)!=0|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break p}if(!a){e=x[b+484348>>2];m=x[b+484344>>2];a=z[l+70>>1];continue}break}if(ea>>>0<=1){a=z[l+72>>1];x[s+8>>2]=0;w[s+20>>1]=a}if(!h){break y}if(!Wu(J,M,L)){break y}C[s>>3]=C[t+24>>3];x[31725]=0;O(607,X|0,s|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}x[s+16>>2]=x[L>>2];w[s+24>>1]=z[M>>1];x[31725]=0;W(608,t|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}a=z[l+74>>1];w[l+72>>1]=a;ua=l,va=z[_b(x[K>>2],a)>>1],w[ua+70>>1]=va;x[l+52>>2]=x[l+48>>2]}if(z[M>>1]==65535){break m}a=x[b+484344>>2];e=z[l+70>>1];if(!He(a,x[b+484348>>2],e)){a=z[l+72>>1];if((a|0)==z[K+28>>1]){if(!h){break n}if(!Wu(J,M,L)){break o}C[s>>3]=C[t+24>>3];x[31725]=0;O(607,X|0,s|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}x[s+16>>2]=x[L>>2];w[s+24>>1]=z[M>>1];x[31725]=0;W(608,t|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}x[l+52>>2]=x[l+48>>2];continue}w[M>>1]=a+1;continue}break}k=x[L>>2];if(k>>>0>=A[Wb(a,e)+12>>2]){x[L>>2]=0;k=0}if((h|0)!=2){break w}if(z[l+72>>1]!=(g&65535)|(f|0)!=(k|0)){break v}}h=1;v[s+26|0]=1;break m}a=0;if((h|0)==3){break u}}a=0;if(A[J+28>>2]<ca>>>0){break u}x[t+24>>2]=0;x[t+28>>2]=2146435072;x[J+28>>2]=0;ca=ca>>>(ca>>>0>256)|0;k=x[L>>2];a=1}g=z[l+72>>1];f=Oq(i+24|0,na);x[31725]=0;g=ha(606,J|0,g|0,k|0,f|0,(q|0)!=0|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break s}if((a|g)==1){if(ea>>>0<=1){w[s+20>>1]=z[l+72>>1];x[s+8>>2]=x[l+48>>2]}if(!h){break n}if(!Wu(J,M,L)){break o}C[s>>3]=C[t+24>>3];x[31725]=0;O(607,X|0,s|0);a=x[31725];x[31725]=0;if((a|0)==1){break r}x[s+16>>2]=x[L>>2];w[s+24>>1]=z[M>>1];x[31725]=0;W(608,t|0);a=x[31725];x[31725]=0;if((a|0)==1){break r}x[l+52>>2]=x[l+48>>2];continue}w[s+22>>1]=z[l+72>>1];x[s+12>>2]=x[l+48>>2];NT(b,l,0);n=x[l+48>>2];g=Wb(x[b+484344>>2],z[l+70>>1]);if(n>>>0>=A[g+12>>2]){x[L>>2]=0;n=0}if(q){continue}a=0;n=jd(x[g>>2],x[x[g+48>>2]+12>>2],n,0);Jb(i+24|0,I,77);m=Hb(x[x[i+24>>2]>>2],x[i+28>>2]);B:{while(1){if(z[b+480188>>1]>a>>>0){C:{if(!(!yB(n)&(!m|!(y[((a<<5)+b|0)+480281|0]&4)))){ap((l+D(a,872)|0)+1404|0);break C}if(Vg(y[n|0])){D:{if(!Ed(y[l+223884|0])){break D}g=y[n+1|0];if(g-251>>>0<5|!g){break D}e=y[n+5|0];h=y[n+3|0];k=Mj(y[n+2|0],y[n+4|0]);f=i+24|0;v[f|0]=g-1;x[f+4>>2]=k&65535;x[31725]=0;g=P(609,ra|0,f|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break B}ua=g,ya=E(E(Mj(h,e)>>>0)/E(999)),B[ua>>2]=ya}ap((l+D(a,872)|0)+1404|0);break C}g=l+D(a,872)|0;f=g+1408|0;e=y[n+4|0]|y[n+5|0]<<8;v[f|0]=e;v[f+1|0]=e>>>8;f=g+1404|0;e=y[n|0]|y[n+1|0]<<8|(y[n+2|0]<<16|y[n+3|0]<<24);v[f|0]=e;v[f+1|0]=e>>>8;v[f+2|0]=e>>>16;v[f+3|0]=e>>>24;E:{F:{G:{H:{switch(y[n+3|0]-16|0){case 0:e=y[n+5|0];break G;case 3:break E;case 4:break F;case 1:break H;default:break C}}Jb(i+24|0,I,5);if(!Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break C}e=y[n+5|0];if(!e){break C}}LT(b,l,e&255);break C}f=g+1409|0;e=y[f|0];I:{if(!(e|!(x[b+480180>>2]&16777250))){v[f|0]=y[g+1449|0];break I}v[g+1449|0]=e}g=y[n+5|0];f=g&240;if((f|0)!=224){if((f|0)!=96){break C}x[l+24>>2]=x[l+24>>2]+(g&15);break C}if(x[Z>>2]){break C}g=g&15;if(g?0:y[b+480180|0]&2){break C}x[Z>>2]=g+1;break C}g=y[n+5|0];if((g&240)!=224){break C}x[Z>>2]=(g&15)+1}n=n+6|0;a=a+1|0;continue}break}g=Ql(l);x[i+24>>2]=1;a=x[ad(Z,i+24|0)>>2];w[l+68>>1]=65535;x[l+60>>2]=-1;x[l+64>>2]=-1;ia=g-1|0;a=g-a|0;T=D(a,1e4);n=0;while(1){J:{K:{L:{M:{N:{if(z[b+480188>>1]<=n>>>0){if(x[b+480180>>2]!=4|x[l+40>>2]!=65535){break N}x[l+52>>2]=x[l+48>>2];w[l+74>>1]=z[l+72>>1];continue t}h=l+D(n,872)|0;k=h+1404|0;if(yB(k)){break J}q=h+616|0;da=h+1409|0;e=y[da|0];_=h+1407|0;u=y[_|0];if(!Y){break L}H=y[k|0];f=H;m=h+1405|0;F=y[m|0];if(F){v[h+1415|0]=0;v[h+1419|0]=F;ua=Ve(x[t+8>>2],n),va=255,v[ua+5|0]=va;f=y[k|0]}O:{if(!Tc(f)){break O}v[h+1415|0]=H;wV(q);if(!oa){if(x[Ve(x[t+8>>2],n)>>2]!=-1){break O}}F=h+1272|0;f=y[h+1419|0];f=x[(f?f>>>0>z[b+480192>>1]?F:((f<<2)+b|0)+900380|0:F)>>2];if(!f){break O}F=y[f+21|0];if(Cd(F)){ua=h+1453|0,va=Wh(F),v[ua|0]=va}f=y[f+22|0];if(!Cd(f)){break O}ua=h+1454|0,va=Wh(f),v[ua|0]=va}P:{if(!(Tc(y[k|0])|y[m|0])){break P}F=h+1419|0;m=y[F|0];Q:{if(!m){m=0;break Q}if(z[b+480192>>1]<m>>>0){break Q}f=x[((m<<2)+b|0)+900380>>2];if(!f|!(v[f+15|0]&1)){break Q}Yq(q,x[f+8>>2],b);m=y[F|0]}f=xr(b,H,m&255);if(!f){break P}f=D(f,104)+b|0;if(!(y[f+484414|0]&32)){break P}Yq(q,z[f+484408>>1],b)}R:{S:{T:{f=y[h+1406|0];switch(f-1|0){case 1:break L;case 2:case 3:break S;case 0:break T;default:break R}}ua=Ve(x[t+8>>2],n),va=y[h+1408|0],v[ua+5|0]=va;break L}f=y[h+1408|0];if(!f){break L}v[h+1450|0]=f;break L}if((f|0)==11){break M}break L}x[l+32>>2]=x[b+480216>>2];a=Wb(x[b+484344>>2],z[l+70>>1]);f=x[a+16>>2];if(KT(f,x[a+20>>2])){x[l+32>>2]=f}f=JT(b,l);a=D(f,g);C[t+24>>3]=C[t+24>>3]+ +(a>>>0)/+A[b+24620>>2];x[l>>2]=a+x[l>>2];U:{V:{W:{if(oa){break W}n=0;ia=(r|0)!=0&(f|0)!=(r|0);while(1){if(z[b+480188>>1]<=n>>>0){break W}G=Ve(x[t+8>>2],n);X:{if(x[G>>2]==-1){break X}q=l+D(n,872)|0;H=q+1404|0;T=x[q+1316>>2];if(!T){if(yB(H)){break X}}u=q+1409|0;k=y[u|0];e=Rl(y[H+2|0],y[H+3|0]);if(y[q+1405|0]){x[q+1276>>2]=0}h=q+616|0;a=k&15;m=0;Y:{if(!Tc(y[H|0])){break Y}if(e&y[G+4|0]!=0){wB(i+24|0,b,h,T,0);m=x[i+28>>2];x[q+624>>2]=x[i+24>>2];x[q+628>>2]=m}v[q+1418|0]=y[q+1415|0];T=q+1308|0;da=x[T>>2];m=y[q+1419|0];if(m){Ro(b,h,m,e,1,1)}m=y[H|0];x[31725]=0;ga(610,b|0,h|0,m|0,e|0,1,0,65535);m=x[31725];x[31725]=0;if((m|0)==1){break V}k=k>>>4|0;IT(b,h);HT(x[b+480180>>2],z[b+480188>>1],l,n&65535);_=Ve(x[t+8>>2],n);v[_+4|0]=1;G=y[q+1407|0];Z:{if(!((y[u|0]&240)!=208|(G-19&255)>>>0>1)){m=a;if(a>>>0<g>>>0){break Z}}m=(G|0)==33?g>>>0>k>>>0?k:0:0}F=x[Z>>2];if(!(!(x[b+480180>>2]&16777250)|(!m|F>>>0<2))){m=D(F-1|0,x[l+24>>2]+x[l+40>>2]|0)+m|0}if(!e){x[_>>2]=0}_:{if((G|0)==9){break _}$:{if((G|0)!=19){if((G|0)!=20|(k|0)!=8){break $}break _}if((k|0)==8){break _}}if(y[q+1406|0]!=2){break Y}}x[T>>2]=da}aa:{if(!Tc(y[H|0])){Jb(i+24|0,I,114);if(!Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break aa}}ba:{ca:{da:{ea:{e=y[q+1407|0];switch(e-42|0){case 1:break ba;case 0:break ca;case 2:break da;default:break ea}}if((e|0)!=10){break ba}e=z[l+70>>1];k=x[l+48>>2];x[31725]=0;aa(611,b|0,h|0,n&65535,k|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){break aa}break U}k=ova(y[u|0],0,x[q+692>>2],0);e=hb;G=e>>>8|0;Qo(b,h,Bc((e&255)<<24|k>>>8,G));break aa}if(!x[q+720>>2]){break ba}x[31725]=0;V(612,t|0,n&65535,r|0,-1);e=x[31725];x[31725]=0;if((e|0)==1){break U}FT(h,y[u|0]);m=x[l+40>>2]-1|0;break aa}if(y[q+1406|0]!=15){break aa}k=x[q+720>>2];if(!k){break aa}e=y[q+1408|0];if(e>>>0>9){break aa}fa:{if(!e){e=x[q+1280>>2];break fa}e=x[yb(k+68|0,e-1|0)>>2];x[q+1280>>2]=e}Qo(b,h,e)}ga:{ha:{ia:{switch(y[H|0]-253|0){case 0:if(z[b+480192>>1]){break ha}break;case 1:case 2:break ha;default:break ia}}e=y[q+1407|0];if(!((y[u|0]&240)!=192|(e-19&255)>>>0>1)&a>>>0<g>>>0){break ha}G=e&255;if((G|0)==25){break ha}k=0;if(!((G|0)==33&(a|0)!=0&g>>>0>a+m>>>0)){break ga}}e=y[q+1407|0];k=1}G=q+1304|0;ja:{ka:{la:{a=e&255;if((a|0)!=46){if((a|0)!=13){break la}F=y[u|0]<<2;break ka}F=y[u|0];break ka}if(y[q+1406|0]!=1){break ja}F=y[q+1408|0]<<2}x[G>>2]=F}G=q+1407|0;ma:{na:{oa:{if(k|(!x[q+720>>2]|a>>>0>46)){break oa}Jb(i+24|0,ma,a);if(Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break na}e=y[G|0];if((e|0)!=19){break oa}a=y[u|0]&240;if((a|0)==16){break na}e=19;if((a|0)==32){break na}}if(!k){break ma}}xV(h);ua=Ve(x[t+8>>2],n),va=0,x[ua>>2]=va;break X}if(ia){x[31725]=0;V(612,t|0,n&65535,r|0,-1);a=x[31725];x[31725]=0;if((a|0)==1){break U}e=y[G|0]}pa:{qa:{ra:{sa:{ta:{a=e&255;if(a-6>>>0>=2){ua:{switch(a-19|0){case 1:break sa;case 0:break ta;default:break ua}}if(a-35>>>0<2){break qa}if((a|0)==45){break ra}if((a|0)!=11){break pa}}if(!y[u|0]&x[b+480180>>2]==1){break pa}a=q+1467|0;e=0;while(1){if((e|0)==(g|0)){break pa}v[a|0]=!e|y[a|0]&254;Po(b,h,y[u|0]);e=e+1|0;continue}}e=y[u|0];a=e&15;if(!(a|x[b+480180>>2]&1048580)){break pa}k=q+1467|0;v[k|0]=y[k|0]|1;e=e&240;if((e|0)!=176){if((e|0)!=160){break pa}Oo(b,h,a,0);break pa}No(b,h,a,0);break pa}va:{wa:{xa:{a=y[u|0];switch(a-158|0){case 1:break wa;case 0:break xa;default:break va}}x[31725]=0;V(612,t|0,n&65535,r|0,-1);a=x[31725];x[31725]=0;if((a|0)==1){break U}x[q+704>>2]=x[q+704>>2]&-129;break pa}x[31725]=0;V(612,t|0,n&65535,r|0,-1);a=x[31725];x[31725]=0;if((a|0)==1){break U}a=x[q+704>>2];x[q+704>>2]=a|128;if(x[h+4>>2]){break pa}e=x[q+692>>2];if(!e){break pa}if(!(ua=Tc(y[H|0]),va=1,xa=a&2,xa?ua:va)){break pa}x[h>>2]=-1;x[h+4>>2]=e-1;break pa}if((a&240)!=112|a>>>0<115){break pa}uV(h,a,x[b+480180>>2]);break pa}ET(h,y[u|0]);break pa}x[31725]=0;a=n&65535;V(612,t|0,a|0,r|0,-1);e=x[31725];x[31725]=0;if((e|0)==1){break U}ua=q+1390|0,va=DT(b,z[l+70>>1],x[l+48>>2],a),w[ua>>1]=va}k=q+1467|0;a=y[k|0]|1;v[k|0]=a;ya:{za:{Aa:{Ba:{Ca:{u=q+1406|0;switch(y[u|0]-3|0){case 11:break za;case 0:case 1:break Aa;case 3:break Ba;case 2:break Ca;default:break ya}}a=y[q+1408|0];Jb(i+24|0,I,41);Oo(b,h,a,Hb(x[x[i+24>>2]>>2],x[i+28>>2]));break ya}a=y[q+1408|0];Jb(i+24|0,I,41);No(b,h,a,Hb(x[x[i+24>>2]>>2],x[i+28>>2]));break ya}e=y[q+1408|0];Da:{if(e){break Da}Jb(i+24|0,I,41);e=0;if(!Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break Da}e=y[q+1450|0];if(!e){break ya}}e=y[u|0]==3?e<<4:e;a=0;while(1){if((a|0)==(g|0)){break ya}v[k|0]=!a|y[k|0]&254;Po(b,h,e&255);a=a+1|0;continue}}e=y[q+1408|0];if(e>>>0>1){break ya}v[k|0]=a&247|!e<<3}if(y[k|0]&8){break X}a=1;Ea:{Fa:{Ga:{e=y[H+3|0];if(e>>>0>28){break Ga}h=1<<e;if(h&92){break Ea}if(!(h&268959744)){break Ga}if((y[H+5|0]-16&255)>>>0<32){break Ea}break Fa}if(e-38>>>0<4){break Ea}}a=(y[H+2|0]-11&255)>>>0<3}if(a){e=Ve(x[t+8>>2],n);a=x[e>>2];x[e>>2]=a+g;x[31725]=0;V(612,t|0,n&65535,f|0,a+m|0);a=x[31725];x[31725]=0;if((a|0)!=1){break X}a=N()|0;break l}a=Ve(x[t+8>>2],n);x[a>>2]=x[a>>2]+(g-m|0)}n=n+1|0;continue}}G=CT(b,l,K,0);r=f;continue t}a=N()|0;break l}a=N()|0;break l}f=y[h+1408|0];if(!f){break L}m=i+24|0;vB(m,b,y[k+3|0],f,0);w[h+1384>>1]=z[i+24>>1];if(y[af(m)|0]){break K}}Ha:{Ia:{Ja:{Ka:{La:{switch(u-12|0){case 0:BT(b,l,n&65535);break Ha;case 2:f=AT(b,l,n&65535,e);if((f|0)==-1){break Ha}x[l+60>>2]=f;break Ha;case 5:Jb(i+24|0,I,5);if(Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break Ha}k=D(Mo(b,z[l+70>>1],x[l+48>>2],n&65535,0),1e4);x[i+56>>2]=k;Ma:{if(!Y|!(x[b+480180>>2]&16777250)){break Ma}if(k>>>0>=1e4){v[h+1451|0]=(k>>>0)/1e4;break Ma}k=D(y[h+1451|0],1e4);x[i+56>>2]=k}f=x[b+8>>2];if(k>>>0>=32e4){x[i+24>>2]=D(x[f+24>>2],1e4);ua=ba,va=x[Gb(i+56|0,i+24|0)>>2],x[ua>>2]=va;break Ha}m=x[ba>>2];H=(k>>>0)/1e4|0;F=D(T,H&15);k=m-F|0;x[ba>>2]=(H&240)==16?m+F|0:k>>>0<=m>>>0?k:0;m=x[f+20>>2];f=x[f+24>>2];Jb(i+24|0,I,8);Mp(ba,D(m,1e4),Hb(x[x[i+24>>2]>>2],x[i+28>>2])?255e4:D(f,1e4));break Ha;case 8:Na:{switch((e&240)-144>>>4|0){case 0:if(e>>>0>145){break Ha}x[h+704>>2]=x[h+704>>2]&-257|((e|0)==145)<<8;break Ha;case 1:v[h+1452|0]=e&15;break Ha;case 2:break Ka;case 6:break Na;default:break Ha}}v[h+1460|0]=e&15;break Ha;case 1:case 3:case 4:case 6:break Ha;case 7:break La;default:break Ia}}f=e&240;if((f|0)==240){break Ja}if((f|0)!=96){break Ha}}uB(b,l,n&65535,e&15);break Ha}v[h+1460|0]=e&15;break Ha}if((u|0)!=28|(e&240)!=160){break Ha}Jb(i+24|0,I,58);if(Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break Ha}v[h+1452|0]=e&15}if(!Y){break J}Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{switch(u-2|0){case 0:if(!e){break Oa}Jb(i+24|0,I,90);if(!Hb(x[x[i+24>>2]>>2],x[i+28>>2])){v[h+1428|0]=e}v[h+1427|0]=e;break K;case 1:if(!e){break Oa}Jb(i+24|0,I,90);if(!Hb(x[x[i+24>>2]>>2],x[i+28>>2])){v[h+1427|0]=e}v[h+1428|0]=e;break K;case 2:if(!e){break Oa}w[h+1384>>1]=e;break K;case 8:if(!e){break Oa}x[h+1280>>2]=e<<8;break K;case 4:case 9:if(!e){break Oa}v[h+1425|0]=e;break K;case 11:ua=Ve(x[t+8>>2],n),va=e,v[ua+5|0]=va;break K;case 44:ua=Ve(x[t+8>>2],n),va=e+3>>>2|0,v[ua+5|0]=va;break K;case 21:f=x[b+480180>>2];e=e<<(!(f&59593760)&e<<24>>24>=0);m=e&255;if(m>>>0<=128){x[R>>2]=m<<1;break K}if(f&16777250){break K}x[R>>2]=256;break K;case 22:Jb(i+24|0,I,9);Xa:{if(Hb(x[x[i+24>>2]>>2],x[i+28>>2])){f=h+1433|0;if(e){v[f|0]=e;break Xa}e=y[f|0];break Xa}if(e){v[l+1433|0]=e;break Xa}e=y[l+1433|0]}f=e&15;m=e&255;Ya:{if(!((f|0)!=15|m>>>0<16)){e=(e&240)>>>4<<!(x[b+480180>>2]&59593760);f=x[R>>2]+(e<<1)|0;break Ya}m=m&240;if(!(!f|(m|0)!=240)){e=f<<(x[b+480180>>2]&59593760?1:2);f=x[R>>2]-e|0;break Ya}if(m){e=(e>>>3&30)<<!(x[b+480180>>2]&59593760);f=x[R>>2]+D(a,e)|0;break Ya}e=f<<(x[b+480180>>2]&59593760?1:2);f=x[R>>2]-D(a,e)|0}x[R>>2]=f;Fe(R,0,256);break K;case 19:if(e>>>0>64){break K}x[h+1364>>2]=e;break K;case 20:f=h+1432|0;Za:{if(e){v[f|0]=e;break Za}e=y[f|0]}u=h+1364|0;f=x[u>>2];m=e&15;k=e&255;_a:{if(!((m|0)!=15|k>>>0<16)){x[i+24>>2]=f+(k>>>4|0);break _a}if(!(!m|(k&240)!=240)){x[i+24>>2]=f-m;break _a}if(m){x[i+24>>2]=f-D(a,m);break _a}x[i+24>>2]=f+D(a,k>>>4|0)}Fe(i+24|0,0,64);x[u>>2]=x[i+24>>2];break K;case 7:fn(b,q,e,8);break K;case 29:case 30:break Pa;case 25:break Qa;case 6:break Ra;case 24:break Sa;case 3:break Ta;case 5:break Ua;case 18:break Va;case 17:break Wa;default:break K}}if(e>>>0>15){break Va}f=(e&1)<<14;m=z[b+480188>>1];k=0;while(1){if((k|0)==(m|0)){break Va}u=l+D(k,872)|0;x[u+704>>2]=(f|x[u+704>>2]&-16385)^16384;k=k+1|0;continue}}if((e&240)!=128){break K}fn(b,q,e&15,4);break K}if(e){v[h+1425|0]=e}e=0}Pl(q,e);break K}zT(b,q,e);break K}yT(q,e);break K}xT(q,e);break K}$a:{if(e<<24>>24>=0){f=Oe(sa,y[h+1460|0]);break $a}f=Oe(ta,e&127)}m=y[da|0];x[31725]=0;ja(613,b|0,l|0,n&65535,0,f|0,m|0);f=x[31725];x[31725]=0;if((f|0)!=1){break K}a=N()|0;break l}e=0}ab:{bb:{switch(y[h+1406|0]-2|0){case 0:fn(b,q,y[h+1408|0],6);break ab;case 5:Jb(i+24|0,I,53);f=y[h+1408|0];if(Hb(x[x[i+24>>2]>>2],x[i+28>>2])){v[h+1439|0]=f&15;break ab}Pl(q,f<<4);break ab;case 6:break bb;default:break ab}}Pl(q,y[h+1408|0])}cb:{db:{eb:{fb:{gb:{f=y[_|0];switch(f-5|0){case 1:break cb;case 3:break eb;case 0:case 2:break fb;default:break gb}}switch(f-26|0){case 1:break db;case 0:break fb;default:break cb}}hb:{if(x[b+480180>>2]&16777248){f=g;if(!(y[b+480208|0]&4)){break hb}}f=a}m=y[h+1439|0];Jb(i+24|0,I,21);h=h+1435|0;k=y[h|0];f=D(f,m);ua=h,va=(Hb(x[x[i+24>>2]>>2],x[i+28>>2])?f<<2:f)+k|0,v[ua|0]=va;break cb}ib:{if(x[b+480180>>2]&16777248){f=g;if(!(y[b+480208|0]&4)){break ib}}f=a}m=y[h+1442|0];Jb(i+24|0,I,21);h=h+1436|0;k=y[h|0];f=D(f,m);ua=h,va=(Hb(x[x[i+24>>2]>>2],x[i+28>>2])?f<<2:f)+k|0,v[ua|0]=va;break cb}f=h+1437|0;v[f|0]=y[f|0]+D(ia,y[h+1445|0]);vT(b,q)}Jb(i+24|0,I,78);if(!Hb(x[x[i+24>>2]>>2],x[i+28>>2])){break J}f=e&255;if(!f){break J}uT(q,f)}n=n+1|0;continue}}break}a=N()|0;break l}a=N()|0;break l}a=N()|0;break l}a=N()|0;break l}a=N()|0;break l}h=1;break m}h=0}jb:{if(($|0)!=7){break jb}a=0;while(1){if(z[b+480188>>1]<=a>>>0){break jb}kb:{if(x[Ve(x[t+8>>2],a)>>2]==-1){break kb}x[31725]=0;V(612,t|0,a&65535,r|0,-1);d=x[31725];x[31725]=0;if((d|0)!=1){break kb}a=N()|0;break l}a=a+1|0;continue}}if(y[s+26|0]){w[s+20>>1]=z[l+72>>1];x[s+8>>2]=x[l+48>>2]}C[s>>3]=C[t+24>>3];x[31725]=0;O(607,X|0,s|0);a=x[31725];x[31725]=0;lb:{mb:{nb:{ob:{if((a|0)!=1){if(!Y){break a}if(!(h?y[s+26|0]:1)){break nb}f=iB(i+56|0);if(Ed(y[fa+24|0])){hT(f,fa)}tB(fa);a=yc(b+1074376|0,l,614);r=0;while(1){if((r|0)==256){Fn(a+223848|0,l+223848|0);d=a+223860|0;r=y[d+24|0];g=l+223860|0;pb:{if((Ed(y[g+24|0])|0)==(r|0)){if(!r){break pb}r=ec(d);Mu(d,x[r>>2]);x[d>>2]=x[g>>2];x[d+4>>2]=x[g+4>>2];x[d+8>>2]=x[g+8>>2];qb:{if(!x[zb(d)>>2]){x[d>>2]=r;break qb}x[x[r>>2]+8>>2]=r;r=ec(g);x[g>>2]=r;x[r>>2]=0;ua=zb(g),va=0,x[ua>>2]=va}d=d+12|0;r=ec(d);Lu(d,x[r>>2]);g=g+12|0;x[d>>2]=x[g>>2];x[d+4>>2]=x[g+4>>2];x[d+8>>2]=x[g+8>>2];rb:{if(!x[zb(d)>>2]){x[d>>2]=r;break rb}x[x[r>>2]+8>>2]=r;d=ec(g);x[g>>2]=d;x[d>>2]=0;ua=zb(g),va=0,x[ua>>2]=va}break pb}if(r){tB(d);break pb}hT(d,g)}}else{d=D(r,872);Mq((d+a|0)+616|0,(d+l|0)+616|0);r=r+1|0;continue}break}sB(a);x[b+1074400>>2]=0;v[b+1074476|0]=1;a=b+1074392|0;x[a>>2]=-2;x[a+4>>2]=0;x[b+1074428>>2]=x[b+1074424>>2];a=x[b+1298300>>2];if(!Pj(a)){break ob}break mb}a=N()|0;break l}x[31725]=0;W(614,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break mb}break lb}if((c|0)==3){break b}x[b+1074416>>2]=x[b+480196>>2];x[b+1074420>>2]=x[b+480204>>2];x[b+1074456>>2]=x[b+480200>>2];break b}r=($|0)==7;a=0;while(1){if(z[b+480188>>1]<=a>>>0){a=FC(i+24|0);ua=i,va=$i(x[f+12>>2]),x[ua+20>>2]=va;g=b+906300|0;m=Rf(f+12|0);while(1){d=x[i+20>>2];if(!Zg(d,m)){sb:{m=250;d=a;tb:{while(1){if(m>>>0>=32){if(x[a>>2]){a=1;break tb}else{m=m-32|0;a=a+4|0;continue}}break}a=(x[d+28>>2]&67108863)!=0}if(!a){break sb}a=0;while(1){if((a|0)==250){break sb}Jb(i+12|0,d,a);ub:{if(!Hb(x[x[i+12>>2]>>2],x[i+16>>2])){break ub}r=x[vd(g,a)>>2];e=x[x[r>>2]+180>>2];x[31725]=0;W(e|0,r|0);r=x[31725];x[31725]=0;if((r|0)!=1){break ub}break lb}a=a+1|0;continue}}ua=i,va=$i(x[f>>2]),x[ua+12>>2]=va;a=Rf(f);while(1){d=x[i+12>>2];if(Zg(d,a)){d=td(d);ka=B[ec(d)>>2];ua=vd(g,y[d|0]),ya=ka,B[ua+144>>2]=ya;ah(i+12|0);continue}else{Nq(f);break b}}}r=td(d);h=zb(r);vb:{e=y[r|0];d=x[vd(g,e)>>2];if(d){Jb(i+12|0,a,e);if(!Hb(x[x[i+12>>2]>>2],x[i+16>>2])){x[31725]=0;P(615,a|0,e|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break vb}e=x[x[d>>2]+176>>2];x[31725]=0;O(e|0,d|0,-1);e=x[31725];x[31725]=0;if((e|0)==1){break vb}}ka=B[h>>2];r=x[r+4>>2];e=x[x[d>>2]+44>>2];x[31725]=0;wa(e|0,d|0,r|0,E(ka));d=x[31725];x[31725]=0;if((d|0)==1){break vb}}ah(i+20|0);continue}break}break lb}d=D(a,872)+b|0;g=y[d+1075791|0];if(g){v[d+1075794|0]=g}g=Ve(x[t+8>>2],a);if(!(y[g+5|0]==255|r)){v[i+24|0]=64;ua=d+1075680|0,va=y[Rb(g+5|0,i+24|0)|0]<<2,x[ua>>2]=va}wb:{g=x[d+1075096>>2];xb:{if(!g|!(y[g+35|0]&2)){break xb}e=x[b+1298300>>2];if(!Dd(e)){break xb}x[31725]=0;k=e;e=a&65535;S(616,k|0,e|0,g+68|0);g=x[31725];x[31725]=0;if((g|0)==1){break wb}g=x[b+1298300>>2];x[31725]=0;S(617,g|0,e|0,1);g=x[31725];x[31725]=0;if((g|0)==1){break wb}}x[d+1075008>>2]=0;a=a+1|0;continue}break}}a=N()|0;Nq(f)}Qu(J)}tT(t)}Yi(X);Q(a|0);p()}a=la&255;if((a|0)==y[b+484376|0]){break a}ek(qa,a)}if(c&9){a=b+1298264|0;if(x[a>>2]){mU(a);b=x[a>>2];ll(a);Db(b);ua=zb(a),va=0,x[ua>>2]=va;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[J>>2];x[a+4>>2]=x[J+4>>2];b=zb(J);ua=zb(a),va=x[b>>2],x[ua>>2]=va;x[b>>2]=0;x[J>>2]=0;x[J+4>>2]=0;a=a+12|0;c=ec(a);Sq(a,x[c>>2]);b=J+12|0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];yb:{if(!x[zb(a)>>2]){x[a>>2]=c;break yb}x[x[c>>2]+8>>2]=c;a=ec(b);x[b>>2]=a;x[a>>2]=0;ua=zb(b),va=0,x[ua>>2]=va}}Qu(J);tT(t);fb=i+192|0}function FY(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,q=0,r=0,s=E(0),t=E(0),u=0,C=0,F=0,G=E(0),H=0,I=0,J=E(0),K=0,L=E(0),M=0,N=E(0),O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=E(0),W=E(0),X=0,Y=0,Z=0,$=0,aa=E(0),ba=E(0),ca=E(0),da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;$=fb-16|0;fb=$;a:{if(x[a+1420>>2]>=0){x[f>>2]=0;e=x[a+1420>>2];d=(e|0)>0?e:0;while(1){if((d|0)!=(g|0)){x[(D(g,20)+a|0)+1436>>2]=0;g=g+1|0;continue}break}b:{c:{d:{if((e|0)>3){break d}g=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{j=b+d|0;if(y[j|0]!=79|(y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24))!=(y[125924]|y[125925]<<8|(y[125926]<<16|y[125927]<<24))){break f}q=d+26|0;if((q|0)>=(c|0)){break e}n=d+27|0;i=b+q|0;f=y[i|0];if((n+f|0)>=(c|0)){break e}h=f+27|0;g=0;while(1)if((f|0)==(g|0)){g=0;Q=0;while(1){f=22;if((g|0)!=22){Q=fz(Q,y[(d+g|0)+b|0]);g=g+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;Q=fz(Q,0);continue}break}x[a+1420>>2]=e+1;e=D(e,20)+a|0;x[e+1432>>2]=Q;x[e+1428>>2]=h-26;x[e+1424>>2]=y[j+22|0]|y[j+23|0]<<8|(y[j+24|0]<<16|y[j+25|0]<<24);f=y[(q+y[i|0]|0)+b|0]==255?-1:y[j+6|0]|y[j+7|0]<<8|(y[j+8|0]<<16|y[j+9|0]<<24);x[e+1436>>2]=q;x[e+1440>>2]=f;e=x[a+1420>>2];if((e|0)!=4){break f}e=4;break d}else{h=y[(g+n|0)+b|0]+h|0;g=g+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){i=(d|0)>(e|0)?d:e;while(1){if((d|0)==(i|0)){break b}g=0;f=D(d,20)+a|0;m=f+1428|0;j=x[m>>2];q=x[f+1436>>2];n=c-q|0;h=(j|0)<(n|0)?j:n;k=(h|0)>0?h:0;Y=f+1432|0;Q=x[Y>>2];while(1){if((g|0)!=(k|0)){Q=fz(Q,y[(g+q|0)+b|0]);g=g+1|0;continue}break}x[m>>2]=j-h;x[Y>>2]=Q;if((j|0)<=(n|0)){f=f+1424|0;if(x[f>>2]==(Q|0)){x[a+1380>>2]=-1;x[a+992>>2]=0;x[a+1420>>2]=-1;b=x[(D(d,20)+a|0)+1440>>2];x[a+1060>>2]=b;x[a+1064>>2]=(b|0)!=-1;g=h+q|0;break c}e=e-1|0;x[a+1420>>2]=e;e=D(e,20)+a|0;x[f+16>>2]=x[e+1440>>2];g=e+1432|0;j=x[g+4>>2];x[f+8>>2]=x[g>>2];x[f+12>>2]=j;e=e+1424|0;g=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=g;e=x[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=g}break a}x[a+100>>2]=0;x[a+32>>2]=b;x[a+40>>2]=b+c;if(!aM(a)){x[f>>2]=0;c=0;break a}fa=fb-16|0;fb=fa;ha=$+4|0;x[a+1504>>2]=0;x[a+1508>>2]=0;h:{if(x[a+96>>2]){break h}i:{j:{k:{if(x[a+1380>>2]!=-1){break k}c=hf(a);if(x[a+96>>2]){break i}if((c|0)!=79){break j}if((hf(a)|0)!=103){break j}if((hf(a)|0)!=103){break j}if((hf(a)|0)!=83){break j}if(!$L(a)){break i}if(!(v[a+1375|0]&1)){break k}v[a+1376|0]=0;x[a+1384>>2]=0;fc(a,32);break i}j=cz(a);break i}fc(a,30)}if(!j){break h}if(rc(a,1)){fc(a,35);break h}l:{m:{if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){c=rc(a,Pm(x[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=x[a+408>>2]){break h}x[fa+12>>2]=c;h=D(c,6)+a|0;if(!y[h+412|0]){g=x[a+112>>2];j=g>>1;break m}g=x[a+116>>2];j=g>>1;c=rc(a,1);k=rc(a,1);if(c|!y[h+412|0]){break m}x[ha>>2]=g-x[a+112>>2]>>2;c=x[a+112>>2]+g>>2;break l}_(6325,13258,3152,10763);p()}x[ha>>2]=0;c=j}x[fa+8>>2]=c;n:{if(!(!y[h+412|0]|k)){c=D(g,3);x[$+8>>2]=c-x[a+112>>2]>>2;g=c+x[a+112>>2]>>2;break n}x[$+8>>2]=j}x[fa+4>>2]=g;g=1}if(g){Y=x[ha>>2];ka=x[$+8>>2];ia=x[fa+4>>2];h=0;O=fb-2368|0;fb=O;o=x[a+404>>2];oa=D(x[fa+12>>2],6)+a|0;C=y[oa+413|0];T=o+D(C,40)|0;S=x[((y[oa+412|0]<<2)+a|0)+104>>2];da=S>>1;ra=0-da|0;o:{while(1){c=x[a+4>>2];if((c|0)>(h|0)){c=y[(x[T+4>>2]+D(h,3)|0)+2|0];H=(O+1344|0)+(h<<2)|0;x[H>>2]=0;g=y[(c+T|0)+9|0];if(z[((g<<1)+a|0)+132>>1]){j=x[a+260>>2];p:{q:{if(!rc(a,1)){break q}c=2;n=x[((h<<2)+a|0)+996>>2];q=j+D(g,1596)|0;F=x[(y[q+1588|0]<<2)+89132>>2];g=Pm(F)-1|0;ta=n,ua=rc(a,g),w[ta>>1]=ua;ta=n,ua=rc(a,g),w[ta+2>>1]=ua;i=0;while(1){if(y[q|0]>i>>>0){K=y[(i+q|0)+1|0];g=K+q|0;r=y[g+49|0];m=-1<<r;k=y[g+33|0];r:{if(!r){j=0;break r}g=x[a+124>>2]+D(y[g+65|0],2096)|0;if(x[a+1396>>2]<=9){El(a)}j=x[a+1392>>2];I=w[(g+((j&1023)<<1)|0)+36>>1];s:{if((I|0)>=0){u=j;I=I&65535;j=y[I+x[g+8>>2]|0];x[a+1392>>2]=u>>>j;j=x[a+1396>>2]-j|0;x[a+1396>>2]=(j|0)>0?j:0;j=(j|0)<0?-1:I;break s}j=Om(a,g)}if(!y[g+23|0]){break r}j=x[x[g+2088>>2]+(j<<2)>>2]}I=m^-1;g=c+k|0;while(1){if((c|0)!=(g|0)){m=0;k=w[((q+(K<<4)|0)+((j&I)<<1)|0)+82>>1];t:{if((k|0)<0){break t}k=x[a+124>>2]+D(k&65535,2096)|0;if(x[a+1396>>2]<=9){El(a)}m=x[a+1392>>2];P=w[(k+((m&1023)<<1)|0)+36>>1];u:{if((P|0)>=0){u=m;P=P&65535;m=y[P+x[k+8>>2]|0];x[a+1392>>2]=u>>>m;m=x[a+1396>>2]-m|0;x[a+1396>>2]=(m|0)>0?m:0;m=(m|0)<0?-1:P;break u}m=Om(a,k)}if(!y[k+23|0]){break t}m=x[x[k+2088>>2]+(m<<2)>>2]}j=j>>r;w[n+(c<<1)>>1]=m;c=c+1|0;continue}break}i=i+1|0;c=g;continue}break}if(x[a+1396>>2]==-1){break q}w[O+320>>1]=257;c=2;while(1){m=x[q+1592>>2];if((m|0)<=(c|0)){c=0;while(1){if((c|0)>=(m|0)){break p}if(!y[(O+320|0)+c|0]){w[n+(c<<1)>>1]=65535;m=x[q+1592>>2]}c=c+1|0;continue}}else{g=q+338|0;j=c<<1;m=j+q|0;r=y[m+1088|0];k=r<<1;i=z[g+k>>1];H=y[m+1089|0];K=H<<1;I=w[k+n>>1];m=w[K+n>>1]-I|0;k=m>>31;g=(D((k^m)-k|0,z[g+j>>1]-i|0)|0)/(z[g+K>>1]-i|0)|0;m=I+((m|0)<0?0-g|0:g)|0;k=j+n|0;j=z[k>>1];v:{w:{if(j){g=O+320|0;v[g+H|0]=1;v[g+r|0]=1;v[c+g|0]=1;g=j<<16>>16;i=F-m|0;if((g|0)>=((i|0)<(m|0)?i:m)<<1){if((i|0)>(m|0)){break v}m=F+(j^-1)|0;break w}if(g&1){m=m-(g+1>>>1|0)|0;break w}m=(g>>1)+m|0;break w}v[(O+320|0)+c|0]=0}w[k>>1]=m}c=c+1|0;continue}}}x[H>>2]=1}h=h+1|0;continue}else{fc(a,21);c=0;break o}}break}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){yc(O+320|0,O+1344|0,c<<2);j=z[T>>1];c=0;while(1){if((c|0)==(j|0)){la=o+D(C,40)|0}else{h=x[T+4>>2]+D(c,3)|0;g=y[h+1|0];m=O+1344|0;h=m+(y[h|0]<<2)|0;if(!(x[(g<<2)+m>>2]?x[h>>2]:0)){x[(O+1344|0)+(g<<2)>>2]=0;x[h>>2]=0}c=c+1|0;continue}break}j=0;while(1){x:{if(y[la+8|0]>j>>>0){m=0;c=x[a+4>>2];q=(c|0)>0?c:0;c=0;while(1){if((c|0)==(q|0)){break x}if(y[(x[T+4>>2]+D(c,3)|0)+2|0]==(j|0)){n=m+O|0;h=c<<2;y:{if(x[h+(O+1344|0)>>2]){h=0;g=1;break y}h=x[(a+h|0)+800>>2];g=0}v[n|0]=g;x[(O+256|0)+(m<<2)>>2]=h;m=m+1|0}c=c+1|0;continue}}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){h=(da|0)>0?da:0;g=z[T>>1];j=a+800|0;z:while(1){if((g|0)<=0){K=da<<2;m=0;c=0;while(1){j=x[a+4>>2];if((j|0)<=(c|0)){while(1){if((j|0)>(m|0)){T=y[oa+412|0];H=S>>1;g=H<<2;la=x[a+92>>2];k=S>>3;P=S>>2;j=x[((m<<2)+a|0)+800>>2];c=H<<2;K=j+c|0;A:{if(x[a+80>>2]){q=uo(a,g);break A}q=Fd(g)}g=(q+c|0)-8|0;n=x[((T<<2)+a|0)+1068>>2];i=n;c=j;while(1){if((c|0)!=(K|0)){B[g+4>>2]=E(B[c>>2]*B[i>>2])-E(B[i+4>>2]*B[c+8>>2]);B[g>>2]=E(B[c>>2]*B[i+4>>2])+E(B[c+8>>2]*B[i>>2]);c=c+16|0;i=i+8|0;g=g-8|0;continue}break}c=((H<<2)+j|0)-12|0;while(1){if(g>>>0>=q>>>0){B[g+4>>2]=E(B[c>>2]*B[i+4>>2])-E(B[c+8>>2]*B[i>>2]);B[g>>2]=E(E(-B[c+8>>2])*B[i+4>>2])-E(B[i>>2]*B[c>>2]);c=c-16|0;i=i+8|0;g=g-8|0;continue}break}c=P<<2;r=c+j|0;g=c+q|0;i=(n+(H<<2)|0)-32|0;c=q;h=j;while(1){if(i>>>0>=n>>>0){l=B[c>>2];s=B[g>>2];t=B[g+4>>2];G=B[c+4>>2];B[r+4>>2]=t+G;B[r>>2]=B[g>>2]+B[c>>2];t=E(t-G);l=E(s-l);B[h+4>>2]=E(t*B[i+16>>2])-E(B[i+20>>2]*l);B[h>>2]=E(l*B[i+16>>2])+E(t*B[i+20>>2]);l=B[c+8>>2];s=B[g+8>>2];t=B[g+12>>2];G=B[c+12>>2];B[r+12>>2]=t+G;B[r+8>>2]=B[g+8>>2]+B[c+8>>2];t=E(t-G);l=E(s-l);B[h+12>>2]=E(t*B[i>>2])-E(B[i+4>>2]*l);B[h+8>>2]=E(l*B[i>>2])+E(t*B[i+4>>2]);c=c+16|0;g=g+16|0;h=h+16|0;r=r+16|0;i=i-32|0;continue}break}g=Pm(S);c=S>>4;h=H-1|0;i=0-k|0;YL(c,j,h,i,n);YL(c,j,h-P|0,i,n);I=S>>5;c=0-c|0;qq(I,j,h,c,n,16);qq(I,j,h-k|0,c,n,16);qq(I,j,h-(k<<1)|0,c,n,16);qq(I,j,h+D(k,-3)|0,c,n,16);c=g-4>>1;r=(c|0)<=2?2:c;c=2;while(1){B:{C:{D:{if((c|0)==(r|0)){ja=g-7|0;break D}i=0;k=2<<c;k=(k|0)>0?k:0;F=8<<c;C=S>>c+4;o=S>>c+2;Z=0-(o>>1)|0;while(1){if((i|0)==(k|0)){break C}qq(C,j,h-D(i,o)|0,Z,n,F);i=i+1|0;continue}}while(1){E:{if((r|0)<(ja|0)){ma=32<<r;F=2<<r;Z=8<<r;i=S>>r+6;X=S>>r+2;ea=0-(X>>1)|0;g=h;c=n;while(1){if((i|0)<=0){break E}k=F;o=(g<<2)+j|0;C=o+(ea<<2)|0;U=D(Z,12)+c|0;l=B[U>>2];M=(Z<<3)+c|0;s=B[M>>2];u=(Z<<2)+c|0;t=B[u>>2];G=B[U+4>>2];L=B[M+4>>2];V=B[u+4>>2];W=B[c+4>>2];ca=B[c>>2];U=0-X<<2;while(1){if((k|0)>0){M=C-4|0;N=B[M>>2];aa=B[o>>2];ba=B[C>>2];B[o>>2]=aa+ba;u=o-4|0;J=B[u>>2];B[u>>2]=J+B[M>>2];J=E(J-N);N=E(aa-ba);B[M>>2]=E(J*ca)+E(W*N);B[C>>2]=E(N*ca)-E(W*J);M=C-12|0;aa=B[M>>2];u=o-8|0;J=B[u>>2];R=u;u=C-8|0;ba=B[u>>2];B[R>>2]=J+ba;R=o-12|0;N=B[R>>2];B[R>>2]=N+B[M>>2];N=E(N-aa);J=E(J-ba);B[M>>2]=E(N*t)+E(V*J);B[u>>2]=E(J*t)-E(V*N);M=C-20|0;aa=B[M>>2];u=o-16|0;J=B[u>>2];R=u;u=C-16|0;ba=B[u>>2];B[R>>2]=J+ba;R=o-20|0;N=B[R>>2];B[R>>2]=N+B[M>>2];N=E(N-aa);J=E(J-ba);B[M>>2]=E(N*s)+E(L*J);B[u>>2]=E(J*s)-E(L*N);M=C-28|0;aa=B[M>>2];u=o-24|0;J=B[u>>2];R=u;u=C-24|0;ba=B[u>>2];B[R>>2]=J+ba;R=o-28|0;N=B[R>>2];B[R>>2]=N+B[M>>2];N=E(N-aa);J=E(J-ba);B[M>>2]=E(N*l)+E(G*J);B[u>>2]=E(J*l)-E(G*N);k=k-1|0;C=C+U|0;o=o+U|0;continue}break}i=i-1|0;g=g-8|0;c=(ma<<2)+c|0;continue}}c=(h<<2)+j|0;h=c-(I<<6)|0;l=B[n+(S>>3<<2)>>2];ca=E(-l);while(1){if(c>>>0>h>>>0){L=B[c>>2];g=c-32|0;V=B[g>>2];B[c>>2]=L+V;n=c-4|0;s=B[n>>2];k=n;n=c-36|0;W=B[n>>2];B[k>>2]=s+W;i=c-8|0;t=B[i>>2];k=i;i=c-40|0;J=B[i>>2];B[k>>2]=t+J;k=c-12|0;G=B[k>>2];u=k;k=c-44|0;N=B[k>>2];B[u>>2]=G+N;B[g>>2]=L-V;B[n>>2]=s-W;n=c-16|0;s=B[n>>2];u=n;n=c-48|0;aa=B[n>>2];B[u>>2]=s+aa;t=E(t-J);G=E(G-N);B[i>>2]=l*E(t+G);B[k>>2]=l*E(G-t);i=c-28|0;t=B[i>>2];k=c-60|0;G=B[k>>2];F=c-24|0;L=B[F>>2];r=c-56|0;V=B[r>>2];C=c-20|0;W=B[C>>2];u=C;C=c-52|0;J=B[C>>2];B[u>>2]=W+J;B[F>>2]=L+V;B[i>>2]=t+G;B[n>>2]=W-J;B[C>>2]=-E(s-aa);s=E(t-G);t=E(L-V);B[r>>2]=l*E(s-t);B[k>>2]=E(t+s)*ca;XL(c);XL(g);c=c+-64|0;continue}break}k=H-4|0;g=q+(k<<2)|0;i=(q+(P<<2)|0)-16|0;c=x[((T<<2)+a|0)+1100>>2];while(1){if(i>>>0>=q>>>0){h=(z[c>>1]<<2)+j|0;B[g+12>>2]=B[h>>2];B[g+8>>2]=B[h+4>>2];B[i+12>>2]=B[h+8>>2];B[i+8>>2]=B[h+12>>2];h=(z[c+2>>1]<<2)+j|0;B[g+4>>2]=B[h>>2];B[g>>2]=B[h+4>>2];B[i+4>>2]=B[h+8>>2];B[i>>2]=B[h+12>>2];c=c+4|0;g=g-16|0;i=i-16|0;continue}break}c=x[((T<<2)+a|0)+1084>>2];i=q;g=i+(H<<2)|0;h=g;while(1){n=h-16|0;if(n>>>0>i>>>0){l=B[i+4>>2];F=h-4|0;s=B[F>>2];t=E(l-s);G=B[c+4>>2];l=E(l+s);s=B[i>>2];r=h-8|0;L=B[r>>2];V=E(s-L);W=B[c>>2];ca=E(E(G*l)-E(V*W));B[i+4>>2]=t+ca;s=E(s+L);l=E(E(G*V)+E(l*W));B[i>>2]=s+l;B[F>>2]=ca-t;B[r>>2]=s-l;l=B[i+8>>2];s=B[n>>2];t=E(l+s);G=B[c+12>>2];l=E(l-s);s=B[i+12>>2];h=h-12|0;L=B[h>>2];V=E(s+L);W=B[c+8>>2];ca=E(E(G*l)+E(V*W));B[i+8>>2]=t+ca;s=E(s-L);l=E(E(G*V)-E(l*W));B[i+12>>2]=s+l;B[n>>2]=t-ca;B[h>>2]=l-s;i=i+16|0;c=c+16|0;h=n;continue}break}i=x[((T<<2)+a|0)+1076>>2]+(H<<2)|0;c=(k<<2)+j|0;h=((S<<2)+j|0)-16|0;while(1){n=g-32|0;if(n>>>0>=q>>>0){l=B[g-8>>2];s=B[i-4>>2];t=B[i-8>>2];G=B[g-4>>2];L=E(E(l*s)-E(t*G));B[j>>2]=L;B[c+12>>2]=-L;l=E(E(t*E(-l))-E(s*G));B[K>>2]=l;B[h+12>>2]=l;l=B[g-16>>2];s=B[i-12>>2];t=B[i-16>>2];G=B[g-12>>2];L=E(E(l*s)-E(t*G));B[j+4>>2]=L;B[c+8>>2]=-L;l=E(E(t*E(-l))-E(s*G));B[K+4>>2]=l;B[h+8>>2]=l;l=B[g-24>>2];s=B[i-20>>2];t=B[i-24>>2];G=B[g-20>>2];L=E(E(l*s)-E(t*G));B[j+8>>2]=L;B[c+4>>2]=-L;l=E(E(t*E(-l))-E(s*G));B[K+8>>2]=l;B[h+4>>2]=l;l=B[n>>2];s=B[i-28>>2];i=i-32|0;t=B[i>>2];G=B[g-28>>2];L=E(E(l*s)-E(t*G));B[j+12>>2]=L;B[c>>2]=-L;l=E(E(t*E(-l))-E(s*G));B[K+12>>2]=l;B[h>>2]=l;h=h-16|0;c=c-16|0;K=K+16|0;j=j+16|0;g=n;continue}break}if(!x[a+80>>2]){Db(q)}x[a+92>>2]=la;break B}r=r+1|0;continue}}c=c+1|0;continue}break}m=m+1|0;j=x[a+4>>2];continue}break}}else{g=c<<2;j=g+a|0;n=x[j+800>>2];F:{if(x[g+(O+320|0)>>2]){Tb(n,0,K);break F}H=x[j+996>>2];G:{g=y[(T+y[(x[T+4>>2]+D(c,3)|0)+2|0]|0)+9|0];if(!z[((g<<1)+a|0)+132>>1]){fc(a,21);break G}F=S>>1;r=x[a+260>>2]+D(g,1596)|0;j=D(y[r+1588|0],w[H>>1]);i=1;g=0;while(1){if(x[r+1592>>2]>(i|0)){h=y[(i+r|0)+838|0]<<1;q=w[h+H>>1];if((q|0)>=0){q=D(y[r+1588|0],q&65535);h=z[(h+r|0)+338>>1];if((h|0)!=(g|0)){k=q-j|0;C=h-g|0;o=(k|0)/(C|0)|0;H:{I=(h|0)<(F|0)?h:F;if((I|0)<=(g|0)){break H}u=k;k=k>>31;P=o>>31;P=((u^k)-k|0)-D(C,(P^o)-P|0)|0;Z=k|1;k=n+(g<<2)|0;B[k>>2]=B[((j&255)<<2)+89152>>2]*B[k>>2];I=I-1|0;k=0;while(1){if((g|0)==(I|0)){break H}g=g+1|0;U=n+(g<<2)|0;k=k+P|0;M=(k|0)<(C|0);j=(j+o|0)+(M?0:Z)|0;B[U>>2]=B[((j&255)<<2)+89152>>2]*B[U>>2];k=k-(M?0:C)|0;continue}}g=h}j=q}i=i+1|0;continue}break}if((g|0)>=(F|0)){break G}j=(j<<2)+89152|0;while(1){if((g|0)==(F|0)){break G}h=n+(g<<2)|0;B[h>>2]=B[j>>2]*B[h>>2];g=g+1|0;continue}}}c=c+1|0;continue}break}_L(a);I:{if(y[a+1377|0]){x[a+1060>>2]=ra;v[a+1377|0]=0;x[a+1064>>2]=1;x[a+1412>>2]=S-ia;break I}c=x[a+1412>>2];if(!c){break I}g=ka-Y|0;if((g|0)<=(c|0)){x[a+1412>>2]=c-g;x[ha>>2]=ka;Y=ka;break I}Y=c+Y|0;x[ha>>2]=Y;x[a+1412>>2]=0}c=x[a+1064>>2];J:{K:{L:{M:{if(x[a+1388>>2]==x[a+1404>>2]){N:{if(!c|!(y[a+1375|0]&4)){break N}c=x[a+1408>>2];g=x[a+1060>>2];if(c>>>0>=g+(ia-Y|0)>>>0){break N}g=c-g|0;c=(c>>>0>=g>>>0?g:0)+Y|0;c=(c|0)<(ia|0)?c:ia;x[$+12>>2]=c;x[a+1060>>2]=c+x[a+1060>>2];break K}x[a+1064>>2]=1;c=x[a+1408>>2]+(Y-da|0)|0;break M}if(!c){break L}c=x[a+1060>>2]}x[a+1060>>2]=c+(ka-Y|0)}if(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0){break J}x[$+12>>2]=ia}c=1;break o}_(6325,13258,3451,5634);p()}g=g-1|0;c=x[T+4>>2]+D(g,3)|0;q=x[j+(y[c+1|0]<<2)>>2];n=x[j+(y[c|0]<<2)>>2];c=0;while(1){if((c|0)==(h|0)){continue z}i=c<<2;m=i+q|0;t=B[m>>2];i=i+n|0;l=B[i>>2];O:{if(l>E(0)){if(t>E(0)){s=E(l-t);break O}s=l;l=E(l+t);break O}if(t>E(0)){s=E(l+t);break O}s=l;l=E(l-t)}B[i>>2]=l;B[m>>2]=s;c=c+1|0;continue}}}_(6325,13258,3335,5634);p()}Z=O+256|0;H=fb-16|0;fb=H;i=x[a+4>>2];r=x[a+396>>2];g=y[(j+la|0)+24|0];F=r+D(g,24)|0;h=x[F+4>>2];ja=z[((g<<1)+a|0)+268>>1];c=da<<((ja|0)==2);n=c>>>0>h>>>0?h:c;h=x[F>>2];I=(n-(c>>>0>h>>>0?h:c)>>>0)/A[F+8>>2]|0;q=I<<2;c=D(i,q+4|0);M=x[x[a+124>>2]+D(y[F+13|0],2096)>>2];R=x[a+92>>2];P:{if(x[a+80>>2]){h=uo(a,c);i=x[a+4>>2];break P}h=Fd(c)}n=(m|0)>0?m:0;C=da<<2;c=0;o=(i|0)>0?i:0;k=(i<<2)+h|0;while(1){if((c|0)!=(o|0)){x[(c<<2)+h>>2]=k;c=c+1|0;k=k+q|0;continue}break}q=h;c=0;while(1){if((c|0)!=(n|0)){if(!y[c+O|0]){Tb(x[Z+(c<<2)>>2],0,C)}c=c+1|0;continue}break}Q:{if(!((m|0)==1|(ja|0)!=2)){c=0;while(1){R:{if((c|0)!=(n|0)){if(y[c+O|0]){break R}}else{c=n}if((c|0)==(m|0)){break Q}n=r+D(g,24)|0;r=(m|0)!=2;C=(m|0)<3;i=0;while(1){if((i|0)==8){break Q}S:{if(!r){k=0;h=0;while(1){if((h|0)>=(I|0)){break S}c=x[F>>2]+D(x[F+8>>2],h)|0;x[H+12>>2]=c&1;x[H+8>>2]=c>>1;if(!i){g=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){El(a)}c=x[a+1392>>2];o=w[(g+((c&1023)<<1)|0)+36>>1];T:{if((o|0)>=0){u=c;o=o&65535;c=y[o+x[g+8>>2]|0];x[a+1392>>2]=u>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:o;break T}c=Om(a,g)}c=y[g+23|0]?x[x[g+2088>>2]+(c<<2)>>2]:c;if((c|0)==-1){break Q}x[x[q>>2]+(k<<2)>>2]=x[x[n+16>>2]+(c<<2)>>2]}c=0;while(1){if(!((c|0)>=(M|0)|(h|0)>=(I|0))){g=x[F+8>>2];o=w[(x[n+20>>2]+(y[x[x[q>>2]+(k<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];U:{if((o|0)>=0){if(!ZL(a,x[a+124>>2]+D(o&65535,2096)|0,Z,2,H+12|0,H+8|0,da,g)){break Q}h=h+1|0;break U}h=h+1|0;g=x[F>>2]+D(g,h)|0;x[H+8>>2]=g>>1;x[H+12>>2]=g&1}c=c+1|0;continue}break}k=k+1|0;continue}}if(C){break S}k=0;h=0;while(1){if((h|0)>=(I|0)){break S}g=x[F>>2]+D(x[F+8>>2],h)|0;c=(g|0)/(m|0)|0;x[H+12>>2]=g-D(c,m);x[H+8>>2]=c;if(!i){g=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){El(a)}c=x[a+1392>>2];o=w[(g+((c&1023)<<1)|0)+36>>1];V:{if((o|0)>=0){u=c;o=o&65535;c=y[o+x[g+8>>2]|0];x[a+1392>>2]=u>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:o;break V}c=Om(a,g)}c=y[g+23|0]?x[x[g+2088>>2]+(c<<2)>>2]:c;if((c|0)==-1){break Q}x[x[q>>2]+(k<<2)>>2]=x[x[n+16>>2]+(c<<2)>>2]}c=0;while(1){if(!((c|0)>=(M|0)|(h|0)>=(I|0))){g=x[F+8>>2];o=w[(x[n+20>>2]+(y[x[x[q>>2]+(k<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];W:{if((o|0)>=0){if(!ZL(a,x[a+124>>2]+D(o&65535,2096)|0,Z,m,H+12|0,H+8|0,da,g)){break Q}h=h+1|0;break W}h=h+1|0;g=x[F>>2]+D(g,h)|0;o=(g|0)/(m|0)|0;x[H+8>>2]=o;x[H+12>>2]=g-D(m,o)}c=c+1|0;continue}break}k=k+1|0;continue}}i=i+1|0;continue}}c=c+1|0;continue}}ma=r+D(g,24)|0;i=0;while(1){if((i|0)==8){break Q}k=0;m=0;while(1){if((k|0)<(I|0)){X:{if(i){break X}c=0;while(1){if((c|0)==(n|0)){break X}if(!y[c+O|0]){h=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){El(a)}g=x[a+1392>>2];r=w[(h+((g&1023)<<1)|0)+36>>1];Y:{if((r|0)>=0){u=g;r=r&65535;g=y[r+x[h+8>>2]|0];x[a+1392>>2]=u>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:r;break Y}g=Om(a,h)}g=y[h+23|0]?x[x[h+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[q+(c<<2)>>2]+(m<<2)>>2]=x[x[ma+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}h=0;while(1){Z:{if((h|0)>=(M|0)){break Z}c=0;if((k|0)>=(I|0)){break Z}while(1){if((c|0)!=(n|0)){_:{if(y[c+O|0]){break _}g=c<<2;r=w[(x[ma+20>>2]+(y[x[x[g+q>>2]+(m<<2)>>2]+h|0]<<4)|0)+(i<<1)>>1];if((r|0)<0){break _}K=x[a+124>>2]+D(r&65535,2096)|0;X=x[g+Z>>2];U=x[F+8>>2];P=x[F>>2]+D(U,k)|0;$:{aa:{if(ja){r=0;while(1){g=1;if((r|0)>=(U|0)){break $}ea=X+(P<<2)|0;g=U-r|0;C=0;l=E(0);ba:{o=WL(a,K);if((o|0)<0){break ba}C=x[K>>2];g=(g|0)>(C|0)?C:g;u=D(o,C);if(y[K+22|0]){o=0;g=(g|0)>0?g:0;C=1;while(1){if((g|0)==(o|0)){break ba}ga=ea+(o<<2)|0;l=E(l+B[x[K+28>>2]+(o+u<<2)>>2]);B[ga>>2]=B[ga>>2]+l;o=o+1|0;l=E(l+B[K+12>>2]);continue}}o=0;g=(g|0)>0?g:0;C=1;while(1){if((g|0)==(o|0)){break ba}ga=ea+(o<<2)|0;B[ga>>2]=B[ga>>2]+E(B[x[K+28>>2]+(o+u<<2)>>2]+E(0));o=o+1|0;continue}}if(!C){break aa}g=x[K>>2];P=g+P|0;r=g+r|0;continue}}r=0;ea=(U|0)/x[K>>2]|0;u=(ea|0)>0?ea:0;ga=X+(P<<2)|0;g=1;while(1){if((r|0)==(u|0)){break $}C=r+P|0;o=r<<2;r=r+1|0;sa=o+ga|0;X=U-C|0;o=0;l=E(0);ca:{na=WL(a,K);if((na|0)<0){break ca}C=0;o=x[K>>2];X=(o|0)<(X|0)?o:X;X=(X|0)>0?X:0;na=D(o,na);o=1;while(1){if((C|0)==(X|0)){break ca}qa=sa+(D(C,ea)<<2)|0;s=E(l+B[x[K+28>>2]+(C+na<<2)>>2]);B[qa>>2]=B[qa>>2]+s;l=y[K+22|0]?s:l;C=C+1|0;continue}}if(o){continue}break}}g=0}if(!g){break Q}}c=c+1|0;continue}break}k=k+1|0;h=h+1|0;continue}break}m=m+1|0;continue}break}i=i+1|0;continue}}if(!x[a+80>>2]){Db(q)}x[a+92>>2]=R;fb=H+16|0;j=j+1|0;continue}}_(6325,13258,3302,5634);p()}fb=O+2368|0}else{c=0}fb=fa+16|0;if(!c){da:{ea:{fa:{c=x[a+100>>2];switch(c-32|0){case 0:break ea;case 3:break fa;default:break da}}x[a+100>>2]=0;while(1){if((Ph(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}if(x[a+992>>2]){break da}x[a+100>>2]=0;while(1){if((Ph(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}x[a+1420>>2]=0;x[a+992>>2]=0;x[a+1504>>2]=0;x[a+1508>>2]=0;x[a+1412>>2]=0;x[a+1416>>2]=0;v[a+1377|0]=0;x[a+1064>>2]=0;x[a+100>>2]=c;x[f>>2]=0;c=1;break a}h=x[$+12>>2];n=x[$+4>>2];j=x[$+8>>2];ga:{ha:{q=x[a+992>>2];if(q){g=q<<1;ia:{if((g|0)==x[a+112>>2]){c=a+1092|0}else{c=0;if((g|0)!=x[a+116>>2]){break ia}c=a+1096|0}c=x[c>>2]}if(!c){break ha}m=(q|0)>0?q:0;while(1){if(x[a+4>>2]>(Q|0)){i=(Q<<2)+a|0;g=0;while(1){if((g|0)!=(m|0)){k=x[i+800>>2]+(g+n<<2)|0;u=k;l=B[k>>2];k=g<<2;B[u>>2]=E(l*B[k+c>>2])+E(B[k+x[i+928>>2]>>2]*B[c+(q+(g^-1)<<2)>>2]);g=g+1|0;continue}break}Q=Q+1|0;continue}break}Q=x[a+992>>2]}x[a+992>>2]=h-j;q=(h|0)<(j|0);i=(q?j:h)-j|0;while(1){if(x[a+4>>2]>(pa|0)){c=(pa<<2)+a|0;g=0;while(1){if((g|0)!=(i|0)){B[x[c+928>>2]+(g<<2)>>2]=B[x[c+800>>2]+(g+j<<2)>>2];g=g+1|0;continue}break}pa=pa+1|0;continue}break}if(!Q){break ha}c=(q?h:j)-n|0;x[a+1416>>2]=c+x[a+1416>>2];break ga}c=0}g=c;c=0;j=x[a+4>>2];h=(j|0)>0?j:0;while(1){if((c|0)!=(h|0)){q=(c<<2)+a|0;x[q+864>>2]=x[q+800>>2]+(n<<2);c=c+1|0;continue}break}if(d){x[d>>2]=j}x[f>>2]=g;x[e>>2]=a+864;c=x[a+32>>2]-b|0}fb=$+16|0;return c}function xqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;d=fb-1728|0;fb=d;xc(b);f=fb-16|0;fb=f;j=d+1602|0;$X(f+8|0,j);h=x[f+12>>2];k=b;kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(h|0)){Vb(k,x[f+12>>2])}fb=f+16|0;b=(b|0)==(h|0);if(!b){_X(j)}a:{if(!b){break a}if(!aY(d+1602|0)){break a}if(!Mb(x[k>>2],x[k+8>>2],Bc(256,0))){break a}b:{if(!c){break b}Bd(a,1048576);gg(a);b=fb-16|0;fb=b;e=tc(b+4|0,4230);_c(d+1344|0,e);tb(e);fb=b+16|0;b=y[d+1610|0]|y[d+1611|0]<<8;x[d+144>>2]=b>>>8;x[31725]=0;x[d+12>>2]=b&255;O(446,d+72|0,d+12|0);b=x[31725];x[31725]=0;c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){x[31725]=0;V(432,d+256|0,d+1344|0,d+144|0,d+72|0);b=x[31725];x[31725]=0;if((b|0)==1){break i}b=d+256|0;Ab(a+1298344|0,b);tb(b);tb(d+72|0);e=d+1344|0;Eb(e);f=tc(b,15115);Ab(a+1298356|0,f);tb(f);We(e,2,d+1612|0);Mr(b,22,e);Ab(a+1298368|0,b);tb(b);G=a+1298404|0,H=x[Fc(b,22)>>2],x[G>>2]=H;HC(e,2,d+1644|0);Cc(b,e);Ab(a+1298308|0,b);tb(b);w[a+480188>>1]=y[d+1714|0]|y[d+1715|0]<<8;f=y[d+1718|0];x[a+480204>>2]=125e4;x[a+480208>>2]=32792;G=a,H=Kd(f,1,31),x[G+480196>>2]=H;w[a+480192>>1]=y[d+1724|0]|y[d+1725|0]<<8;w[a+480190>>1]=y[d+1726|0]|y[d+1727|0]<<8;f=Kd(y[d+1719|0],1,32);x[a+480216>>2]=f;x[a+480228>>2]=96;x[a+480232>>2]=48;x[a+480220>>2]=f<<2;Dw(k,e);f=a+484376|0;Vr(Xb(x[a+484360>>2],y[f|0]),e,y[d+1708|0]|y[d+1709|0]<<8,65535,65535);bf(Xb(x[a+484360>>2],y[f|0]),y[d+1710|0]|y[d+1711|0]<<8);q=ih(k);fe(b,k,q?274:0);u=ic(d+1324|0,b);ub(b);x[31725]=0;b=R(153,k|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}x[31725]=0;S(187,d+256|0,k|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break g}b=d+256|0;t=ic(d+1304|0,b);ub(b);s=z[a+480188>>1];if(q){w[a+480188>>1]=s+8}B=c&1;if(!B){break f}x[31725]=0;O(225,a+484344|0,y[d+1712|0]|y[d+1713|0]<<8);b=x[31725];x[31725]=0;if((b|0)!=1){break f}g=N()|0;break e}g=N()|0;break h}g=N()|0;tb(d+72|0)}Eb(d+1344|0);break c}g=N()|0;break d}o=a+484344|0;j:{k:{while(1){l:{m:{n:{o:{p:{q:{if((y[d+1712|0]|y[d+1713|0]<<8)>>>0<=r>>>0){b=y[d+1716|0]|y[d+1717|0]<<8;if((b-2&65535)>>>0>=4998){break o}if(!(g&1)){break q}h=0;b=Gc(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break p}x[31725]=0;b=R(191,k|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}x[d+12>>2]=b;x[31725]=0;b=R(153,k|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break k}x[31725]=0;S(187,d+72|0,k|0,b+1&-2);b=x[31725];x[31725]=0;if((b|0)==1){break k}b=d+72|0;i=ic(d+256|0,b);ub(b);wc(d+12|0,1024);if(!B){break m}m=x[d+12>>2];if(!m){break m}x[31725]=0;b=U(198,o|0,r&65535,m|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){if(!b){break m}j=0;e=0;if(v[d+1720|0]&1){break n}r:while(1){if((j|0)==(m|0)){break m}b=Wb(x[o>>2],r);cf(d+72|0,x[b>>2],x[x[b+48>>2]+12>>2],j);e=0;while(1){if((e|0)==(s|0)){j=j+1|0;continue r}x[31725]=0;O(624,i|0,d+144|0);b=x[31725];x[31725]=0;if((b|0)!=1){g=ZX(Wc(x[d+72>>2],e),d+144|0)|g;e=e+1|0;continue}break}break}break l}break l}h=2;b=_e(2646e3/+(D(b,D(x[a+480216>>2],x[a+480196>>2]))>>>0)*1e4)}v[a+480224|0]=h;x[a+480204>>2]=b}b=z[a+480188>>1];x[31725]=0;v[d+256|0]=0;r=U(625,d+1292|0,b|0,d+256|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){h=a+1298320|0;j=a+1298332|0;n=0;s:{t:{u:{v:{w:{x:{while(1){b=x[t+8>>2];e=x[t>>2];x[31725]=0;b=U(152,e|0,b|0,8)|0;e=x[31725];x[31725]=0;y:{if((e|0)!=1){if(b){break y}b=a+906300|0;h=x[r>>2];j=0;while(1){f=z[a+480188>>1];if(f>>>0<=j>>>0){x[d+248>>2]=0;x[d+252>>2]=0;x[d+240>>2]=0;x[d+244>>2]=0;x[d+232>>2]=0;x[d+236>>2]=0;x[d+224>>2]=0;x[d+228>>2]=0;z:{A:{if(!q){break A}e=0;x[31725]=0;O(626,u|0,d+256|0);b=x[31725];x[31725]=0;if((b|0)==1){break z}while(1){if((e|0)==8){e=0;x[31725]=0;j=P(216,d+212|0,z[d+256>>1])|0;b=x[31725];x[31725]=0;if((b|0)!=1){B:{C:{D:{E:{while(1){if(z[d+256>>1]<=e>>>0){x[31725]=0;i=U(627,d+200|0,y[d+1712|0]|y[d+1713|0]<<8,25288)|0;b=x[31725];x[31725]=0;if((b|0)==1){break C}f=0;break D}x[31725]=0;b=R(191,k|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){x[31725]=0;S(187,d+144|0,k|0,b<<5);b=x[31725];x[31725]=0;if((b|0)==1){break E}f=d+144|0;b=ic(d+72|0,f);hd(eh(x[j>>2],e),b);ub(b);e=e+1|0;ub(f);continue}break}g=N()|0;break B}g=N()|0;break B}while(1){if((y[d+1708|0]|y[d+1709|0]<<8)>>>0<=f>>>0){md(i);Qc(j);break A}F:{g=d+f|0;e=y[g+274|0];if(e>>>0>=z[d+256>>1]){break F}b=z[_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],f)>>1];if(b>>>0>=(y[d+1712|0]|y[d+1713|0]<<8)>>>0){break F}G:{h=_b(x[i>>2],b);m=z[h>>1];H:{if((m|0)==65535){w[h>>1]=e;break H}if((e|0)==(m|0)){break H}x[31725]=0;e=P(628,o|0,b|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break G}if((e|0)==65535){break H}G=_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],f),H=e,w[G>>1]=H;b=e}if(!He(x[a+484344>>2],x[a+484348>>2],b)){break F}m=eh(x[j>>2],y[g+274|0]);xc(m);e=x[m>>2];x[31725]=0;e=R(156,e|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break G}l=e>>>5|0;h=0;I:while(1){e=Wb(x[o>>2],b);if(A[e+12>>2]<=h>>>0){break F}g=0;e=jd(x[e>>2],x[x[e+48>>2]+12>>2],h,z[a+480188>>1]-8&65535);while(1){if((g|0)==8){h=h+1|0;continue I}v[e|0]=0;v[e+1|0]=0;v[e+2|0]=0;v[e+3|0]=0;v[e+4|0]=0;v[e+5|0]=0;J:{if(h>>>0>=l>>>0){break J}x[31725]=0;P(629,m|0,d+72|0)|0;q=x[31725];x[31725]=0;if((q|0)==1){break G}if(v[d+72|0]>=0){break J}v[e|0]=61;v[e+1|0]=y[(d+240|0)+(g<<1)|0];q=y[d+72|0]&31;v[d+144|0]=q;if(q){Qf(d+144|0,15);v[e+3|0]=20;v[e+5|0]=y[d+144|0]|208}v[e+2|0]=1;v[e+4|0]=y[d+73|0]+3>>>2}e=e+6|0;g=g+1|0;continue}}}g=N()|0;md(i);break B}f=f+1|0;continue}}g=N()|0}Qc(j);break s}g=N()|0;break s}f=e<<1;g=f+(d+240|0)|0;b=z[a+480192>>1]+1&65535;h=z[x[a+8>>2]+58>>1];while(1){K:{L:{j=b&65535;if(j>>>0<=h>>>0){if(x[((j<<2)+a|0)+900380>>2]){break L}}else{b=65535}b=b&65535;break K}b=b+1|0;continue}break}w[g>>1]=b;m=f+(d+224|0)|0;f=z[(d+f|0)+258>>1];w[m>>1]=f;M:{if((b|0)!=65535){x[31725]=0;b=U(253,a|0,b|0,f+1&65535)|0;f=x[31725];x[31725]=0;N:{O:{if((f|0)!=1){if(!b){break M}x[31725]=0;O(290,d+144|0,4475);f=x[31725];x[31725]=0;if((f|0)==1){break O}x[31725]=0;x[d+12>>2]=e+1;S(630,d+72|0,d+144|0,d+12|0);f=x[31725];x[31725]=0;if((f|0)==1){break N}f=b+492|0;b=d+72|0;zc(f,b);tb(b);Eb(d+144|0);break M}g=N()|0;break s}g=N()|0;break s}g=N()|0;Eb(d+144|0);break s}w[g>>1]=0}e=e+1|0;continue}}P:{Q:{b=y[d+1720|0]|y[d+1721|0]<<8|(y[d+1722|0]<<16|y[d+1723|0]<<24);if(!(b&2)){break Q}b=(((b&8?z[a+480188>>1]:s)&65535)+((y[d+1610|0]|y[d+1611|0]<<8)>>>0>591?n:0)|0)+(b>>>4&1)|0;f=0;R:while(1){e=0;if((y[d+1712|0]|y[d+1713|0]<<8)>>>0<=f>>>0){break Q}while(1){S:{if((b|0)!=(e|0)){g=x[k+8>>2];h=x[k>>2];x[31725]=0;g=U(152,h|0,g|0,4)|0;h=x[31725];x[31725]=0;if((h|0)==1){break P}if(g){break S}}f=f+1|0;continue R}x[31725]=0;O(631,y[d+1610|0]|y[d+1611|0]<<8,k|0);g=x[31725];x[31725]=0;if((g|0)==1){break P}e=e+1|0;continue}}}x[31725]=0;j=P(216,d+188|0,255)|0;b=x[31725];x[31725]=0;if((b|0)!=1){f=0;while(1){T:{b=f;U:{if((b|0)==255){n=FC(d+72|0);o=FC(d+144|0);g=0;while(1){V:{W:{X:{if((g|0)==256){h=0;break X}x[31725]=0;O(632,k|0,d+256|0);b=x[31725];x[31725]=0;if((b|0)==1){break W}x[31725]=0;b=R(153,k|0)|0;e=x[31725];x[31725]=0;Y:{Z:{_:{if((e|0)!=1){x[31725]=0;S(187,d+12|0,k|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break _}e=d+12|0;i=ic(d+52|0,e);ub(e);if((y[d+1726|0]|y[d+1727|0]<<8)>>>0>g>>>0){e=d+40|0;We(e,2,d+256|0);x[31725]=0;O(220,d+12|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break Y}e=d+12|0;zc(((g<<5)+a|0)+946336|0,e);tb(e)}if(!b){break V}if((y[d+1726|0]|y[d+1727|0]<<8)>>>0>g>>>0){break Z}break V}g=N()|0;break U}g=N()|0;break U}x[31725]=0;b=D(g+1|0,104)+a|0;e=b+484380|0;O(281,e|0,32);f=x[31725];x[31725]=0;$:{aa:{ba:{if((f|0)!=1){Ep(e);x[31725]=0;O(633,i|0,d+12|0);f=x[31725];x[31725]=0;if((f|0)==1){break Y}f=x[d+12>>2];x[e>>2]=f;x[b+484404>>2]=x[d+16>>2];if(y[d+20|0]>=2){h=b+484414|0;w[h>>1]=z[h>>1]|1;f=f>>>1|0;x[e>>2]=f}if(y[d+21|0]>=2){h=b+484414|0;w[h>>1]=z[h>>1]|64;x[e>>2]=f>>>1}h=2;switch(y[d+23|0]-1|0){case 0:break aa;case 1:break ba;default:break $}}break Y}h=6}e=b+484414|0;w[e>>1]=z[e>>1]|h}x[b+484384>>2]=x[d+24>>2];x[b+484388>>2]=x[d+28>>2];w[b+484410>>1]=z[d+32>>1]>>>7;e=y[d+34|0];ca:{if((e|0)==128){e=b+484414|0;f=z[e>>1]|256;w[e>>1]=f;break ca}w[b+484408>>1]=(e<<24>>24)+128;f=z[b+484414>>1]}h=b+484414|0;w[h>>1]=f|32;v[b+484416|0]=y[d+35|0];e=y[d+22|0];if(e&2){b=d+40|0;Jb(b,o,g);hp(b);e=y[d+22|0]}if(e&5){w[h>>1]=z[h>>1]|16384}if(!(e&8)){break V}b=d+40|0;Jb(b,n,g);hp(b);e=0;while(1){if((e|0)==8){break V}b=e<<1;da:{if(z[b+(d+224|0)>>1]!=(g|0)){break da}b=x[((z[b+(d+240|0)>>1]<<2)+a|0)+900380>>2];if(!b){break da}v[b+14|0]=0}e=e+1|0;continue}}g=N()|0;ub(i);break U}while(1){ea:{fa:{if((y[d+1724|0]|y[d+1725|0]<<8)>>>0<=h>>>0){if(!(c&2)){break fa}g=0;ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{while(1){if(z[a+480190>>1]<=g>>>0){break fa}g=g+1|0;c=D(g,104)+a|0;e=c+484380|0;b=c+484416|0;hm(e,(+(v[b|0]-49|0)+ +v[c+484417|0]*-.0078125)/-12);w[b>>1]=0;b=z[c+484414>>1];if(!(b&16384)){b=Xc(d+256|0,b&1?16:8,b&64?3:1,0,11);x[31725]=0;U(217,b|0,e|0,k|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}g=N()|0;break U}x[31725]=0;e=R(153,k|0)|0;b=x[31725];x[31725]=0;oa:{if((b|0)==1){break oa}x[31725]=0;P(185,k|0,12)|0;b=x[31725];x[31725]=0;if((b|0)==1){break oa}b=Fb(d+256|0);x[31725]=0;S(272,k|0,b|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break na}ze(c+484423|0,b);x[31725]=0;O(385,d+52|0,16450);c=x[31725];x[31725]=0;if((c|0)==1){break ma}x[d+8>>2]=g;c=x[a+1298404>>2];x[31725]=0;S(634,d+40|0,c|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break la}x[31725]=0;V(432,d+12|0,d+52|0,d+8|0,d+40|0);c=x[31725];x[31725]=0;if((c|0)==1){break ka}c=x[a+1298472>>2];x[31725]=0;S(387,c|0,2,d+12|0);c=x[31725];x[31725]=0;if((c|0)==1){break ja}tb(d+12|0);tb(d+40|0);Eb(d+52|0);tb(b);continue}break}g=N()|0;break U}g=N()|0;break ga}g=N()|0;break ga}g=N()|0;break ha}g=N()|0;break ia}g=N()|0;tb(d+12|0)}tb(d+40|0)}Eb(d+52|0)}tb(b);break U}b=x[eh(x[j>>2],h)>>2];x[31725]=0;b=R(156,b|0)|0;e=x[31725];x[31725]=0;pa:{qa:{if((e|0)!=1){if(!b){h=h+1|0;continue}b=eh(x[j>>2],h);xc(b);x[31725]=0;O(635,b|0,d+256|0);b=x[31725];x[31725]=0;if((b|0)==1){break qa}i=Nb(d+12|0);x[31725]=0;S(636,k|0,i|0,z[d+256>>1]);b=x[31725];x[31725]=0;if((b|0)==1){break pa}h=h+1|0;b=x[((h<<2)+a|0)+900380>>2];if(!b|y[b+34|0]){break ea}x[b+4>>2]=32;e=0;Kv(b,0);s=b+108|0;l=b+236|0;while(1){if((e|0)==96){break ea}f=y[(d+e|0)+258|0];ra:{if(f>>>0>=z[d+256>>1]){break ra}m=Ve(x[i>>2],f);f=y[m|0];g=f+1|0;q=e+12|0;G=_b(l,q),H=g,w[G>>1]=H;if(f>>>0>=z[a+480190>>1]){break ra}f=D(g,104)+a|0;v[f+484418|0]=y[d+354|0]&3;v[f+484419|0]=y[d+355|0];v[f+484420|0]=y[d+356|0];v[f+484421|0]=y[d+357|0];w[f+484412>>1]=y[m+1|0]<<1;v[f+484417|0]=y[m+2|0];f=g-1|0;Jb(d+52|0,n,f);if(Hb(x[x[d+52>>2]>>2],x[d+56>>2])){v[b+14|0]=0}Jb(d+52|0,o,f);if(!Hb(x[x[d+52>>2]>>2],x[d+56>>2])){break ra}G=xb(s,q),H=61,v[G|0]=H}e=e+1|0;continue}}g=N()|0;break U}g=N()|0;break U}g=N()|0;Ae(i);break U}Qc(j);dc(r);ub(t);ub(u);break b}Ae(i);continue}}g=N()|0;break U}ub(i);g=g+1|0;continue}}x[31725]=0;O(632,k|0,d+144|0);e=x[31725];x[31725]=0;sa:{ta:{ua:{va:{if((e|0)!=1){x[31725]=0;e=R(153,k|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break va}x[31725]=0;e=(e|0)==32?428:e;i=e?(y[d+1610|0]|y[d+1611|0]<<8)>>>0>513?e+4|0:e:e;S(187,d+72|0,k|0,i|0);e=x[31725];x[31725]=0;if((e|0)==1){break ua}g=d+72|0;e=ic(d+256|0,g);h=Ge(d+12|0,hd(eh(x[j>>2],b),e));ub(e);f=b+1|0;ub(g);if(b>>>0>=(y[d+1724|0]|y[d+1725|0]<<8)>>>0){break T}x[31725]=0;b=f&65535;g=U(253,a|0,b|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break ta}break sa}g=N()|0;break U}g=N()|0;break U}g=N()|0;break U}if(!g){break T}b=d+72|0;We(b,2,d+144|0);x[31725]=0;O(220,d+256|0,b|0);b=x[31725];x[31725]=0;wa:{if((b|0)!=1){b=d+256|0;zc(g+492|0,b);tb(b);if(!i){break T}x[31725]=0;O(635,h|0,d+256|0);b=x[31725];x[31725]=0;if((b|0)!=1){o=3;i=0;if((y[d+1610|0]|y[d+1611|0]<<8)>>>0<513){n=0;break wa}x[31725]=0;n=R(191,h|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break sa}if((y[d+1610|0]|y[d+1611|0]<<8)>>>0<514){break wa}x[31725]=0;o=R(153,h|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break wa}break sa}break sa}break sa}x[g>>2]=y[d+358|0]|y[d+359|0]<<8;v[g+16|0]=y[((y[d+360|0]|y[d+361|0]<<8)&3)+25290|0];v[g+17|0]=y[(y[d+361|0]&3)+25290|0];v[g+18|0]=y[((y[d+360|0]|y[d+361|0]<<8)>>>12&3)+25294|0];while(1){xa:{ya:{if((i|0)==4){if(!(v[g+60|0]&1|y[g+16|0]==3)){x[g>>2]=32767}mk(g,127,1);lk(g,0,1);if(!n){break T}x[31725]=0;O(637,h|0,d+72|0);b=x[31725];x[31725]=0;if((b|0)==1){break sa}if(n&2){mk(g,GD(x[a+480208>>2],+((y[d+74|0]|y[d+75|0]<<8)>>>0)),1);lk(g,y[d+76|0],1)}v[g+25|0]=y[d+73|0]==1;if(!(n&4)){break T}v[g+31|0]=y[d+79|0]+1;b=v[d+80|0];v[g+34|0]=b+1;if((b|0)<0){v[g+30|0]=y[d+87|0]+1}if(!y[d+84|0]){break ya}i=g+108|0;e=0;while(1){if((e|0)==128){break ya}b=e+1|0;x[d+52>>2]=b+v[d+84|0];WX(d+52|0);n=x[d+52>>2];G=xb(i,e),H=n,v[G|0]=H;e=b;continue}}if(!(o&1)){break xa}x[31725]=0;O(638,h|0,d+72|0);b=x[31725];x[31725]=0;za:{if((b|0)!=1){b=_h(g,y[i+25298|0]);Aa:{if((i|0)!=3){e=y[d+72|0];m=y[b+12|0]&-17;break Aa}e=y[d+72|0];m=e<<4&16|y[b+12|0]&-17}v[b+12|0]=e>>>1&2|(e<<1&4|(m&248|e&1));v[d+52|0]=y[d+73|0];v[d+40|0]=16;e=y[Rb(d+52|0,d+40|0)|0];x[31725]=0;O(295,b|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break za}e=y[d+74|0];v[b+15|0]=e;v[b+16|0]=e;v[b+13|0]=y[d+75|0];v[b+14|0]=y[d+76|0];e=0;m=x[b>>2];s=Sd(m,x[b+4>>2]);while(1){if((e|0)==(s|0)){break xa}l=yb(m,e);b=(d+72|0)+(e<<2)|0;w[l>>1]=y[b+8|0]|y[b+9|0]<<8;G=l,H=Kd(y[b+10|0]|y[b+11|0]<<8,0,64),v[G+2|0]=H;e=e+1|0;continue}}break sa}break sa}Kv(g,0);break T}i=i+1|0;o=o>>>1|0;continue}}g=N()|0;ub(h)}Qc(j);break s}ub(h);continue}}g=N()|0;break s}g=N()|0;break s}g=N()|0;break s}else{e=v[xb(h,j)|0];Ba:{if((e|0)<=(j|0)|(e|0)>=(f|0)){break Ba}e=y[((e<<5)+a|0)+480288|0];if(!e){break Ba}f=((j<<5)+a|0)+480288|0;g=y[f|0];if(!g){v[f|0]=e;break Ba}g=g-1|0;while(1){f=g&255;g=vm(x[vd(b,f)+28>>2]);f=vd(b,f);if((g|0)==255){e=e-1&255;x[f+28>>2]=e>>>0<250?e+128|0:0}else{g=vm(x[f+28>>2]);continue}break}}j=j+1|0;continue}}}g=N()|0;break s}x[31725]=0;f=R(153,t|0)|0;b=x[31725];x[31725]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((b|0)!=1){x[31725]=0;b=R(153,t|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ka}x[31725]=0;S(187,d+256|0,t|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break Ka}e=d+256|0;b=ic(d+72|0,e);ub(e);if((f|0)==4674381){break Ga}if((f|0)==5068115){break Fa}if((f|0)==726487106){break Ja}if((f|0)==844387158){break Ea}e=0;if((f|0)==1280004692){break Ia}if((f|0)==1314144592){break Ha}if((f|0)!=1397445204){break Da}x[31725]=0;e=R(191,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break u}e=e>>>0<256?48:e>>>8|0;x[a+480228>>2]=e;x[a+480232>>2]=e>>>1;e=0;while(1){if(z[a+480188>>1]<=e>>>0){break Da}x[31725]=0;f=P(639,b|0,d+256|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break x}if(f){w[((e<<5)+a|0)+480286>>1]=z[d+256>>1]>>>10;G=xb(x[r>>2],e),H=y[d+259|0],v[G|0]=H}e=e+1|0;continue}}g=N()|0;break s}g=N()|0;break s}if(g&1){break Da}v[a+480224|0]=2;x[31725]=0;C=+ia(640,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break Ca}if(!(C>1e-8)){break Da}G=a,H=_e(2646e3/(C*+(D(x[a+480216>>2],x[a+480196>>2])>>>0))*1e4),x[G+480204>>2]=H;break Da}while(1){La:{if(z[a+480188>>1]<=e>>>0){break Da}f=x[b>>2];x[31725]=0;f=U(152,f|0,x[d+80>>2],1)|0;i=x[31725];x[31725]=0;if((i|0)==1){break w}if(!f){break Da}f=Fb(d+256|0);x[31725]=0;S(360,b|0,f|0,-1);i=x[31725];x[31725]=0;if((i|0)!=1){i=d+12|0;wg(i,3,Kb(f),Yc(x[d+260>>2],y[d+267|0]));x[31725]=0;O(220,d+144|0,i|0);i=x[31725];x[31725]=0;if((i|0)==1){break La}i=d+144|0;pm(((e<<5)+a|0)+480289|0,i);tb(i);tb(f);e=e+1|0;continue}}break}g=N()|0;tb(f);break t}while(1){if((y[d+1712|0]|y[d+1713|0]<<8)>>>0<=e>>>0){break Da}f=x[b>>2];x[31725]=0;f=U(152,f|0,x[d+80>>2],1)|0;i=x[31725];x[31725]=0;if((i|0)==1){break v}if(!f){break Da}if(!yp(x[a+484344>>2],x[a+484348>>2],e&65535)){break Da}f=Fb(d+256|0);x[31725]=0;S(360,b|0,f|0,-1);i=x[31725];x[31725]=0;Ma:{if((i|0)==1){break Ma}i=x[o>>2];x[31725]=0;O(285,Wb(i,e)|0,f|0);i=x[31725];x[31725]=0;if((i|0)==1){break Ma}tb(f);e=e+1|0;continue}break}g=N()|0;tb(f);break t}x[31725]=0;P(185,b|0,1)|0;e=x[31725];x[31725]=0;if((e|0)==1){break u}x[31725]=0;e=R(204,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break u}x[31725]=0;V(338,j|0,b|0,e|0,2);e=x[31725];x[31725]=0;if((e|0)!=1){break Da}break u}x[31725]=0;P(641,b|0,d+12|0)|0;e=x[31725];x[31725]=0;Na:{if((e|0)!=1){e=Fb(d+256|0);x[31725]=0;S(360,b|0,e|0,-1);f=x[31725];x[31725]=0;if((f|0)==1){break Na}if(!Ld(e,12682)){x[31725]=0;S(260,d+144|0,22,e|0);f=x[31725];x[31725]=0;if((f|0)==1){break Na}f=d+144|0;Ab(h,f);tb(f)}tb(e);break Da}g=N()|0;break t}g=N()|0;tb(e);break t}x[31725]=0;n=R(153,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break u}}ub(b);continue}break}g=N()|0;break t}g=N()|0;break t}g=N()|0;break t}g=N()|0;break t}g=N()|0}ub(b)}dc(r);break e}g=N()|0;break e}while(1){b=x[i>>2];x[31725]=0;b=U(152,b|0,x[d+264>>2],1)|0;f=x[31725];x[31725]=0;Oa:{if((f|0)!=1){if(!b){break m}x[31725]=0;h=R(199,i|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}n=0;if((h|0)!=255){break Oa}x[31725]=0;n=R(199,i|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;h=R(199,i|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break Oa}}break l}break l}if(h&127){b=Wb(x[o>>2],r);f=jd(x[b>>2],x[x[b+48>>2]+12>>2],e,j&65535);DE(d+72|0);if(h&1){x[31725]=0;b=R(199,i|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break l}v[d+72|0]=b}if(h&2){x[31725]=0;b=R(199,i|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break l}v[d+73|0]=b}if(h&4){x[31725]=0;b=R(199,i|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break l}v[d+74|0]=b}if(h&8){x[31725]=0;b=R(199,i|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break l}v[d+75|0]=b}if(h&16){x[31725]=0;b=R(199,i|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break l}v[d+76|0]=b}if(h&32){x[31725]=0;b=R(199,i|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break l}v[d+77|0]=b}if(h&64){x[31725]=0;b=R(199,i|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break l}v[d+78|0]=b}E=ZX(f,d+72|0);x[d+144>>2]=n;x[d+52>>2]=m+(e^-1);F=x[Gb(d+144|0,d+52|0)>>2];h=0;b=f;while(1){if((h|0)!=(F|0)){b=D(z[a+480188>>1],6)+b|0;l=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=l;v[b+1|0]=l>>>8;v[b+2|0]=l>>>16;v[b+3|0]=l>>>24;l=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=l;v[b+5|0]=l>>>8;h=h+1|0;continue}break}g=g|E}e=(e+n|0)+1|0;while(1){if(e>>>0>=m>>>0){j=j+1|0;e=e-m|0;continue}break}if(s>>>0>(j&65535)>>>0){continue}break}}ub(i);r=r+1|0;continue}break}g=N()|0;ub(i);break e}g=N()|0;break e}g=N()|0}ub(t)}ub(u)}Q(g|0);p()}e=1}fb=d+1728|0;return e|0}function rta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;d=fb-1120|0;fb=d;xc(b);e=fb-16|0;fb=e;o=d+884|0;w_(e+8|0,o);g=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);k=x[e+4>>2];if((k|0)==(g|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(k|0);if(!e){v_(o)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!e){break o}if(!y_(d+884|0)){break o}if(!Mb(x[b>>2],x[b+8>>2],Bc(x_(y[d+888|0]|y[d+889|0]<<8|(y[d+890|0]<<16|y[d+891|0]<<24)),hb))){break o}if(!c){f=1;break o}Bd(a,16777216);gg(a);x[a+480208>>2]=x[a+480208>>2]|16809984;e=d+448|0;yr(e,32);g=x[d+460>>2];f=a+1074320|0;x[f>>2]=x[d+456>>2];x[f+4>>2]=g;f=x[d+452>>2];x[a+1074312>>2]=x[d+448>>2];x[a+1074316>>2]=f;Lb(Lb(a+1074312|0,57,y[d+887|0]>5),114,1);f=rp(d+840|0);C=f,E=Kd(y[d+1084|0],1,31),x[C+8>>2]=E;C=f,E=Kd(y[d+1085|0],1,12),x[C+4>>2]=E;C=f,E=Bb(y[d+1086|0]|y[d+1087|0]<<8),x[C>>2]=E;iE(a+1298412|0,f);w[a+480188>>1]=32;f=d+36|0;t_(f,3,d+1088|0);Mr(e,1,f);Ab(a+1298368|0,e);tb(e);p:{if(y[d+887|0]<=5){ig(d+36|0,3924);break p}e=fb-16|0;fb=e;f=tc(e+4|0,3993);_c(d+36|0,f);tb(f);fb=e+16|0}x[31725]=0;S(372,d+448|0,d+36|0,y[d+887|0]);e=x[31725];x[31725]=0;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((e|0)!=1){e=d+448|0;Ab(a+1298344|0,e);tb(e);f=d+36|0;Eb(f);g=tc(e,15119);Ab(a+1298356|0,g);tb(g);C=a+1298404|0,E=x[Fc(e,26)>>2],x[C>>2]=E;We(f,3,d+892|0);Cc(e,f);Ab(a+1298308|0,e);tb(e);x[a+480228>>2]=256;x[a+480200>>2]=384/(z[a+480188>>1]+3>>>0);G:{if(y[d+887|0]>5){break G}C=d,E=Bb(y[d+1112|0]|y[d+1113|0]<<8),w[C+448>>1]=E;w[d+36>>1]=1;e=d+448|0;f=d+36|0;C=a,E=z[qe(e,f)>>1],x[C+480196>>2]=E;C=d,E=Bb(y[d+1114|0]|y[d+1115|0]<<8),w[C+448>>1]=E;w[d+36>>1]=1;C=a,E=D(z[qe(e,f)>>1],1e4),x[C+480204>>2]=E;C=d,E=Bc(((Bb(y[d+1116|0]|y[d+1117|0]<<8)<<8)+2047>>>0)/4095|0,0),x[C+448>>2]=E;x[d+36>>2]=256;C=a,E=x[Gb(e,f)>>2],x[C+480200>>2]=E;C=d,E=Bb(y[d+1118|0]|y[d+1119|0]<<8),w[C+448>>1]=E;Gf(e,127);f=0;e=z[d+448>>1];while(1){if((e|0)==(f|0)){break G}C=d,E=Bc(((Wk(b)<<8)+2047>>>0)/4095|0,0),w[C+36>>1]=E;w[d+344>>1]=256;C=((f<<5)+a|0)+480284|0,E=z[Nc(d+36|0,d+344|0)>>1],w[C>>1]=E;f=f+1|0;continue}}cd(b,$b(y[d+888|0]|y[d+889|0]<<8|(y[d+890|0]<<16|y[d+891|0]<<24)));o=Ge(d+820|0,b);x[31725]=0;O(377,d+808|0,o|0);b=x[31725];x[31725]=0;H:{I:{J:{K:{L:{if((b|0)!=1){x[31725]=0;S(378,d+448|0,d+808|0,1346458707);b=x[31725];x[31725]=0;if((b|0)==1){break H}x[31725]=0;b=U(152,x[d+448>>2],x[d+456>>2],2)|0;e=x[31725];x[31725]=0;if((e|0)==1){break K}if(!b){break I}x[31725]=0;b=R(275,d+448|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break K}if((b-1&65535)>>>0>126){break I}w[a+480188>>1]=b;b=d+448|0;ub(b);x[31725]=0;S(378,b|0,d+808|0,1397706311);b=x[31725];x[31725]=0;if((b|0)!=1){break L}a=N()|0;break c}a=N()|0;break b}x[31725]=0;b=U(152,x[d+448>>2],x[d+456>>2],2)|0;e=x[31725];x[31725]=0;if((e|0)==1){break E}if(!b){break I}x[31725]=0;b=R(275,d+448|0)|0;e=x[31725];x[31725]=0;M:{if((e|0)==1){break M}w[d+36>>1]=b;b=y[a+484376|0];e=x[a+484360>>2];x[31725]=0;f=R(275,d+448|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break M}bf(Xb(e,b),f);x[31725]=0;b=R(204,d+448|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break M}Gf(d+36|0,lm(b>>>1|0));b=y[a+484376|0];e=x[a+484360>>2];x[31725]=0;S(278,Xb(e,b)|0,d+448|0,z[d+36>>1]);b=x[31725];x[31725]=0;if((b|0)!=1){break J}}break E}a=N()|0;ub(d+448|0);break c}b=d+448|0;ub(b);x[31725]=0;S(378,b|0,d+808|0,1480806221);b=x[31725];x[31725]=0;if((b|0)==1){break F}x[31725]=0;b=U(152,x[d+448>>2],x[d+456>>2],3)|0;e=x[31725];x[31725]=0;if((e|0)!=1){if(b){break D}b=160;while(1){N:{f=b;if(!b){f=0;break N}b=f-1|0;if(y[(d+b|0)+924|0]==32){continue}}break}x[31725]=0;V(345,a+1298332|0,d+924|0,f|0,4);b=x[31725];x[31725]=0;if((b|0)!=1){break C}break B}break B}ub(d+448|0);f=0;break q}a=N()|0;break c}a=N()|0;Eb(d+36|0);break a}a=N()|0;break c}a=N()|0;ub(d+448|0);break c}x[31725]=0;b=R(275,d+448|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;V(338,a+1298332|0,d+448|0,b|0,4);b=x[31725];x[31725]=0;if((b|0)!=1){break C}}break B}b=d+448|0;ub(b);x[31725]=0;S(378,b|0,d+808|0,1413697073);b=x[31725];x[31725]=0;if((b|0)==1){break A}x[31725]=0;b=R(199,d+448|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break y}if(b){break z}x[31725]=0;b=P(151,d+448|0,2648)|0;e=x[31725];x[31725]=0;if((e|0)==1){break y}if(!b){break z}f=0;x[31725]=0;b=R(283,d+448|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break y}while(1){if((f|0)==32){break z}e=((f<<5)+a|0)+480280|0;x[e>>2]=x[e>>2]&-1025|!(b>>>f&1)<<10;f=f+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}b=d+448|0;ub(b);x[31725]=0;S(378,b|0,d+808|0,1413697074);b=x[31725];x[31725]=0;if((b|0)==1){break x}x[31725]=0;b=U(152,x[d+448>>2],x[d+456>>2],12)|0;e=x[31725];x[31725]=0;if((e|0)==1){break w}O:{if(!b){break O}x[31725]=0;O(379,d+36|0,d+448|0);b=x[31725];x[31725]=0;if((b|0)==1){break w}b=d+36|0;e=af(b);f=ec(b);g=s_(b);k=zb(b);i=r_(b);b=D(Kd(Bb(y[e|0]|y[e+1|0]<<8),32,999),1e4);e=ova(Bb(y[f|0]|y[f+1|0]<<8),0,1e4,0);f=hb;e=e+32768|0;f=e>>>0<32768?f+1|0:f;C=a,E=((Bc((f&65535)<<16|e>>>16,f>>>16|0)>>>0)%1e4|0)+b|0,x[C+480204>>2]=E;C=a,E=Kd(Bb(y[g|0]|y[g+1|0]<<8),1,255),x[C+480196>>2]=E;b=16/(Kd(Bb(y[i|0]|y[i+1|0]<<8),1,16)>>>0)|0;x[a+480216>>2]=b;C=a,E=D(Kd(Bb(y[k|0]|y[k+1|0]<<8),1,16),b),x[C+480220>>2]=E;if(!Bb(z[d+36>>1])){break O}x[31725]=0;b=R(275,d+448|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break w}x[a+480208>>2]=x[a+480208>>2]&-17|!b<<4}b=d+448|0;ub(b);x[31725]=0;S(378,b|0,d+808|0,1414942540);b=x[31725];x[31725]=0;if((b|0)==1){break v}x[31725]=0;b=U(152,x[d+448>>2],x[d+456>>2],2)|0;e=x[31725];x[31725]=0;if((e|0)==1){break t}if(!b){break u}x[31725]=0;b=R(275,d+448|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break t}w[d+36>>1]=b;w[d+344>>1]=z[a+480188>>1];b=z[Nc(d+36|0,d+344|0)>>1];f=0;while(1){if((b|0)==(f|0)){break u}x[31725]=0;e=R(275,d+448|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break t}w[d+36>>1]=e;w[d+344>>1]=4096;C=((f<<5)+a|0)+480286|0,E=z[Nc(d+36|0,d+344|0)>>1]>>>6&255,w[C>>1]=E;f=f+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}ub(d+448|0);x[31725]=0;S(378,d+36|0,d+808|0,1296652368);b=x[31725];x[31725]=0;if((b|0)==1){break s}x[31725]=0;b=U(152,x[d+36>>2],x[d+44>>2],56)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}if(!b){break r}x[31725]=0;O(380,d+36|0,d+448|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}if((Bb(y[d+482|0]|y[d+483|0]<<8)|0)!=4){break r}if((Bb(y[d+496|0]|y[d+497|0]<<8)|0)!=257){break r}C=d,E=Bb(y[d+488|0]|y[d+489|0]<<8),w[C+344>>1]=E;w[d+796>>1]=16384;e=z[Nc(d+344|0,d+796|0)>>1];b=e>>>24|0;f=(e<<8)+2048|0;b=f>>>0<2048?b+1|0:b;C=a,E=Bc((b&4095)<<20|f>>>12,b>>>12|0),x[C+480200>>2]=E;f=0;while(1){if(Bb(y[d+486|0]|y[d+487|0]<<8)>>>0<=(f&65535)>>>0){break r}x[31725]=0;O(381,d+36|0,d+344|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}P:{if(y[d+344|0]){break P}b=Bb(y[d+346|0]|y[d+347|0]<<8);if(b>>>0>=z[a+480188>>1]){break P}b=(b<<5)+a|0;C=b+480284|0,E=Bc(((Bb(y[d+350|0]|y[d+351|0]<<8)<<8)+2047>>>0)/4095|0,0),w[C>>1]=E;h=b+480286|0;e=Bb(y[d+348|0]|y[d+349|0]<<8);b=e>>>26|0;g=(e<<6)+2048|0;b=g>>>0<2048?b+1|0:b;C=h,E=Bc((b&4095)<<20|g>>>12,b>>>12|0)&255,w[C>>1]=E}f=f+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}b=d+36|0;ub(b);x[31725]=0;S(382,b|0,d+808|0,1396788530);b=x[31725];x[31725]=0;if((b|0)==1){break e}C=d,E=wb(x[d+36>>2]),x[C+760>>2]=E;f=c&2;g=d+450|0;k=wb(x[d+40>>2]);Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{while(1){e=x[d+760>>2];if(!Ib(e,k)){b=d+36|0;Qc(b);x[31725]=0;S(382,b|0,d+808|0,1396788560);b=x[31725];x[31725]=0;if((b|0)==1){break f}C=d,E=wb(x[d+36>>2]),x[C+784>>2]=E;g=d+450|0;k=wb(x[d+40>>2]);break Q}x[31725]=0;b=P(383,e|0,d+448|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break S}_:{$:{if(!b){break $}b=Bb(z[d+448>>1]);if((b-4e3&65535)>>>0<61537){break $}if(Bb(z[d+496>>1])>>>0>1){break $}if(Bb(z[d+478>>1])>>>0>1){break $}if(b>>>0>z[a+480190>>1]){w[a+480190>>1]=b}x[31725]=0;i=D(b,104)+a|0;b=i+484380|0;O(384,d+448|0,b|0);j=x[31725];x[31725]=0;aa:{ba:{ca:{if((j|0)==1){break ca}j=d+796|0;bj(j,3,g);x[31725]=0;O(220,d+344|0,j|0);j=x[31725];x[31725]=0;if((j|0)==1){break ba}j=d+344|0;zc(((Bb(z[d+448>>1])<<5)+a|0)+946304|0,j);tb(j);if(!f){break $}j=z[d+522>>1]|z[d+524>>1]<<16;x[31725]=0;j=P(151,e|0,$b(j)-8|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break ca}if(!j){break $}if(Bb(z[d+478>>1])){break aa}j=d+344|0;Xc(j,(Bb(y[d+480|0]|y[d+481|0]<<8)|0)==8?8:16,(Bb(y[d+484|0]|y[d+485|0]<<8)|0)==1?1:2,!Bb(y[d+482|0]|y[d+483|0]<<8),0);x[31725]=0;U(217,j|0,b|0,e|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break aa}a=N()|0;break R}a=N()|0;break R}a=N()|0;break R}b=Fb(d+344|0);j=z[d+498>>1];x[31725]=0;S(272,e|0,b|0,Bb(j)|0);e=x[31725];x[31725]=0;if((e|0)==1){break U}ze(i+484423|0,b);if((Bb(z[d+478>>1])|0)==1){x[31725]=0;O(385,d+784|0,16450);e=x[31725];x[31725]=0;if((e|0)==1){break _}x[31725]=0;S(260,d+772|0,0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break Z}x[31725]=0;V(386,d+796|0,d+784|0,z[d+448>>1],d+772|0);e=x[31725];x[31725]=0;if((e|0)==1){break Y}e=x[a+1298472>>2];x[31725]=0;S(387,e|0,2,d+796|0);e=x[31725];x[31725]=0;if((e|0)==1){break X}tb(d+796|0);tb(d+772|0);Eb(d+784|0)}tb(b)}Sf(d+760|0);continue}break}a=N()|0;break T}a=N()|0;break V}a=N()|0;break W}a=N()|0;tb(d+796|0)}tb(d+772|0)}Eb(d+784|0);break T}a=N()|0}tb(b);break R}a=N()|0}Qc(d+36|0);break c}da:{while(1){ea:{e=x[d+784>>2];if(!Ib(e,k)){Qc(d+36|0);x[31725]=0;S(382,d+796|0,d+808|0,1447382614);b=x[31725];x[31725]=0;if((b|0)!=1){break da}a=N()|0;break c}x[31725]=0;b=P(388,e|0,d+448|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break ea}fa:{ga:{if(!b){break ga}b=Bb(z[d+448>>1]);if((b-4e3&65535)>>>0<61537){break ga}if(Bb(z[d+502>>1])){break ga}if(b>>>0>z[a+480190>>1]){w[a+480190>>1]=b}x[31725]=0;b=(D(b,104)+a|0)+484380|0;O(389,d+448|0,b|0);i=x[31725];x[31725]=0;if((i|0)==1){break ea}i=d+796|0;bj(i,3,g);x[31725]=0;O(220,d+344|0,i|0);i=x[31725];x[31725]=0;if((i|0)==1){break ea}i=d+344|0;zc(((Bb(z[d+448>>1])<<5)+a|0)+946304|0,i);tb(i);if(!f){break ga}i=z[d+478>>1];j=d+344|0;Xc(j,(Bb(z[d+482>>1])|0)==8?8:16,Bb(i)&1?2:1,1,0);x[31725]=0;U(217,j|0,b|0,e|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break fa}}Sf(d+784|0);continue}}break}a=N()|0;Qc(d+36|0);break c}x[31725]=0;S(382,d+784|0,d+808|0,1413828182);b=x[31725];x[31725]=0;if((b|0)==1){break h}x[31725]=0;S(382,d+772|0,d+808|0,1346719318);b=x[31725];x[31725]=0;if((b|0)==1){break j}x[31725]=0;S(382,d+760|0,d+808|0,1229869908);b=x[31725];x[31725]=0;if((b|0)==1){break l}C=d,E=wb(x[d+760>>2]),x[C+12>>2]=E;i=d+394|0;j=d+346|0;n=d+450|0;r=wb(x[d+764>>2]);while(1){ha:{ia:{ja:{ka:{g=x[d+12>>2];if(!Ib(g,r)){Qc(d+760|0);x[31725]=0;S(382,d+344|0,d+808|0,1346458692);b=x[31725];x[31725]=0;if((b|0)!=1){break ka}a=N()|0;break k}x[31725]=0;b=P(390,g|0,d+448|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break n}if(!b){break ha}if(Bb(z[d+478>>1])){break ha}b=z[d+448>>1];x[31725]=0;e=U(253,a|0,Bb(b)|0,0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break n}if(!e){break ha}b=Bb(z[d+448>>1]);if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=b}b=d+344|0;bj(b,3,n);x[31725]=0;O(220,d+36|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break ja}b=d+36|0;zc(e+492|0,b);tb(b);v[e+33|0]=2;if((xe(w[d+482>>1])|0)>0){v[e+15|0]=y[e+15|0]|1;f=xe(w[d+482>>1]);b=f>>>24|0;k=(f<<8&-256)+2047|0;f=b&255;C=e,E=Bc(qva(k,k>>>0<2047?f+1|0:f,4095,0),hb),x[C+8>>2]=E}k=e+108|0;h=e+236|0;b=0;while(1){la:{x[d+36>>2]=128;x[d+344>>2]=128;f=b&255;if(f>>>0>=A[Gb(d+36|0,d+344|0)>>2]){x[31725]=0;O(391,d+36|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break la}C=d,E=$i(x[d+36>>2]),x[C+344>>2]=E;b=Rf(d+36|0);f=z[a+480190>>1];k=z[d+480>>1];while(1){h=x[d+344>>2];if(Ib(h,b)){h=z[jp(h)>>1];if(f>>>0>(h-1&65535)>>>0){C=(D(h,104)+a|0)+484410|0,E=Bb(k),w[C>>1]=E}ah(d+344|0);continue}break}Tv(d+36|0);mk(e,127,1);lk(e,0,1);b=Bb(z[d+498>>1]);if(!b){x[e>>2]=0;b=z[d+484>>1];x[31725]=0;V(392,e|0,0,Bb(b)|0,d+796|0);b=x[31725];x[31725]=0;if((b|0)==1){break n}b=z[d+488>>1];x[31725]=0;V(392,e|0,1,Bb(b)|0,d+772|0);b=x[31725];x[31725]=0;if((b|0)==1){break n}b=z[d+486>>1];x[31725]=0;V(392,e|0,2,Bb(b)|0,d+784|0);b=x[31725];x[31725]=0;if((b|0)!=1){break ha}break n}x[31725]=0;S(393,g|0,d+344|0,((b|0)==1?98:102)|0);b=x[31725];x[31725]=0;ma:{na:{oa:{if((b|0)!=1){b=Bb(z[d+344>>1]);k=b&1;if(!k){break ia}f=b&24;if(f){break oa}f=0;break na}a=N()|0;break m}if((f|0)!=8){break ma}f=1}v[e+25|0]=f}pa:{qa:{ra:{sa:{if(!(b&2)){break sa}x[31725]=0;b=U(394,d+332|0,j|0,24)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ra}x[31725]=0;s=+ia(395,b|0);f=x[31725];x[31725]=0;if((f|0)==1){break qa}tb(b);if(!(s>20)){break sa}mk(e,GD(x[a+480208>>2],s),1)}if(Bb(z[d+344>>1])&4){break pa}break ia}a=N()|0;break m}a=N()|0;tb(b);break m}x[31725]=0;b=U(394,d+320|0,i|0,24)|0;f=x[31725];x[31725]=0;ta:{if((f|0)!=1){x[31725]=0;s=+ia(395,b|0);f=x[31725];x[31725]=0;if((f|0)==1){break ta}tb(b);lk(e,gm(s*127/24),1);break ia}a=N()|0;break m}a=N()|0;tb(b);break m}else{l=(d+448|0)+(f<<1)|0;m=y[l+52|0];C=_b(h,f),E=m,w[C>>1]=E;m=xb(k,f);l=km(v[l+53|0]+y[m|0]|0);C=xb(k,f),E=l,v[C|0]=E;b=b+1|0;continue}}break}a=N()|0;break m}b=x[d+348>>2];e=x[d+344>>2];x[31725]=0;k=a+484344|0;O(225,k|0,Uf(e,b)&65535);b=x[31725];x[31725]=0;ua:{if((b|0)!=1){x[d+32>>2]=x[a+480204>>2];x[d+28>>2]=x[a+480196>>2];C=d,E=wb(x[d+344>>2]),x[C+24>>2]=E;l=c&1;m=wb(x[d+348>>2]);while(1){va:{wa:{xa:{ya:{za:{Aa:{c=x[d+24>>2];if(!Ib(c,m)){x[31725]=0;S(378,d+36|0,d+808|0,1414414669);b=x[31725];x[31725]=0;if((b|0)!=1){break Aa}a=N()|0;break ua}if(!l){break va}b=x[c+8>>2];e=x[c>>2];x[31725]=0;b=U(152,e|0,b|0,24)|0;e=x[31725];x[31725]=0;if((e|0)==1){break za}if(!b){break va}x[31725]=0;i=R(275,c|0)|0;b=x[31725];x[31725]=0;Ba:{Ca:{Da:{Ea:{if((b|0)!=1){v[d+464|0]=0;x[d+456>>2]=0;x[d+460>>2]=0;x[d+448>>2]=0;x[d+452>>2]=0;x[31725]=0;O(396,c|0,d+448|0);b=x[31725];x[31725]=0;if((b|0)==1){break Ea}x[31725]=0;r=R(275,c|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Da}x[31725]=0;j=R(275,c|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break Ca}x[31725]=0;n=R(275,c|0)|0;b=x[31725];x[31725]=0;Fa:{if((b|0)==1){break Fa}b=x[c+8>>2];e=x[c>>2];x[31725]=0;b=U(152,e|0,b|0,D(D(j,n),5)|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Fa}if(!(b&r>>>0<2)){break va}x[31725]=0;b=U(198,k|0,i|0,j|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Fa}if(!b){break va}b=x[k>>2];x[31725]=0;O(397,Wb(b,i)|0,d+448|0);b=x[31725];x[31725]=0;if((b|0)!=1){break Ba}}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}v[d+12|0]=0;b=de(d+36|0,0,d+12|0);x[31725]=0;e=U(373,d+760|0,n|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break wa}g=0;Ga:while(1){if((g|0)==(j|0)){md(e);break va}b=Wb(x[k>>2],i);cf(d+36|0,x[b>>2],x[x[b+48>>2]+12>>2],g);f=0;while(1){if((f|0)==(n|0)){g=g+1|0;continue Ga}b=ch(d+12|0);if(z[a+480188>>1]>f>>>0){b=Wc(x[d+36>>2],f)}x[31725]=0;O(398,c|0,d|0);h=x[31725];x[31725]=0;Ha:{if((h|0)==1){break Ha}h=y[d|0];if((h-1&255)>>>0<=119){h=h+1|0;v[b|0]=h;C=_b(x[e>>2],f),E=h,v[C|0]=E}h=y[d+1|0];if(h){v[b+1|0]=h;C=_b(x[e>>2],f),E=h,v[C+1|0]=E}h=y[d+4|0];if(h){v[b+2|0]=1;v[b+4|0]=r?h-16|0:h>>>2|0}h=y[d+887|0];t=y[d+3|0];u=y[d+2|0];q=_b(x[e>>2],f);B=y[q+1|0];q=y[q|0];x[31725]=0;ya(375,a|0,b|0,u|0,t|0,h|0,q|0,B|0,d+32|0,d+28|0);b=x[31725];x[31725]=0;if((b|0)==1){break Ha}f=f+1|0;continue}break}break}a=N()|0;md(e);break ua}x[31725]=0;b=U(152,x[d+36>>2],x[d+44>>2],38)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(!b){break xa}x[31725]=0;b=R(275,d+36|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ya}c=d+452|0;f=0;Ia:{while(1){if(b>>>0<=(f&65535)>>>0){break xa}x[31725]=0;e=U(152,x[d+36>>2],x[d+44>>2],36)|0;g=x[31725];x[31725]=0;Ja:{if((g|0)!=1){if(e){break Ja}break xa}break ya}x[31725]=0;O(399,d+36|0,d+448|0);e=x[31725];x[31725]=0;if((e|0)!=1){Ka:{if(Bb(z[d+448>>1])){break Ka}if(Bb(z[d+450>>1])>>>0>=z[a+480188>>1]){break Ka}We(d,3,c);x[31725]=0;O(220,d+12|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break Ia}e=d+12|0;pm(((Bb(z[d+450>>1])<<5)+a|0)+480289|0,e);tb(e)}f=f+1|0;continue}break}break ya}break ya}break ya}a=N()|0;break ua}a=N()|0;ub(d+36|0);break ua}ub(d+36|0);Qc(d+344|0);Qc(d+772|0);Qc(d+784|0);Qc(d+796|0);f=1;break q}a=N()|0;break ua}Sf(d+24|0);continue}}a=N()|0}Qc(d+344|0);break k}a=N()|0;break m}f=0;while(1){if(y[d+445|0]<=f>>>0){break ha}x[31725]=0;O(400,g|0,d+36|0);b=x[31725];x[31725]=0;La:{Ma:{if((b|0)!=1){x[d>>2]=33620480;C=d,E=(Bb(z[d+484>>1])|0)!=0,v[C+32|0]=E;C=d,E=(Bb(z[d+486>>1])|0)!=0,v[C+33|0]=E;C=d,E=(Bb(z[d+488>>1])|0)!=0,v[C+34|0]=E;C=d,E=k&(Bb(z[d+490>>1])|0)!=0,v[C+35|0]=E;if(!y[(d+32|0)+f|0]|f>>>0>3){break La}b=(f|0)!=3;if(!b&(v[e+100|0]&1)){break La}x[31725]=0;h=y[d+f|0];S(401,d+36|0,e|0,h|0);l=x[31725];x[31725]=0;if((l|0)==1){break Ma}if(!b){v[e+100|0]=y[e+100|0]|16}Na:{switch(h|0){case 0:if(Bb(y[d+48|0]|y[d+49|0]<<8)&1){b=Bb(y[d+46|0]|y[d+47|0]<<8)&32767}else{b=0}x[e>>2]=b;break La;case 2:break Na;default:break La}}if(!(Bb(y[d+48|0]|y[d+49|0]<<8)&2)){break La}C=d,E=Bb(y[d+42|0]|y[d+43|0]<<8),w[C+28>>1]=E;w[d+24>>1]=1;b=z[qe(d+28|0,d+24|0)>>1];h=zi(Bc(((Bb(y[d+38|0]|y[d+39|0]<<8)<<6|48)>>>0)/100|0,0));C=d,E=Bb(y[d+40|0]|y[d+41|0]<<8),w[C+28>>1]=E;w[d+24>>1]=1;l=bh(256/z[qe(d+28|0,d+24|0)>>1]|0);m=z[d+448>>1];t=y[d+44|0]|y[d+45|0]<<8;x[31725]=0;q=Bb(m);m=Bb(t);ja(402,a|0,q|0,y[(m>>>0<6?m:0)+24960|0],255/(b>>>0)|0,h|0,l|0);b=x[31725];x[31725]=0;if((b|0)!=1){break La}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}f=f+1|0;continue}}Sf(d+12|0);continue}}ie(d+808|0);ub(o)}fb=d+1120|0;return f|0}a=N()|0}Qc(d+760|0);break k}a=N()|0}Qc(d+772|0);break i}a=N()|0}Qc(d+784|0);break g}a=N()|0}Qc(d+796|0);break c}a=N()|0;break c}a=N()|0;break c}a=N()|0;ub(d+36|0)}ie(d+808|0)}ub(o)}Q(a|0);p()}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,P=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,Z=0,$=0,aa=0,ba=0,ca=0,da=0;l=fb-1168|0;fb=l;xc(b);a:{if(!ss(b,l+1144|0)){break a}if(!FR(l+1144|0)){break a}if((y[l+1152|0]|y[l+1153|0]<<8|(y[l+1154|0]<<16|y[l+1155|0]<<24))!=(lh(x[b>>2])|0)){break a}if((y[l+1160|0]|y[l+1161|0]<<8|(y[l+1162|0]<<16|y[l+1163|0]<<24))!=(lf(b)|0)){break a}if(!c){d=1;break a}f=l+1088|0;Tb(f,0,56);e=-2;b:{if(!f){break b}x[f+44>>2]=0;x[f+48>>2]=0;x[f+52>>2]=0;x[f+20>>2]=0;x[f+24>>2]=0;x[f+8>>2]=0;g=x[f+32>>2];if(!g){x[f+32>>2]=1172;g=1172}if(!x[f+36>>2]){x[f+36>>2]=1173}g=ib[g|0](x[f+40>>2],1,43784)|0;e=-4;if(!g){break b}x[f+28>>2]=g;x[g+43780>>2]=1;x[g+10992>>2]=0;x[g+10996>>2]=0;x[g>>2]=0;x[g+11008>>2]=15;x[g+11e3>>2]=1;x[g+11004>>2]=0;e=0}if(e){break a}d=y[l+1160|0]|y[l+1161|0]<<8|(y[l+1162|0]<<16|y[l+1163|0]<<24);x[l+1084>>2]=d;K=y[l+1164|0]|y[l+1165|0]<<8|(y[l+1166|0]<<16|y[l+1167|0]<<24);T=VZ(l+1072|0,K);c:{d:{while(1){if(!(!K|!d|(i|0)==1)){x[l+32>>2]=1024;d=l+32|0;V=x[Gb(d,l+1084|0)>>2];i=gc(l+40|0,l+48|0,V);f=x[i>>2];i=x[i+4>>2];x[31725]=0;co(161,d,b,f,i);d=x[31725];x[31725]=0;if((d|0)==1){break d}g=l+48|0;i=g;d=V;f=aa^-1;while(1){if(d>>>0<4){while(1){if(d){f=x[(((y[i|0]^f)&255)<<2)+79568>>2]^f>>>8;d=d-1|0;i=i+1|0;continue}break}aa=f^-1}else{f=x[(((y[i|0]^f)&255)<<2)+79568>>2]^f>>>8;f=f>>>8^x[(((f^y[i+1|0])&255)<<2)+79568>>2];f=f>>>8^x[(((f^y[i+2|0])&255)<<2)+79568>>2];f=f>>>8^x[(((f^y[i+3|0])&255)<<2)+79568>>2];d=d-4|0;i=i+4|0;continue}break}x[l+1092>>2]=V;x[l+1088>>2]=g;x[l+1104>>2]=K;x[l+1100>>2]=x[T>>2]+ba;B=fb-16|0;fb=B;i=-2;q=l+1088|0;e:{if(!q){break e}h=x[q+28>>2];if(!h){break e}da=x[q+4>>2];x[h+11e3>>2]=0;f:{if(x[h+43780>>2]<0){break f}if(x[h+11004>>2]){break e}f=x[h+11008>>2];i=0;x[h+11004>>2]=0;d=x[h+10996>>2];if(!d){X=(f|0)>0?11:10;I=h+11012|0;g=x[q+4>>2];f=x[h+10992>>2];while(1){x[B+12>>2]=g;x[B+8>>2]=32768-f;F=x[q>>2];d=0;g=0;C=0;E=0;J=0;L=0;W=0;M=0;Y=0;Z=fb-144|0;fb=Z;g:{h:{O=f+I|0;if(O>>>0>=I>>>0){G=x[B+8>>2]+O|0;r=G-I|0;$=(I^-1)+G|0;if(!(r&$)){break h}}x[B+8>>2]=0;x[B+12>>2]=0;n=-3;break g}o=x[B+12>>2];u=o+F|0;P=x[h+60>>2];t=x[h+40>>2];i=x[h+36>>2];s=x[h+32>>2];f=x[h+56>>2];e=x[h+4>>2];n=-1;m=O;j=F;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{k=x[h>>2];switch(k|0){case 36:break k;case 39:break m;case 10:break n;case 35:break o;case 17:break p;case 21:break q;case 34:break r;case 2:break w;case 53:break A;case 26:break C;case 25:break D;case 24:break E;case 23:break F;case 18:break G;case 16:break H;case 14:break I;case 51:break L;case 6:break M;case 3:break N;case 37:break O;case 42:break P;case 41:break Q;case 32:break R;case 27:break S;case 11:break T;case 38:break U;case 9:break V;case 52:break W;case 7:break X;case 5:break Y;case 1:break Z;case 0:break _;default:break j}}x[h+28>>2]=1;f=0;x[h+8>>2]=0;x[h+12>>2]=0;x[h+16>>2]=1;t=0;i=0;s=0;e=0;if(X&1){break Z}break v}if((o|0)<=0){n=1;x[h>>2]=1;break i}x[h+8>>2]=y[F|0];j=F+1|0;break w}if((o|0)<=0){break x}W=e+8|0;j=F+1|0;f=y[F|0]<<e|f;d=2;break u}d=4;break u}M=f;break K}d=7;break u}d=8;break u}C=i;break J}E=f;break B}n=1;if((o|0)<=0){break y}e=e+8|0;j=F+1|0;break t}g=i;d=e;break z}k=2;break s}k=37;break k}d=1;break u}d=3;break u}d=5;break u}d=6;break u}d=9;break u}d=10;break u}d=11;break u}d=12;break u}d=13;break u}d=14;break u}d=15;break u}d=16;break u}d=17;break u}d=18;break u}k=1;break s}x[h>>2]=32;break i}x[h>>2]=5;n=1;break i}if(j>>>0>=u>>>0){x[h>>2]=2;n=1;break i}d=y[j|0];x[h+12>>2]=d;j=j+1|0;k=36;g=x[h+8>>2];i=256<<(g>>>4);if(i>>>0>32768|i>>>0>r>>>0|(((d|g<<8)>>>0)%31|d&32)){break l}i=0;if((g&15)!=8){break l}}d=0}$:while(1){aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{switch(d|0){case 0:if(e>>>0>2){break Ga}d=1;continue;case 3:break Ea;case 2:break Fa;case 1:break Ha;case 9:break la;case 10:break ma;case 11:break na;case 12:break oa;case 13:break pa;case 14:break qa;case 15:break ra;case 16:break sa;case 17:break ta;case 8:break za;case 7:break Aa;case 6:break Ba;case 5:break Ca;case 4:break Da;default:break ua}}while(1){if(j>>>0>=u>>>0){x[h>>2]=3;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;if(e>>>0<3){continue}break}}d=f&7;x[h+20>>2]=d;g=d>>>1|0;x[h+24>>2]=g;e=e-3|0;f=f>>>3|0;if(d>>>0>=2){break ya}W=e;break va}e=W&-8;f=f>>>(W&7)|0;i=0;d=0;break xa}while(1){if(j>>>0>=u>>>0){x[h>>2]=6;n=1;break i}f=y[j|0]<<e|f;d=e>>>0>4294967287;j=j+1|0;e=e+8|0;if(d){continue}break}d=1;break xa}if(j>>>0>=u>>>0){x[h>>2]=7;n=1;break i}v[(h+i|0)+10528|0]=y[j|0];j=j+1|0;d=2;break xa}while(1){if(j>>>0>=u>>>0){x[h>>2]=51;n=1;break i}f=y[j|0]<<e|f;d=e>>>0>4294967287;j=j+1|0;e=e+8|0;if(d){continue}break}break da}if(m>>>0<G>>>0){v[m|0]=s;i=i-1|0;m=m+1|0;f=M;break ea}n=2;k=52;f=M;break k}if(m>>>0<G>>>0){break wa}n=2;k=9;break k}if(j>>>0<u>>>0){d=G-m|0;g=u-j|0;d=d>>>0<g>>>0?d:g;d=d>>>0<i>>>0?d:i;i=i-d|0;m=yc(m,j,d)+d|0;j=d+j|0;break ca}x[h>>2]=38;n=1;break i}C=0;Ia:{switch(g-1|0){case 0:x[h+44>>2]=288;x[h+48>>2]=32;d=h+3552|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=h+3560|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=h+3568|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=h+3576|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=h- -64|0;g=0;while(1){k=144;if((g|0)==144){while(1){g=256;if((k|0)==256){while(1){k=280;if((g|0)==280){while(1){if((k|0)==288){break ia}v[d|0]=8;k=k+1|0;d=d+1|0;continue}}else{v[d|0]=7;g=g+1|0;d=d+1|0;continue}}}else{v[d|0]=9;k=k+1|0;d=d+1|0;continue}}}else{v[d|0]=8;g=g+1|0;d=d+1|0;continue}};case 2:break n;default:break Ia}}d=0;break ka}while(1){Ja:{Ka:{La:{Ma:{Na:{Oa:{switch(d|0){case 0:if(i>>>0>3){break Na}if(!e){e=0;break Ma}if(e>>>0>7){break Ka}d=3;continue $;case 1:v[(h+i|0)+10528|0]=f;e=e-8|0;f=f>>>8|0;break Ja;default:break Oa}}i=i+1|0;break La}i=z[h+10528>>1];if((i|0)==(z[h+10530>>1]^65535)){break ea}break m}d=4;continue $}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(m>>>0<G>>>0){v[m|0]=y[(P-s&$)+I|0];m=m+1|0;P=P+1|0;d=7;break fa}n=2;k=53;break k}while(1){if(j>>>0>=u>>>0){x[h>>2]=27;n=1;f=E;break i}E=y[j|0]<<e|E;j=j+1|0;e=e+8|0;if(t>>>0>e>>>0){continue}break}d=6;break fa}if(j>>>0>=u>>>0){x[h>>2]=26;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;d=4;if(e>>>0<15){break fa}d=5;break fa}while(1){if(j>>>0>=u>>>0){x[h>>2]=25;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;if(t>>>0>e>>>0){continue}break}d=3;break fa}if(m>>>0>=G>>>0){n=2;k=24;break k}v[m|0]=i;m=m+1|0;break ga}if(j>>>0>=u>>>0){x[h>>2]=23;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;d=0;if(e>>>0<15){break fa}d=1;break fa}while(1){if(j>>>0>=u>>>0){x[h>>2]=18;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;if(t>>>0>e>>>0){continue}break}Y=s-16|0;d=3;break ha}if(j>>>0>=u>>>0){x[h>>2]=16;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;d=1;if(e>>>0<15){break ha}d=2;break ha}while(1){if(j>>>0>=u>>>0){x[h>>2]=14;n=1;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;if(e>>>0<3){continue}break}d=1;break ja}d=C+22236|0;while(1){if(j>>>0>=u>>>0){x[h>>2]=11;n=1;i=C;break i}f=y[j|0]<<e|f;j=j+1|0;e=e+8|0;L=v[d|0];if(e>>>0<L>>>0){continue}break}d=1}while(1){Pa:{Qa:{Ra:{if(!d){if(C>>>0>2){break Ra}L=v[C+22236|0];if(L>>>0<=e>>>0){break Pa}d=9;continue $}d=C<<2;x[(d+h|0)+44>>2]=x[d+81104>>2]+((-1<<L^-1)&f);C=C+1|0;e=e-L|0;f=f>>>L|0;break Qa}i=0;Tb(h+7040|0,0,288);d=0;break ja}d=0;continue}d=1;continue}}while(1){Sa:{Ta:{Ua:{if(!d){if(A[h+52>>2]<=i>>>0){break Ua}if(e>>>0>2){break Sa}d=10;continue $}v[(y[i+81120|0]+h|0)+7040|0]=f&7;i=i+1|0;e=e-3|0;f=f>>>3|0;break Ta}x[h+52>>2]=19;break ia}d=0;continue}d=1;continue}}J=x[h+24>>2];d=0}while(1){Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{switch(d|0){case 0:d=0;if((J|0)<0){break ga}R=Tb(Z,0,64);g=D(J,3488)+h|0;Tb(g+352|0,0,3200);ca=g- -64|0;H=x[h+24>>2];k=x[((H<<2)+h|0)+44>>2];while(1){if((d|0)!=(k|0)){g=(y[d+ca|0]<<2)+R|0;x[g>>2]=x[g>>2]+1;d=d+1|0;continue}break};x[R+64>>2]=0;x[R+68>>2]=0;r=0;d=1;g=0;while(1){if((d|0)!=16){o=d<<2;d=d+1|0;o=x[o+R>>2];g=o+g<<1;x[(R- -64|0)+(d<<2)>>2]=g;r=o+r|0;continue}break};S=0;o=-1;if((g|0)!=65536&r>>>0>=2){break o}while(1){if(k>>>0>S>>>0){r=y[S+ca|0];cb:{if(!r){break cb}d=(R- -64|0)+(r<<2)|0;g=x[d>>2];x[d>>2]=g+1;d=0;k=r;while(1){if(k){d=g&1|d<<1;g=g>>>1|0;k=k-1|0;continue}break}if(r>>>0<=10){g=1<<r;r=r<<9|S;k=D(J,3488)+h|0;while(1){if(d>>>0>1023){break cb}w[(k+(d<<1)|0)+352>>1]=r;d=d+g|0;continue}}H=D(J,3488)+h|0;g=H+((d&1023)<<1)|0;k=w[g+352>>1];db:{if(k){g=o;o=k;break db}w[g+352>>1]=o;g=o-2|0}d=d>>>9|0;while(1){d=d>>>1|0;k=d&1;if(r>>>0>=12){k=(H+(k+(o^-1)<<1)|0)+2400|0;o=w[k>>1];if(!o){w[k>>1]=g;o=g;g=g-2|0}r=r-1|0;continue}break}w[((D(J,3488)+h|0)+(k+(o^-1)<<1)|0)+2400>>1]=S;o=g}S=S+1|0;H=x[h+24>>2];k=x[((H<<2)+h|0)+44>>2];continue}break};d=0;if((H|0)!=2){break Wa}break _a;case 1:d=w[(((f&1023)<<1)+h|0)+7328>>1];eb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break eb}break Za}if(e>>>0<11){break eb}k=10;while(1){d=w[(((f>>>k&1)+(d^-1)<<1)+h|0)+9376>>1];if((d|0)<0){g=k+2|0;k=k+1|0;if(e>>>0>=g>>>0){continue}}break}if((d|0)>=0){break Za}}d=11;continue $;case 2:s=w[(((f&1023)<<1)+h|0)+7328>>1];if((s|0)>=0){break ab}d=10;while(1){g=f>>>d|0;d=d+1|0;s=w[(((g&1)+(s^-1)<<1)+h|0)+9376>>1];if((s|0)<0){continue}break};break $a;default:break bb}}d=v[Y+18443|0]+((-1<<t^-1)&f)|0;e=e-t|0;f=f>>>t|0;g=h+i|0;Tb(g+10532|0,(s|0)==16?y[g+10531|0]:0,d);d=d+i|0;break _a}d=s>>>9|0;s=s&511}e=e-d|0;f=f>>>d|0;if(s>>>0>15){break Ya}v[(h+i|0)+10532|0]=s;d=i+1|0}g=x[h+48>>2];i=x[h+44>>2];o=g+i|0;if(o>>>0<=d>>>0){break Xa}if(e>>>0<=14){if((u-j|0)<=1){i=d;d=1;continue}f=y[j|0]<<e|y[j+1|0]<<e+8|f;j=j+2|0;e=e+16|0}i=d}d=2;continue}if(!((s|0)!=16|i)){i=0;s=16;break p}Y=s-16|0;t=v[s+22216|0];if(t>>>0<=e>>>0){break Va}d=12;continue $}if((d|0)!=(o|0)){i=d;break q}o=h+10532|0;yc(h- -64|0,o,i);yc(h+3552|0,i+o|0,g);H=x[h+24>>2];i=d}J=H-1|0;x[h+24>>2]=J;d=0;continue}d=3;continue}}d=2}fb:while(1){gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{switch(d|0){case 0:d=w[(((f&1023)<<1)+h|0)+352>>1];wb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break wb}break gb}if(e>>>0<11){break wb}k=10;while(1){d=w[(((f>>>k&1)+(d^-1)<<1)+h|0)+2400>>1];if((d|0)<0){g=k+2|0;k=k+1|0;if(e>>>0>=g>>>0){continue}}break}if((d|0)>=0){break gb}}d=13;continue $;case 1:i=w[(((f&1023)<<1)+h|0)+352>>1];if((i|0)>=0){break ub}d=10;while(1){g=f>>>d|0;d=d+1|0;i=w[(((g&1)+(i^-1)<<1)+h|0)+2400>>1];if((i|0)<0){continue}break};break tb;case 3:break jb;case 4:break kb;case 5:break pb;case 6:break qb;case 2:break vb;default:break rb}}while(1){d=u-j|0;if(!((G-m|0)>1&(d|0)>=4)){if(e>>>0>14){break gb}if((d|0)<=1){d=0;continue fb}f=y[j|0]<<e|y[j+1|0]<<e+8|f;e=e+16|0;j=j+2|0;break gb}if(!(e>>>0>14)){f=(y[j|0]|y[j+1|0]<<8)<<e|f;j=j+2|0;e=e+16|0}r=e;i=w[(((f&1023)<<1)+h|0)+352>>1];xb:{if((i|0)<0){d=10;while(1){g=f>>>d|0;d=d+1|0;i=w[(((g&1)+(i^-1)<<1)+h|0)+2400>>1];if((i|0)<0){continue}break}break xb}d=i>>>9|0}e=r-d|0;f=f>>>d|0;if(i&256){break sb}if(!(e>>>0>14)){f=(y[j|0]|y[j+1|0]<<8)<<e|f;j=j+2|0;e=e+16|0}r=e;k=w[(((f&1023)<<1)+h|0)+352>>1];yb:{if((k|0)<0){d=10;while(1){g=f>>>d|0;d=d+1|0;k=w[(((g&1)+(k^-1)<<1)+h|0)+2400>>1];if((k|0)<0){continue}break}break yb}d=k>>>9|0}v[m|0]=i;e=r-d|0;f=f>>>d|0;if(!(k&256)){v[m+1|0]=k;m=m+2|0;continue}break}m=m+1|0;i=k;break sb}d=i>>>9|0;i=i&511}e=e-d|0;f=f>>>d|0;if(i>>>0>255){break sb}d=14;continue $}g=i&511;i=256;if((g|0)==256){break ba}d=g-257<<2;i=x[d+80592>>2];t=0;if(g-285>>>0<4294967276){break ib}t=x[d+80720>>2];if(t>>>0>e>>>0){d=15;continue $}d=3;continue}if(!i){i=-1;break nb}i=i-1|0;d=18;continue $}e=e-t|0;f=E>>>t|0;s=((-1<<t^-1)&E)+s|0;break ob}d=w[(((f&1023)<<1)+h|0)+3840>>1];zb:{if((d|0)<0){k=10;while(1){g=f>>>k|0;k=k+1|0;d=w[(((g&1)+(d^-1)<<1)+h|0)+5888>>1];if((d|0)<0){continue}break}break zb}k=d>>>9|0;d=d&511}e=e-k|0;E=f>>>k|0;g=d<<2;s=x[g+80848>>2];t=0;if(d-30>>>0<4294967270){f=E;break ob}t=x[g+80976>>2];if(t>>>0<=e>>>0){break mb}d=17;continue $}P=m-I|0;d=(P-s&$)+I|0;if((d>>>0<m>>>0?m:d)+i>>>0>G>>>0){break lb}while(1){if(i>>>0>=3){v[m|0]=y[d|0];v[m+1|0]=y[d+1|0];v[m+2|0]=y[d+2|0];i=i-3|0;d=d+3|0;m=m+3|0;continue}break}if(!i){i=0;break nb}v[m|0]=y[d|0];if((i|0)!=1){v[m+1|0]=y[d+1|0]}m=i+m|0}d=2;continue}d=6;continue}d=7;continue}d=w[(((f&1023)<<1)+h|0)+3840>>1];Ab:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break Ab}break hb}if(e>>>0<11){break Ab}k=10;while(1){d=w[(((f>>>k&1)+(d^-1)<<1)+h|0)+5888>>1];if((d|0)<0){g=k+2|0;k=k+1|0;if(e>>>0>=g>>>0){continue}}break}if((d|0)>=0){break hb}}d=16;continue $}e=e-t|0;i=((-1<<t^-1)&f)+i|0;f=f>>>t|0}if(e>>>0>14){break hb}if((u-j|0)<=1){d=4;continue}f=y[j|0]<<e|y[j+1|0]<<e+8|f;e=e+16|0;j=j+2|0}d=5;continue}d=1;continue}}if(!i|!e){break ca}if(e>>>0>7){break da}d=5;continue}e=e-8|0;M=f>>>8|0;s=f&255;d=6;continue}if(i){break aa}i=0}if(v[h+20|0]&1){break t}d=0;continue}d=7;continue}}f=0;d=e>>>3|0;g=j-F|0;g=g>>>0<=j>>>0?g:0;d=d>>>0<g>>>0?d:g;if((e&-8)==d<<3){j=j-d|0;g=0;d=0;e=0;if(!(X&1)){break r}k=0;break s}_(6874,13236,2797,6884);p()}while(1){Bb:{Cb:{Db:{Eb:{Fb:{switch(k|0){case 0:if(g>>>0>3){i=g;e=d;break r}e=0;if(!d){i=g;break Bb}if(d>>>0>7){break Eb}k=1;continue;case 1:break Fb;default:break Db}}while(1){if(j>>>0>=u>>>0){x[h>>2]=41;n=1;i=g;e=d;break i}f=y[j|0]<<d|f;o=d>>>0>4294967287;j=j+1|0;d=d+8|0;if(o){continue}break}}k=f&255;f=f>>>8|0;d=d-8|0;break Cb}if(j>>>0>=u>>>0){x[h>>2]=42;n=1;break i}k=y[j|0];j=j+1|0;g=i;d=e}x[h+16>>2]=x[h+16>>2]<<8|k;g=g+1|0;k=0;continue}k=2;continue}}n=0;k=34;break k}k=21;break k}k=17;break k}k=35;break k}k=10;break k}k=39;break k}i=1}x[h>>2]=k}d=e>>>3|0;g=j-F|0;g=g>>>0<=j>>>0?g:0;d=d>>>0<g>>>0?d:g;j=j-d|0;e=e-(d<<3)|0}x[h+4>>2]=e;x[h+60>>2]=P;x[h+40>>2]=t;x[h+36>>2]=i;x[h+32>>2]=s;x[h+56>>2]=(((e&63)>>>0<32?-1<<e:0)^-1)&f;x[B+12>>2]=j-F;e=m-O|0;x[B+8>>2]=e;if((n|0)<0){break g}j=(e>>>0)%5552|0;d=x[h+28>>2];f=d>>>16|0;k=d&65535;while(1){g=0;if(e){d=O;while(1){if((g|7)>>>0<j>>>0){i=y[d|0]+k|0;o=i+y[d+1|0]|0;r=o+y[d+2|0]|0;E=r+y[d+3|0]|0;M=E+y[d+4|0]|0;C=M+y[d+5|0]|0;m=C+y[d+6|0]|0;k=m+y[d+7|0]|0;f=k+(m+(C+(M+(E+(r+(o+(f+i|0)|0)|0)|0)|0)|0)|0)|0;d=d+8|0;g=g+8|0;continue}break}g=j&8184;while(1){if((g|0)!=(j|0)){g=g+1|0;k=y[d|0]+k|0;f=k+f|0;d=d+1|0;continue}break}e=e-j|0;f=(f>>>0)%65521|0;k=(k>>>0)%65521|0;O=j+O|0;j=5552;continue}break}d=f<<16|k;x[h+28>>2]=d;if(n){break g}n=0;if(!(X&1)){break g}n=(d|0)!=x[h+16>>2]?-2:0}fb=Z+144|0;x[h+43780>>2]=n;d=x[B+12>>2];x[q>>2]=d+x[q>>2];x[q+4>>2]=x[q+4>>2]-d;x[q+8>>2]=d+x[q+8>>2];x[q+48>>2]=x[h+28>>2];d=x[B+8>>2];x[h+10996>>2]=d;i=x[q+16>>2];d=d>>>0<i>>>0?d:i;yc(x[q+12>>2],x[h+10992>>2]+I|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];e=x[h+10996>>2];x[h+10996>>2]=e-d;f=d+x[h+10992>>2]&32767;x[h+10992>>2]=f;if((n|0)<0){break f}if(!((n|0)!=1|da)){i=-5;break e}if(n){i=0;g=x[q+4>>2];if(!g|!x[q+16>>2]){break e}if((d|0)==(e|0)){continue}break e}break}i=(d|0)==(e|0);break e}f=x[q+16>>2];d=d>>>0<f>>>0?d:f;yc(x[q+12>>2],(x[h+10992>>2]+h|0)+11012|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];f=x[h+10996>>2];x[h+10996>>2]=f-d;x[h+10992>>2]=d+x[h+10992>>2]&32767;if(x[h+43780>>2]){break e}i=(d|0)==(f|0);break e}i=-3}fb=B+16|0;d=x[l+1084>>2]-V|0;x[l+1084>>2]=d;g=K+ba|0;K=x[l+1104>>2];ba=g-K|0;continue}break}b=l+1088|0;Gb:{if(!b){break Gb}d=x[b+28>>2];if(!d){break Gb}ib[x[b+36>>2]](x[b+40>>2],d);x[b+28>>2]=0}d=0;Hb:{Ib:{if(!((y[l+1156|0]|y[l+1157|0]<<8|(y[l+1158|0]<<16|y[l+1159|0]<<24))!=(aa|0)|(i|0)!=1|K)){oe(l+24|0,x[T>>2],x[T+4>>2]);b=Nd(l+16|0);x[31725]=0;d=x[b+4>>2];x[l+8>>2]=x[b>>2];x[l+12>>2]=d;b=jg(556,l+48|0,x[l+24>>2],x[l+28>>2],l+8|0);d=x[31725];x[31725]=0;if((d|0)==1){break Ib}x[31725]=0;d=U(917,a|0,b|0,c|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break Hb}ub(b)}dc(T);break a}a=N()|0;break c}a=N()|0;ub(b);break c}a=N()|0}dc(T);Q(a|0);p()}fb=l+1168|0;return d|0}function Yqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=E(0),A=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=E(0),M=E(0),O=0,P=0,S=0,V=0,W=0,Z=0,_=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=E(0),ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=E(0);n=fb-96|0;fb=n;xc(c);a:{while(1){b:{if(!Mb(x[c>>2],x[c+8>>2],4)){break b}h=n+76|0;d=fb-16|0;fb=d;c:{if(!Mb(x[c>>2],x[c+8>>2],3)){A=0;while(1){if((A|0)!=3){fh(h+A|0);A=A+1|0;continue}break}break c}$w(d+8|0,h);rd(d,c,x[d+8>>2],x[d+12>>2])}fb=d+16|0;d:{e:{if(!kd(h,15018,3)){h=n+32|0;d=fb-16|0;fb=d;f:{if(!Mb(x[c>>2],x[c+8>>2],7)){A=0;while(1){if((A|0)!=7){fh(h+A|0);A=A+1|0;continue}break}break f}Rr(d+8|0,h);rd(d,c,x[d+8>>2],x[d+12>>2])}fb=d+16|0;A=0;h=3;while(1){if((h|0)==7){break d}d=v[(n+32|0)+h|0];if((d|0)<0){break e}h=h+1|0;A=d&255|A<<7;continue}}g:{if(kd(n+76|0,14195,3)){break g}if(!oY(c,13675)){break g}Vb(c,Pg(c)+16|0);continue}if(!kd(n+76|0,28590,3)){continue}if(!kd(n+76|0,28594,3)){continue}if(!y[n+76|0]){Gh(c,2);continue}if(BV(n+76|0)){break b}}h=0;break a}Vb(c,A);continue}break}xc(c);d=n+76|0;rD(d,c);V=x[n+76>>2];c=$e(d);O=Nb(n- -64|0);x[31725]=0;aa=R(593,n+60|0)|0;d=x[31725];x[31725]=0;h:{i:{j:{if((d|0)!=1){JB(Tb(x[aa>>2],0,6668));x[n+48>>2]=0;x[n+52>>2]=0;x[n+40>>2]=0;x[n+44>>2]=0;x[n+32>>2]=0;x[n+36>>2]=0;x[31725]=0;ba=R(594,n+20|0)|0;d=x[31725];x[31725]=0;k:{if((d|0)!=1){A=0;while(1){G=x[aa>>2];g=Gc(V,ca);W=x[ba>>2];d=0;m=0;s=fb-17152|0;fb=s;x[s+17148>>2]=0;l:{m:{n:{if(y[G+6152|0]!=255|(g|0)<5){break n}if(!uq(G+6152|0,c)){break n}h=kz(y[c+1|0],y[c+2|0],x[G+6148>>2])+tq(c)|0;x[s+17148>>2]=h;if((g|0)==(h|0)){h=g;break m}o:{if((g|0)>=(h+4|0)){if(uq(c,c+h|0)){break o}}x[s+17148>>2]=0;break n}if(h){break m}}f=c;C=Tb(G,0,6668)+6148|0;r=s+17148|0;o=g-4|0;I=(o|0)>0?o:0;while(1){p:{q:{r:{s:{if((m|0)==(I|0)){m=g;break s}if(!hM(f)){break q}i=kz(y[f+1|0],y[f+2|0],x[C>>2]);h=i+tq(f)|0;j=4;k=m+4|0;t:{while(1){if(!(j>>>0>2303|i)){if((o|0)<=((j<<1)+m|0)){break t}i=0;l=f+j|0;u:{if(!uq(f,l)){break u}e=j-tq(f)|0;q=tq(l)+e|0;if((g|0)<(q+(j+k|0)|0)){break u}if(!uq(f,l+q|0)){break u}x[C>>2]=e;i=e;h=j}j=j+1|0;continue}break}if(!i|(g|0)<(h+m|0)){break t}k=g-m|0;j=0;e=0;while(1){v:{w:{if((e|0)!=10){l=(e|0)!=0;K=j;j=f+j|0;j=(K+kz(y[j+1|0],y[j+2|0],i)|0)+tq(j)|0;if((k|0)<(j+4|0)){break v}if(uq(f,f+j|0)){break w}l=0}else{l=1}break v}e=e+1|0;continue}break}if(!l){break t}d=h;break s}if((g|0)!=(h|0)|m){break r}m=0;d=g}x[r>>2]=d;d=m;break p}x[C>>2]=0}f=f+1|0;m=m+1|0;continue}break}h=x[s+17148>>2];if((g|0)>=(d+h|0)?h:0){break m}x[n+32>>2]=d;q=0;break l}F=c+d|0;x[G+6152>>2]=y[F|0]|y[F+1|0]<<8|(y[F+2|0]<<16|y[F+3|0]<<24);x[n+36>>2]=d;x[n+32>>2]=d+h;x[n+40>>2]=y[F+3|0]>191?1:2;ra=n,sa=kM(y[F+1|0],y[F+2|0]),x[ra+44>>2]=sa;x[n+48>>2]=4-(y[F+1|0]>>>1&3);ra=n,sa=jz(y[F+1|0],y[F+2|0]),x[ra+52>>2]=sa;if(!W){q=iz(y[F+1|0]);break l}jM(s+17136|0,F+4|0,h-4|0);if(!(v[F+1|0]&1)){ue(s+17136|0,16)}x:{if(x[n+48>>2]==3){q=0;d=s+17136|0;ia=s+3728|0;h=ia;f=0;e=y[F+1|0];g=D((e>>>3&1)+(e>>>4&1)|0,3)+(y[F+2|0]>>>2&3)|0;g=g-((g|0)!=0)|0;m=y[F+3|0]>191?1:2;y:{if(e&8){i=ue(d,9);m=m<<1;f=ue(d,m+7|0);break y}i=ue(d,m|8)>>>m|0}e=D(g,40);C=e+81440|0;o=e+81760|0;r=D(g,23)+81248|0;e=-1;l=0;z:{while(1){g=y[F+3|0];I=ue(d,12);w[h+4>>1]=I;j=ue(d,9);w[h+6>>1]=j;if((j&65535)>>>0>288){break z}j=g>>>0>191?f<<4:f;ra=h,sa=ue(d,8),v[ra+10|0]=sa;g=ue(d,y[F+1|0]&8?4:9);v[h+13|0]=22;v[h+14|0]=0;x[h>>2]=r;w[h+8>>1]=g;A:{if(ue(d,1)){g=ue(d,2);v[h+11|0]=g;if(!(g&255)){break z}g=ue(d,1);w[h+18>>1]=65287;v[h+12|0]=g;if(y[h+11|0]==2){B:{if(!(g&255)){x[h>>2]=C;v[h+18|0]=8;f=0;g=39;break B}x[h>>2]=o;f=y[F+1|0]&8?8:6;g=30}v[h+14|0]=g;v[h+13|0]=f;j=j&3855}g=ue(d,10);ra=h,sa=ue(d,3),v[ra+21|0]=sa;ra=h,sa=ue(d,3),v[ra+22|0]=sa;ra=h,sa=ue(d,3),v[ra+23|0]=sa;f=g<<5;break A}v[h+11|0]=0;v[h+12|0]=0;f=ue(d,15);ra=h,sa=ue(d,4),v[ra+18|0]=sa;g=ue(d,3);v[h+20|0]=255;v[h+19|0]=g}v[h+17|0]=f&31;v[h+15|0]=f>>>10;v[h+16|0]=f>>>5&31;l=(I&65535)+l|0;C:{if(y[F+1|0]&8){g=ue(d,1);break C}g=z[h+8>>1]>499}v[h+24|0]=g;ra=h,sa=ue(d,1),v[ra+25|0]=sa;g=ue(d,1);v[h+27|0]=j>>>12&15;v[h+26|0]=g;h=h+28|0;f=j<<4;m=m-1|0;if(m){continue}break}e=(x[d+4>>2]+l|0)>(x[d+8>>2]+(i<<3)|0)?-1:i}if(!((e|0)<0|x[s+17140>>2]>x[s+17144>>2])){d=s+17136|0;f=x[d+4>>2];j=x[d+8>>2];m=s+900|0;h=x[G+6144>>2];g=h-e|0;h=(e|0)>(h|0)?h:e;g=yc(m+12|0,(((g|0)>0?g:0)+G|0)+6156|0,h);i=x[d>>2]+(x[d+4>>2]/8|0)|0;d=(j-f|0)/8|0;yc(g+h|0,i,d);jM(m,g,d+h|0);D:{h=x[G+6144>>2]>=(e|0);if(!h){break D}ma=G+2304|0;na=s+8608|0;oa=s+3840|0;while(1){if((y[F+1|0]&8?2:1)>>>0<=q>>>0){break D}pa=Tb(oa,0,4608);e=x[n+40>>2];m=D(D(e,q),28)+ia|0;d=0;ja=(e|0)>0?e:0;C=s+900|0;I=C+7548|0;Z=G+6152|0;while(1){if((d|0)!=(ja|0)){f=D(d,28)+m|0;K=z[f+4>>1];S=x[C+4>>2];t=(C+D(d,39)|0)+16156|0;e=I;o=d;g=fb-48|0;fb=g;d=f;J=y[d+25|0];H=D(!y[d+13|0]+(y[d+14|0]!=0)|0,28)+82080|0;E:{if(y[Z+1|0]&8){i=y[d+27|0];f=y[z[d+8>>1]+82176|0];j=f&3;v[g+47|0]=j;v[g+46|0]=j;f=f>>>2|0;v[g+45|0]=f;v[g+44|0]=f;break E}f=(y[Z+3|0]&16)>>>4&(o|0)!=0;k=f?12:0;f=z[d+8>>1]>>>f|0;while(1){if((f|0)>=0){i=3;j=1;while(1){if((i|0)>=0){l=y[(i+k|0)+82192|0];v[(g+44|0)+i|0]=((f|0)/(j|0)|0)%(l|0);i=i-1|0;j=D(j,l);continue}break}k=k+4|0;f=f-j|0;continue}break}H=k+H|0;i=-16}j=g;da=g+44|0;f=0;while(1){F:{G:{H:{if((f|0)==4){break H}r=y[f+H|0];if(!r){break H}if(i&8){yc(j,t,r);break G}k=y[f+da|0];if(!k){Tb(j,0,r);Tb(t,0,r);break G}ea=(i|0)>=0?-1:-1<<k^-1;l=0;while(1){if((l|0)==(r|0)){break G}P=ue(C,k);v[l+t|0]=(P|0)==(ea|0)?-1:P;v[j+l|0]=P;l=l+1|0;continue}}v[j+2|0]=0;v[j|0]=0;v[j+1|0]=0;break F}i=i<<1;f=f+1|0;j=j+r|0;t=r+t|0;continue}break}I:{j=y[d+14|0];if(j){f=2-J|0;l=y[d+23|0]<<f;r=y[d+22|0]<<f;k=y[d+21|0]<<f;t=y[d+13|0];i=0;while(1){if(i>>>0>=j>>>0){break I}f=g+(i+t|0)|0;v[f|0]=k+y[f|0];v[f+1|0]=r+y[f+1|0];v[f+2|0]=l+y[f+2|0];i=i+3|0;continue}}if(!y[d+24|0]){break I}i=0;while(1){if((i|0)==10){break I}f=g+i|0;v[f+11|0]=y[f+11|0]+y[i+82216|0];i=i+1|0;continue}}f=J+1|0;i=0;u=hz(E(2048),((((y[Z+3|0]&224)==96)<<1)-y[d+10|0]|0)+258|0);while(1){if(y[d+13|0]+(j&255)>>>0>i>>>0){ra=e+(i<<2)|0,ta=hz(u,y[g+i|0]<<f),B[ra>>2]=ta;i=i+1|0;j=y[d+14|0];continue}break}fb=g+48|0;l=(C+D(o,2304)|0)+2940|0;i=e;da=K+S|0;u=E(0);f=x[C+4>>2];g=x[C>>2]+((f|0)/8|0)|0;e=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);e=(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))<<(f&7);k=f|-8;t=g+4|0;r=d;H=x[d>>2];J=z[d+6>>1];d=0;while(1){J:{K:{if((J|0)>0){g=d+1|0;f=d+r|0;d=y[f+15|0];ea=(w[(d<<1)+86640>>1]<<1)+82256|0;P=y[f+18|0];if(d>>>0>=16){fa=y[d+86704|0];qa=32-fa|0;while(1){ga=y[H|0]>>>1|0;ha=(J|0)<(ga|0)?J:ga;u=B[i>>2];while(1){f=e>>>27|0;d=5;while(1){f=w[ea+(f<<1)>>1];if((f|0)<0){e=e<<d;j=f&7;f=(e>>>32-j|0)-(f>>3)|0;k=d+k|0;d=j;continue}break}d=f>>>8|0;k=d+k|0;e=e<<d;j=0;while(1){if((j|0)!=2){K=f&15;L:{if((K|0)==15){k=k+fa|0;d=e<<fa;while(1){if((k|0)>=0){d=y[t|0]<<k|d;t=t+1|0;k=k-8|0;continue}break}K=(e>>>qa|0)+15|0;e=K;M:{if((e|0)<=128){L=B[(e<<2)+86800>>2];break M}ka=e>>>0<1024;e=ka?e<<3:e;S=e<<1&64;M=E(E((e&63)-S|0)/E(S+(e&-64)|0));L=E((ka?E(16):E(256))*E(E(E(M*E(E(M*E(.2222222238779068))+E(1.3333333730697632)))+E(1))*B[(e+S>>6<<2)+86800>>2]))}L=E(E(u*L)*E(d>>31|1));break L}d=e;L=E(u*B[(((d>>>27&16|K)^16)<<2)+86736>>2])}B[l>>2]=L;f=f>>>4|0;l=l+4|0;j=j+1|0;e=(K|0)!=0;k=e+k|0;e=d<<e;continue}break}while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}ha=ha-1|0;if(ha){continue}break}i=i+4|0;H=H+1|0;J=J-ga|0;if((J|0)<=0){break K}d=(P|0)>0;P=P-1|0;if(d){continue}break}break K}while(1){S=y[H|0]>>>1|0;K=(J|0)<(S|0)?J:S;u=B[i>>2];while(1){d=e>>>27|0;f=5;while(1){d=w[ea+(d<<1)>>1];if((d|0)<0){e=e<<f;j=d&7;d=(e>>>32-j|0)-(d>>3)|0;k=f+k|0;f=j;continue}break}f=d>>>8|0;k=f+k|0;e=e<<f;f=0;while(1){if((f|0)!=2){j=d&15;B[l>>2]=u*B[(((j|e>>>27&16)^16)<<2)+86736>>2];d=d>>>4|0;l=l+4|0;f=f+1|0;j=(j|0)!=0;k=j+k|0;e=e<<j;continue}break}while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}K=K-1|0;if(K){continue}break}i=i+4|0;H=H+1|0;J=J-S|0;if((J|0)<=0){break K}d=(P|0)>0;P=P-1|0;if(d){continue}break}break K}f=1-J|0;while(1){N:{g=y[r+26|0]?86624:86592;d=y[g+(e>>>28|0)|0];if(!(d&8)){d=y[g+((e<<4>>>32-(d&3))+(d>>>3)|0)|0]}g=d&7;k=g+k|0;if((da|0)<((k+(t-x[C>>2]<<3)|0)-24|0)){break N}f=f-1|0;if(!f){f=y[H|0];if(f>>>0<2){break N}H=H+1|0;u=B[i>>2];i=i+4|0;f=f>>>1|0}e=e<<g;if(d>>>0>=128){B[l>>2]=(e|0)<0?E(-u):u;k=k+1|0;e=e<<1}if(d&64){B[l+4>>2]=(e|0)<0?E(-u):u;k=k+1|0;e=e<<1}f=f-1|0;if(!f){g=y[H|0];if(g>>>0<2){break N}H=H+1|0;u=B[i>>2];i=i+4|0;f=g>>>1|0}if(d&32){B[l+8>>2]=(e|0)<0?E(-u):u;k=k+1|0;e=e<<1}if(d&16){B[l+12>>2]=(e|0)<0?E(-u):u;k=k+1|0;e=e<<1}while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}l=l+16|0;continue}break}x[C+4>>2]=da;break J}d=g;continue}break}d=o+1|0;continue}break}d=y[G+6155|0];O:{if(d&16){l=C+16195|0;d=0;g=fb-16|0;fb=g;j=C+2940|0;i=j+2304|0;I=x[m>>2];k=y[m+14|0];t=y[m+13|0];r=k+t|0;o=g+4|0;x[o+8>>2]=-1;x[o>>2]=-1;x[o+4>>2]=-1;while(1){if((d|0)!=(r|0)){H=d+I|0;f=y[H|0];e=0;P:{while(1){if(e>>>0>=f>>>0){break P}J=e<<2;if(B[J+i>>2]==E(0)){e=e+2|0;if(B[(J|4)+i>>2]==E(0)){continue}}break}x[o+((d>>>0)%3<<2)>>2]=d;f=y[H|0]}d=d+1|0;i=(f<<2)+i|0;continue}break}if(t){d=x[g+4>>2];e=x[g+8>>2];d=(d|0)>(e|0)?d:e;e=x[g+12>>2];d=(d|0)>(e|0)?d:e;x[g+12>>2]=d;x[g+8>>2]=d;x[g+4>>2]=d}e=k?3:1;i=r-e|0;d=0;while(1){if((d|0)!=(e|0)){o=d+i|0;f=o-e|0;if((f|0)<=x[(g+4|0)+(d<<2)>>2]){f=y[Z+1|0]<<28>>31&3}else{f=y[f+l|0]}v[l+o|0]=f;d=d+1|0;continue}break}o=x[m>>2];r=g+4|0;I=w[m+36>>1]&1;i=0;k=y[Z+1|0]&8?7:64;while(1){t=i+o|0;e=y[t|0];if(e){f=y[Z+3|0]&32;Q:{R:{if(x[r+((i>>>0)%3<<2)>>2]>=(i|0)){break R}d=y[i+l|0];if(d>>>0>=k>>>0){break R}L=f?E(1.4142135381698608):E(1);S:{if(y[Z+1|0]&8){d=d<<3;u=B[d+87332>>2];M=B[d+87328>>2];break S}M=hz(E(1),d+1>>>1<<I);d=d&1;u=d?E(1):M;M=d?M:E(1)}M=E(L*M);L=E(L*u);d=0;while(1){if((d|0)!=(e|0)){f=(d<<2)+j|0;u=B[f>>2];B[f+2304>>2]=u*L;B[f>>2]=u*M;d=d+1|0;continue}break}break Q}if(!f){break Q}gM(j,e)}i=i+1|0;j=(y[t|0]<<2)+j|0;continue}break}fb=g+16|0;break O}if((d&224)!=96){break O}gM(C+2940|0,576)}j=C+7708|0;d=0;while(1){if((d|0)!=(ja|0)){e=y[G+6153|0];o=(y[m+12|0]!=0)<<1<<((D((e>>>3&1)+(e>>>4&1)|0,3)+(y[G+6154|0]>>>2&3)|0)==2);l=(C+D(d,2304)|0)+2940|0;i=l;if(y[m+14|0]){f=x[m>>2]+y[m+13|0]|0;t=((C+D(d,2304)|0)+D(o,72)|0)+2940|0;g=t;e=j;while(1){r=y[f|0];if(r){k=r<<1;I=0;while(1){if((r|0)!=(I|0)){B[e>>2]=B[g>>2];B[e+4>>2]=B[(r<<2)+g>>2];B[e+8>>2]=B[(k<<2)+g>>2];g=g+4|0;I=I+1|0;e=e+12|0;continue}break}f=f+3|0;g=(k<<2)+g|0;continue}break}yc(t,j,e-j|0);e=o-1|0}else{e=31}while(1){g=0;if((e|0)>0){while(1){if((g|0)!=8){f=g<<2;r=f+i|0;u=B[r+72>>2];M=B[f+87392>>2];L=B[f+87424>>2];f=(17-g<<2)+i|0;la=B[f>>2];B[r+72>>2]=E(u*M)-E(L*la);B[f>>2]=E(u*L)+E(la*M);g=g+1|0;continue}break}i=i+72|0;e=e-1|0;continue}break}g=l;e=D(d,1152)+G|0;f=y[m+11|0];if(o){eM(g,e,87456,o);g=D(o,72)+g|0;e=D(o,36)+e|0}T:{if((f|0)==2){i=32-o|0;f=fb-80|0;fb=f;r=f|8;I=f|4;while(1){if((i|0)>0){o=yc(f,g,72);k=x[e+20>>2];x[g+16>>2]=x[e+16>>2];x[g+20>>2]=k;k=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=k;k=x[e+4>>2];x[g>>2]=x[e>>2];x[g+4>>2]=k;K=o;o=e+24|0;gz(K,g+24|0,o);gz(I,g+48|0,o);gz(r,e,o);g=g+72|0;e=e+36|0;i=i-1|0;continue}break}fb=f+80|0;break T}eM(g,e,D((f|0)==3,72)+87456|0,32-o|0)}f=0;i=l+72|0;while(1){g=1;if(f>>>0<=31){while(1){if(g>>>0<=17){e=(g<<2)+i|0;B[e>>2]=-B[e>>2];g=g+2|0;continue}break}i=i+144|0;f=f+2|0;continue}break}m=m+28|0;d=d+1|0;continue}break}iM(ma,pa,18,x[n+40>>2],W,na);q=q+1|0;W=D(x[n+40>>2],1152)+W|0;continue}}e=s+900|0;f=x[e+8>>2]>>>3|0;j=x[e+4>>2]+7>>>3|0;d=f-j|0;g=(d|0)>=511?511:d;if((d|0)>0){nl(G+6156|0,(e+(d>>>0>511?f-511|0:j)|0)+12|0,g)}x[G+6144>>2]=g;break x}JB(G);break l}f=s+17136|0;q=0;m=0;i=0;g=s;d=0;U:{V:{W:{h=y[F+3|0];j=h>>>6|0;switch(j-1|0){case 2:break U;case 0:break W;default:break V}}d=(h>>>2&12)+4|0;break U}d=32}h=y[F+1|0];X:{if((h&6)==6){h=32;e=88860;break X}if(!(h&8)){h=30;e=88863;break X}l=y[F+2|0];e=l>>>2&3;h=jz(h,l)>>>((j|0)!=3)|0;h=h?h:192;if(h>>>0<=55){h=(e|0)==2?12:8;e=88884;break X}h=h>>>0<=95?27:(e|0)!=1?30:27;e=88872}v[g+768|0]=h;v[g+769|0]=(d|0)<(h|0)?d:h;h=e;j=88768;while(1){d=y[g+768|0];if(q>>>0>=d>>>0){q=0;while(1){e=d<<1&510;if(e>>>0>q>>>0){e=g+q|0;Y:{if(!y[e+770|0]){h=6;break Y}h=2;if((y[F+1|0]&6)==6){break Y}h=ue(f,2);d=y[g+768|0]}v[e+834|0]=h;q=q+1|0;continue}break}m=g+770|0;j=g+834|0;h=0;i=e;while(1){if((h|0)!=(i|0)){l=y[m|0];e=l?19>>>y[h+j|0]&3|4:0;m=m+1|0;l=D(l,3)-6|0;u=E(0);d=4;while(1){if(d){if(d&e){C=ue(f,6);o=(C|0)/3|0;u=E(B[(l+(D(o,-3)+C|0)<<2)+88896>>2]*E(2097152>>>o|0))}B[g>>2]=u;d=d>>>1|0;g=g+4|0;continue}break}h=h+1|0;continue}break}q=y[s+769|0];d=y[s+768|0];d=d>>>0<q>>>0?q:d;while(1){if((d|0)!=(q|0)){v[((q<<1)+s|0)+771|0]=0;q=q+1|0;continue}break}}else{if((i|0)==(q|0)){j=y[h|0]+88768|0;i=y[h+2|0]+q|0;m=y[h+1|0];h=h+3|0}e=q<<1;d=y[ue(f,m)+j|0];v[(e+g|0)+770|0]=d;l=y[g+769|0];if(l>>>0>q>>>0){d=y[ue(f,m)+j|0];l=y[g+769|0]}v[((e|1)+g|0)+770|0]=l?d:0;q=q+1|0;continue}break}h=0;g=Tb(s+3840|0,0,4608);I=G+2304|0;k=s+8608|0;q=0;Z:{while(1){if((q|0)==3){break Z}F=g+(h<<2)|0;C=s+17136|0;f=0;l=x[n+48>>2]|1;o=(l|0)>0?l:0;e=576;while(1){if((f|0)!=4){m=F+(D(f,l)<<2)|0;j=0;while(1){if(y[s+768|0]<<1>>>0>j>>>0){_:{i=y[(j+s|0)+770|0];if(!i){break _}if(i>>>0<=16){r=(-1<<i-1)+1|0;d=0;while(1){if((d|0)==(o|0)){break _}ra=(d<<2)+m|0,ta=E(ue(C,i)+r|0),B[ra>>2]=ta;d=d+1|0;continue}}d=2<<i-17;i=ue(C,(d-(d>>>3|0)|0)+3|0);t=d>>>1|0;r=d|1;d=0;while(1){if((d|0)==(o|0)){break _}K=i;i=(i>>>0)/(r>>>0)|0;B[(d<<2)+m>>2]=K-(t+D(r,i)|0)|0;d=d+1|0;continue}}j=j+1|0;m=(e<<2)+m|0;e=18-e|0;continue}break}f=f+1|0;continue}break}h=(l<<2)+h|0;if((h|0)==12){d=(q<<2)+s|0;h=g;e=y[s+769|0];f=g+D(e,72)|0;yc(f+2304|0,f,D(y[s+768|0]-e|0,72));m=0;while(1){if(y[s+768|0]>m>>>0){f=0;while(1){if((f|0)!=12){e=(f<<2)+h|0;B[e>>2]=B[d>>2]*B[e>>2];e=e+2304|0;B[e>>2]=B[d+12>>2]*B[e>>2];f=f+1|0;continue}break}d=d+24|0;h=h+72|0;m=m+1|0;continue}break}iM(I,g,12,x[n+40>>2],W,k);Tb(g,0,4608);W=D(x[n+40>>2],768)+W|0;h=0}q=q+1|0;if(x[s+17140>>2]<=x[s+17144>>2]){continue}break}JB(G);q=0;break l}h=1}q=D(iz(y[G+6153|0]),h)}fb=s+17152|0;d=x[n+32>>2];if((d|0)<0|!d){break h}h=x[n+44>>2];if((h|0)!=(_|0)?_:0){break h}d=x[n+40>>2];if((d|0)!=(A|0)?A:0){break h}if(d-3>>>0<4294967294|(h|0)<=0){break i}x[n+16>>2]=0;ra=n,sa=Gc(V,ca),x[ra+12>>2]=sa;g=x[hk(n+32|0,n+16|0,n+12|0)>>2];x[n+16>>2]=0;ra=n,sa=Gc(V,ca),x[ra+12>>2]=sa;e=x[hk(n+32|0,n+16|0,n+12|0)>>2];f=e>>31;$:{if(!q){break $}A=x[ba>>2];x[31725]=0;U(595,O|0,A|0,A+(D(d,q)<<1)|0)|0;A=x[31725];x[31725]=0;if((A|0)!=1){break $}c=T(125e3)|0;if((gb|0)==($(125e3)|0)){Y(c|0)|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;A=d;_=h;if((c|0)!=1){break h}c=N()|0}md(ba);break k}if((Zc(x[O>>2],x[O+4>>2])>>>0)/(d>>>0)>>>0>268435456){break i}c=c+g|0;_=h;A=d;h=ca-(f+(e>>>0>V>>>0)|0)|0;ca=h;V=V-e|0;if(!!V&(h|0)>=0|(h|0)>0){continue}break}break h}c=N()|0}aU(aa);break j}c=N()|0}md(O);Kc(n+76|0);Q(c|0);p()}A=d;_=h}h=0;aa:{if(!_|!A){break aa}c=x[O>>2];d=x[O+4>>2];if(lc(c,d)){break aa}if((Zc(c,d)>>>0)/(A>>>0)>>>0>268435456){break aa}Vu(a,b);b=D(b,104)+a|0;a=b+484380|0;ra=a,sa=(Zc(x[O>>2],x[O+4>>2])>>>0)/(A>>>0)|0,x[ra>>2]=sa;d=b+484414|0;c=z[d>>1];w[d>>1]=(A|0)==2?c|65:c&65470|1;Fh(a);c=b+484400|0;h=je(x[a>>2],x[c>>2]);if(!h){break aa}d=wb(x[O>>2]);h=wb(x[O+4>>2]);b=fb-16|0;fb=b;kV(b+8|0,d,h,x[c>>2]);fb=b+16|0;h=je(x[a>>2],x[a+20>>2])}md(ba);aU(aa);md(O);Kc(n+76|0)}fb=n+96|0;return h|0}function ZC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=E(0),K=E(0),L=0,M=0,N=0,O=E(0);C=fb-1520|0;fb=C;e=C+8|0;M=Tb(e,0,1512),N=-1,x[M+1420>>2]=N;v[C+56|0]=1;x[C+48>>2]=a+b;x[C+40>>2]=a;b=0;q=fb-1024|0;fb=q;v[e+1377|0]=1;a:{if(!Pt(e)){break a}f=y[e+1375|0];if(!(f&2)){fc(e,34);break a}if(f&4){fc(e,34);break a}if(f&1){fc(e,34);break a}if(x[e+1116>>2]!=1){fc(e,34);break a}f=y[e+1120|0];if((f|0)!=30){b:{if((f|0)!=64){break b}if(!dz(e,q+1018|0,6)|y[q+1018|0]!=102|(y[q+1019|0]!=105|y[q+1020|0]!=115)){break b}if(y[q+1021|0]!=104|y[q+1022|0]!=101|y[q+1023|0]!=97){break b}if((hf(e)|0)!=100){break b}if(hf(e)){break b}fc(e,38);break a}fc(e,34);break a}if((hf(e)|0)!=1){fc(e,34);break a}if(!dz(e,q+1018|0,6)){fc(e,10);break a}if(!bz(q+1018|0)){fc(e,34);break a}if(Bj(e)){fc(e,34);break a}f=hf(e);x[e+4>>2]=f;if(!f){fc(e,34);break a}if(f>>>0>=17){fc(e,5);break a}f=Bj(e);x[e>>2]=f;if(!f){fc(e,34);break a}Bj(e);Bj(e);Bj(e);g=hf(e);f=g>>>4|0;x[e+116>>2]=1<<f;h=g&15;x[e+112>>2]=1<<h;if(h-14>>>0<=4294967287){fc(e,20);break a}if(g+32<<24>>24>=0){fc(e,20);break a}c:{if(f>>>0<h>>>0){fc(e,20);break c}if(!(hf(e)&1)){fc(e,34);break c}if(!Pt(e)){break a}if(!cz(e)){break a}if(!ez(e)){break a}d:{e:{if((Ph(e)|0)==3){while(1){if((b|0)!=6){M=(q+1018|0)+b|0,N=Ph(e),v[M|0]=N;b=b+1|0;continue}break}if(!bz(q+1018|0)){fc(e,20);break c}g=az(e);b=te(e,g+1|0);x[e+20>>2]=b;if(!b){break e}b=0;h=(g|0)>0?g:0;while(1){if((b|0)!=(h|0)){f=Ph(e);v[x[e+20>>2]+b|0]=f;b=b+1|0;continue}break}v[g+x[e+20>>2]|0]=0;b=az(e);x[e+28>>2]=0;x[e+24>>2]=b;if((b|0)<=0){break d}b=te(e,b<<2);x[e+28>>2]=b;if(b){break d}fc(e,3);break c}fc(e,20);break c}fc(e,3);break c}while(1){f:{g:{if(x[e+24>>2]>(m|0)){j=az(e);b=te(e,j+1|0);g=m<<2;x[g+x[e+28>>2]>>2]=b;if(!x[g+x[e+28>>2]>>2]){break g}b=0;h=(j|0)>0?j:0;while(1){if((b|0)==(h|0)){break f}f=Ph(e);v[x[g+x[e+28>>2]>>2]+b|0]=f;b=b+1|0;continue}}if(!(Ph(e)&1)){fc(e,20);break c}VL(e,y[e+1376|0]);v[e+1376|0]=0;while(1){b=ez(e);VL(e,b);v[e+1376|0]=0;if(b){continue}break}b=0;if(!cz(e)){break a}if(!aM(e)){if(x[e+100>>2]!=21){break a}x[e+100>>2]=20;break a}h=0;while(1){if((h|0)!=256){i=h<<24;f=0;while(1){if((f|0)!=8){i=i>>31&79764919^i<<1;f=f+1|0;continue}break}x[(h<<2)+495792>>2]=i;h=h+1|0;continue}break}if((Ph(e)|0)==5){while(1){if((b|0)!=6){M=(q+1018|0)+b|0,N=Ph(e),v[M|0]=N;b=b+1|0;continue}break}if(!bz(q+1018|0)){fc(e,20);break c}b=rc(e,8)+1|0;x[e+120>>2]=b;b=te(e,D(b,2096));x[e+124>>2]=b;if(!b){fc(e,3);break c}Tb(b,0,D(x[e+120>>2],2096));h:{i:{while(1){j:{k:{if(x[e+120>>2]>(k|0)){b=x[e+124>>2];if((rc(e,8)&255)!=66){fc(e,20);break c}if((rc(e,8)&255)!=67){fc(e,20);break c}if((rc(e,8)&255)!=86){fc(e,20);break c}g=b+D(k,2096)|0;M=g,N=rc(e,8)&255|rc(e,8)<<8,x[M>>2]=N;M=g,N=rc(e,8)&255|(rc(e,8)<<8&65280|rc(e,8)<<16),x[M+4>>2]=N;t=g+4|0;b=0;f=rc(e,1);if(!f){b=rc(e,1)}v[g+23|0]=b;h=x[t>>2];if(!(x[g>>2]|!h)){fc(e,20);break c}l:{if(b&255){i=uo(e,h);break l}i=te(e,h);x[g+8>>2]=i}if(!i){fc(e,3);break c}r=0;if(f){break k}b=0;while(1){f=x[t>>2];if((f|0)<=(b|0)){break j}m:{n:{if(y[g+23|0]){if(!rc(e,1)){break n}}f=rc(e,5)+1|0;v[b+i|0]=f;if((f&255)!=32){r=r+1|0;break m}fc(e,20);break c}v[b+i|0]=255}b=b+1|0;continue}}f=rc(e,6)+1&255;b=0;o:{while(1){if((b|0)==(f|0)){break o}b=b+1|0;if(!rc(e,16)){continue}break}fc(e,20);break c}b=rc(e,6)+1|0;x[e+128>>2]=b;b=te(e,D(b,1596));x[e+260>>2]=b;p:{q:{if(b){r=0;h=0;r:while(1){if(x[e+128>>2]<=(h|0)){break q}b=rc(e,16);w[((h<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){fc(e,20);break c}if(!b){f=x[e+260>>2]+D(h,1596)|0;M=f,N=rc(e,8),v[M|0]=N;M=f,N=rc(e,16),w[M+2>>1]=N;M=f,N=rc(e,16),w[M+4>>1]=N;M=f,N=rc(e,6),v[M+6|0]=N;M=f,N=rc(e,8),v[M+7|0]=N;k=rc(e,4)+1|0;v[f+8|0]=k;b=0;while(1){if((k&255)>>>0>b>>>0){M=b+f|0,N=rc(e,8),v[M+9|0]=N;b=b+1|0;k=y[f+8|0];continue}break}fc(e,4);break c}n=x[e+260>>2]+D(h,1596)|0;f=rc(e,5);v[n|0]=f;i=0;k=-1;while(1)if((f&255)>>>0<=i>>>0){g=k+1|0;f=0;while(1){if((f|0)!=(g|0)){j=f+n|0;M=j,N=rc(e,3)+1|0,v[M+33|0]=N;b=rc(e,2);v[j+49|0]=b;if(b&255){b=rc(e,8);v[j+65|0]=b;if(x[e+120>>2]<=(b&255)){break p}}i=0;while(1){if(1<<y[j+49|0]>(i|0)){b=rc(e,8)-1|0;w[((n+(f<<4)|0)+(i<<1)|0)+82>>1]=b;i=i+1|0;if(x[e+120>>2]>b<<16>>16){continue}break p}break}f=f+1|0;continue}break}k=2;M=n,N=rc(e,2)+1|0,v[M+1588|0]=N;b=rc(e,4);x[n+1592>>2]=2;m=0;w[n+338>>1]=0;v[n+1589|0]=b;w[n+340>>1]=1<<b;G=n+338|0;l=0;while(1){if(y[n|0]>l>>>0){f=n+y[(l+n|0)+1|0]|0;i=0;while(1){if(y[f+33|0]>i>>>0){b=rc(e,y[n+1589|0]);w[(n+(x[n+1592>>2]<<1)|0)+338>>1]=b;k=x[n+1592>>2]+1|0;x[n+1592>>2]=k;i=i+1|0;continue}break}l=l+1|0;continue}break}while(1){if((k|0)>(m|0)){f=z[(n+(m<<1)|0)+338>>1];b=(q+16|0)+(m<<2)|0;w[b+2>>1]=m;w[b>>1]=f;m=m+1|0;k=x[n+1592>>2];continue}break}UL(q+16|0,k,1174);k=x[n+1592>>2];g=((k|0)<=1?1:k)-1|0;i=0;f=0;while(1){if((f|0)!=(g|0)){b=q+16|0;j=z[b+(f<<2)>>1];f=f+1|0;if((j|0)!=z[b+(f<<2)>>1]){continue}break p}break}while(1){if((i|0)<(k|0)){v[(i+n|0)+838|0]=y[((q+16|0)+(i<<2)|0)+2|0];i=i+1|0;k=x[n+1592>>2];continue}break}i=2;while(1){if((i|0)<(k|0)){x[q+12>>2]=0;x[q+8>>2]=0;f=0;b=(i|0)>0?i:0;o=G+(i<<1)|0;k=65536;j=-1;while(1){if((b|0)!=(f|0)){g=G+(f<<1)|0;l=z[g>>1];if(!((j|0)>=(l|0)|z[o>>1]<=l>>>0)){x[q+12>>2]=f;l=z[g>>1];j=l}if(!((k|0)<=(l|0)|z[o>>1]>=l>>>0)){x[q+8>>2]=f;k=z[g>>1]}f=f+1|0;continue}break}b=n+(i<<1)|0;v[b+1088|0]=x[q+12>>2];v[b+1089|0]=x[q+8>>2];i=i+1|0;k=x[n+1592>>2];continue}break}r=(k|0)>(r|0)?k:r;h=h+1|0;continue r}else{b=rc(e,4);v[(i+n|0)+1|0]=b;b=b&255;k=(b|0)>(k|0)?b:k;i=i+1|0;f=y[n|0];continue}}}fc(e,3);break c}b=rc(e,6)+1|0;x[e+264>>2]=b;b=te(e,D(b,24));x[e+396>>2]=b;if(!b){fc(e,3);break c}f=0;Tb(b,0,D(x[e+264>>2],24));s:{t:{while(1){if(x[e+264>>2]>(f|0)){h=x[e+396>>2];b=rc(e,16);w[((f<<1)+e|0)+268>>1]=b;k=20;if((b&65535)>>>0>2){break s}o=h+D(f,24)|0;M=o,N=rc(e,24),x[M>>2]=N;b=rc(e,24);x[o+4>>2]=b;if(b>>>0<A[o>>2]){break s}M=o,N=rc(e,24)+1|0,x[M+8>>2]=N;M=o,N=rc(e,6)+1|0,v[M+12|0]=N;b=rc(e,8);v[o+13|0]=b;if(x[e+120>>2]<=(b&255)){break s}b=0;while(1){h=y[o+12|0];if(h>>>0>b>>>0){j=(q+16|0)+b|0;l=rc(e,3);if(rc(e,1)){h=rc(e,5)}else{h=0}v[j|0]=l+(h<<3);b=b+1|0;continue}break}b=te(e,h<<4);x[o+20>>2]=b;if(!b){break t}h=0;while(1){if(y[o+12|0]>h>>>0){i=y[(q+16|0)+h|0];b=0;while(1){if((b|0)!=8){u:{if(i>>>b&1){l=rc(e,8);g=b<<1;j=h<<4;w[g+(j+x[o+20>>2]|0)>>1]=l;if(x[e+120>>2]<=w[g+(j+x[o+20>>2]|0)>>1]){break s}break u}w[(x[o+20>>2]+(h<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;continue}break}h=h+1|0;continue}break}b=te(e,x[(x[e+124>>2]+D(y[o+13|0],2096)|0)+4>>2]<<2);x[o+16>>2]=b;if(!b){break t}l=0;Tb(b,0,x[(x[e+124>>2]+D(y[o+13|0],2096)|0)+4>>2]<<2);while(1){b=x[e+124>>2]+D(y[o+13|0],2096)|0;if(x[b+4>>2]>(l|0)){b=x[b>>2];h=te(e,b);g=l<<2;x[g+x[o+16>>2]>>2]=h;i=l;if(!x[g+x[o+16>>2]>>2]){break t}while(1){if((b|0)>0){b=b-1|0;v[b+x[g+x[o+16>>2]>>2]|0]=(i|0)%y[o+12|0];i=(i|0)/y[o+12|0]|0;continue}break}l=l+1|0;continue}break}f=f+1|0;continue}break}b=rc(e,6)+1|0;x[e+400>>2]=b;b=te(e,D(b,40));x[e+404>>2]=b;if(!b){fc(e,3);break c}Tb(b,0,D(x[e+400>>2],40));h=0;while(1){v:{if(x[e+400>>2]>(h|0)){b=x[e+404>>2];if(rc(e,16)){fc(e,20);break c}f=b+D(h,40)|0;b=te(e,D(x[e+4>>2],3));x[f+4>>2]=b;if(!b){fc(e,3);break c}if(rc(e,1)){b=rc(e,4)+1|0}else{b=1}v[f+8|0]=b;w:{if(rc(e,1)){g=rc(e,8)+1|0;w[f>>1]=g;b=0;k=x[e+4>>2];if((k|0)<(g&65535)){fc(e,20);break c}while(1){if(z[f>>1]<=b>>>0){break w}g=rc(e,Pm(k-1|0));j=D(b,3);v[j+x[f+4>>2]|0]=g;g=rc(e,Pm(x[e+4>>2]-1|0));v[(j+x[f+4>>2]|0)+1|0]=g;k=x[e+4>>2];g=j+x[f+4>>2]|0;j=y[g|0];if((k|0)<=(j|0)){fc(e,20);break c}g=y[g+1|0];if((g|0)>=(k|0)){fc(e,20);break c}b=b+1|0;if((g|0)!=(j|0)){continue}break}fc(e,20);break c}w[f>>1]=0}if(rc(e,2)){fc(e,20);break c}b=0;if(y[f+8|0]>=2){while(1){if(x[e+4>>2]<=(b|0)){break v}j=rc(e,4);g=D(b,3);v[(g+x[f+4>>2]|0)+2|0]=j;b=b+1|0;if(y[(g+x[f+4>>2]|0)+2|0]<y[f+8|0]){continue}break}fc(e,20);break c}while(1){if(x[e+4>>2]<=(b|0)){break v}v[(x[f+4>>2]+D(b,3)|0)+2|0]=0;b=b+1|0;continue}}M=e,N=rc(e,6)+1|0,x[M+408>>2]=N;f=e+412|0;i=0;x:{while(1){if(x[e+408>>2]<=(i|0)){break x}h=f+D(i,6)|0;M=h,N=rc(e,1),v[M|0]=N;M=h,N=rc(e,16),w[M+2>>1]=N;M=h,N=rc(e,16),w[M+4>>1]=N;b=rc(e,8);v[h+1|0]=b;if(z[h+2>>1]){fc(e,20);break c}if(z[h+4>>1]){fc(e,20);break c}i=i+1|0;if(x[e+400>>2]>(b&255)){continue}break}fc(e,20);break c}_L(e);x[e+992>>2]=0;g=r<<1;b=0;while(1){if(x[e+4>>2]>(b|0)){j=(b<<2)+e|0;M=j,N=te(e,x[e+116>>2]<<2),x[M+800>>2]=N;M=j,N=te(e,x[e+116>>2]<<1&2147483646),x[M+928>>2]=N;h=te(e,g);x[j+996>>2]=h;f=x[j+800>>2];if(h?!f|!x[j+928>>2]:1){fc(e,3);break c}Tb(f,0,x[e+116>>2]<<2);b=b+1|0;continue}break}b=0;if(!TL(e,0,x[e+112>>2])){break a}if(!TL(e,1,x[e+116>>2])){break a}x[e+104>>2]=x[e+112>>2];j=x[e+116>>2];x[e+108>>2]=j;f=x[e+264>>2];h=(f|0)>0?f:0;l=(j|0)/2|0;k=0;while(1){if((b|0)!=(h|0)){g=x[e+396>>2]+D(b,24)|0;f=x[g+4>>2];i=f>>>0<l>>>0?f:l;f=x[g>>2];f=(i-(f>>>0<l>>>0?f:l)>>>0)/A[g+8>>2]|0;k=(f|0)>(k|0)?f:k;b=b+1|0;continue}break}f=j<<1&2147483646;b=D(x[e+4>>2],(k<<2)+4|0);f=b>>>0<f>>>0?f:b;x[e+12>>2]=f;y:{z:{if(!x[e+80>>2]){break z}b=x[e+92>>2];if((b|0)!=x[e+84>>2]){break y}if(b>>>0>=(f+x[e+88>>2]|0)+1512>>>0){break z}fc(e,3);break c}A:{if(x[e+1380>>2]==-1){x[e+52>>2]=y[e+48|0]?0:x[e+32>>2]-x[e+36>>2]|0;break A}x[e+52>>2]=0}b=1;break a}_(7344,13258,4196,8829);p()}b=0;B:{while(1){if(y[f+8|0]<=b>>>0){break B}rc(e,8);j=b+f|0;M=j,N=rc(e,8),v[M+9|0]=N;g=rc(e,8);v[j+24|0]=g;if(x[e+128>>2]<=y[j+9|0]){fc(e,20);break c}b=b+1|0;if(x[e+264>>2]>(g&255)){continue}break}fc(e,20);break c}h=h+1|0;continue}}k=3}fc(e,k);break c}fc(e,20);break c}m=rc(e,5);b=0;while(1){f=x[t>>2];if((f|0)<=(b|0)){break j}h=rc(e,Pm(f-b|0));m=m+1|0;if((m|0)>=32){fc(e,20);break c}f=b+h|0;if((f|0)>x[t>>2]){fc(e,20);break c}else{Tb(b+i|0,m,h);b=f;continue}}}C:{D:{E:{F:{G:{H:{if(y[g+23|0]){if(f>>2>(r|0)){break H}if(x[e+16>>2]<(f|0)){x[e+16>>2]=f;f=x[t>>2]}b=te(e,f);x[g+8>>2]=b;if(!b){fc(e,3);break c}yc(b,i,x[t>>2]);Aj(e,i,x[t>>2]);i=x[g+8>>2];v[g+23|0]=0;f=x[t>>2]}m=0;h=(f|0)>0?f:0;b=0;while(1){if((b|0)==(h|0)){break G}m=((y[b+i|0]-11&255)>>>0<244)+m|0;b=b+1|0;continue}}x[g+2092>>2]=r;l=g+2092|0;if(r){break F}b=0;h=0;break E}x[g+2092>>2]=m;b=te(e,f<<2);x[g+32>>2]=b;if(b){l=g+2092|0;b=0;break D}fc(e,3);break c}b=te(e,r);x[g+8>>2]=b;if(!b){fc(e,3);break c}b=uo(e,x[l>>2]<<2);x[g+32>>2]=b;if(!b){fc(e,3);break c}b=uo(e,x[l>>2]<<2);if(!b){break C}f=x[t>>2];h=x[l>>2]}f=(h<<3)+f|0;if(f>>>0<=A[e+16>>2]){break D}x[e+16>>2]=f}s=x[t>>2];f=0;h=fb-128|0;fb=h;u=Tb(h,0,128);h=(s|0)>0?s:0;while(1){I:{J:{if((f|0)!=(h|0)){if(y[f+i|0]==255){break J}h=f}if((h|0)==(s|0)){f=1;if(!x[g+2092>>2]){break I}_(15771,13258,1103,7588);p()}j=h+i|0;f=y[j|0];if(f>>>0<32){QL(g,0,h,0,f,b);n=1;j=y[j|0]+1|0;f=1;K:{while(1){if((f|0)==(j|0)){L:while(1){M:{f=1;h=h+1|0;if((s|0)<=(h|0)){break I}G=h+i|0;j=y[G|0];if((j|0)==255){continue}f=j;if(f>>>0>=32){break M}while(1){if((f|0)<=0){f=0;break I}o=u+(f<<2)|0;r=x[o>>2];if(!r){f=f-1|0;continue}break}x[o>>2]=0;QL(g,Nm(r),h,n,j,b);n=n+1|0;m=y[G|0];if((m|0)==(f|0)){continue}while(1){if((f|0)>=(m|0)){continue L}j=u+(m<<2)|0;if(x[j>>2]){break K}x[j>>2]=r+(1<<32-m);m=m-1|0;continue}}break}}else{x[u+(f<<2)>>2]=1<<32-f;f=f+1|0;continue}break}_(15230,13258,1118,7588);p()}_(15815,13258,1133,7588);p()}_(15237,13258,1104,7588);p()}f=f+1|0;continue}break}fb=u+128|0;if(!f){if(y[g+23|0]){Aj(e,b,0)}fc(e,20);break c}f=x[l>>2];if(f){f=te(e,(f<<2)+4|0);x[g+2084>>2]=f;if(!f){fc(e,3);break c}f=te(e,(x[l>>2]<<2)+4|0);x[g+2088>>2]=f;if(!f){fc(e,3);break c}x[g+2088>>2]=f+4;x[f>>2]=-1;f=0;m=0;N:{O:{P:{if(y[g+23|0]){while(1){m=x[g+2092>>2];if((m|0)<=(f|0)){break P}h=f<<2;M=h+x[g+2084>>2]|0,N=Nm(x[h+x[g+32>>2]>>2]),x[M>>2]=N;f=f+1|0;continue}}while(1){if(x[g+4>>2]>(f|0)){if(PL(y[g+23|0],y[f+i|0])){M=x[g+2084>>2]+(m<<2)|0,N=Nm(x[x[g+32>>2]+(f<<2)>>2]),x[M>>2]=N;m=m+1|0}f=f+1|0;continue}break}if(x[g+2092>>2]!=(m|0)){break O}}UL(x[g+2084>>2],m,1175);x[x[g+2084>>2]+(x[g+2092>>2]<<2)>>2]=-1;h=0;f=x[g+(y[g+23|0]?2092:4)>>2];r=(f|0)>0?f:0;Q:{while(1){if((h|0)!=(r|0)){f=h;j=y[g+23|0];f=j?x[(f<<2)+b>>2]:f;G=y[f+i|0];R:{if(!PL(j,G)){break R}o=h<<2;s=Nm(x[o+x[g+32>>2]>>2]);f=x[g+2092>>2];m=0;while(1){if((f|0)>=2){u=f>>>1|0;j=u+m|0;n=s>>>0<A[x[g+2084>>2]+(j<<2)>>2];f=n?u:f-u|0;m=n?m:j;continue}break}f=m<<2;if((s|0)!=x[f+x[g+2084>>2]>>2]){break Q}if(y[g+23|0]){x[f+x[g+2088>>2]>>2]=x[b+o>>2];v[x[g+8>>2]+m|0]=G;break R}x[f+x[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break N}_(12299,13258,1230,9982);p()}_(7529,13258,1200,9982);p()}}if(y[g+23|0]){Aj(e,b,x[l>>2]<<2);Aj(e,x[g+32>>2],x[l>>2]<<2);Aj(e,i,x[t>>2]);x[g+32>>2]=0}b=0;h=0;while(1){if((b|0)!=1024){w[(g+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=x[g+(y[g+23|0]?2092:4)>>2];b=(b|0)>=32767?32767:b;f=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){S:{if(y[x[g+8>>2]+h|0]>10){break S}T:{if(y[g+23|0]){b=Nm(x[x[g+2084>>2]+(h<<2)>>2]);break T}b=x[x[g+32>>2]+(h<<2)>>2]}while(1){if(b>>>0>1023){break S}w[(g+(b<<1)|0)+36>>1]=h;b=(1<<y[x[g+8>>2]+h|0])+b|0;continue}}h=h+1|0;continue}break}b=rc(e,4);v[g+21|0]=b;b=b&255;if(b>>>0>=3){fc(e,20);break c}if(b){M=g,O=RL(rc(e,32)),B[M+12>>2]=O;M=g,O=RL(rc(e,32)),B[M+16>>2]=O;M=g,N=rc(e,4)+1|0,v[M+20|0]=N;M=g,N=rc(e,1),v[M+22|0]=N;f=x[g>>2];h=x[t>>2];U:{if(y[g+21|0]==1){H=J(xt(+E(E(sq(+E(h|0)))/E(f|0))));V:{if(F(H)<2147483648){b=~~H;break V}b=-2147483648}L=+(f|0);H=J(wk(+E(E(b|0)+E(1)),L));W:{if(F(H)<2147483648){f=~~H;break W}f=-2147483648}b=((f|0)<=(h|0))+b|0;I=E(b|0);if(wk(+E(I+E(1)),L)<=+(h|0)){b=-1}else{H=J(wk(+I,L));X:{if(F(H)<2147483648){f=~~H;break X}f=-2147483648}b=(f|0)>(h|0)?-1:b}if((b|0)>=0){break U}fc(e,20);break c}b=D(f,h)}x[g+24>>2]=b;if(!b){fc(e,20);break c}s=uo(e,b<<1);if(!s){break i}b=0;while(1){i=x[g+24>>2];if((i|0)>(b|0)){f=rc(e,y[g+20|0]);if((f|0)==-1){Aj(e,s,x[g+24>>2]<<1);fc(e,20);break c}else{w[s+(b<<1)>>1]=f;b=b+1|0;continue}}break}Y:{Z:{if(y[g+21|0]==1){n=y[g+23|0];_:{if(n){b=x[l>>2];if(b){break _}break Y}b=x[t>>2]}b=te(e,D(x[g>>2],b)<<2);x[g+28>>2]=b;if(!b){Aj(e,s,x[g+24>>2]<<1);fc(e,3);break c}h=0;b=x[(n?l:t)>>2];r=(b|0)>0?b:0;G=g+2088|0;K=E(0);while(1){if((h|0)==(r|0)){break Z}f=h;f=n?x[x[G>>2]+(f<<2)>>2]:f;i=x[g>>2];b=0;l=1;while(1){if((b|0)<(i|0)){I=E(K+E(E(E(z[s+(((f>>>0)/(l>>>0)>>>0)%A[g+24>>2]<<1)>>1])*B[g+16>>2])+B[g+12>>2]));B[x[g+28>>2]+(D(h,i)+b<<2)>>2]=I;K=y[g+22|0]?I:K;b=b+1|0;i=x[g>>2];if((b|0)>=(i|0)){continue}u=x[g+24>>2];ova(u,0,l,0);if(hb){Aj(e,s,u<<1);fc(e,20);break c}else{l=D(l,u);continue}}break}h=h+1|0;continue}}b=te(e,i<<2);x[g+28>>2]=b;if(!b){break h}b=0;K=E(0);while(1){i=x[g+24>>2];if((i|0)<=(b|0)){break Y}I=E(K+E(E(E(z[s+(b<<1)>>1])*B[g+16>>2])+B[g+12>>2]));B[x[g+28>>2]+(b<<2)>>2]=I;K=y[g+22|0]?I:K;b=b+1|0;continue}}v[g+21|0]=2;i=x[g+24>>2]}Aj(e,s,i<<1)}k=k+1|0;continue}break}fc(e,3);break c}fc(e,3);break c}Aj(e,s,x[g+24>>2]<<1);fc(e,3);break c}fc(e,20);break c}fc(e,3);break c}v[j+x[g+x[e+28>>2]>>2]|0]=0;m=m+1|0;continue}}b=0}fb=q+1024|0;$:{aa:{if(!b){x[d>>2]=x[C+104>>2]?1:x[C+108>>2];break aa}b=te(C+8|0,1512);if(b){M=c,N=x[yc(b,C+8|0,1512)+32>>2]-a|0,x[M>>2]=N;x[d>>2]=0;break $}}bM(C+8|0);b=0}fb=C+1520|0;return b}function PK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,w=0,z=0,B=0,C=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;r=fb-48|0;fb=r;a:{if(c>>>0<=2){c=c<<2;I=x[c+95724>>2];J=x[c+95712>>2];while(1){c=x[b+4>>2];b:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break b}c=sd(b)}if(zl(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break c}c=sd(b)}e:{f:{while(1){if(v[g+4952|0]==(c|32)){g:{if(g>>>0>6){break g}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break g}c=sd(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}l=fb-16|0;fb=l;h=(q(E(E(o|0)*E(Infinity))),j(2));b=h&2147483647;h:{if(b-8388608>>>0<=2130706431){c=b;b=b>>>7|0;c=c<<25;d=b+1065353216|0;break h}c=h<<25;d=h>>>7|2147418112;if(b>>>0>=2139095040){break h}c=0;d=0;if(!b){break h}c=b;b=G(b);bg(l,c,0,0,0,b+81|0);k=x[l>>2];i=x[l+4>>2];c=x[l+8>>2];d=x[l+12>>2]^65536|16265-b<<16}x[r>>2]=k;x[r+4>>2]=i;x[r+8>>2]=c;x[r+12>>2]=h&-2147483648|d;fb=l+16|0;k=x[r+8>>2];i=x[r+12>>2];h=x[r>>2];m=x[r+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(v[g+9978|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break l}c=sd(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=x[b+4>>2];o:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break o}g=sd(b)}if((g&-33)==88){f=fb-432|0;fb=f;c=x[b+4>>2];p:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break p}g=sd(b)}q:{r:{while(1){if((g|0)!=48){s:{if((g|0)!=46){break q}c=x[b+4>>2];if((c|0)==x[b+104>>2]){break s}x[b+4>>2]=c+1;g=y[c|0];break r}}else{c=x[b+4>>2];if((c|0)!=x[b+104>>2]){H=1;x[b+4>>2]=c+1;g=y[c|0]}else{H=1;g=sd(b)}continue}break}g=sd(b)}s=1;if((g|0)!=48){break q}while(1){c=t;t=c-1|0;u=u-!c|0;c=x[b+4>>2];t:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break t}g=sd(b)}if((g|0)==48){continue}break}H=1}m=1073676288;u:{while(1){v:{c=g|32;w:{x:{K=g-48|0;if(K>>>0<10){break x}if((g|0)!=46&c-97>>>0>5){break u}if((g|0)!=46){break x}if(s){break v}s=1;t=k;u=i;break w}c=(g|0)>57?c-87|0:K;y:{if((i|0)<=0&k>>>0<=7|(i|0)<0){e=c+(e<<4)|0;break y}if(!i&k>>>0<=28){nh(f+48|0,c);Vd(f+32|0,C,F,h,m,0,0,0,1073414144);C=x[f+32>>2];F=x[f+36>>2];h=x[f+40>>2];m=x[f+44>>2];Vd(f+16|0,x[f+48>>2],x[f+52>>2],x[f+56>>2],x[f+60>>2],C,F,h,m);Sg(f,x[f+16>>2],x[f+20>>2],x[f+24>>2],x[f+28>>2],l,p,z,B);z=x[f+8>>2];B=x[f+12>>2];l=x[f>>2];p=x[f+4>>2];break y}if(!c|n){break y}Vd(f+80|0,C,F,h,m,0,0,0,1073610752);Sg(f- -64|0,x[f+80>>2],x[f+84>>2],x[f+88>>2],x[f+92>>2],l,p,z,B);z=x[f+72>>2];B=x[f+76>>2];n=1;l=x[f+64>>2];p=x[f+68>>2]}k=k+1|0;i=k?i:i+1|0;H=1}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0]}else{g=sd(b)}continue}break}g=46}z:{if(!H){c=x[b+116>>2];A:{B:{if((c|0)>0|(c|0)>=0){c=x[b+4>>2];x[b+4>>2]=c-1;if(!d){break B}x[b+4>>2]=c-2;if(!s){break A}x[b+4>>2]=c-3;break A}if(d){break A}}Ji(b,0,0)}nj(f+96|0,+(o|0)*0);l=x[f+96>>2];p=x[f+100>>2];c=x[f+108>>2];b=x[f+104>>2];break z}if((i|0)<=0&k>>>0<=7|(i|0)<0){h=k;m=i;while(1){e=e<<4;h=h+1|0;m=h?m:m+1|0;if((h|0)!=8|m){continue}break}}C:{D:{E:{if((g&-33)==80){h=OK(b,d);c=hb;m=c;if(h|(c|0)!=-2147483648){break C}if(d){c=x[b+116>>2];if((c|0)>0|(c|0)>=0){break E}break D}l=0;p=0;Ji(b,0,0);c=0;b=0;break z}h=0;m=0;if(x[b+116>>2]<0){break C}}x[b+4>>2]=x[b+4>>2]-1}h=0;m=0}if(!e){nj(f+112|0,+(o|0)*0);l=x[f+112>>2];p=x[f+116>>2];c=x[f+124>>2];b=x[f+120>>2];break z}b=s?t:k;i=(s?u:i)<<2|b>>>30;c=h+(b<<2)|0;b=i+m|0;k=c-32|0;i=(c>>>0<h>>>0?b+1|0:b)-(c>>>0<32)|0;b=i;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){x[31600]=68;nh(f+160|0,o);Vd(f+144|0,x[f+160>>2],x[f+164>>2],x[f+168>>2],x[f+172>>2],-1,-1,-1,2147418111);Vd(f+128|0,x[f+144>>2],x[f+148>>2],x[f+152>>2],x[f+156>>2],-1,-1,-1,2147418111);l=x[f+128>>2];p=x[f+132>>2];c=x[f+140>>2];b=x[f+136>>2];break z}b=I-226|0;c=b>>31;if((i|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(i|0)){if((e|0)>=0){while(1){Sg(f+416|0,l,p,z,B,0,0,0,-1073807360);b=cV(l,p,z,B,1073610752);c=(b|0)>=0;b=c;Sg(f+400|0,l,p,z,B,b?x[f+416>>2]:l,b?x[f+420>>2]:p,b?x[f+424>>2]:z,b?x[f+428>>2]:B);b=k;k=b-1|0;i=i-!b|0;z=x[f+408>>2];B=x[f+412>>2];l=x[f+400>>2];p=x[f+404>>2];e=c|e<<1;if((e|0)>=0){continue}break}}b=i-((I>>31)+(k>>>0<I>>>0)|0)|0;c=(k-I|0)+32|0;b=c>>>0<32?b+1|0:b;c=c>>>0<J>>>0&(b|0)<=0|(b|0)<0?(c|0)>0?c:0:J;F:{if((c|0)>=113){nh(f+384|0,o);t=x[f+392>>2];u=x[f+396>>2];C=x[f+384>>2];F=x[f+388>>2];h=0;b=0;break F}nj(f+352|0,tk(1,144-c|0));nh(f+336|0,o);C=x[f+336>>2];F=x[f+340>>2];t=x[f+344>>2];u=x[f+348>>2];RK(f+368|0,x[f+352>>2],x[f+356>>2],x[f+360>>2],x[f+364>>2],C,F,t,u);w=x[f+376>>2];L=x[f+380>>2];h=x[f+372>>2];b=x[f+368>>2]}d=!(e&1)&((mn(l,p,z,B,0,0,0,0)|0)!=0&(c|0)<32);$n(f+320|0,d+e|0);Vd(f+304|0,C,F,t,u,x[f+320>>2],x[f+324>>2],x[f+328>>2],x[f+332>>2]);c=b;Sg(f+272|0,x[f+304>>2],x[f+308>>2],x[f+312>>2],x[f+316>>2],b,h,w,L);b=d;Vd(f+288|0,C,F,t,u,b?0:l,b?0:p,b?0:z,b?0:B);Sg(f+256|0,x[f+288>>2],x[f+292>>2],x[f+296>>2],x[f+300>>2],x[f+272>>2],x[f+276>>2],x[f+280>>2],x[f+284>>2]);qz(f+240|0,x[f+256>>2],x[f+260>>2],x[f+264>>2],x[f+268>>2],c,h,w,L);b=x[f+240>>2];d=x[f+244>>2];c=x[f+248>>2];h=x[f+252>>2];if(!mn(b,d,c,h,0,0,0,0)){x[31600]=68}QK(f+224|0,b,d,c,h,k);l=x[f+224>>2];p=x[f+228>>2];c=x[f+236>>2];b=x[f+232>>2];break z}x[31600]=68;nh(f+208|0,o);Vd(f+192|0,x[f+208>>2],x[f+212>>2],x[f+216>>2],x[f+220>>2],0,0,0,65536);Vd(f+176|0,x[f+192>>2],x[f+196>>2],x[f+200>>2],x[f+204>>2],0,0,0,65536);l=x[f+176>>2];p=x[f+180>>2];c=x[f+188>>2];b=x[f+184>>2]}x[r+16>>2]=l;x[r+20>>2]=p;x[r+24>>2]=b;x[r+28>>2]=c;fb=f+432|0;k=x[r+24>>2];i=x[r+28>>2];h=x[r+16>>2];m=x[r+20>>2];break a}if(x[b+116>>2]<0){break n}x[b+4>>2]=x[b+4>>2]-1}g=b;w=o;f=d;b=0;o=0;e=fb-8976|0;fb=e;K=0-I|0;L=K-J|0;G:{H:{while(1){if((c|0)!=48){I:{if((c|0)!=46){break G}c=x[g+4>>2];if((c|0)==x[g+104>>2]){break I}x[g+4>>2]=c+1;c=y[c|0];break H}}else{b=x[g+4>>2];if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0]}else{c=sd(g)}b=1;continue}break}c=sd(g)}n=1;if((c|0)!=48){break G}while(1){b=k;k=b-1|0;i=i-!b|0;b=x[g+4>>2];J:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0];break J}c=sd(g)}if((c|0)==48){continue}break}b=1}x[e+784>>2]=0;K:{L:{d=(c|0)==46;l=c-48|0;M:{N:{O:{if(d|l>>>0<=9){while(1){P:{if(d&1){if(!n){k=h;i=m;n=1;break P}d=!b;break O}h=h+1|0;m=h?m:m+1|0;if((o|0)<=2044){H=(c|0)==48?H:h;b=(e+784|0)+(o<<2)|0;if(s){l=(D(x[b>>2],10)+c|0)-48|0}x[b>>2]=l;b=1;d=s+1|0;c=(d|0)==9;s=c?0:d;o=c+o|0;break P}if((c|0)==48){break P}x[e+8960>>2]=x[e+8960>>2]|1;H=18396}c=x[g+4>>2];Q:{if((c|0)!=x[g+104>>2]){x[g+4>>2]=c+1;c=y[c|0];break Q}c=sd(g)}d=(c|0)==46;l=c-48|0;if(d|l>>>0<10){continue}break}}k=n?k:h;i=n?i:m;if(!(!b|(c&-33)!=69)){l=OK(g,f);b=hb;p=b;R:{if(l|(b|0)!=-2147483648){break R}if(!f){break M}l=0;p=0;if(x[g+116>>2]<0){break R}x[g+4>>2]=x[g+4>>2]-1}i=i+p|0;k=k+l|0;i=k>>>0<l>>>0?i+1|0:i;break L}d=!b;if((c|0)<0){break N}}if(x[g+116>>2]<0){break N}x[g+4>>2]=x[g+4>>2]-1}if(!d){break L}x[31600]=28}h=0;m=0;Ji(g,0,0);c=0;b=0;break K}b=x[e+784>>2];if(!b){nj(e,+(w|0)*0);h=x[e>>2];m=x[e+4>>2];c=x[e+12>>2];b=x[e+8>>2];break K}if(!((h|0)!=(k|0)|(i|0)!=(m|0)|(h>>>0>9&(m|0)>=0|(m|0)>0)|(b>>>J|0?(J|0)<=30:0))){nh(e+48|0,w);$n(e+32|0,b);Vd(e+16|0,x[e+48>>2],x[e+52>>2],x[e+56>>2],x[e+60>>2],x[e+32>>2],x[e+36>>2],x[e+40>>2],x[e+44>>2]);h=x[e+16>>2];m=x[e+20>>2];c=x[e+28>>2];b=x[e+24>>2];break K}if(k>>>0>K>>>1>>>0&(i|0)>=0|(i|0)>0){x[31600]=68;nh(e+96|0,w);Vd(e+80|0,x[e+96>>2],x[e+100>>2],x[e+104>>2],x[e+108>>2],-1,-1,-1,2147418111);Vd(e- -64|0,x[e+80>>2],x[e+84>>2],x[e+88>>2],x[e+92>>2],-1,-1,-1,2147418111);h=x[e+64>>2];m=x[e+68>>2];c=x[e+76>>2];b=x[e+72>>2];break K}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(i|0)<=(b|0)|(b|0)>(i|0)){x[31600]=68;nh(e+144|0,w);Vd(e+128|0,x[e+144>>2],x[e+148>>2],x[e+152>>2],x[e+156>>2],0,0,0,65536);Vd(e+112|0,x[e+128>>2],x[e+132>>2],x[e+136>>2],x[e+140>>2],0,0,0,65536);h=x[e+112>>2];m=x[e+116>>2];c=x[e+124>>2];b=x[e+120>>2];break K}if(s){if((s|0)<=8){b=(e+784|0)+(o<<2)|0;g=x[b>>2];while(1){g=D(g,10);s=s+1|0;if((s|0)!=9){continue}break}x[b>>2]=g}o=o+1|0}n=k;S:{if((k|0)<(H|0)|(H|0)>=9|(k|0)>17){break S}if((n|0)==9){nh(e+192|0,w);$n(e+176|0,x[e+784>>2]);Vd(e+160|0,x[e+192>>2],x[e+196>>2],x[e+200>>2],x[e+204>>2],x[e+176>>2],x[e+180>>2],x[e+184>>2],x[e+188>>2]);h=x[e+160>>2];m=x[e+164>>2];c=x[e+172>>2];b=x[e+168>>2];break K}if((n|0)<=8){nh(e+272|0,w);$n(e+256|0,x[e+784>>2]);Vd(e+240|0,x[e+272>>2],x[e+276>>2],x[e+280>>2],x[e+284>>2],x[e+256>>2],x[e+260>>2],x[e+264>>2],x[e+268>>2]);nh(e+224|0,x[(0-n<<2)+95712>>2]);tR(e+208|0,x[e+240>>2],x[e+244>>2],x[e+248>>2],x[e+252>>2],x[e+224>>2],x[e+228>>2],x[e+232>>2],x[e+236>>2]);h=x[e+208>>2];m=x[e+212>>2];c=x[e+220>>2];b=x[e+216>>2];break K}b=(D(n,-3)+J|0)+27|0;c=x[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break S}nh(e+352|0,w);$n(e+336|0,c);Vd(e+320|0,x[e+352>>2],x[e+356>>2],x[e+360>>2],x[e+364>>2],x[e+336>>2],x[e+340>>2],x[e+344>>2],x[e+348>>2]);nh(e+304|0,x[(n<<2)+95640>>2]);Vd(e+288|0,x[e+320>>2],x[e+324>>2],x[e+328>>2],x[e+332>>2],x[e+304>>2],x[e+308>>2],x[e+312>>2],x[e+316>>2]);h=x[e+288>>2];m=x[e+292>>2];c=x[e+300>>2];b=x[e+296>>2];break K}while(1){c=o;o=c-1|0;if(!x[(e+784|0)+(o<<2)>>2]){continue}break}s=0;b=(n|0)%9|0;T:{if(!b){d=0;break T}d=0;b=(n|0)<0?b+9|0:b;U:{if(!c){c=0;break U}k=x[(0-b<<2)+95712>>2];i=1e9/(k|0)|0;l=0;g=0;while(1){h=l;l=(e+784|0)+(g<<2)|0;m=x[l>>2];o=(m>>>0)/(k>>>0)|0;h=h+o|0;x[l>>2]=h;h=!h&(d|0)==(g|0);d=h?d+1&2047:d;n=h?n-9|0:n;l=D(i,m-D(k,o)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!l){break U}x[(e+784|0)+(c<<2)>>2]=l;c=c+1|0}n=(n-b|0)+9|0}while(1){g=(e+784|0)+(d<<2)|0;V:{while(1){W:{if((n|0)<36){break W}if((n|0)!=36){break V}if(A[g>>2]<=10384592){break W}n=36;break V}o=c+2047|0;l=0;b=c;while(1){c=b;h=o&2047;o=(e+784|0)+(h<<2)|0;b=x[o>>2];m=b>>>3|0;k=l;l=b<<29;k=k+l|0;b=m;i=k>>>0<l>>>0?b+1|0:b;if(!i&k>>>0<1000000001){l=0}else{l=qva(k,i,1e9,0);b=ova(l,hb,-1e9,-1);k=b+k|0}x[o>>2]=k;b=(h|0)!=(c-1&2047)?c:(d|0)==(h|0)?c:k?c:h;o=h-1|0;if((d|0)!=(h|0)){continue}break}s=s-29|0;if(!l){continue}break}d=d-1&2047;if((d|0)==(b|0)){k=e+784|0;c=k+((b+2046&2047)<<2)|0;g=c;m=x[c>>2];c=b-1&2047;x[g>>2]=m|x[k+(c<<2)>>2]}n=n+9|0;x[(e+784|0)+(d<<2)>>2]=l;continue}break}X:{Y:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;Z:{while(1){b=d;g=0;_:{while(1){$:{d=b+g&2047;if((d|0)==(c|0)){break $}d=x[(e+784|0)+(d<<2)>>2];i=x[(g<<2)+95664>>2];if(d>>>0<i>>>0){break $}if(d>>>0>i>>>0){break _}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break _}g=0;k=0;i=0;h=0;m=0;while(1){d=b+g&2047;if((d|0)==(c|0)){c=c+1&2047;x[(e+(c<<2)|0)+780>>2]=0}$n(e+768|0,x[(e+784|0)+(d<<2)>>2]);Vd(e+752|0,k,i,h,m,0,0,1342177280,1075633366);Sg(e+736|0,x[e+752>>2],x[e+756>>2],x[e+760>>2],x[e+764>>2],x[e+768>>2],x[e+772>>2],x[e+776>>2],x[e+780>>2]);h=x[e+744>>2];m=x[e+748>>2];k=x[e+736>>2];i=x[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}nh(e+720|0,w);Vd(e+704|0,k,i,h,m,x[e+720>>2],x[e+724>>2],x[e+728>>2],x[e+732>>2]);h=x[e+712>>2];m=x[e+716>>2];k=0;i=0;l=x[e+704>>2];p=x[e+708>>2];f=s+113|0;g=f-I|0;o=(g|0)<(J|0);d=o?(g|0)>0?g:0:J;if((d|0)<=112){break Z}break X}s=h+s|0;d=c;if((b|0)==(c|0)){continue}break}m=1e9>>>h|0;o=-1<<h^-1;g=0;d=b;while(1){i=g;g=(e+784|0)+(b<<2)|0;f=x[g>>2];i=i+(f>>>h|0)|0;x[g>>2]=i;i=!i&(b|0)==(d|0);d=i?d+1&2047:d;n=i?n-9|0:n;g=D(m,f&o);b=b+1&2047;if((c|0)!=(b|0)){continue}break}if(!g){continue}if((d|0)!=(k|0)){x[(e+784|0)+(c<<2)>>2]=g;c=k;continue Y}x[l>>2]=x[l>>2]|1;continue}break}break}nj(e+656|0,tk(1,225-d|0));RK(e+688|0,x[e+656>>2],x[e+660>>2],x[e+664>>2],x[e+668>>2],l,p,h,m);C=x[e+696>>2];F=x[e+700>>2];z=x[e+688>>2];B=x[e+692>>2];nj(e+640|0,tk(1,113-d|0));OQ(e+672|0,l,p,h,m,x[e+640>>2],x[e+644>>2],x[e+648>>2],x[e+652>>2]);k=x[e+672>>2];i=x[e+676>>2];t=x[e+680>>2];u=x[e+684>>2];qz(e+624|0,l,p,h,m,k,i,t,u);Sg(e+608|0,z,B,C,F,x[e+624>>2],x[e+628>>2],x[e+632>>2],x[e+636>>2]);h=x[e+616>>2];m=x[e+620>>2];l=x[e+608>>2];p=x[e+612>>2]}n=b+4&2047;aa:{if((n|0)==(c|0)){break aa}n=x[(e+784|0)+(n<<2)>>2];ba:{if(n>>>0<=499999999){if(!n&(b+5&2047)==(c|0)){break ba}nj(e+496|0,+(w|0)*.25);Sg(e+480|0,k,i,t,u,x[e+496>>2],x[e+500>>2],x[e+504>>2],x[e+508>>2]);t=x[e+488>>2];u=x[e+492>>2];k=x[e+480>>2];i=x[e+484>>2];break ba}if((n|0)!=5e8){nj(e+592|0,+(w|0)*.75);Sg(e+576|0,k,i,t,u,x[e+592>>2],x[e+596>>2],x[e+600>>2],x[e+604>>2]);t=x[e+584>>2];u=x[e+588>>2];k=x[e+576>>2];i=x[e+580>>2];break ba}M=+(w|0);if((b+5&2047)==(c|0)){nj(e+528|0,M*.5);Sg(e+512|0,k,i,t,u,x[e+528>>2],x[e+532>>2],x[e+536>>2],x[e+540>>2]);t=x[e+520>>2];u=x[e+524>>2];k=x[e+512>>2];i=x[e+516>>2];break ba}nj(e+560|0,M*.75);Sg(e+544|0,k,i,t,u,x[e+560>>2],x[e+564>>2],x[e+568>>2],x[e+572>>2]);t=x[e+552>>2];u=x[e+556>>2];k=x[e+544>>2];i=x[e+548>>2]}if((d|0)>111){break aa}OQ(e+464|0,k,i,t,u,0,0,0,1073676288);if(mn(x[e+464>>2],x[e+468>>2],x[e+472>>2],x[e+476>>2],0,0,0,0)){break aa}Sg(e+448|0,k,i,t,u,0,0,0,1073676288);t=x[e+456>>2];u=x[e+460>>2];k=x[e+448>>2];i=x[e+452>>2]}Sg(e+432|0,l,p,h,m,k,i,t,u);qz(e+416|0,x[e+432>>2],x[e+436>>2],x[e+440>>2],x[e+444>>2],z,B,C,F);h=x[e+424>>2];m=x[e+428>>2];l=x[e+416>>2];p=x[e+420>>2];ca:{if((L-2|0)>=(f&2147483647)){break ca}x[e+408>>2]=h;x[e+412>>2]=m&2147483647;x[e+400>>2]=l;x[e+404>>2]=p;Vd(e+384|0,l,p,h,m,0,0,0,1073610752);c=cV(x[e+400>>2],x[e+404>>2],x[e+408>>2],x[e+412>>2],1081081856);b=(c|0)>=0;h=b?x[e+392>>2]:h;m=b?x[e+396>>2]:m;l=b?x[e+384>>2]:l;p=b?x[e+388>>2]:p;s=b+s|0;if(!(o&((d|0)!=(g|0)|(c|0)<0)&(mn(k,i,t,u,0,0,0,0)|0)!=0)&(s+110|0)<=(L|0)){break ca}x[31600]=68}QK(e+368|0,l,p,h,m,s);h=x[e+368>>2];m=x[e+372>>2];c=x[e+380>>2];b=x[e+376>>2]}x[r+40>>2]=b;x[r+44>>2]=c;x[r+32>>2]=h;x[r+36>>2]=m;fb=e+8976|0;k=x[r+40>>2];i=x[r+44>>2];h=x[r+32>>2];m=x[r+36>>2];break a;case 3:break j;default:break m}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}break i}da:{c=x[b+4>>2];ea:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break ea}c=sd(b)}if((c|0)==40){g=1;break da}i=2147450880;if(x[b+116>>2]<0){break a}x[b+4>>2]=x[b+4>>2]-1;break a}while(1){c=x[b+4>>2];fa:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break fa}c=sd(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}i=2147450880;if((c|0)==41){break a}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}ga:{if(d){if(g){break ga}break a}break i}while(1){if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g){continue}break}break a}x[31600]=28;Ji(b,0,0)}i=0}x[a>>2]=h;x[a+4>>2]=m;x[a+8>>2]=k;x[a+12>>2]=i;fb=r+48|0}function Rra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;d=fb-416|0;fb=d;xc(b);f=d+411|0;e=zE(b,f);if(!e){jZ(f)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!e){break j}if(!kZ(d+411|0)){break j}if(!c){q=1;break j}H=Ge(d+388|0,b);x[31725]=0;O(509,d+376|0,H|0);b=x[31725];x[31725]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((b|0)!=1){x[31725]=0;S(510,d+356|0,d+376|0,20041);b=x[31725];x[31725]=0;if((b|0)==1){break t}x[31725]=0;e=R(174,x[d+356>>2])|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}if(!e){break k}x[31725]=0;e=P(511,d+356|0,d+265|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}if(!e){break k}x[31725]=0;O(248,a|0,16384);b=x[31725];x[31725]=0;if((b|0)==1){break l}x[a+480208>>2]=8;x[31725]=0;e=U(268,a+1074312|0,9,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}x[31725]=0;e=U(268,e|0,114,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}x[31725]=0;e=P(269,e|0,21)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}x[31725]=0;P(269,e|0,30)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}x[31725]=0;e=P(1,d+252|0,8280)|0;b=x[31725];x[31725]=0;if((b|0)==1){break q}Ab(a+1298344|0,e);tb(e);x[31725]=0;e=P(1,d+240|0,10751)|0;b=x[31725];x[31725]=0;if((b|0)==1){break p}Ab(a+1298356|0,e);tb(e);x[31725]=0;j=P(1,d+228|0,18124)|0;b=x[31725];x[31725]=0;if((b|0)==1){break o}e=15041;b=y[d+415|0];switch(b-16|0){case 1:break m;case 0:break s;default:break r}}g=N()|0;break a}g=N()|0;break b}e=15022;break m}if(!b){break n}e=22255;break m}g=N()|0;break c}g=N()|0;break c}g=N()|0;break c}e=13322}x[31725]=0;f=P(1,d+216|0,e|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;S(2,d+192|0,j|0,f|0);b=x[31725];x[31725]=0;if((b|0)==1){break f}e=d+192|0;Ab(a+1298368|0,e);tb(e);tb(f);tb(j);I=a+1298404|0,J=x[Fc(e,4)>>2],x[I>>2]=J;b=d+84|0;We(b,3,d+265|0);x[31725]=0;O(220,e|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break g}e=d+192|0;Ab(a+1298308|0,e);tb(e);b=d+84|0;wi(b,3,d+297|0);x[31725]=0;S(371,e|0,4,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break h}b=d+192|0;Ab(a+1298320|0,b);tb(b);x[a+480200>>2]=y[d+321|0]+1;I=a,J=Kd(y[d+322|0],1,255),x[I+480196>>2]=J;I=a,J=D(Kd(y[d+323|0],4,255),1e4),x[I+480204>>2]=J;e=y[a+484376|0];b=x[a+484360>>2];x[31725]=0;aa(350,Xb(b,e)|0,d+356|0,y[d+317|0]|y[d+318|0]<<8,65535,65535);b=x[31725];x[31725]=0;if((b|0)==1){break l}bf(Xb(x[a+484360>>2],y[a+484376|0]),y[d+319|0]|y[d+320|0]<<8);w[a+480188>>1]=0;b=0;while(1){if((b|0)==32){x[31725]=0;S(510,d+192|0,d+376|0,17741);b=x[31725];x[31725]=0;if((b|0)!=1){b=d+192|0;f=hd(d+356|0,b);ub(b);b=x[f>>2];x[31725]=0;e=R(156,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}x[31725]=0;V(338,a+1298332|0,f|0,e|0,0);b=x[31725];x[31725]=0;if((b|0)==1){break l}x[31725]=0;S(510,d+192|0,d+376|0,21321);b=x[31725];x[31725]=0;if((b|0)!=1){b=d+192|0;k=hd(f,b);ub(b);b=x[k>>2];x[31725]=0;e=R(174,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}u:{v:{if(e){x[31725]=0;S(510,d+192|0,d+376|0,16723);b=x[31725];x[31725]=0;if((b|0)==1){break u}x[31725]=0;h=R(199,k|0)|0;b=x[31725];x[31725]=0;w:{if((b|0)!=1){j=c&2;f=0;while(1){if(h>>>0<=(f&255)>>>0){break w}x[31725]=0;i=R(199,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}if(!i){break w}e=x[k+8>>2];b=x[k>>2];x[31725]=0;e=U(152,b|0,e|0,56)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}if(!e){break w}if(i>>>0>z[a+480190>>1]){w[a+480190>>1]=i}x[31725]=0;q=D(i,104)+a|0;m=q+484380|0;O(281,m|0,0);b=x[31725];x[31725]=0;if((b|0)==1){break v}np(m);x[31725]=0;S(319,k|0,((i<<5)+a|0)+946304|0,32);b=x[31725];x[31725]=0;if((b|0)==1){break v}x[31725]=0;O(322,k|0,q+484423|0);b=x[31725];x[31725]=0;if((b|0)==1){break v}x:{if(y[d+415|0]<=15){x[31725]=0;g=R(191,k|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break x}break v}x[31725]=0;g=R(153,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}}x[q+484404>>2]=g<<1;x[31725]=0;e=R(153,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}x[m>>2]=e;x[31725]=0;e=R(153,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}C=q+484384|0;x[C>>2]=e;x[31725]=0;e=R(153,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}E=q+484388|0;x[E>>2]=e;if(e){b=q+484414|0;w[b>>1]=z[b>>1]|2;x[E>>2]=e+x[C>>2]}x[31725]=0;e=R(199,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}if(y[d+415|0]<=15){w[q+484410>>1]=e}x[31725]=0;i=R(199,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}b=q+484414|0;e=z[b>>1];o=8;if(i&1){e=e|1;w[b>>1]=e;x[m>>2]=x[m>>2]>>>1;x[C>>2]=x[C>>2]>>>1;x[E>>2]=x[E>>2]>>>1;o=16}w[b>>1]=e&65531|i<<1&4;b=Xc(d+84|0,o,1,0,((i&12)!=0)<<3);y:{if(!j){break y}x[31725]=0;U(217,b|0,m|0,d+192|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break y}break v}f=f+1|0;continue}}break v}ub(d+192|0)}x[31725]=0;S(510,d+192|0,d+376|0,18761);b=x[31725];x[31725]=0;z:{if((b|0)!=1){b=d+192|0;n=hd(k,b);ub(b);b=x[n>>2];x[31725]=0;e=R(174,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break l}if(!e){break z}r=Nb(d+84|0);u=Nb(d+180|0);s=Nb(d+168|0);x[31725]=0;S(510,d+148|0,d+376|0,17750);b=x[31725];x[31725]=0;A:{if((b|0)==1){break A}b=x[d+160>>2];x[d+56>>2]=x[d+156>>2];x[d+60>>2]=b;x[d- -64>>2]=x[d+164>>2];x[31725]=0;b=x[d+152>>2];x[d+48>>2]=x[d+148>>2];x[d+52>>2]=b;O(512,d+48|0,r|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}x[31725]=0;S(510,d+128|0,d+376|0,17744);b=x[31725];x[31725]=0;if((b|0)==1){break A}b=x[d+140>>2];x[d+32>>2]=x[d+136>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+144>>2];x[31725]=0;b=x[d+132>>2];x[d+24>>2]=x[d+128>>2];x[d+28>>2]=b;O(512,d+24|0,u|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}x[31725]=0;S(510,d+108|0,d+376|0,17734);b=x[31725];x[31725]=0;if((b|0)==1){break A}b=x[d+120>>2];x[d+8>>2]=x[d+116>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+124>>2];x[31725]=0;b=x[d+112>>2];x[d>>2]=x[d+108>>2];x[d+4>>2]=b;O(512,d|0,s|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}x[31725]=0;q=R(199,n|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break A}o=0;while(1){if(q>>>0<=(o&255)>>>0){dp(s);dp(u);dp(r);break z}x[31725]=0;O(200,d+72|0,n|0);b=x[31725];x[31725]=0;B:{if((b|0)!=1){F=Jc(d+72|0);C:{D:{if(!y[d+72|0]){break D}f=x[n+8>>2];e=x[n>>2];b=y[F|0];x[31725]=0;e=U(152,e|0,f|0,D(b,14)+32|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break A}if(!e){break D}x[31725]=0;l=U(253,a|0,y[d+72|0],0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break A}if(l){break C}}b=y[F|0];x[31725]=0;P(185,n|0,D(b,14)+32|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break B}break A}x[31725]=0;S(319,n|0,l+492|0,32);b=x[31725];x[31725]=0;if((b|0)==1){break A}m=l+88|0;C=l+68|0;E=l+48|0;i=l+236|0;b=0;f=0;while(1){if(y[F|0]<=(f&255)>>>0){break B}x[31725]=0;O(513,n|0,d+192|0);e=x[31725];x[31725]=0;if((e|0)==1){break A}e=y[d+192|0];E:{if(!e|e>>>0>z[a+480190>>1]){break E}if(y[d+193|0]>=129){v[d+193|0]=128}while(1){j=b&255;h=y[d+193|0];if(j>>>0>h>>>0){e=x[r+4>>2];b=x[r>>2];x[31725]=0;V(514,E|0,y[d+195|0],b|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}e=x[u+4>>2];b=x[u>>2];x[31725]=0;V(514,C|0,y[d+197|0],b|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}e=x[s+4>>2];b=x[s>>2];x[31725]=0;V(514,m|0,y[d+205|0],b|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break A}x[l>>2]=(y[d+198|0]|y[d+199|0]<<8)+1>>>1;e=y[d+192|0];F:{if(y[d+195|0]&64){w[(D(e,104)+a|0)+484410>>1]=y[d+194|0];break F}b=(D(e,104)+a|0)+484414|0;w[b>>1]=z[b>>1]|32768}w[d+106>>1]=y[d+196|0]<<1;w[d+104>>1]=254;t=D(e,104)+a|0;I=t+484408|0,J=z[Nc(d+106|0,d+104|0)>>1],w[I>>1]=J;v[t+484418|0]=y[(y[d+203|0]&3)+25028|0];e=t+484419|0;k=y[d+202|0];v[e|0]=k;j=y[d+201|0]+3>>>2|0;v[t+484420|0]=j;v[t+484421|0]=y[d+200|0];b=h+1|0;if(k){j=zi(Bc(((j<<8|k>>>1)>>>0)/(k>>>0)|0,0))}else{j=255}v[e|0]=j;if(!(y[d+197|0]&64)){break E}e=t+484414|0;w[e>>1]=z[e>>1]|32}else{e=y[d+192|0];I=_b(i,j),J=e,w[I>>1]=J;b=b+1|0;continue}break}}f=f+1|0;continue}}break A}o=o+1|0;continue}}g=N()|0;dp(s);dp(u);dp(r);break c}g=N()|0;break c}q=1;G=Nb(d+180|0);G:{if(!(c&1)){break G}x[31725]=0;S(510,d+192|0,d+376|0,21076);b=x[31725];x[31725]=0;H:{I:{J:{K:{L:{M:{if((b|0)!=1){j=hd(n,d+192|0);b=x[j>>2];x[31725]=0;c=R(174,b|0)|0;b=x[31725];x[31725]=0;N:{O:{P:{if((b|0)!=1){ub(d+192|0);if(!c){break N}x[31725]=0;e=R(191,j|0)|0;c=x[31725];x[31725]=0;b=1;if((c|0)==1){break P}x[31725]=0;f=e+1|0;O(515,G|0,f|0);c=x[31725];x[31725]=0;if((c|0)==1){break P}while(1){if((b|0)==(f|0)){break N}x[31725]=0;e=R(191,j|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break O}x[31725]=0;S(187,d+84|0,j|0,e|0);c=x[31725];x[31725]=0;if((c|0)==1){break O}c=d+84|0;e=ic(d+192|0,c);hd(eh(x[G>>2],b),e);ub(e);b=b+1|0;ub(c);continue}}g=N()|0;ub(d+192|0);break H}g=N()|0;break H}g=N()|0;break H}x[31725]=0;S(510,d+192|0,d+376|0,16720);b=x[31725];x[31725]=0;if((b|0)==1){break J}B=hd(j,d+192|0);b=x[B>>2];x[31725]=0;c=R(174,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break K}ub(d+192|0);if(!c){break M}x[31725]=0;F=R(199,B|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break I}l=0;Q:{R:{S:while(1){T:{if(F>>>0<=(l&65535)>>>0){x[31725]=0;P(151,B|0,1)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break T}break I}f=32;U:{if(y[d+415|0]<16){break U}x[31725]=0;O(516,B|0,d+192|0);b=x[31725];x[31725]=0;if((b|0)==1){break Q}f=y[d+192|0];if(f>>>0<=z[a+480188>>1]|f>>>0>32){break U}w[a+480188>>1]=f}b=0;while(1){j=b&65535;if(j>>>0>=f>>>0){l=l+1|0;continue S}x[31725]=0;e=R(191,B|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break R}if(!(!e|j>>>0>31|j>>>0<z[a+480188>>1])){w[a+480188>>1]=b+1}b=b+1|0;continue}}break}x[31725]=0;r=a+484344|0;O(225,r|0,F|0);b=x[31725];x[31725]=0;if((b|0)==1){break I}C=d+194|0;n=0;while(1){if((n|0)==(F|0)){break M}u=Fb(d+84|0);V:{if(y[d+415|0]<16){c=32;j=64;break V}x[31725]=0;O(516,B|0,d+192|0);b=x[31725];x[31725]=0;if((b|0)==1){break L}e=y[d+193|0];c=y[d+192|0];b=d+72|0;df(b,C,16,3);x[31725]=0;O(220,d+168|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break L}b=d+168|0;Ab(u,b);tb(b);j=e+1|0}x[31725]=0;e=U(198,r|0,n&65535,j|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break L}W:{if(!e){x[31725]=0;P(185,B|0,c<<1)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break W}break L}b=x[r>>2];x[31725]=0;O(285,Wb(b,n)|0,u|0);b=x[31725];x[31725]=0;if((b|0)==1){break L}E=j-1|0;k=0;while(1){s=k&65535;if(s>>>0>=c>>>0){break W}x[31725]=0;e=R(191,B|0)|0;b=x[31725];x[31725]=0;X:{if((b|0)!=1){if(!e){break X}b=x[G>>2];if(Uf(b,x[G+4>>2])>>>0<=e>>>0|s>>>0>=z[a+480188>>1]){break X}A=eh(b,e);xc(A);f=0;Y:while(1){e=f;if(j>>>0<=e>>>0){break X}f=x[A+8>>2];b=x[A>>2];x[31725]=0;f=U(152,b|0,f|0,1)|0;b=x[31725];x[31725]=0;Z:{_:{$:{aa:{ba:{if((b|0)!=1){if(!f){break X}b=Wb(x[r>>2],n);b=jd(x[b>>2],x[x[b+48>>2]+12>>2],e,s);x[31725]=0;h=R(199,A|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break L}m=h<<24>>24;g=(m&252)>>>2|0;switch((m&3)-1|0){case 2:break _;case 1:break $;case 0:break aa;default:break ba}}break L}f=(e+g|0)+1|0;continue}f=0;if(!e){continue}f=Wb(x[r>>2],n);i=jd(x[f>>2],x[x[f+48>>2]+12>>2],e-1|0,s);while(1){f=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);v[b|0]=f;v[b+1|0]=f>>>8;v[b+2|0]=f>>>16;v[b+3|0]=f>>>24;f=y[i+4|0]|y[i+5|0]<<8;v[b+4|0]=f;v[b+5|0]=f>>>8;f=e+1|0;if((e|0)==(E|0)){continue Y}b=D(z[a+480188>>1],6)+b|0;h=g&255;e=f;g=g-1|0;if(h){continue}break}continue}if(e>>>0<=g>>>0){break Z}f=Wb(x[r>>2],n);h=jd(x[f>>2],x[x[f+48>>2]+12>>2],g,s);f=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);v[b|0]=f;v[b+1|0]=f>>>8;v[b+2|0]=f>>>16;v[b+3|0]=f>>>24;f=y[h+4|0]|y[h+5|0]<<8;v[b+4|0]=f;v[b+5|0]=f>>>8;break Z}if(g&1){x[31725]=0;h=R(199,A|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break L}v[b|0]=h>>>0>120?-1:h}if(g&2){x[31725]=0;h=R(199,A|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break L}v[b+1|0]=h}l=0;f=0;ca:{if(g&4){x[31725]=0;f=R(199,A|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break ca}}t=0;if(g&8){x[31725]=0;i=R(199,A|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break ca}l=i&15;t=i>>>4|0}o=0;i=0;if(g&16){x[31725]=0;i=R(199,A|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break ca}}if((m|0)<0){x[31725]=0;o=R(199,A|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break ca}}g=fb-16|0;fb=g;h=g+14|0;hZ(h,l,i);l=Jc(h);h=g+12|0;hZ(h,((t-1&255)>>>0<6?t+15|0:t)&255,o);m=Jc(h);da:{ea:{fa:{if(y[g+14|0]==10){i=y[m|0];h=y[l|0]&15;v[l|0]=h?-1:i;o=i|h<<8;h=y[g+12|0];if((h|0)!=10){break fa}h=0;v[g+12|0]=0;break fa}if(y[g+12|0]!=10){break ea}h=y[m|0]&15;v[m|0]=h?-1:0;o=h<<8;h=y[g+14|0]}if(o-256>>>0>4294967038){break ea}if(yi(h)>>>0>=yi(10)>>>0){break ea}v[b+5|0]=o;v[b+2|0]=15;v[b+3|0]=10;v[b+4|0]=o>>>8;break da}if(f){v[b+2|0]=1;v[b+4|0]=f+2>>>2}GE(g+14|0,l,g+12|0,m);i=y[g+14|0];h=y[g+12|0];if((i|0)==20|(h|0)!=(i|0)?i:0){if(!h){v[b+5|0]=y[l|0];v[b+3|0]=i;break da}if(!f){Hn(g+10|0,b,i,y[l|0],h,y[m|0]);break da}if(yi(i)>>>0>yi(h)>>>0){v[b+5|0]=y[l|0];v[b+3|0]=i;break da}}v[b+5|0]=y[m|0];v[b+3|0]=h}fb=g+16|0;break Z}break L}f=e+1|0;continue}}break L}k=k+1|0;continue}}tb(u);n=n+1|0;continue}}g=N()|0;break H}g=N()|0;break H}g=N()|0;break H}x[31725]=0;S(510,d+192|0,d+376|0,20048);b=x[31725];x[31725]=0;ga:{ha:{if((b|0)!=1){e=hd(B,d+192|0);b=x[e>>2];x[31725]=0;c=R(174,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break ha}ub(d+192|0);if(!c){break G}while(1){if(!gk(x[a+484344>>2],x[a+484348>>2])){break G}c=x[e+8>>2];b=x[e>>2];x[31725]=0;c=U(152,b|0,c|0,16)|0;b=x[31725];x[31725]=0;if((b|0)==1){break ga}if(!c){break G}x[31725]=0;O(396,e|0,d+192|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=x[a+484344>>2];x[31725]=0;O(397,Wb(b,0)|0,d+192|0);b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}g=N()|0;break H}g=N()|0;break H}g=N()|0;ub(d+192|0);break H}g=N()|0;break H}g=N()|0;tb(u);break H}g=N()|0;ub(d+192|0);break H}g=N()|0;break H}g=N()|0}Qc(G);break c}Qc(G);break k}g=N()|0;ub(d+192|0);break c}g=N()|0;break c}g=N()|0;break c}g=N()|0;break c}h=(b<<5)+a|0;j=h+480280|0;Xe(j);f=v[(b+d|0)+324|0];e=f<<1&254;w[h+480284>>1]=(e|0)==254?256:e;ia:{if((f|0)<0){x[j>>2]=x[j>>2]|1024;break ia}w[a+480188>>1]=b+1}x[31725]=0;O(517,d+356|0,h+480289|0);e=x[31725];x[31725]=0;if((e|0)==1){break i}b=b+1|0;continue}}g=N()|0;break c}ub(d+356|0);ie(d+376|0);ub(H)}fb=d+416|0;return q|0}g=N()|0;break c}g=N()|0;break c}g=N()|0;break c}g=N()|0;tb(f);break d}g=N()|0}tb(j)}ub(d+356|0)}ie(d+376|0)}ub(H);Q(g|0);p()}function Vta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;d=fb-240|0;fb=d;xc(b);f=fb-16|0;fb=f;j=d+218|0;Zv(f+8|0,j);g=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(g|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(g|0)==(i|0);if(!f){a$(j)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}if(!b$(d+218|0)){break n}if(!c){e=1;break n}Bd(a,1024);gg(a);x[a+480208>>2]=x[a+480208>>2]|12;dg(a+1074312|0,21);e=Bb(y[d+234|0]|y[d+235|0]<<8);if(e){x[a+480204>>2]=D(e,1e4)}e=Bb(y[d+232|0]|y[d+233|0]<<8);if(e){x[a+480196>>2]=e}if(!y[d+228|0]){Yh(a,1)}wE(b,a+1298308|0,$b(y[d+222|0]|y[d+223|0]<<8|(y[d+224|0]<<16|y[d+225|0]<<24))-14|0);b=Ge(d+112|0,b);x[31725]=0;O(348,d+204|0,b|0);e=x[31725];x[31725]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((e|0)!=1){ub(b);x[31725]=0;S(349,d+112|0,d+204|0,1395544366);b=x[31725];x[31725]=0;if((b|0)==1){break s}x[31725]=0;b=R(279,x[d+112>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break y}if(!b){break r}x[31725]=0;b=R(275,d+112|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break y}x[31725]=0;e=R(275,d+112|0)|0;f=x[31725];x[31725]=0;A:{if((f|0)==1){break A}x[31725]=0;P(185,d+112|0,4)|0;f=x[31725];x[31725]=0;if((f|0)==1){break A}f=y[a+484376|0];g=x[a+484360>>2];x[31725]=0;aa(350,Xb(g,f)|0,d+112|0,b|0,65535,65535);b=x[31725];x[31725]=0;if((b|0)!=1){break z}}break y}e=N()|0;ub(b);break a}bf(Xb(x[a+484360>>2],y[a+484376|0]),e);b=d+112|0;ub(b);x[31725]=0;S(349,b|0,d+204|0,1346458708);b=x[31725];x[31725]=0;if((b|0)==1){break x}x[31725]=0;f=R(279,x[d+112>>2])|0;b=x[31725];x[31725]=0;if((b|0)==1){break w}e=0;b=0;if(!f){break t}x[31725]=0;f=R(275,d+112|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break w}w[a+480188>>1]=f;if((f-33&65535)>>>0<65504){break t}x[31725]=0;b=R(275,d+112|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break w}x[31725]=0;O(225,a+484344|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break w}b=0;x[31725]=0;n=R(283,d+112|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break w}switch(n-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}e=N()|0;ub(d+112|0);break b}e=N()|0;break b}e=N()|0;ub(d+112|0);break b}if(n){break t}}b=1}ub(d+112|0);if(!b){break o}x[31725]=0;S(349,d+184|0,d+204|0,1398157625);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;b=R(279,x[d+184>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}if(!b){break q}x[31725]=0;P(185,d+184|0,2)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}x[31725]=0;b=R(283,d+184|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}G=a,H=_e((+(b>>>0)*2.3283064365386963e-10+ +(A[a+480204>>2]/1e4>>>0))*1e4),x[G+480204>>2]=H;b=0;x[31725]=0;P(351,d+184|0,d+112|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}f=z[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){G=d,H=Bb(z[(d+112|0)+(b<<1)>>1]),x[G+48>>2]=H;x[d+32>>2]=180;e=x[ud(d+48|0,d+32|0)>>2]-90|0;j=e>>31<<7|e>>>25;G=((b<<5)+a|0)+480284|0,H=Gc(pva(e<<7|45,j,90,0),hb)+128|0,w[G>>1]=H;b=b+1|0;continue}else{B:{x[31725]=0;P(185,d+184|0,16)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break B}break c}}break}x[31725]=0;b=U(152,x[d+184>>2],x[d+192>>2],2)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}C:{if(b){x[31725]=0;b=R(275,d+184|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break C}w[d+48>>1]=b;w[d+32>>1]=256;G=a,H=z[Nc(d+48|0,d+32|0)>>1],x[G+480200>>2]=H}x[31725]=0;P(185,d+184|0,128)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}x[31725]=0;b=P(351,d+184|0,d+48|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){if(!b){break q}e=z[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(e|0)){G=d,H=Bb(z[(d+48|0)+(b<<1)>>1]),x[G+32>>2]=H;x[d+20>>2]=128;G=((b<<5)+a|0)+480286|0,H=x[ud(d+32|0,d+20|0)>>2]/2&255,w[G>>1]=H;b=b+1|0;continue}else{x[a+480228>>2]=x[a+480228>>2]<<1;break q}}break c}break c}e=N()|0;break b}ub(d+112|0);break p}ub(d+184|0);x[31725]=0;S(349,d+112|0,d+204|0,1413830740);b=x[31725];x[31725]=0;D:{E:{if((b|0)!=1){x[31725]=0;b=R(279,x[d+112>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break e}if(!b){break D}x[31725]=0;O(352,d+112|0,d+48|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}if((Bb(y[d+58|0]|y[d+59|0]<<8)|0)!=65535){break E}x[31725]=0;P(185,d+112|0,1)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break E}break e}e=N()|0;break b}x[31725]=0;b=R(204,d+112|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break e}x[31725]=0;V(338,a+1298332|0,d+112|0,b|0,2);b=x[31725];x[31725]=0;if((b|0)==1){break e}}ub(d+112|0);x[31725]=0;S(349,d+48|0,d+204|0,1229869908);b=x[31725];x[31725]=0;if((b|0)==1){break h}x[31725]=0;b=R(279,x[d+48>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}F:{if(!b){break F}x[31725]=0;b=R(275,d+48|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}x[31725]=0;e=U(152,x[d+48>>2],x[d+56>>2],D(f,(b>>>14&2)+50|0)|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break g}if(!e){break H}w[a+480190>>1]=f;g=a+480190|0;j=d+130|0;i=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){x[31725]=0;b=R(275,d+48|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break I}break g}M:{if(i){o=b}else{x[31725]=0;e=R(275,d+48|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break M}o=e+1|0}w[d+20>>1]=o;x[31725]=0;O(353,d+48|0,d+112|0);e=x[31725];x[31725]=0;if((e|0)==1){break L}e=z[d+20>>1];if((e-4e3&65535)>>>0>=61537){G=a,H=z[qe(g,d+20|0)>>1],w[G+480190>>1]=H;k=y[d+236|0]|y[d+237|0]<<8|(y[d+238|0]<<16|y[d+239|0]<<24);x[31725]=0;V(354,d+112|0,(D(e,104)+a|0)+484380|0,$b(k)|0,n|0);e=x[31725];x[31725]=0;if((e|0)==1){break K}e=d+32|0;Zk(e,2,j);x[31725]=0;O(220,d+184|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break J}e=d+184|0;zc(((z[d+20>>1]<<5)+a|0)+946304|0,e);tb(e)}b=b+1|0;continue}break}e=N()|0;break f}e=N()|0;break f}e=N()|0;break f}e=N()|0;break f}if((b|0)!=4){break F}w[d+112>>1]=z[a+480190>>1];w[d+184>>1]=255;b=d+184|0;G=a,H=z[Nc(d+112|0,b)>>1],w[G+480192>>1]=H;x[31725]=0;S(349,b|0,d+204|0,1229278806);b=x[31725];x[31725]=0;if((b|0)==1){break j}N:while(1){O:{x[31725]=0;b=U(152,x[d+48>>2],x[d+56>>2],15)|0;e=x[31725];x[31725]=0;if((e|0)==1){break O}if(!b){break G}x[31725]=0;O(355,d+48|0,d+32|0);b=x[31725];x[31725]=0;if((b|0)==1){break k}b=Bb(z[d+32>>1]);if(b>>>0>=z[a+480192>>1]){continue}e=D(b,104)+a|0;v[e+484524|0]=y[d+40|0];f=y[d+39|0];v[e+484523|0]=255;v[e+484525|0]=f;x[31725]=0;b=b+1&65535;e=U(253,a|0,b|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break k}if(!e){continue}G=d,H=Bb(y[d+37|0]|y[d+38|0]<<8),w[G+112>>1]=H;w[d+20>>1]=4095;G=e,H=z[Nc(d+112|0,d+20|0)>>1],x[G>>2]=H;b=y[d+35|0];if((b|0)==255){continue}x[31725]=0;b=P(151,d+184|0,D(b,34)+2|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break k}if(!b){continue}x[31725]=0;O(356,d+184|0,d+112|0);b=x[31725];x[31725]=0;if((b|0)==1){break k}v[e+60|0]=y[e+60|0]|1;b=z[d+112>>1];x[d+24>>2]=16;x[d+28>>2]=240;G=d,H=Bb(b),x[G+20>>2]=H;b=sE(d+20|0);x[31725]=0;O(295,e+48|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break k}b=0;f=x[e+48>>2];j=x[e+52>>2];g=Sd(f,j);while(1)if(b>>>0>=g>>>0){b=y[d+36|0];if((b|0)!=255){v[e- -64|0]=b;v[e+63|0]=b;v[e+60|0]=y[e+60|0]|4}if(lc(f,j)){continue N}b=g-1|0;v[e+62|0]=b;v[e+61|0]=b;v[e+60|0]=y[e+60|0]|2;continue N}else{v[d+20|0]=64;i=(d+112|0)+(b<<1)|0;v[d+16|0]=y[i+2|0];k=Rb(d+20|0,d+16|0);h=yb(f,b);v[h+2|0]=y[k|0];w[h>>1]=y[i+3|0];b=b+1|0;continue}}break}break k}ub(d+48|0);break p}ub(d+184|0)}ub(d+48|0);x[31725]=0;S(357,d+184|0,d+204|0,1145131092);b=x[31725];x[31725]=0;if((b|0)==1){break m}G=d,H=wb(x[d+184>>2]),x[G+20>>2]=H;j=a+484344|0;u=c&1;r=d+48|4;B=wb(x[d+188>>2]);s=(n|0)!=841887798;C=(n|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{f=x[d+20>>2];if(!Ib(f,B)){Qc(d+184|0);x[31725]=0;S(349,d+112|0,d+204|0,1346458702);b=x[31725];x[31725]=0;if((b|0)!=1){break aa}e=N()|0;break b}x[31725]=0;P(185,f|0,4)|0;b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;i=R(275,f|0)|0;b=x[31725];x[31725]=0;ba:{if((b|0)!=1){x[31725]=0;k=R(275,f|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break R}k=s?k:(k>>>0)/A[a+480196>>2]|0;if(!u|i>>>0>255){break P}x[31725]=0;b=U(198,j|0,i|0,k|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break R}if(b){break ba}break P}e=N()|0;break Q}if(!s){q=0;x[31725]=0;P(185,f|0,4)|0;b=x[31725];x[31725]=0;if((b|0)==1){break R}while(1){t=q&65535;if(t>>>0>=z[a+480188>>1]){break P}x[31725]=0;b=R(275,f|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break $}x[31725]=0;S(187,d+48|0,f|0,b+(b&1)&65535);b=x[31725];x[31725]=0;if((b|0)==1){break S}b=d+48|0;g=ic(d+112|0,b);ub(b);x[d+48>>2]=0;x[d+52>>2]=0;e=0;ca:{while(1){b=x[g>>2];x[31725]=0;b=U(152,b|0,x[d+120>>2],6)|0;h=x[31725];x[31725]=0;if((h|0)==1){break ca}h=x[d+48>>2];if(b&h>>>0<k>>>0){b=Wb(x[j>>2],i);b=jd(x[b>>2],x[x[b+48>>2]+12>>2],h,t);x[31725]=0;O(358,d+32|0,g|0);h=x[31725];x[31725]=0;da:{ea:{if((h|0)!=1){h=d+32|0;l=Jc(h);E=af(h);F=fj(h);o=ec(h);m=v[d+32|0];if((m-1&255)>>>0>95){break ea}v[b|0]=m+13;if(!x[d+52>>2]){break da}v[b+3|0]=19;x[d+16>>2]=15;G=b,H=y[ud(r,d+16|0)|0]|208,v[G+5|0]=H;break da}break T}if((m|0)>=0){break da}if(x[d+52>>2]){v[b+3|0]=19;x[d+16>>2]=15;G=b,H=y[ud(r,d+16|0)|0]|192,v[G+5|0]=H;break da}v[b|0]=254}if(y[l|0]){v[b+2|0]=1;v[d+16|0]=64;G=b,H=y[Rb(l,d+16|0)|0],v[G+4|0]=H}l=y[E|0];if(l){v[b+1|0]=l}l=y[F|0];m=y[o|0];if(l|m){Bf(b,l,m)}h=v[h+5|0];b=h&255;l=d+48|0;if((h|0)<0){x[31725]=0;h=R(199,g|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break T}b=h|b<<8&32512}e=b+e|0;dE(l,e,x[a+480196>>2]);continue}break}ub(g);q=q+1|0;continue}break}break T}b=Wb(x[j>>2],i);G=d,H=wb(x[b>>2]),x[G+48>>2]=H;h=wb(x[b+4>>2]);while(1){b=x[d+48>>2];if(!Ib(b,h)){break P}x[31725]=0;O(359,d+32|0,f|0);e=x[31725];x[31725]=0;if((e|0)!=1){v[d+15|0]=0;fa:{if(!C){e=x[d+32>>2];x[d+112>>2]=e;g=d+112|0;i=Jc(g);k=af(g);g=fj(g);if(e<<24>>24>0){v[b|0]=(D((e&240)>>>4|0,12)+(e&15)|0)+12}e=y[i|0];if(e>>>0>=4){v[b+2|0]=1;v[b+4|0]=(e>>>2|0)-1;e=y[i|0]}v[b+1|0]=e<<4&48|y[k|0]>>>4;e=y[k|0]&15;v[d+15|0]=e;g=y[g|0];v[b+5|0]=g;break fa}e=x[d+32>>2];x[d+8>>2]=e;x[d+4>>2]=e;e=d+16|0;lp(e,d+4|0,b);g=d+112|0;VD(g,d+15|0,b+5|0);UD(g,e);e=xb(d+32|0,0);v[b+1|0]=y[b+1|0]|y[e|0]&48;g=y[b+5|0];e=y[d+15|0]}Bf(b,e&255,g);e=y[b+3|0];ga:{if(e>>>0>11){break ga}e=1<<e;ha:{if(!(e&2240)){if(!(e&12)){break ga}if(!y[b+5|0]){break ha}break ga}e=y[b+5|0];g=e&240;if(g){v[b+5|0]=g;break ga}if(e){break ga}}v[b+3|0]=0}vg(d+48|0);continue}break}e=N()|0;break Q}e=N()|0;break Q}x[31725]=0;b=R(279,x[d+112>>2])|0;e=x[31725];x[31725]=0;ia:{ja:{ka:{la:{ma:{if((e|0)!=1){if(b){f=Fb(d+48|0);b=0;na:{while(1){oa:{x[31725]=0;e=U(152,x[d+112>>2],x[d+120>>2],1)|0;g=x[31725];x[31725]=0;if((g|0)==1){break oa}if(!e){break na}if(gk(x[a+484344>>2],x[a+484348>>2])>>>0<=b>>>0){break na}x[31725]=0;S(360,d+112|0,f|0,32);e=x[31725];x[31725]=0;if((e|0)==1){break oa}e=x[j>>2];x[31725]=0;O(285,Wb(e,b)|0,f|0);e=x[31725];x[31725]=0;if((e|0)==1){break oa}b=b+1|0;continue}break}e=N()|0;tb(f);break ma}tb(f)}b=d+112|0;ub(b);x[31725]=0;S(349,b|0,d+204|0,1414679374);b=x[31725];x[31725]=0;if((b|0)==1){break la}x[31725]=0;b=R(279,x[d+112>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break V}if(!b){break ia}f=Fb(d+48|0);b=0;while(1){x[31725]=0;e=U(152,x[d+112>>2],x[d+120>>2],1)|0;g=x[31725];x[31725]=0;if((g|0)==1){break ka}if(!(e&z[a+480188>>1]>b>>>0)){break ja}x[31725]=0;S(360,d+112|0,f|0,32);e=x[31725];x[31725]=0;if((e|0)==1){break ka}pm(((b<<5)+a|0)+480289|0,f);b=b+1|0;continue}}e=N()|0}ub(d+112|0);break b}e=N()|0;break b}e=N()|0;tb(f);break U}tb(f)}b=d+112|0;ub(b);x[31725]=0;S(357,b|0,d+204|0,1145129300);b=x[31725];x[31725]=0;if((b|0)==1){break W}G=d,H=wb(x[d+112>>2]),x[G+48>>2]=H;e=c&2;f=wb(x[d+116>>2]);pa:{qa:{ra:{sa:{ta:{ua:{while(1){b=x[d+48>>2];if(!Ib(b,f)){Qc(d+112|0);b=Fb(d+48|0);if((n|0)!=841887798){break ta}x[31725]=0;c=P(1,d+112|0,9490)|0;e=x[31725];x[31725]=0;if((e|0)==1){break ua}Ab(b,c);tb(c);break sa}x[31725]=0;c=R(275,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break X}va:{if(!(!e|c>>>0>=z[a+480190>>1])){c=D(c,104)+a|0;g=z[c+484518>>1];g=Xc(d+184|0,g&1?16:8,g&64?2:1,1,0);x[31725]=0;U(217,g|0,c+484484|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break va}}Sf(d+48|0);continue}break}break X}e=N()|0;break Y}x[31725]=0;S(349,d+112|0,d+204|0,1447383635);c=x[31725];x[31725]=0;wa:{xa:{ya:{za:{Aa:{if((c|0)!=1){x[31725]=0;c=R(279,x[d+112>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break ra}if(!c){break xa}x[31725]=0;c=R(283,d+112|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Aa}x[31725]=0;O(270,d+32|0,4292);e=x[31725];x[31725]=0;if((e|0)==1){break za}x[d+20>>2]=c>>>4;x[31725]=0;x[d+16>>2]=c&15;V(361,d+184|0,d+32|0,d+20|0,d+16|0);c=x[31725];x[31725]=0;if((c|0)==1){break ya}c=d+184|0;Ab(b,c);tb(c);Eb(d+32|0);break wa}e=N()|0;break Y}e=N()|0;break Z}e=N()|0;break Z}e=N()|0;Eb(d+32|0);break Z}x[31725]=0;c=P(1,d+184|0,8509)|0;e=x[31725];x[31725]=0;if((e|0)==1){break _}Ab(b,c);tb(c)}ub(d+112|0)}x[31725]=0;c=P(1,d+32|0,8509)|0;e=x[31725];x[31725]=0;if((e|0)==1){break qa}Ab(a+1298344|0,c);tb(c);x[31725]=0;c=P(1,d+20|0,10133)|0;e=x[31725];x[31725]=0;if((e|0)==1){break pa}Ab(a+1298356|0,c);tb(c);Ab(a+1298368|0,b);G=a+1298404|0,H=x[Fc(d+16|0,28)>>2],x[G>>2]=H;tb(b);e=1;break o}e=N()|0;break Z}e=N()|0;break Y}e=N()|0;break Y}e=N()|0;break Q}e=N()|0}ub(d+112|0)}tb(b);break b}e=N()|0;Qc(d+112|0);break b}e=N()|0;break b}e=N()|0}ub(d+112|0);break b}e=N()|0;ub(g);break Q}e=N()|0;break Q}e=N()|0}Qc(d+184|0);break b}Sf(d+20|0);continue}}e=0}ie(d+204|0)}fb=d+240|0;return e|0}e=N()|0;break b}e=N()|0;break f}e=N()|0;ub(d+184|0);break f}e=N()|0;break f}e=N()|0;break f}e=N()|0;break b}e=N()|0}ub(d+48|0);break b}e=N()|0;ub(d+112|0);break b}e=N()|0;break b}e=N()|0;ub(d+184|0)}ie(d+204|0)}Q(e|0);p()}function Xua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;d=fb-416|0;fb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!Ci(b,d+408|0)){break F}if(!z0(d+408|0)){break F}if(!c){r=1;break F}s=Ge(d+388|0,b);x[31725]=0;O(265,d+376|0,s|0);b=x[31725];x[31725]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){x[31725]=0;S(266,d+208|0,d+376|0,1229866575);b=x[31725];x[31725]=0;if((b|0)==1){break da}x[31725]=0;r=P(267,d+208|0,d+366|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break fa}ub(d+208|0);if(!r){break G}x[31725]=0;O(248,a|0,524288);b=x[31725];x[31725]=0;ga:{if((b|0)==1){break ga}gg(a);x[a+480208>>2]=12;B=a,C=Kd(Bb(z[d+374>>1]),1,127),w[B+480188>>1]=C;B=d,C=Bb(z[d+366>>1]),w[B+208>>1]=C;w[d+320>>1]=255;B=a,C=z[Nc(d+208|0,d+320|0)>>1],w[B+480192>>1]=C;B=d,C=Bb(z[d+368>>1]),w[B+208>>1]=C;w[d+320>>1]=3999;B=a,C=z[Nc(d+208|0,d+320|0)>>1],w[B+480190>>1]=C;x[31725]=0;b=U(268,a+1074312|0,6,1)|0;e=x[31725];x[31725]=0;if((e|0)==1){break ga}x[31725]=0;b=P(269,b|0,21)|0;e=x[31725];x[31725]=0;if((e|0)==1){break ga}x[31725]=0;P(269,b|0,13)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break ea}}b=N()|0;break b}b=N()|0;break a}b=N()|0;ub(d+208|0);break b}x[31725]=0;b=P(1,d+352|0,9282)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}Ab(a+1298344|0,b);tb(b);x[31725]=0;b=P(1,d+340|0,10317)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}Ab(a+1298356|0,b);tb(b);x[31725]=0;O(270,d+320|0,4336);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;O(271,d+300|0,d+412|0);b=x[31725];x[31725]=0;if((b|0)==1){break g}x[31725]=0;O(271,d+264|0,d+413|0);b=x[31725];x[31725]=0;if((b|0)==1){break i}x[31725]=0;V(91,d+208|0,d+320|0,d+300|0,d+264|0);b=x[31725];x[31725]=0;if((b|0)==1){break j}b=d+208|0;Ab(a+1298368|0,b);tb(b);tb(d+264|0);tb(d+300|0);e=d+320|0;Eb(e);B=a+1298404|0,C=x[Fc(b,28)>>2],x[B>>2]=C;x[31725]=0;S(266,e|0,d+376|0,1312902469);b=x[31725];x[31725]=0;if((b|0)==1){break k}x[31725]=0;b=R(156,x[d+320>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break m}x[31725]=0;f=a+1298308|0;S(272,d+320|0,f|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break m}x[31725]=0;S(266,d+300|0,d+376|0,1397706311);b=x[31725];x[31725]=0;if((b|0)==1){break n}lj(Xb(x[a+484360>>2],y[a+484376|0]));e=a+484360|0;g=Bb(z[d+370>>1]);while(1){ha:{if(g>>>0<=(h&65535)>>>0){break ha}x[31725]=0;b=U(152,x[d+300>>2],x[d+308>>2],46)|0;i=x[31725];x[31725]=0;ia:{if((i|0)!=1){if(!b){break ha}x[31725]=0;O(273,d+300|0,d+208|0);b=x[31725];x[31725]=0;if((b|0)!=1){if(!Ad(x[a+1298312>>2],y[a+1298319|0])){break ia}x[31725]=0;O(274,f|0,d+208|0);b=x[31725];x[31725]=0;if((b|0)!=1){break ia}}b=N()|0;break o}b=N()|0;break o}x[31725]=0;i=R(275,d+300|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break ca}b=Xb(x[a+484360>>2],y[a+484376|0]);if(!lc(x[b>>2],x[b+4>>2])){x[31725]=0;b=R(276,e|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break ca}if((b|0)==255){break ha}b=Xb(x[a+484360>>2],y[a+484376|0])}x[31725]=0;O(277,d+288|0,d+208|0);j=x[31725];x[31725]=0;if((j|0)==1){break ca}j=b;b=d+288|0;wp(j,b);tb(b);b=y[a+484376|0];j=x[a+484360>>2];x[31725]=0;S(278,Xb(j,b)|0,d+300|0,i|0);b=x[31725];x[31725]=0;if((b|0)==1){break ca}h=h+1|0;continue}break}ek(e,0);x[31725]=0;S(266,d+264|0,d+376|0,1229869908);b=x[31725];x[31725]=0;if((b|0)==1){break ba}x[31725]=0;b=R(279,x[d+264>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break p}ja:{if(!b){break ja}h=1;ka:{while(1){b=h&65535;if(b>>>0>z[a+480192>>1]){x[31725]=0;S(266,d+188|0,d+376|0,1447382614);b=x[31725];x[31725]=0;if((b|0)!=1){break ka}break p}x[31725]=0;O(280,d+264|0,d+208|0);e=x[31725];x[31725]=0;if((e|0)==1){break p}e=y[d+238|0]|y[d+239|0]<<8;x[31725]=0;b=U(253,a|0,b|0,Bb(e)|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break p}la:{ma:{if(!b){break ma}if(Bb(y[d+238|0]|y[d+239|0]<<8)>>>0>3999){break ma}e=d+112|0;vE(e,2,d+208|0);x[31725]=0;O(220,d+132|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break la}e=d+132|0;zc(b+492|0,e);tb(e);f=d+112|0;vE(f,2,d+208|0);x[31725]=0;O(220,e|0,f|0);e=x[31725];x[31725]=0;if((e|0)==1){break p}e=d+132|0;zc(((Bb(y[d+238|0]|y[d+239|0]<<8)<<5)+a|0)+946304|0,e);tb(e);x[b>>2]=0;B=b,C=xe((y[d+254|0]|y[d+255|0]<<8)<<16>>16)+128&65535,x[B+8>>2]=C;wc(b+8|0,256);v[b+15|0]=y[b+15|0]|1;b=y[d+238|0]|y[d+239|0]<<8;x[31725]=0;b=D(Bb(b),104)+a|0;O(281,b+484380|0,0);e=x[31725];x[31725]=0;if((e|0)==1){break p}B=d,C=Bb(y[d+240|0]|y[d+241|0]<<8),w[B+132>>1]=C;w[d+112>>1]=64;B=b+484410|0,C=z[Nc(d+132|0,d+112|0)>>1]<<2,w[B>>1]=C;f=b+484404|0;e=$b(y[d+242|0]|y[d+243|0]<<8|(y[d+244|0]<<16|y[d+245|0]<<24));g=ova(e,e>>31,8303,0);e=hb;g=g+4181|0;e=g>>>0<4181?e+1|0:e;B=f,C=Gc(pva(g,e,8363,0),hb),x[B>>2]=C;e=$b(y[d+250|0]|y[d+251|0]<<8|(y[d+252|0]<<16|y[d+253|0]<<24));if(!e){break ma}f=Bb(y[d+256|0]|y[d+257|0]<<8);if(!(f&3)){break ma}g=e;e=$b(y[d+246|0]|y[d+247|0]<<8|(y[d+248|0]<<16|y[d+249|0]<<24));x[b+484388>>2]=g+e;x[b+484384>>2]=e;b=b+484414|0;e=z[b>>1];w[b>>1]=e|2;if(!(f&2)){break ma}w[b>>1]=e|6}h=h+1|0;continue}break}break p}b=x[d+200>>2];x[d+32>>2]=x[d+196>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+204>>2];x[31725]=0;b=x[d+192>>2];x[d+24>>2]=x[d+188>>2];x[d+28>>2]=b;V(282,d+24|0,0,a|0,0);b=x[31725];x[31725]=0;if((b|0)==1){break p}x[31725]=0;S(266,d+168|0,d+376|0,1346719318);b=x[31725];x[31725]=0;if((b|0)==1){break p}b=x[d+180>>2];x[d+8>>2]=x[d+176>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+184>>2];x[31725]=0;b=x[d+172>>2];x[d>>2]=x[d+168>>2];x[d+4>>2]=b;V(282,d|0,1,a|0,y[d+412|0]>2|0);b=x[31725];x[31725]=0;if((b|0)==1){break p}b=z[a+480192>>1]+1&65535;f=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(f|0)){break ja}e=x[((b<<2)+a|0)+900380>>2];if(!(!e|v[e+60|0]&1)){x[e>>2]=32767}b=b+1|0;continue}}ub(d+264|0);x[31725]=0;S(266,d+208|0,d+376|0,1346458708);b=x[31725];x[31725]=0;if((b|0)==1){break q}x[31725]=0;b=R(174,x[d+208>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break s}if(!(!(c&1)|b^1)){x[31725]=0;S(266,d+264|0,d+376|0,1347305805);b=x[31725];x[31725]=0;if((b|0)==1){break t}x[31725]=0;P(185,d+264|0,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}b=z[d+372>>1];x[31725]=0;n=a+484344|0;O(225,n|0,Bb(b)|0);b=x[31725];x[31725]=0;if((b|0)==1){break v}l=Nb(d+152|0);j=0;while(1){if(Bb(z[d+372>>1])>>>0<=m>>>0){md(l);f=j;ub(d+264|0);if(!(c&4)){break $}e=0;if(!t){break aa}g=z[a+480188>>1];b=0;e=1;while(1){if((b|0)==(g|0)){break aa}i=(b<<5)+a|0;v[i+480288|0]=1;i=i+480280|0;x[i>>2]=x[i>>2]|67108864;b=b+1|0;continue}}x[31725]=0;b=R(275,d+208|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break x}x[31725]=0;e=R(283,d+208|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break y}x[31725]=0;S(187,d+112|0,d+208|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break z}e=d+112|0;k=ic(d+132|0,e);ub(e);x[31725]=0;e=U(198,n|0,m&65535,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break B}na:{if(e){q=Fb(d+100|0);x[31725]=0;O(284,d+264|0,q|0);e=x[31725];x[31725]=0;if((e|0)==1){break C}e=x[n>>2];x[31725]=0;O(285,Wb(e,m)|0,q|0);e=x[31725];x[31725]=0;if((e|0)==1){break C}o=0;e=Wb(x[n>>2],m);cf(d+88|0,x[e>>2],x[x[e+48>>2]+12>>2],0);lj(l);u=(b>>>0<=1?1:b)-1|0;oa:while(1){b=x[k>>2];x[31725]=0;b=U(152,b|0,x[d+140>>2],1)|0;e=x[31725];x[31725]=0;if((e|0)==1){break na}pa:{if(!b){break pa}x[31725]=0;b=R(199,k|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break C}if(!b){B=d,C=wb(x[l>>2]),x[B+84>>2]=C;e=wb(x[l+4>>2]);while(1){b=x[d+84>>2];if(Ib(b,e)){ye(Wb(x[n>>2],m),Ye(Ne(d+112|0,y[b|0],y[b+1|0]),o));Md(d+84|0);continue}else{lj(l);if((o|0)==(u|0)){break pa}b=Wb(x[n>>2],m);o=o+1|0;cf(d+112|0,x[b>>2],x[x[b+48>>2]+12>>2],o);b=x[d+116>>2];x[d+88>>2]=x[d+112>>2];x[d+92>>2]=b;continue oa}}}w[d+116>>1]=0;x[d+112>>2]=0;g=d+112|0;if(b>>>0<=z[a+480188>>1]){g=Wc(x[d+88>>2],b-1|0)}x[31725]=0;b=R(199,k|0)|0;e=x[31725];x[31725]=0;qa:{ra:{if((e|0)!=1){sa:{if(!(b&1)){break sa}x[31725]=0;e=R(199,k|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break C}if((e|0)!=31){if((e-1&255)>>>0>252){break sa}e=(D(e>>>4|0,12)+(e&15)|0)+13|0}else{e=255}v[g|0]=e}if(!(b&2)){break qa}x[31725]=0;e=R(199,k|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break ra}}break C}v[g+1|0]=e}if(!(b&60)){continue}e=0;h=0;if(b&4){x[31725]=0;h=R(199,k|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break C}}if(b&8){x[31725]=0;e=R(199,k|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break C}}i=0;f=0;if(b&16){x[31725]=0;f=R(199,k|0)|0;A=x[31725];x[31725]=0;if((A|0)==1){break C}}if(b&32){x[31725]=0;i=R(199,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break C}}b=d+84|0;w0(b,f,i);f=Jc(b);b=d+82|0;w0(b,h,e);e=Jc(b);b=y[d+82|0];ta:{if((b|0)!=13){if(b){break ta}b=0;if(y[d+84|0]==13){break ta}}tg(d+84|0,d+82|0);tg(f,e);b=y[d+82|0]}Hn(d+80|0,g,y[d+84|0],y[f|0],b&255,y[e|0]);if(v0(y[d+80|0],y[d+81|0])){b=x[vb(d+76|0,wb(x[l>>2]))>>2];x[31725]=0;S(286,l|0,b|0,d+80|0);b=x[31725];x[31725]=0;if((b|0)==1){break C}}b=y[g+3|0];if((b|0)==43){t=1;continue}if((b|0)!=31){continue}j=1;continue}break}tb(q)}ub(k);m=m+1|0;continue}break}break C}f=0;e=0;if(c&4){break aa}break H}b=N()|0;break b}b=N()|0;break o}b=N()|0;break o}x[d+152>>2]=-1778364416;x[d+156>>2]=-16756736;x[31725]=0;S(266,d+264|0,d+376|0,1146310725);b=x[31725];x[31725]=0;if((b|0)==1){break E}x[31725]=0;b=R(279,x[d+264>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break D}if(b){x[31725]=0;j=R(275,d+264|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break D}b=0;i=e;while(1){ua:{if((b|0)==(j|0)){x[31725]=0;O(287,d+264|0,d+152|0);b=x[31725];x[31725]=0;if((b|0)!=1){break ua}break D}x[31725]=0;g=R(199,d+264|0)|0;h=x[31725];x[31725]=0;va:{wa:{if((h|0)!=1){if(z[a+480188>>1]<=b>>>0){break va}if(!e){break wa}h=((b<<5)+a|0)+480280|0;x[h>>2]=x[h>>2]&-67108865|((g|0)!=0)<<26;break va}break D}if(g){break va}i=1;v[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}e=i&1}ub(d+264|0);if(!e){break $}b=vd(a+906300|0,0);x[31725]=0;W(288,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break _}x[b+16>>2]=810369604;x[b+20>>2]=1869112133;x[b+24>>2]=655376;x[b+28>>2]=0;x[d+264>>2]=0;g=b+48|0;s0(b+32|0,g,d+264|0);x[31725]=0;e=P(36,d+132|0,9571)|0;i=x[31725];x[31725]=0;if((i|0)==1){break Z}tE(g,e);tb(e);x[31725]=0;e=P(36,d+112|0,9535)|0;g=x[31725];x[31725]=0;if((g|0)==1){break Y}mw(b+80|0,e);tb(e);x[31725]=0;O(289,b+4|0,8);e=x[31725];x[31725]=0;if((e|0)==1){break _}r0(d+264|0,y[d+153|0],y[d+155|0],y[d+157|0],y[d+159|0]);e=x[d+268>>2];b=x[b+4>>2];g=x[d+264>>2];v[b|0]=g;v[b+1|0]=g>>>8;v[b+2|0]=g>>>16;v[b+3|0]=g>>>24;v[b+4|0]=e;v[b+5|0]=e>>>8;v[b+6|0]=e>>>16;v[b+7|0]=e>>>24}if(!f){break H}e=a+902204|0;b=0;while(1){if((b|0)==32){break H}x[d+88>>2]=D(b,127)>>>5;x[31725]=0;O(290,d+152|0,4093);f=x[31725];x[31725]=0;if((f|0)==1){break X}x[31725]=0;O(291,d+100|0,d+88|0);f=x[31725];x[31725]=0;if((f|0)==1){break W}x[31725]=0;S(292,d+264|0,d+152|0,d+100|0);f=x[31725];x[31725]=0;if((f|0)==1){break V}f=d+264|0;ee(d+68|0,f);sf(Oe(e,b),x[d+68>>2],x[d+72>>2]);tb(f);tb(d+100|0);f=d+152|0;Eb(f);x[31725]=0;O(290,f|0,4075);f=x[31725];x[31725]=0;if((f|0)==1){break T}x[31725]=0;O(291,d+100|0,d+88|0);f=x[31725];x[31725]=0;if((f|0)==1){break S}x[31725]=0;S(292,d+264|0,d+152|0,d+100|0);f=x[31725];x[31725]=0;if((f|0)==1){break R}f=d+264|0;ee(d+60|0,f);sf(Oe(e,b+32|0),x[d+60>>2],x[d+64>>2]);tb(f);tb(d+100|0);f=d+152|0;Eb(f);x[31725]=0;O(290,f|0,4066);f=x[31725];x[31725]=0;if((f|0)==1){break P}x[31725]=0;O(291,d+100|0,d+88|0);f=x[31725];x[31725]=0;if((f|0)==1){break O}x[31725]=0;S(292,d+264|0,d+152|0,d+100|0);f=x[31725];x[31725]=0;if((f|0)==1){break N}f=d+264|0;ee(d+52|0,f);sf(Oe(e,b- -64|0),x[d+52>>2],x[d+56>>2]);tb(f);tb(d+100|0);f=d+152|0;Eb(f);x[31725]=0;O(290,f|0,4039);f=x[31725];x[31725]=0;if((f|0)==1){break L}x[31725]=0;O(291,d+100|0,d+88|0);f=x[31725];x[31725]=0;if((f|0)==1){break K}x[31725]=0;S(292,d+264|0,d+152|0,d+100|0);f=x[31725];x[31725]=0;if((f|0)==1){break J}f=d+264|0;ee(d+44|0,f);sf(Oe(e,b+96|0),x[d+44>>2],x[d+48>>2]);b=b+1|0;tb(f);tb(d+100|0);Eb(d+152|0);continue}}b=N()|0;break r}b=N()|0;break r}b=N()|0;break r}b=N()|0;break r}b=N()|0;break U}b=N()|0;tb(d+100|0)}Eb(d+152|0);break r}b=N()|0;break r}b=N()|0;break Q}b=N()|0;tb(d+100|0)}Eb(d+152|0);break r}b=N()|0;break r}b=N()|0;break M}b=N()|0;tb(d+100|0)}Eb(d+152|0);break r}b=N()|0;break r}b=N()|0;break I}b=N()|0;tb(d+100|0)}Eb(d+152|0);break r}x[31725]=0;S(266,d+264|0,d+376|0,1397575756);b=x[31725];x[31725]=0;xa:{if((b|0)!=1){x[31725]=0;b=R(174,x[d+264>>2])|0;e=x[31725];x[31725]=0;if((e|0)!=1){ya:{h=1;if(!(c&2)|b^1){break xa}while(1){c=h&65535;if(c>>>0>z[a+480190>>1]){break xa}x[31725]=0;b=R(283,d+264|0)|0;e=x[31725];x[31725]=0;za:{if((e|0)!=1){x[31725]=0;e=R(283,d+264|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break ya}if(!(b&7)){break za}c=(D(c,104)+a|0)+484380|0;x[c>>2]=e;b=Xc(d+152|0,b&4?32:b&2?16:8,1,1,0);x[31725]=0;U(217,b|0,c|0,d+264|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break za}break ya}break ya}h=h+1|0;continue}}}b=N()|0;ub(d+264|0);break r}b=N()|0;break r}ub(d+264|0);ub(d+208|0);ub(d+300|0);ub(d+320|0)}ie(d+376|0);ub(s)}fb=d+416|0;return r|0}b=N()|0;break r}b=N()|0;ub(d+264|0);break r}b=N()|0;tb(q);break A}b=N()|0}ub(k);break w}b=N()|0;break w}b=N()|0;break w}b=N()|0}md(l);break u}b=N()|0}ub(d+264|0);break r}b=N()|0;break r}b=N()|0}ub(d+208|0);break o}b=N()|0;break o}b=N()|0;ub(d+264|0)}ub(d+300|0);break l}b=N()|0;break l}b=N()|0}ub(d+320|0);break b}b=N()|0;break b}b=N()|0;tb(d+264|0);break h}b=N()|0}tb(d+300|0);break f}b=N()|0}Eb(d+320|0);break b}b=N()|0;break b}b=N()|0;break b}b=N()|0}ie(d+376|0)}ub(s);Q(b|0);p()}function Spa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=fb-336|0;fb=d;xc(b);a:{if(!op(b,d+324|0)){break a}if(!GX(d+324|0)){break a}q=Ge(d+304|0,b);o=Nb(d+292|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!c){x[31725]=0;O(665,d+40|0,q|0);b=x[31725];x[31725]=0;if((b|0)==1){break v}break x}x[31725]=0;O(666,d+40|0,q|0);b=x[31725];x[31725]=0;if((b|0)==1){break w}}b=d+40|0;zv(o,b);ie(b);x[31725]=0;S(667,b|0,o|0,1413891155);b=x[31725];x[31725]=0;y:{z:{if((b|0)!=1){x[31725]=0;e=P(668,d+40|0,14138)|0;b=x[31725];x[31725]=0;if((b|0)==1){break z}ub(d+40|0);if((c|0)!=0&e){break y}break b}b=N()|0;break c}b=N()|0;ub(d+40|0);break c}x[31725]=0;O(248,a|0,4194304);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[a+480208>>2]=12;x[31725]=0;S(667,d+272|0,o|0,1280592212);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(156,x[d+272>>2])|0;k=x[31725];x[31725]=0;if((k|0)==1){break g}x[31725]=0;S(457,d+272|0,a+1298308|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break g}lj(Xb(x[a+484360>>2],y[a+484376|0]));k=Nb(d+260|0);v[d+259|0]=0;v[d+258|0]=0;x[31725]=0;S(669,d+244|0,o|0,1196314451);b=x[31725];x[31725]=0;if((b|0)==1){break i}m=a+484360|0;s=d,t=wb(x[d+244>>2]),x[s+240>>2]=t;f=d+228|0;l=wb(x[d+248>>2]);A:{while(1){b=x[d+240>>2];if(!Ib(b,l)){break A}j=Ge(d+40|0,b);x[31725]=0;e=P(670,j|0,d+28|0)|0;b=x[31725];x[31725]=0;B:{C:{if((b|0)!=1){b=1;if(!(e&y[d+37|0]==1)){break B}s=a,t=Kd(y[d+38|0],z[a+480188>>1],127),w[s+480188>>1]=t;x[31725]=0;h=R(671,d+184|0)|0;b=x[31725];x[31725]=0;D:{E:{F:{if((b|0)!=1){b=d+172|0;df(b,d+28|0,9,1);x[31725]=0;O(220,d+136|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break F}b=d+16|0;gc(b,f,10);e=b;b=d+136|0;um(e,b);tb(b);b=Xb(x[a+484360>>2],y[a+484376|0]);if(lc(x[b>>2],x[b+4>>2])){break D}x[31725]=0;b=R(276,m|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break m}if((b|0)!=255){break E}b=2;break C}b=N()|0;break k}b=N()|0;break l}b=Xb(x[a+484360>>2],y[a+484376|0])}x[31725]=0;O(672,d+160|0,f|0);e=x[31725];x[31725]=0;if((e|0)==1){break m}e=b;b=d+160|0;wp(e,b);tb(b);x[31725]=0;O(666,d+172|0,j|0);b=x[31725];x[31725]=0;if((b|0)!=1){s=d,t=wb(x[d+172>>2]),x[s+156>>2]=t;r=wb(x[d+176>>2]);while(1){G:{H:{I:{J:{K:{b=x[d+156>>2];if(Ib(b,r)){tp(d+136|0,b);xi(d+16|0,x[b>>2],x[b+4>>2]);e=x[d+16>>2];if((e|0)==1212960847){break K}b=0;if((e|0)!=1312903248){break G}while(1){e=b&65535;if(e>>>0>=z[a+480188>>1]){break G}x[31725]=0;i=U(152,x[d+136>>2],x[d+144>>2],2)|0;g=x[31725];x[31725]=0;if((g|0)==1){break I}if(!i){break G}x[31725]=0;O(200,d+8|0,d+136|0);i=x[31725];x[31725]=0;if((i|0)!=1){DC(h,e,y[d+8|0],y[Jc(d+8|0)|0],d+259|0,k);b=b+1|0;continue}break}break I}b=0;if(z[d+220>>1]==65535|z[d+222>>1]==65535){break J}b=y[a+484376|0];e=x[a+484360>>2];x[31725]=0;W(673,Xb(e,b)|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=0;x[31725]=0;O(674,k|0,h|0);e=x[31725];x[31725]=0;if((e|0)!=1){break J}}b=N()|0;break H}if(A[d+20>>2]<9){break G}e=0;x[31725]=0;P(185,d+136|0,2)|0;b=x[31725];x[31725]=0;i=65535;L:{if((b|0)!=1){while(1){x[31725]=0;b=U(152,x[d+136>>2],x[d+144>>2],1)|0;g=x[31725];x[31725]=0;M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((g|0)!=1){if(!b){break G}x[31725]=0;g=R(199,d+136|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break I}b=4;switch(g|0){case 0:break G;case 14:break N;case 13:break O;case 12:break Q;case 8:break R;case 7:break S;case 2:break T;case 6:break U;case 5:break V;case 3:case 4:break W;case 1:break X;default:break P}}break I}b=Xb(x[a+484360>>2],y[a+484376|0]);if(z[d+220>>1]==65535){s=d,t=mm(x[b>>2],x[b+4>>2]),w[s+220>>1]=t}b=mm(x[b>>2],x[b+4>>2]);x[31725]=0;w[d+222>>1]=b;b=P(675,d+136|0,d+258|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break I}Y:{Z:{switch(b-254|0){case 1:b=65535;break Y;case 0:break Z;default:break Y}}b=65534}g=y[a+484376|0];n=x[a+484360>>2];x[31725]=0;O(538,Xb(n,g)|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break I}i=(i&65535)==65535?e:i;break M}x[31725]=0;b=R(191,d+136|0)|0;n=x[31725];x[31725]=0;if((n|0)!=1){_:{if(b>>>0<(i&65535)>>>0){b=z[d+224>>1];break _}b=b-i|0;w[d+224>>1]=b}bf(Xb(x[a+484360>>2],y[a+484376|0]),b&65535);if((g|0)!=3){break M}x[31725]=0;P(185,d+136|0,1)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break M}}break I}x[31725]=0;O(200,d+8|0,d+136|0);b=x[31725];x[31725]=0;if((b|0)!=1){DC(h,y[d+8|0],y[Jc(d+8|0)|0],-1,d+259|0,k);break M}break I}b=1}x[31725]=0;P(185,d+136|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break M}break I}x[31725]=0;b=R(199,d+136|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break I}v[d+227|0]=b;break M}x[31725]=0;b=R(199,d+136|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break I}v[d+226|0]=b;break M}x[31725]=0;b=P(641,d+136|0,d+8|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break I}if(y[d+8|0]|!b|(y[d+10|0]|y[d+9|0]!=255)){break P}if(y[d+11|0]|y[d+12|0]!=1){break P}if(!y[d+13|0]){break M}}ub(d+136|0);b=1;break J}x[31725]=0;O(550,d+8|0,d+136|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=d+8|0;g=Jc(b);DC(h,y[d+8|0],y[af(b)|0],y[g|0],d+259|0,k);break M}break I}x[31725]=0;O(200,d+8|0,d+136|0);b=x[31725];x[31725]=0;if((b|0)==1){break L}b=x[d+196>>2];n=Sc(b,x[d+200>>2]);g=y[d+8|0];if(n>>>0<=g>>>0){break M}n=Jc(d+8|0);s=xb(b,g),t=(y[n|0]>>>2|0)+1|0,v[s|0]=t}e=e+1|0;continue}}break I}break I}ie(d+172|0);break C}b=N()|0;ub(d+136|0)}ie(d+172|0);break l}ub(d+136|0);nm(d+156|0);continue}}b=N()|0;break l}b=N()|0;break k}hr(h)}ub(j);if(!b){Sf(d+240|0);continue}break}e=0;if((b|0)!=2){break s}}e=0;ek(m,0);b=x[k>>2];if(lc(b,x[k+4>>2])){break s}if(!(c&2)){break t}x[31725]=0;S(669,d+136|0,o|0,1347244868);b=x[31725];x[31725]=0;$:{if((b|0)!=1){s=d,t=wb(x[d+136>>2]),x[s+16>>2]=t;e=a+480190|0;h=d+53|0;i=d+57|0;j=wb(x[d+140>>2]);m=y[d+258|0];while(1){b=x[d+16>>2];if(!Ib(b,j)){Qc(d+136|0);b=x[k>>2];break t}aa:{ba:{ca:{if(!m){x[31725]=0;f=P(676,b|0,d+40|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break aa}if(!f){break ba}f=y[d+92|0]|y[d+93|0]<<8;g=f+1|0;w[d+8>>1]=g;if(f>>>0>3998){break ca}s=a,t=z[qe(e,d+8|0)>>1],w[s+480190>>1]=t;x[31725]=0;O(677,d+40|0,(D(g&65535,104)+a|0)+484380|0);f=x[31725];x[31725]=0;if((f|0)==1){break aa}f=d+28|0;EX(f,h);x[31725]=0;O(220,d+172|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break u}f=d+172|0;zc(((z[d+8>>1]<<5)+a|0)+946304|0,f);tb(f);break ca}x[31725]=0;f=P(678,b|0,d+40|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break u}if(!f){break ba}f=y[d+96|0]|y[d+97|0]<<8;g=f+1|0;w[d+8>>1]=g;if(f>>>0>3998){break ca}s=a,t=z[qe(e,d+8|0)>>1],w[s+480190>>1]=t;x[31725]=0;O(679,d+40|0,(D(g&65535,104)+a|0)+484380|0);f=x[31725];x[31725]=0;if((f|0)==1){break u}f=d+28|0;EX(f,i);x[31725]=0;O(220,d+172|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break $}f=d+172|0;zc(((z[d+8>>1]<<5)+a|0)+946304|0,f);tb(f)}f=z[d+8>>1];if((f-1&65535)>>>0>3998){break ba}g=Xc(d+40|0,8,1,0,2);x[31725]=0;U(217,g|0,(D(f,104)+a|0)+484380|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break ba}break u}Sf(d+16|0);continue}break}break u}b=N()|0;break j}break u}b=N()|0;break c}b=N()|0;break c}b=N()|0;Qc(d+136|0);break j}b=CC(b,0);x[a+480196>>2]=y[b+43|0];x[a+480204>>2]=D(y[b+42|0],1e4);bf(Xb(x[a+484360>>2],y[a+484376|0]),z[b+40>>1]);b=0;while(1){if(z[a+480188>>1]>b>>>0){e=(b<<5)+a|0;h=e+480280|0;Xe(h);i=CC(x[k>>2],0);s=e+480286|0,t=y[xb(x[i+12>>2],b)|0],w[s>>1]=t;s=e+480284|0,t=y[xb(x[i>>2],b)|0],w[s>>1]=t;Jb(d+40|0,x[i+24>>2],b);s=h,t=x[h>>2]&-257|(Hb(x[x[d+40>>2]>>2],x[d+44>>2])?256:0),x[s>>2]=t;b=b+1|0;continue}break}x[31725]=0;b=P(1,d+172|0,(y[d+258|0]?17157:17014)|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break n}Ab(a+1298344|0,b);tb(b);x[31725]=0;b=P(1,d+28|0,10137)|0;e=x[31725];x[31725]=0;if((e|0)==1){break o}Ab(a+1298356|0,b);tb(b);s=a+1298404|0,t=x[Fc(d+40|0,4)>>2],x[s>>2]=t;e=1;if(!(c&1)|!z[a+480188>>1]){break s}x[31725]=0;S(669,d+16|0,o|0,1146045008);b=x[31725];x[31725]=0;if((b|0)==1){break p}b=x[d+20>>2];c=x[d+16>>2];x[31725]=0;i=a+484344|0;O(225,i|0,Uf(c,b)&65535);b=x[31725];x[31725]=0;if((b|0)==1){break r}s=d,t=wb(x[d+16>>2]),x[s+240>>2]=t;g=wb(x[d+20>>2]);while(1){h=x[d+240>>2];if(!Ib(h,g)){da:{ea:{b=x[k>>2];e=x[k+4>>2];if(yv(b,e)>>>0<2){break ea}m=y[d+259|0];c=0;while(1){if(yv(b,e)>>>0<=c>>>0){break ea}g=x[a+484344>>2];l=x[a+484348>>2];j=Xj(x[a+484360>>2],c&255);n=x[j>>2];h=CC(b,c);f=z[h+36>>1];if(He(g,l,z[_b(n,f)>>1])){x[31725]=0;e=P(370,j|0,f|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break da}fa:{if(!m){break fa}b=0;while(1){if(z[a+480188>>1]<=b>>>0){break fa}f=BC(x[h+24>>2],b);j=Wb(x[i>>2],e);ga:{if(f){ye(j,Zh(pp(Ye(Ne(d+40|0,20,145),0),b&65535)));break ga}ye(j,Zh(pp(Ye(Ne(d+40|0,9,y[xb(x[h>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;ye(Wb(x[i>>2],e),Zh(Ye(Ne(b,16,y[h+43|0]),0)));ye(Wb(x[i>>2],e),Zh(Ye(Ne(b,17,y[h+42|0]),0)));e=x[k+4>>2];b=x[k>>2]}c=c+1|0;continue}}Qc(d+16|0);e=1;break s}b=N()|0;break q}b=x[h>>2];x[31725]=0;b=R(156,b|0)|0;c=x[31725];x[31725]=0;ha:{ia:{ja:{ka:{la:{ma:{na:{if((c|0)==1){break na}x[31725]=0;c=R(153,h|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break na}if((b|0)!=(c|0)){break ha}b=x[h>>2];x[31725]=0;b=P(680,b|0,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break na}if(!b){break ha}x[31725]=0;m=P(675,h|0,d+258|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break ia}x[31725]=0;f=R(191,h|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break ja}x[31725]=0;b=U(198,i|0,m|0,f|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ja}if(!b){break ha}j=0;while(1){if((f|0)==(j|0)){break ha}b=Wb(x[i>>2],m);cf(d+8|0,x[b>>2],x[x[b+48>>2]+12>>2],j);x[31725]=0;b=R(191,h|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ma}oa:{if(b>>>0>=3){x[31725]=0;S(187,d+136|0,h|0,b-2|0);b=x[31725];x[31725]=0;if((b|0)==1){break ka}b=d+136|0;e=ic(d+40|0,b);ub(b);while(1){b=x[e>>2];x[31725]=0;b=U(152,b|0,x[d+48>>2],3)|0;c=x[31725];x[31725]=0;if((c|0)==1){break oa}if(b){x[31725]=0;O(200,d+136|0,e|0);b=x[31725];x[31725]=0;pa:{qa:{ra:{sa:{if((b|0)!=1){w[d+156>>1]=z[a+480188>>1]-1;s=d,t=y[Jc(d+136|0)|0],w[s+6>>1]=t;c=Wc(x[d+8>>2],z[Nc(d+156|0,d+6|0)>>1]);b=v[d+136|0];if((b|0)>=0){break pa}x[31725]=0;b=R(199,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break la}if(y[d+258|0]){break ra}if((b|0)!=255){break sa}b=254;break qa}break la}if(b>>>0>128){break qa}b=(D(b>>>4|0,12)+(b&15)|0)+13|0;break qa}b=b>>>0<85?b+36|0:b}v[c|0]=b;b=y[d+136|0]}if(b&64){x[31725]=0;b=R(199,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break la}v[c+1|0]=b+1;b=y[d+136|0]}if(b&32){x[31725]=0;b=R(199,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break la}v[d+156|0]=b;v[c+2|0]=1;v[d+6|0]=127;s=c,t=y[Rb(d+156|0,d+6|0)|0]+1>>>1|0,v[s+4|0]=t;b=y[d+136|0]}if(!(b&16)){continue}x[31725]=0;O(200,d+156|0,e|0);b=x[31725];x[31725]=0;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{if((b|0)!=1){b=y[Jc(d+156|0)|0];v[c+5|0]=b;switch(y[d+156|0]-1|0){case 72:break ua;case 71:break va;case 70:break wa;case 61:break xa;case 60:break ya;case 53:break za;case 52:break Aa;case 51:break Ba;case 50:break Da;case 43:break Ea;case 42:break Fa;case 41:break Ga;case 40:break Ha;case 31:break Ia;case 30:break Ja;case 23:break Ka;case 22:break La;case 21:break Ma;case 20:break Na;case 18:break Oa;case 17:break Pa;case 15:break Qa;case 16:break Ra;case 14:break Sa;case 13:break Ta;case 12:break Ua;case 11:break Va;case 10:break Wa;case 3:break Xa;case 2:break Ya;case 1:break Za;case 0:break _a;default:break ta}}break la}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b<<4|15;continue}v[c+5|0]=b<<3|15;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b<<4;continue}v[c+5|0]=b<<3&240;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b|240;continue}v[c+5|0]=b>>>1|240;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b&15;continue}if(b>>>0<=1){v[c+5|0]=b|240;continue}v[c+5|0]=b>>>1&15;continue}v[c+3|0]=2;s=c,t=xv(b,y[d+258|0])|240,v[s+5|0]=t;continue}v[c+3|0]=2;s=c,t=xv(b,y[d+258|0]),v[s+5|0]=t;continue}v[c+3|0]=3;s=c,t=xv(b,y[d+258|0])|240,v[s+5|0]=t;continue}v[c+3|0]=3;s=c,t=xv(b,y[d+258|0]),v[s+5|0]=t;continue}v[c+3|0]=4;if(y[d+258|0]){continue}v[c+5|0]=(b&252)>>>2;continue}v[c+3|0]=20;v[c+5|0]=b&1|16;continue}v[c+3|0]=6;v[c+5|0]=b&240;continue}v[c+3|0]=6;v[c+5|0]=(b&240)>>>4;continue}v[c+3|0]=20;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=b&15|48;continue}v[c+3|0]=7;v[c+5|0]=b|240;continue}v[c+3|0]=7;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=b&15|64;continue}v[c+3|0]=10;x[31725]=0;b=R(199,e|0)|0;l=x[31725];x[31725]=0;if((l|0)!=1){break Ca}break la}v[c+3|0]=15;continue}v[c+3|0]=20;v[c+5|0]=b&15|192;continue}v[c+3|0]=20;v[c+5|0]=b&15|208;continue}v[c+3|0]=12;b=(b&254)>>>1|0}v[c+5|0]=b;x[31725]=0;P(185,e|0,1)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}break la}v[c+5|0]=0;v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=b&15|176;continue}v[c+3|0]=20;v[c+5|0]=b&15|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=b&15|32;continue}v[c+3|0]=20;v[c+5|0]=b&15|128;continue}v[c+3|0]=0;continue}break}ub(e)}j=j+1|0;continue}break}break la}b=N()|0;break q}b=N()|0;break q}b=N()|0;ub(e);break q}b=N()|0;break q}b=N()|0;break q}b=N()|0;break q}Sf(d+240|0);continue}}Qc(d+244|0);DX(k);ub(d+272|0);break b}b=N()|0}Qc(d+16|0);break j}b=N()|0;break j}b=N()|0;break j}b=N()|0;break j}b=N()|0}hr(h)}ub(j)}Qc(d+244|0);break h}b=N()|0}DX(k);break f}b=N()|0}ub(d+272|0);break c}b=N()|0;break c}b=N()|0}ie(o);ub(q);Q(b|0);p()}ie(o);ub(q)}fb=d+336|0;return e|0}function ypa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;e=fb-304|0;fb=e;xc(b);a:{if(!Av(b,e+208|0)){break a}if(!mX(e+208|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(lX(e+208|0),hb))){break a}b:{if(!c){break b}Bd(a,2);x[a+480260>>2]=64;x[a+480264>>2]=32767;i=Fb(e+196|0);d=y[e+248|0]|y[e+249|0]<<8;l=(d|0)==20479?y[e+262|0]|y[e+263|0]<<8:d-16464|0;c:{d:{e:{f:{g:{h:{i:{j:{switch(d>>>12|0){case 0:if((d|0)!=520){break e}x[31725]=0;d=P(1,e+184|0,12377)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(i,d);break f}f=N()|0;break c;case 1:k:{if((d|0)!=4896){break k}d=y[e+270|0]|y[e+271|0]<<8;if(d){break k}if(!((y[e+246|0]|y[e+247|0]<<8)&65455|(y[e+260|0]|y[e+240|0]&15))){l:{if(v[e+259|0]<0){x[a+1074308>>2]=18219008;x[31725]=0;d=P(1,e+184|0,14771)|0;g=x[31725];x[31725]=0;if((g|0)!=1){break l}f=N()|0;break c}x[a+1074308>>2]=16777216;x[31725]=0;d=P(1,e+184|0,13445)|0;g=x[31725];x[31725]=0;if((g|0)==1){break i}}Ab(i,d);tb(d);x[31725]=0;f=1;U(268,a+1074312|0,81,1)|0;d=x[31725];x[31725]=0;g=1;if((d|0)!=1){break e}break d}if(y[e+260|0]|d|(y[e+261|0]|(y[e+246|0]|y[e+247|0]<<8))){break k}x[31725]=0;d=P(1,e+184|0,9476)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(i,d);break f}f=N()|0;break c}x[31725]=0;d=P(1,e+184|0,8494)|0;f=x[31725];x[31725]=0;h=1;if((f|0)!=1){Ab(i,d);tb(d);break g}f=N()|0;break c;case 2:x[31725]=0;d=P(1,e+184|0,6808)|0;f=x[31725];x[31725]=0;g=1;if((f|0)!=1){Ab(i,d);tb(d);break g}f=N()|0;break c;case 3:m:{n:{o:{p:{if(d>>>0<=12820){x[31725]=0;g=P(1,e+184|0,8557)|0;f=x[31725];x[31725]=0;if((f|0)!=1){Ab(i,g);tb(g);break p}f=N()|0;break c}x[31725]=0;O(447,e+184|0,4015);g=x[31725];x[31725]=0;if((g|0)==1){break o}x[31725]=0;x[e+172>>2]=(y[e+248|0]|y[e+249|0]<<8)-12820;S(448,e+48|0,e+184|0,e+172|0);g=x[31725];x[31725]=0;if((g|0)==1){break n}g=e+48|0;Ab(i,g);tb(g);Eb(e+184|0)}g=y[e+248|0]|y[e+249|0]<<8;if(g>>>0<12807){break h}f=y[e+264|0]|y[e+265|0]<<8|(y[e+266|0]<<16|y[e+267|0]<<24);if(f){break m}break h}f=N()|0;break c}f=N()|0;Eb(e+184|0);break c}g=GF(g,f);f=rp(e+48|0);x[f+32>>2]=g;x[31725]=0;O(449,a+1298412|0,f|0);g=x[31725];x[31725]=0;if((g|0)!=1){break h}f=N()|0;break c;case 4:if((d|0)==16640){x[31725]=0;d=P(1,e+184|0,8340)|0;h=x[31725];x[31725]=0;g=1;if((h|0)!=1){Ab(i,d);tb(d);x[31725]=0;U(268,a+1074312|0,81,1)|0;d=x[31725];x[31725]=0;h=0;if((d|0)==1){break d}break e}f=N()|0;break c}x[31725]=0;S(444,e+48|0,d|0,y[e+262|0]|y[e+263|0]<<8);d=x[31725];x[31725]=0;q:{r:{s:{if((d|0)!=1){d=e+48|0;Ab(i,d);tb(d);x[a+480260>>2]=1;if((l|0)<4201){break s}x[31725]=0;U(268,a+1074312|0,7,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}break r}f=N()|0;break c}if((l|0)<2386){break q}}x[31725]=0;U(268,a+1074312|0,38,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}}x[31725]=0;P(269,a+1074312|0,118)|0;d=x[31725];x[31725]=0;g=1;j=1;if((d|0)==1){break d}break e;case 5:if((d|0)!=21575){d=d&4095;x[a+1074308>>2]=d<<16|(d>>>0>296?y[e+262|0]|y[e+263|0]<<8:0)&65535;x[31725]=0;d=P(1,e+184|0,18237)|0;g=x[31725];x[31725]=0;t:{u:{v:{if((g|0)!=1){g=x[a+1074308>>2];x[31725]=0;O(136,e+172|0,g|0);g=x[31725];x[31725]=0;if((g|0)==1){break v}x[31725]=0;S(2,e+48|0,d|0,e+172|0);g=x[31725];x[31725]=0;if((g|0)==1){break u}g=e+48|0;Ab(i,g);tb(g);tb(e+172|0);break f}f=N()|0;break c}f=N()|0;break t}f=N()|0;tb(e+172|0)}tb(d);break c}x[31725]=0;d=P(1,e+184|0,8541)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(i,d);break f}f=N()|0;break c;case 6:x[31725]=0;d=P(1,e+184|0,8340)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(i,d);tb(d);x[31725]=0;U(268,a+1074312|0,81,1)|0;d=x[31725];x[31725]=0;g=0;if((d|0)==1){break d}break e}f=N()|0;break c;case 7:x[31725]=0;d=P(1,e+184|0,8352)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(i,d);break f}f=N()|0;break c;default:break j}}if((d|0)!=51712){break e}x[31725]=0;d=P(1,e+184|0,9275)|0;g=x[31725];x[31725]=0;if((g|0)!=1){Ab(i,d);break f}f=N()|0;break c}f=N()|0;break c}x[31725]=0;g=U(268,a+1074312|0,7,1)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}x[31725]=0;g=U(268,g|0,23,1)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}x[31725]=0;g=U(268,g|0,38,1)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}x[31725]=0;U(268,g|0,107,1)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}g=1;x[a+480260>>2]=1;f=0;if(d>>>0>12820){break e}}x[31725]=0;W(696,e+172|0);d=x[31725];x[31725]=0;w:{x:{y:{if((d|0)!=1){d=y[e+248|0]|y[e+249|0]<<8;x[e+148>>2]=d>>>8&15;x[31725]=0;x[e+132>>2]=d&255;O(446,e+160|0,e+132|0);d=x[31725];x[31725]=0;if((d|0)==1){break y}f=0;x[31725]=0;aa(697,e+48|0,e+172|0,i|0,e+148|0,e+160|0);d=x[31725];x[31725]=0;if((d|0)==1){break x}d=e+48|0;Ab(i,d);tb(d);tb(e+160|0);Eb(e+172|0);break e}f=N()|0;break c}f=N()|0;break w}f=N()|0;tb(e+160|0)}Eb(e+172|0);break c}tb(d);g=0}x[31725]=0;d=P(1,e+172|0,15026)|0;m=x[31725];x[31725]=0;z:{A:{B:{C:{D:{E:{F:{G:{if((m|0)!=1){Ab(a+1298344|0,d);tb(d);x[31725]=0;d=P(1,e+160|0,10474)|0;m=x[31725];x[31725]=0;if((m|0)==1){break G}Ab(a+1298356|0,d);tb(d);o=Ab(a+1298368|0,i);A=a+1298404|0,B=x[Fc(e+48|0,x[a+1074308>>2]?22:4)>>2],x[A>>2]=B;if(g){x[31725]=0;d=P(269,a+1074312|0,77)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[31725]=0;d=P(269,d|0,78)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[31725]=0;d=P(269,d|0,79)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[31725]=0;d=P(269,d|0,80)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[31725]=0;d=P(269,d|0,82)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[31725]=0;d=P(269,d|0,96)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[31725]=0;P(269,d|0,113)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}}d=y[e+248|0]|y[e+249|0]<<8;if(d>>>0<=4865){x[31725]=0;P(269,a+1074312|0,118)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}d=y[e+248|0]|y[e+249|0]<<8}g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|(d&65535)>>>0>12819|f}x[31725]=0;d=a+901404|0;W(698,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break d}if(!f){sr(d)}d=e+148|0;bj(d,1,e+208|0);x[31725]=0;O(220,e+48|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break D}d=e+48|0;Ab(a+1298308|0,d);tb(d);d=y[e+246|0]|y[e+247|0]<<8;if(d&16){x[a+480208>>2]=x[a+480208>>2]|65536}if(d&1){x[a+480208>>2]=x[a+480208>>2]|131072}g=y[e+248|0]|y[e+249|0]<<8;if(!(!(d&64)&(g|0)!=4864)){x[a+480208>>2]=x[a+480208>>2]|2}d=y[e+257|0];x[a+480196>>2]=d;if(!(!h|(d|0)!=255?d:0)){x[a+480196>>2]=6}d=y[e+258|0];x[a+480204>>2]=d>>>0<33?h?125e4:32e4:D(d,1e4);v[e+48|0]=y[e+256|0];v[e+148|0]=64;d=y[Rb(e+48|0,e+148|0)|0];x[a+480200>>2]=d<<2;if(!(d|g>>>0>4895)){x[a+480200>>2]=256}f=y[e+259|0];if((y[e+250|0]|y[e+251|0]<<8)!=1|f>>>0>7){break F}x[e+48>>2]=(f<<4)+16;x[e+148>>2]=127;g=x[ud(e+48|0,e+148|0)>>2];break E}f=N()|0;break c}f=N()|0;break c}g=32;if((f|16)==18){break E}d=f&127;g=48;if(!d){break E}x[e+48>>2]=d;x[e+148>>2]=16;g=x[Ze(e+48|0,e+148|0)>>2]}x[a+480228>>2]=g;d=0;m=x[a+1074308>>2]!=0|f<<24>>24<0;if(!m){A=a,B=Bc(qva(g<<3|5,g>>>29|0,11,0),hb),x[A+480228>>2]=B}w[a+480188>>1]=4;x[a+480232>>2]=j?(l|0)<3299?64:36:36;g=sc(e+144|0);while(1){if((d|0)==32){if(!z[a+480188>>1]){w[a+480188>>1]=1}d=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;aa(350,Xb(f,d)|0,b|0,y[e+240|0]|y[e+241|0]<<8,255,254);d=x[31725];x[31725]=0;if((d|0)!=1){m=Nb(e+148|0);x[31725]=0;U(215,b|0,m|0,y[e+242|0]|y[e+243|0]<<8)|0;d=x[31725];x[31725]=0;if((d|0)!=1){q=Nb(e+132|0);x[31725]=0;U(215,b|0,q|0,y[e+244|0]|y[e+245|0]<<8)|0;d=x[31725];x[31725]=0;H:{if((d|0)!=1){if(y[e+261|0]!=252){break C}d=0;x[31725]=0;O(699,b|0,e+48|0);f=x[31725];x[31725]=0;if((f|0)==1){break H}while(1){if((d|0)==32){break C}f=y[(e+48|0)+d|0];I:{if(!(f&32)){break I}if(h){Pc(e+36|0,g,d);if(Hb(x[x[e+36>>2]>>2],x[e+40>>2])){break I}}w[((d<<5)+a|0)+480284>>1]=(((f&15)<<8|8)>>>0)/15}d=d+1|0;continue}}f=N()|0;break B}f=N()|0;break B}f=N()|0;break A}f=N()|0;break c}f=(d<<5)+a|0;l=f+480280|0;Xe(l);j=y[(d+e|0)+272|0];q=j&126;J:{if((j|0)!=255){j=j<<24>>24;w[a+480188>>1]=d+1;if(m){w[f+480284>>1]=j&8?204:51}if((j|0)>=0){break J}}x[l>>2]=1024}if((q-16&255)>>>0<=13){w[f+480284>>1]=128;f=e+48|0;Pc(f,g,d);hp(f)}d=d+1|0;continue}}f=N()|0;break c}w[e+48>>1]=y[e+242|0]|y[e+243|0]<<8;w[e+36>>1]=3999;f=z[Nc(e+48|0,e+36|0)>>1];w[a+480190>>1]=f;r=c&2;s=e+96|0;d=0;j=0;g=0;l=0;K:{L:{M:{N:{O:{P:{Q:{R:{S:{while(1){if((f&65535)>>>0<=d>>>0){if(!(!(h&j)|l&65535)&(y[e+248|0]|y[e+249|0]<<8)!=4864){break Q}if(!h){break P}x[31725]=0;d=l&65535;f=U(268,a+1074312|0,79,d>>>0>1|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break N}x[31725]=0;d=d>>>0<2;f=U(268,f|0,107,d|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break N}x[31725]=0;U(268,f|0,38,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break N}x[31725]=0;d=l&65535;P(129,o|0,(d>>>0>1?17201:17208)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break N}if(d>>>0<2){break P}x[a+480228>>2]=48;break P}f=_b(x[m>>2],d);f=y[f|0]|y[f+1|0]<<8;x[31725]=0;f=P(151,b|0,f<<4)|0;n=x[31725];x[31725]=0;if((n|0)==1){break L}T:{U:{if(!f){break U}x[31725]=0;f=P(700,b|0,e+48|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break L}if(!f){break U}x[31725]=0;f=d+1|0;n=(D(f,104)+a|0)+484380|0;S(701,e+48|0,n|0,h|0);k=x[31725];x[31725]=0;if((k|0)==1){break L}k=e+24|0;bj(k,1,s);x[31725]=0;O(220,e+36|0,k|0);k=x[31725];x[31725]=0;if((k|0)==1){break T}k=((f<<5)+a|0)+946304|0;f=e+36|0;zc(k,f);tb(f);if(y[e+48|0]>1){break U}V:{if(!r|!(y[e+64|0]|y[e+65|0]<<8|(y[e+66|0]<<16|y[e+67|0]<<24))){break V}f=jX(e+48|0);x[31725]=0;f=P(151,b|0,f|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break S}if(!f){break V}f=e+36|0;iX(f,y[e+78|0],y[e+79|0],(y[e+250|0]|y[e+251|0]<<8)==1);x[31725]=0;U(217,f|0,n|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break R}g=y[e+39|0]==10|g;j=1}l=y[e+88|0]|y[e+89|0]<<8|l}d=d+1|0;f=z[a+480190>>1];continue}break}f=N()|0;break B}f=N()|0;break B}f=N()|0;break B}x[31725]=0;d=P(1,e+48|0,9750)|0;f=x[31725];x[31725]=0;if((f|0)==1){break O}Ab(o,d);tb(d)}if(g&1){break M}break K}f=N()|0;break B}f=N()|0;break B}x[31725]=0;d=P(1,e+36|0,17141)|0;g=x[31725];x[31725]=0;W:{if((g|0)!=1){x[31725]=0;P(76,o|0,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break W}tb(d);break K}f=N()|0;break B}f=N()|0;tb(d);break B}f=N()|0;break B}if(!(c&1)){break z}c=y[e+248|0]|y[e+249|0]<<8;w[e+24>>1]=y[e+244|0]|y[e+245|0]<<8;w[e+16>>1]=255;s=z[Nc(e+24|0,e+16|0)>>1];x[31725]=0;f=a+484344|0;O(225,f|0,s|0);d=x[31725];x[31725]=0;if((d|0)!=1){n=c>>>0<4896;j=0;o=0;r=0;X:{Y:{while(1){if((j|0)==(s|0)){if(!n){break z}a=z[a+480188>>1];if((a|0)>(o+r|0)|(a|0)<=(o-r|0)){break z}c=fb-16|0;fb=c;a=wb(x[f>>2]);x[c+12>>2]=a;d=wb(x[f+4>>2]);while(1){if(Ib(a,d)){b=wb(x[a>>2]);g=wb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=b;while(1){if(Ib(b,g)){if(y[b+3|0]==31){v[b+3|0]=20;v[b+5|0]=y[b+5|0]|128}b=x[vg(a+12|0)>>2];continue}break}fb=a+16|0;a=x[bm(c+12|0)>>2];continue}else{fb=c+16|0}break}break z}x[31725]=0;c=U(198,f|0,j&65535,64)|0;d=x[31725];x[31725]=0;Z:{if((d|0)==1){break Z}_:{if(!c){break _}c=_b(x[q>>2],j);c=y[c|0]|y[c+1|0]<<8;if(!c){break _}x[31725]=0;c=P(151,b|0,c<<4)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Z}if(!c){break _}x[31725]=0;P(185,b|0,2)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Z}d=0;c=Wb(x[f>>2],j);cf(e+24|0,x[c>>2],x[x[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break _}c=d;x[31725]=0;d=R(199,b|0)|0;g=x[31725];x[31725]=0;$:{if((g|0)!=1){d=d<<24>>24;if(d){break $}d=64;if(c>>>0>62){continue}d=Wb(x[f>>2],j);g=x[d>>2];h=x[x[d+48>>2]+12>>2];d=c+1|0;cf(e+16|0,g,h,d);c=x[e+20>>2];x[e+24>>2]=x[e+16>>2];x[e+28>>2]=c;continue}f=N()|0;break B}g=ch(e+16|0);k=d&31;if(k>>>0<z[a+480188>>1]){g=Wc(x[e+24>>2],k)}t=d&255;if(t&32){x[31725]=0;O(200,e+14|0,b|0);h=x[31725];x[31725]=0;aa:{ba:{ca:{if((h|0)!=1){u=Jc(e+14|0);h=y[e+14|0];if(h>>>0>239){break ca}h=hX((D(h>>>4|0,12)+(h&15)|0)+13|0);break ba}f=N()|0;break B}da:{switch(h-254|0){case 0:break ba;case 1:break da;default:break aa}}h=0}v[g|0]=h}v[g+1|0]=y[u|0]}if(t&64){x[31725]=0;h=R(199,b|0)|0;t=x[31725];x[31725]=0;if((t|0)==1){break Y}h=h<<24>>24;v[e+14|0]=h;ea:{if((h|0)<=-64){v[g+2|0]=2;h=h^-128;break ea}v[g+2|0]=1;v[e+13|0]=64;h=y[Rb(e+14|0,e+13|0)|0]}v[g+4|0]=h}fa:{if((d|0)>=0){break fa}x[31725]=0;O(200,e+14|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break X}xD(g,y[e+14|0],y[Jc(e+14|0)|0],0);d=y[g+3|0];ga:{if((d|0)!=10){if((d|0)!=31){if((d|0)!=20){break fa}d=y[g+5|0];if((d&240)!=160|(y[e+248|0]|y[e+249|0]<<8)>>>0>4895){break fa}if((l&65535)>>>0>1){break ga}h=y[(e+k|0)+272|0]&127;if(h>>>0>=16){break ga}ha:{switch(d-160|0){case 0:case 2:v[g+5|0]=h&8?-116:-125;break fa;case 1:case 3:v[g+5|0]=h&8?-125:-116;break fa;default:break ha}}if(d>>>0>167){break ga}v[g+5|0]=136;break fa}d=y[g+5|0];if(d>>>0>15){n=0;break fa}if(d>>>0<=7){r=r+1|0;break fa}o=((d|0)!=8)+o|0;break fa}if(y[g+5|0]|(y[e+248|0]|y[e+249|0]<<8)>>>0>4865){break fa}}v[g+3|0]=37}d=c;continue}}j=j+1|0;continue}break}f=N()|0;break B}f=N()|0;break B}f=N()|0;break B}f=N()|0}md(q)}md(m);break c}md(q);md(m);tb(i);break b}f=N()|0}tb(i);Q(f|0);p()}d=1}fb=e+304|0;return d|0}function npa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,V=0;d=fb-480|0;fb=d;xc(b);k=fb-16|0;fb=k;g=d+276|0;TW(k+8|0,g);h=x[k+12>>2];l=b;kc(k,x[b>>2],x[b+8>>2],x[k+8>>2],x[k+12>>2]);b=x[k+4>>2];if((b|0)==(h|0)){Vb(l,x[k+12>>2])}fb=k+16|0;b=(b|0)==(h|0);if(!b){SW(g)}a:{if(!b){break a}if(!UW(d+276|0)){break a}if(!c){e=1;break a}Bd(a,134217728);b=d+8|0;ig(b,3953);x[31725]=0;S(704,d+116|0,b|0,y[d+280|0]|y[d+281|0]<<8);b=x[31725];x[31725]=0;b:{c:{d:{if((b|0)!=1){b=d+116|0;Ab(a+1298344|0,b);tb(b);Eb(d+8|0);k=tc(b,8974);Ab(a+1298356|0,k);tb(k);T=a+1298404|0,V=x[Fc(b,28)>>2],x[T>>2]=V;x[a+480188>>2]=4;T=a,V=Bb(y[d+412|0]|y[d+413|0]<<8),x[T+480196>>2]=V;b=y[d+416|0]|y[d+417|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;T=a,V=RW(Bb(b)),x[T+480204>>2]=V;jw(Xb(x[a+484360>>2],y[a+484376|0]),d+284|0,y[d+282|0]);n=a+480190|0;m=a+480188|0;o=Nb(d+264|0);t=Nb(d+252|0);e:{while(1){f:{g:{h:{i:{j:{k:{l:{if(Bb(y[d+476|0]|y[d+477|0]<<8)>>>0>(f&65535)>>>0){x[31725]=0;b=R(275,l|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break i}w[d+228>>1]=b;if((b-4e3&65535)>>>0<=61536){break c}e=Bb(y[d+478|0]|y[d+479|0]<<8);if((Bb(y[d+280|0]|y[d+281|0]<<8)|0)==2){x[31725]=0;b=R(283,l|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break j}e=b-2|0}x[31725]=0;S(187,d+8|0,l|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break k}b=d+8|0;g=ic(d+116|0,b);ub(b);B=z[qe(n,d+228|0)>>1];w[a+480190>>1]=B;x[31725]=0;e=D(z[d+228>>1],104)+a|0;h=e+484380|0;O(281,h|0,1);b=x[31725];x[31725]=0;m:{n:{o:{if((b|0)==1){break o}if(Bb(y[d+280|0]|y[d+281|0]<<8)>>>0>1){break n}x[31725]=0;O(705,g|0,e+484423|0);b=x[31725];x[31725]=0;if((b|0)==1){break o}x[31725]=0;P(185,g|0,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break o}x[31725]=0;S(333,g|0,((z[d+228>>1]<<5)+a|0)+946304|0,30);b=x[31725];x[31725]=0;if((b|0)!=1){break m}}h=N()|0;break f}b=Fb(d+8|0);x[31725]=0;S(360,g|0,b|0,257);k=x[31725];x[31725]=0;p:{q:{if((k|0)==1){break q}ze(e+484423|0,b);x[31725]=0;P(185,g|0,1)|0;k=x[31725];x[31725]=0;if((k|0)==1){break q}x[31725]=0;S(360,g|0,b|0,31);k=x[31725];x[31725]=0;if((k|0)==1){break q}zc(((z[d+228>>1]<<5)+a|0)+946304|0,b);if(!(v[d+124|0]&1)){break p}x[31725]=0;P(185,g|0,1)|0;k=x[31725];x[31725]=0;if((k|0)!=1){break p}}h=N()|0;tb(b);break f}tb(b)}x[31725]=0;O(706,g|0,d+8|0);b=x[31725];x[31725]=0;r:{if((b|0)==1){break r}j=fb-16|0;fb=j;k=$b(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24));x[h>>2]=k;v[j+15|0]=y[d+12|0];v[j+14|0]=64;T=h,V=y[Rb(j+15|0,j+14|0)|0]<<2,w[T+30>>1]=V;i=$b(y[d+14|0]|y[d+15|0]<<8|(y[d+16|0]<<16|y[d+17|0]<<24));x[h+4>>2]=i;b=$b(y[d+14|0]|y[d+15|0]<<8|(y[d+16|0]<<16|y[d+17|0]<<24))+$b(y[d+18|0]|y[d+19|0]<<8|(y[d+20|0]<<16|y[d+21|0]<<24))|0;x[h+8>>2]=b;if(i>>>0>=k>>>0){i=k-1|0;x[h+4>>2]=i}if(b>>>0>k>>>0){x[h+8>>2]=k;b=k}s:{if(b>>>0<i>>>0){x[h+4>>2]=0;x[h+8>>2]=0;break s}if(b>>>0<=i>>>0){break s}w[h+34>>1]=z[h+34>>1]|2;T=yb(h+68|0,0),V=i,x[T>>2]=V}fb=j+16|0;t:{switch(Bb(y[d+280|0]|y[d+281|0]<<8)|0){case 2:v[e+484417|0]=y[d+26|0]<<3;break;case 0:break g;default:break t}}x[31725]=0;O(212,t|0,B|0);b=x[31725];x[31725]=0;if((b|0)==1){break r}x[31725]=0;O(707,o|0,B|0);b=x[31725];x[31725]=0;if((b|0)==1){break r}k=Hd(x[o>>2],z[d+228>>1]-1|0);OW(k);x[31725]=0;b=R(275,l|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break l}h=x[l+8>>2];j=x[l>>2];x[31725]=0;h=U(152,j|0,h|0,b<<3)|0;j=x[31725];x[31725]=0;if((j|0)==1){break l}if(h){x[31725]=0;O(708,k|0,b|0);h=x[31725];x[31725]=0;if((h|0)==1){break l}x[d+248>>2]=0;if(!(y[e+484414|0]&2)|b){break h}b=x[e+484384>>2];x[d+240>>2]=b;h=x[e+484388>>2];x[31725]=0;x[d+244>>2]=h-b;O(709,k|0,d+240|0);b=x[31725];x[31725]=0;if((b|0)!=1){break g}h=N()|0;break f}ub(g);break c}h=N()|0;break f}u:{v:{w:{x:{if(Bb(y[d+280|0]|y[d+281|0]<<8)){u=y[d+283|0];w[d+238>>1]=4;C=128;break x}x[31725]=0;C=R(275,l|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){h=N()|0;break e}b=y[d+280|0]|y[d+281|0]<<8;u=y[d+283|0];w[d+238>>1]=4;if(!Bb(b)){break w}}k=x[l+8>>2];h=0;while(1){y:{if((h&65535)>>>0>=C>>>0){break y}x[31725]=0;b=R(275,l|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break v}if((b|0)==65535){break y}x[31725]=0;u=R(275,l|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}x[31725]=0;b=R(275,l|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break v}w[d+238>>1]=b;if(b>>>0>127){break c}T=m,V=z[qe(m,d+238|0)>>1],w[T>>1]=V;x[31725]=0;P(185,l|0,D(b,u)<<2)|0;b=x[31725];x[31725]=0;if((b|0)==1){break v}h=h+1|0;continue}break}x[31725]=0;P(151,l|0,k|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break u}}b=z[m>>1];x[31725]=0;E=P(710,d+240|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){J=a+484344|0;M=c&1;F=Bb(y[d+414|0]|y[d+415|0]<<8);b=0;k=0;while(1){z:{A:{B:{C:{if((b&65535)>>>0>=C>>>0){break C}D:{if(!Bb(y[d+280|0]|y[d+281|0]<<8)){e=z[d+238>>1];h=b;break D}x[31725]=0;h=R(275,l|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break z}if((h|0)==65535){break C}x[31725]=0;u=R(275,l|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break z}x[31725]=0;e=R(275,l|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break z}w[d+238>>1]=e}g=x[l+8>>2];f=x[l>>2];x[31725]=0;i=g;G=u&65535;g=G<<2;e=U(152,f|0,i|0,D(g,e&65535)|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break z}if(!e){break C}if(!M){break B}x[31725]=0;K=h&65535;h=U(198,J|0,K|0,G|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break z}if(!h){break B}r=0;E:while(1){if((r|0)==(G|0)){break A}h=Wb(x[J>>2],K);cf(d+228|0,x[h>>2],x[x[h+48>>2]+12>>2],r);h=0;s=0;F:{G:{switch((F&3)-1|0){case 0:s=!(r&3);break F;case 1:s=!(r&1);break F;case 2:break G;default:break F}}s=(r&3)!=3}H=0;while(1){if(z[d+238>>1]<=h>>>0){r=r+1|0;continue E}e=x[E>>2];g=Wc(x[d+228>>2],h);x[31725]=0;O(359,d+224|0,l|0);f=x[31725];x[31725]=0;if((f|0)==1){break z}j=D(h,9)+e|0;e=d+224|0;f=Jc(e);q=af(e);v[g+1|0]=y[d+224|0];i=y[f|0];v[g|0]=i;f=y[fj(e)|0];v[g+5|0]=f;m=g+5|0;if(i){v[g|0]=i+25;v[j+8|0]=0;v[j|0]=0;v[j+1|0]=0;v[j+2|0]=0;v[j+3|0]=0;v[j+4|0]=0;v[j+5|0]=0;v[j+6|0]=0;v[j+7|0]=0;f=y[g+5|0]}i=f&255;q=y[q|0];H:{I:{if(q>>>0>=240){e=i|(q&15)<<8;if(e){v[g+3|0]=17;T=g,V=gm(+(RW(e)>>>0)/1e4),v[T+5|0]=V;i=0;break H}break I}I=i>>>4|0;L=i<<4;e=I|L;J:{switch(q|0){case 0:if(f&255){v[g+3|0]=1;i=0;break H}break I;case 1:v[g+3|0]=2;i=0;break H;case 2:v[g+3|0]=3;i=0;break H;case 3:v[d+220|0]=15;T=j,V=y[Rb(m,d+220|0)|0]|16,v[T|0]=V;v[j+7|0]=0;v[j+1|0]=0;v[j+2|0]=0;break I;case 4:v[d+220|0]=15;T=j,V=y[Rb(m,d+220|0)|0]|32,v[T|0]=V;v[j+7|0]=0;v[j+1|0]=0;v[j+2|0]=0;break I;case 5:v[j+7|0]=0;v[j+2|0]=0;v[j+1|0]=f;v[j|0]=0;break I;case 6:v[j+7|0]=0;v[j+2|0]=f;v[j|0]=0;v[j+1|0]=0;break I;case 7:v[g+3|0]=23;i=0;k=0;break H;case 8:v[g+3|0]=0;i=1;k=e;break H;case 9:v[g+3|0]=19;v[d+220|0]=15;T=g,V=y[Rb(m,d+220|0)|0]|16,v[T+5|0]=V;i=0;break H;case 10:v[g+3|0]=19;v[d+220|0]=15;T=g,V=y[Rb(m,d+220|0)|0]|32,v[T+5|0]=V;i=0;break H;case 11:v[j+3|0]=e;break I;case 12:v[g+4|0]=f;i=1;v[g+2|0]=1;v[j+3|0]=0;v[g+3|0]=0;break H;case 13:K:{L:{if((f&255)>>>0>=16){v[g+2|0]=4;f=(f&240)>>>4|0;break L}if(!(i&15)){break K}v[g+2|0]=3}v[g+4|0]=f}v[j+3|0]=0;break I;case 14:v[g+3|0]=19;v[g+5|0]=!(f&255);i=0;break H;case 15:v[g+3|0]=16;v[g+5|0]=(f&240)>>>4;F=f&15;i=0;break H;case 16:v[j+5|0]=0;v[j+4|0]=f;break I;case 17:v[j+6|0]=i&15?f:0;break I;case 18:v[g+3|0]=14;i=0;break H;case 19:v[j+8|0]=0;v[j+7|0]=f;v[j+2|0]=0;v[j|0]=0;v[j+1|0]=0;break I;case 20:v[g+3|0]=12;i=0;break H;case 22:e=y[g+1|0];M:{if(!e){break M}i=x[o>>2];if(Ud(i,x[o+4>>2])>>>0<e>>>0){break M}f=f-1|0;v[m|0]=f;x[31725]=0;R(711,d+116|0)|0;q=x[31725];x[31725]=0;if((q|0)==1){break z}x[d+220>>2]=9;e=Hd(i,e-1|0);T=d,V=Ud(x[e>>2],x[e+4>>2]),x[T+112>>2]=V;if(A[Gb(d+220|0,d+112|0)>>2]<=(f&255)>>>0){break M}v[g+2|0]=15;v[g+4|0]=y[g+5|0]}break I;case 23:e=y[g+1|0];N:{if(!e){break N}i=x[o>>2];if(Ud(i,x[o+4>>2])>>>0<e>>>0){break N}f=f-1|0;v[m|0]=f;e=Hd(i,e-1|0);i=x[e>>2];q=Ud(i,x[e+4>>2]);e=f&255;if(q>>>0<=e>>>0){break N}e=Hd(i,e);f=z[e+8>>1];O:{if(f){break O}f=0;i=z[n>>1];if(!vi(i)){break O}f=i+1|0;w[n>>1]=f;w[e+8>>1]=f}v[g+1|0]=f}break I;case 24:e=y[g+1|0];P:{if(!e){break P}i=x[o>>2];if(Ud(i,x[o+4>>2])>>>0<e>>>0){break P}f=f-1|0;v[m|0]=f;x[31725]=0;R(711,d+8|0)|0;q=x[31725];x[31725]=0;if((q|0)==1){break z}x[d+220>>2]=9;e=Hd(i,e-1|0);T=d,V=Ud(x[e>>2],x[e+4>>2]),x[T+112>>2]=V;if(A[Gb(d+220|0,d+112|0)>>2]>(f&255)>>>0){v[g+2|0]=15;v[g+4|0]=y[g+5|0]}e=_b(x[t>>2],y[g+1|0]-1|0);f=z[e>>1];Q:{if(f){break Q}f=0;i=z[n>>1];if(!vi(i)){break Q}f=i+1|0;w[n>>1]=f;w[e>>1]=f}v[g+1|0]=f}break I;case 25:e=y[g+1|0];R:{if(!e){break R}i=x[o>>2];if(Ud(i,x[o+4>>2])>>>0<e>>>0){break R}f=f-1|0;v[m|0]=f;e=Hd(i,e-1|0);i=x[e>>2];q=Ud(i,x[e+4>>2]);e=f&255;if(q>>>0<=e>>>0){break R}e=Hd(i,e);f=z[e+10>>1];S:{if(f){break S}f=0;i=z[n>>1];if(!vi(i)){break S}f=i+1|0;w[n>>1]=f;w[e+10>>1]=f}v[g+1|0]=f}break I;case 29:v[g+5|0]=e;v[g+3|0]=11;if(i&15){v[m|0]=L|15;i=0;break H}i=0;if((f&255)>>>0<16){break H}v[m|0]=I|240;break H;case 32:if((f&255)>>>0>=16){v[j+3|0]=I;break I}v[g+3|0]=19;v[g+5|0]=f|192;i=0;break H;case 33:v[g+3|0]=19;v[d+220|0]=15;T=g,V=y[Rb(m,d+220|0)|0]|208,v[T+5|0]=V;i=0;break H;case 34:v[g+3|0]=19;v[d+220|0]=15;T=g,V=y[Rb(m,d+220|0)|0]|144,v[T+5|0]=V;i=0;break H;case 73:v[g+3|0]=10;i=0;break H;case 78:if((f&112|128)==224){v[g+3|0]=19;i=0;break H}break I;case 79:if((f&255)>>>0<=31){v[g+3|0]=16;i=0;F=0;break H}v[g+3|0]=17;i=0;break H;default:break J}}}v[g+3|0]=0;i=1}e=0;f=y[j+3|0];if(!(y[g+2|0]|!f)){e=f>>>0<16;v[g+4|0]=e?f:f>>>4|0;v[g+2|0]=e?6:5;e=1}T:{if(!i){break T}f=y[j+1|0];U:{if(f){v[g+3|0]=2;break U}f=y[j+2|0];if(f){v[g+3|0]=3;break U}f=y[j|0];if(f){v[g+3|0]=19;break U}f=y[j+7|0];if(f){v[g+3|0]=4;v[j+8|0]=f;break U}f=y[j+4|0];if(f){v[g+3|0]=5;v[j+5|0]=f;break U}f=e;e=y[j+3|0];if(!(f|!e)){v[g+5|0]=e;v[g+3|0]=11;if(e&15){f=e|-16;break U}if(e>>>0<16){break T}f=e|15;break U}f=y[j+6|0];if(f){v[g+3|0]=8;break U}if(s){v[g+3|0]=20;s=0;f=97;break U}s=0;e=k&255;if(!e|H){break T}v[g+5|0]=k;v[g+3|0]=24;if(k&15){f=k|-16}else{H=1;if(e>>>0<16){break T}f=k|15}H=1}v[m|0]=f}h=h+1|0;continue}}}x[a+480228>>2]=256/z[a+480188>>1];i=1;Yh(a,1);if(Bb(y[d+280|0]|y[d+281|0]<<8)){V:{while(1){b=x[l+8>>2];k=x[l>>2];x[31725]=0;b=U(152,k|0,b|0,2)|0;k=x[31725];x[31725]=0;if((k|0)==1){break z}if(!b){break V}x[31725]=0;b=R(275,l|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break z}if((b|0)==65535){break V}x[31725]=0;P(185,l|0,2)|0;b=x[31725];x[31725]=0;if((b|0)==1){break z}x[31725]=0;b=R(283,l|0)|0;k=x[31725];x[31725]=0;if((k|0)!=1){x[31725]=0;P(185,l|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break z}x[31725]=0;P(185,l|0,34)|0;b=x[31725];x[31725]=0;if((b|0)==1){break z}}W:{if(!(c&2)){break W}while(1){b=i&65535;if(b>>>0>B>>>0){break W}X:{h=(D(b,104)+a|0)+484380|0;if(!x[h>>2]){break X}c=Xc(d+228|0,8,1,0,0);x[31725]=0;U(217,c|0,h|0,l|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break z}c=x[o>>2];if(Ud(c,x[o+4>>2])>>>0<b>>>0){break X}j=b-1|0;g=Hd(c,j);c=0;b=0;m=fb-112|0;fb=m;Y:{f=x[h>>2];if(!je(f,x[h+20>>2])){break Y}r=x[g>>2];k=Ud(r,x[g+4>>2]);if(k>>>0<2){break Y}e=bp(m+8|0,h);x[e+20>>2]=0;x[e>>2]=0;Z:{while(1){if((c|0)==(k|0)){break Z}_:{n=Hd(r,c);s=x[n>>2];if(s>>>0>=f>>>0){break _}n=x[n+4>>2];if(n>>>0>f-s>>>0|268435456-n>>>0<b>>>0){break _}b=b+n|0;x[e>>2]=b;c=c+1|0;continue}break}k=c}if(!Fh(e)){break Y}n=e+68|0;b=0;c=0;while(1){if((c|0)==(k|0)){vn(h);b=bp(h,e);x[b+4>>2]=0;x[b+8>>2]=x[b>>2];w[b+34>>1]=z[b+34>>1]|2;break Y}r=x[e+20>>2]+b|0;s=x[h+20>>2];f=Hd(x[g>>2],c);yc(r,s+x[f>>2]|0,x[f+4>>2]);x[f>>2]=b;if(c-10>>>0>=4294967287){T=yb(n,c-1|0),V=b,x[T>>2]=V}c=c+1|0;b=x[f+4>>2]+b|0;continue}}fb=m+112|0;b=z[_b(x[t>>2],j)>>1];if(b){wC(h,(D(b,104)+a|0)+484380|0,0,x[h>>2],0)}b=Hd(x[o>>2],j);T=d,V=wb(x[b>>2]),x[T+228>>2]=V;c=wb(x[b+4>>2]);while(1){b=x[d+228>>2];if(!Ib(b,c)){break X}k=z[b+8>>1];if(k){wC(h,(D(k,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],1)}k=z[b+10>>1];if(k){wC(h,(D(k,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],0)}jl(d+228|0);continue}}i=i+1|0;continue}}QW(E);e=1;break b}x[31725]=0;P(185,l|0,D(g,z[d+238>>1])|0)|0;h=x[31725];x[31725]=0;if((h|0)!=1){break A}break z}b=b+1|0;continue}break}h=N()|0;QW(E);break e}h=N()|0;break e}h=N()|0;break e}h=N()|0;break e}h=N()|0;break f}h=N()|0;break e}h=N()|0;break e}h=N()|0;break e}e=0;while(1){if(b>>>0<=(e&65535)>>>0){break g}x[31725]=0;h=R(283,l|0)|0;j=x[31725];x[31725]=0;$:{if((j|0)==1){break $}x[31725]=0;x[d+240>>2]=h;h=R(283,l|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break $}x[31725]=0;x[d+244>>2]=h;O(709,k|0,d+240|0);h=x[31725];x[31725]=0;if((h|0)==1){break $}e=e+1|0;continue}break}h=N()|0;break f}ub(g);f=f+1|0;continue}break}ub(g)}md(t);PW(o);break d}h=N()|0;Eb(d+8|0)}Q(h|0);p()}e=0}md(t);PW(o)}fb=d+480|0;return e|0}function uoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;d=fb-576|0;fb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!yD(b,d+496|0)){break l}if(!NV(d+496|0)){break l}if(!Mb(x[b>>2],x[b+8>>2],Bc(MV(d+496|0),hb))){break l}if(!c){e=1;break l}Bd(a,4);gg(a);v[a+1074368|0]=4;l=Fb(d+484|0);k=d+534|0;m:{if(!(kd(k,18410,20)|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))!=276)){q=41144;e=48;if((y[d+554|0]|y[d+555|0]<<8)>>>0<260){break m}e=gu(d+513|0,0,20)?1154:34;break m}q=41144;if(!kd(k,18389,20)){e=1;break m}f=d+104|0;wi(f,3,k);x[31725]=0;S(371,d+192|0,4,f|0);f=x[31725];x[31725]=0;n:{if((f|0)!=1){f=d+192|0;Ab(l,f);tb(f);if((y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))!=1852141647|(y[k+4|0]|y[k+5|0]<<8|(y[k+6|0]<<16|y[k+7|0]<<24))!=542396493){break n}e=1048;break m}b=N()|0;break a}if(!kd(k,18137,12)){e=16;if((y[d+546|0]|y[d+547|0]<<8|(y[d+548|0]<<16|y[d+549|0]<<24))==538976288&(y[d+550|0]|y[d+551|0]<<8|(y[d+552|0]<<16|y[d+553|0]<<24))==538976288){break m}v[a+1074368|0]=5;break m}if(!kd(k,11657,20)){e=48;break m}if(!kd(k,25456,15)){x[31725]=0;f=P(269,a+1074312|0,54)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;P(269,f|0,51)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}q=41136;e=16;break m}o:{if(kd(k,25472,14)){if(kd(k,25487,14)){break o}}x[31725]=0;f=P(269,a+1074312|0,57)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;P(269,f|0,51)|0;f=x[31725];x[31725]=0;e=16;if((f|0)!=1){break m}break b}e=kd(k,18225,11)?16:256}f=d+104|0;u=d+513|0;wi(f,3,u);x[31725]=0;O(220,d+192|0,f|0);f=x[31725];x[31725]=0;p:{q:{r:{s:{t:{if((f|0)!=1){f=d+192|0;Ab(a+1298308|0,f);tb(f);x[a+480260>>2]=1;x[a+480264>>2]=31999;bf(Xb(x[a+484360>>2],y[a+484376|0]),y[d+562|0]|y[d+563|0]<<8);w[a+480188>>1]=y[d+564|0]|y[d+565|0]<<8;w[d+192>>1]=y[d+568|0]|y[d+569|0]<<8;w[d+104>>1]=255;G=a,H=z[Nc(f,d+104|0)>>1],w[G+480192>>1]=H;f=y[d+572|0]|y[d+573|0]<<8;if(f){x[a+480196>>2]=f}f=y[d+574|0]|y[d+575|0]<<8;if(f){f=D(f,1e4);f=f>>>0>=1e7?1e7:f;x[a+480204>>2]=f>>>0<=32e4?32e4:f}f=y[d+570|0]|y[d+571|0]<<8;x[a+480208>>2]=f<<4&16|f<<3&32768;g=x[a+484360>>2];m=y[a+484376|0];x[31725]=0;aa(350,Xb(g,m)|0,b|0,y[d+560|0]|y[d+561|0]<<8,65535,65535);g=x[31725];x[31725]=0;if((g|0)==1){break b}g=f>>>12&1?(e|0)==34?146:e:e;if(!(y[d+560|0]|y[d+561|0]<<8|g>>>0>1023)){f=y[a+484376|0];e=x[a+484360>>2];x[31725]=0;W(764,Xb(e,f)|0);f=x[31725];x[31725]=0;if((f|0)==1){break b}}x[31725]=0;P(151,b|0,(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))+60|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}if((y[d+554|0]|y[d+555|0]<<8)>>>0>=260){x[31725]=0;S(765,b|0,d+496|0,a|0);f=x[31725];x[31725]=0;if((f|0)==1){break b}}v[d+483|0]=0;B=c&2;F=d+122|0;n=d+225|0;m=Nb(d+468|0);r=1;f=-1;while(1){e=r&65535;if(e>>>0>z[a+480192>>1]){if(!(!(g&2)|s&255)){g=gu(u,0,20)?g|16:g}if((y[d+554|0]|y[d+555|0]<<8)>>>0>259){break r}if(c&3){x[31725]=0;S(765,b|0,d+496|0,a|0);c=x[31725];x[31725]=0;if((c|0)==1){break q}}if(!B){break r}e=1;while(1){c=e&65535;if(c>>>0>z[a+480190>>1]){break r}n=x[m>>2];x[31725]=0;U(217,yb(n,c-1|0)|0,(D(c,104)+a|0)+484380|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){e=e+1|0;continue}break}b=N()|0;break c}x[31725]=0;i=R(153,b|0)|0;h=x[31725];x[31725]=0;u:{v:{if((h|0)!=1){Gh(b,4);x[31725]=0;S(766,b|0,d+192|0,(i?i:263)|0);i=x[31725];x[31725]=0;if((i|0)==1){break s}w:{if((g|0)==1){i=x[d+192>>2];if((i|0)!=263){g=16;if((i|0)!=245){break w}x[a+1074308>>2]=16777381;x[31725]=0;g=P(1,d+180|0,13445)|0;i=x[31725];x[31725]=0;if((i|0)!=1){Ab(l,g);tb(g);g=17;break w}b=N()|0;break c}x[a+1074308>>2]=16777395;x[31725]=0;g=P(1,d+168|0,13336)|0;i=x[31725];x[31725]=0;if((i|0)!=1){Ab(l,g);tb(g);g=17;break w}b=N()|0;break c}if(y[d+219|0]|y[d+220|0]<<8){break w}i=x[d+192>>2];if(!(!(g&2)|(y[d+221|0]|y[d+222|0]<<8|(y[d+223|0]<<16|y[d+224|0]<<24))|(i|0)!=263)){g=g|16;break w}if(!(!(g&256)|(i|0)==29)){g=g&-257;break w}if(!(g&160)){break w}g=(i|0)==33?g:0}x[31725]=0;i=U(253,a|0,e|0,0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break s}if(!i){break u}i=((e<<2)+a|0)+900380|0;e=x[i>>2];x[31725]=0;O(767,d+192|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break s}e=y[d+218|0];x:{if((f|0)==-1){f=e;break x}if(!(g&32)|(e|0)==(f|0)){break x}g=g&-161|128}e=y[d+219|0]|y[d+220|0]<<8;if(!e){break u}x[31725]=0;h=y[d+439|0];j=y[d+435|0]|y[d+436|0]<<8;o=y[d+434|0];t=y[d+433|0];S(768,d+156|0,a|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break t}g=h|(j|(o|t))?g&-4:g;i=x[i>>2]+236|0;e=12;h=x[d+156>>2];j=Zc(h,x[d+160>>2]);y:{while(1){z:{if((e|0)==108){if((y[d+554|0]|y[d+555|0]<<8)>>>0>259){Nf(m)}e=0;x[31725]=0;i=P(769,d+144|0,y[d+219|0]|y[d+220|0]<<8)|0;h=x[31725];x[31725]=0;if((h|0)!=1){break z}b=N()|0;break y}if(j>>>0>z[_b(i,e)>>1]){o=z[_b(h,z[_b(i,e)>>1])>>1];G=_b(i,e),H=o,w[G>>1]=H}e=e+1|0;continue}break}A:{B:{C:{D:{while(1){h=y[d+219|0]|y[d+220|0]<<8;if(e>>>0>=h>>>0){e=0;if((y[d+554|0]|y[d+555|0]<<8)>>>0<=259){break v}E:{while(1){if(e>>>0>=h>>>0){break v}j=y[yb(x[m>>2],e)+3|0];h=x[yb(x[i>>2],e)>>2];x[31725]=0;S(187,d+72|0,b|0,((j|0)==10?(h+1>>>1|0)+16|0:h)|0);h=x[31725];x[31725]=0;if((h|0)!=1){j=d+72|0;h=ic(d+104|0,j);ub(j);j=x[d+156>>2];if(!(!B|Zc(j,x[d+160>>2])>>>0<=e>>>0)){o=z[_b(j,e)>>1];j=yb(x[m>>2],e);j=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);x[31725]=0;x[d+68>>2]=j;x[d+8>>2]=j;j=ba(770,(D(o,104)+a|0)+484380|0,d+8|0,h|0,d+483|0)|0;o=x[31725];x[31725]=0;if((o|0)==1){break E}C=j^1|C}ub(h);e=e+1|0;h=y[d+219|0]|y[d+220|0]<<8;continue}break}b=N()|0;break A}b=N()|0;ub(h);break A}x[31725]=0;O(771,b|0,d+104|0);h=x[31725];x[31725]=0;if((h|0)==1){break B}h=d+72|0;j=y[d+118|0];F:{if(!(j&48|y[d+121|0]!=173)){Xc(h,8,1,0,10);break F}Xc(h,j&16?16:8,j&32?3:1,0,2)}x[31725]=0;O(772,m|0,h|0);h=x[31725];x[31725]=0;if((h|0)!=1){G=yb(x[i>>2],e),H=x[d+104>>2],x[G>>2]=H;o=y[d+121|0];h=x[d+156>>2];if(Zc(h,x[d+160>>2])>>>0>e>>>0){j=z[_b(h,e)>>1];x[31725]=0;h=(D(j,104)+a|0)+484380|0;O(773,d+104|0,h|0);t=x[31725];x[31725]=0;if((t|0)==1){break D}v[h+38|0]=y[n+202|0];v[h+39|0]=y[n+203|0];v[h+40|0]=y[n+204|0];v[h+41|0]=y[n+205|0];h=d+92|0;Zk(h,3,F);x[31725]=0;O(220,d+72|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break C}h=d+72|0;zc(((j<<5)+a|0)+946304|0,h);tb(h);g=(y[d+118|0]&3)==3?(g&2)>>>1|0?g|4:g:g}s=o|s;e=e+1|0;E=y[xf(x[m+4>>2])+3|0]==10|E;continue}break}b=N()|0;break A}b=N()|0;break A}b=N()|0;break A}b=N()|0}uc(i)}md(d+156|0);break c}b=N()|0;break c}uc(i);md(d+156|0)}r=r+1|0;continue}}b=N()|0;break a}b=N()|0;break c}b=N()|0;break c}G:{if(!(C&1)){break G}x[31725]=0;c=P(1,d+104|0,16662)|0;e=x[31725];x[31725]=0;H:{if((e|0)!=1){e=x[a+1298472>>2];x[31725]=0;S(387,e|0,2,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break H}tb(c);break G}b=N()|0;break c}b=N()|0;tb(c);break c}x[31725]=0;c=P(414,b|0,5558)|0;e=x[31725];x[31725]=0;if((e|0)==1){break q}if(c){x[31725]=0;c=R(153,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break q}x[31725]=0;V(338,a+1298332|0,b|0,c|0,0);c=x[31725];x[31725]=0;if((c|0)==1){break q}g=g|16}x[31725]=0;n=P(414,b|0,14118)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}if(n){x[31725]=0;c=R(153,b|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}x[31725]=0;e=a+901404|0;S(774,b|0,e|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}zD(e);g=g|16}x[31725]=0;c=P(414,b|0,13890)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}if(!c){break p}x[31725]=0;c=R(153,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){w[d+192>>1]=c>>>5;G=d,H=gk(x[a+484344>>2],x[a+484348>>2]),w[G+72>>1]=H;c=z[Nc(d+192|0,d+72|0)>>1];e=0;while(1){if((c|0)==(e|0)){g=g|16;break p}x[31725]=0;O(581,b|0,d+192|0);i=x[31725];x[31725]=0;I:{if((i|0)==1){break I}i=x[a+484344>>2];x[31725]=0;O(582,Wb(i,e)|0,d+192|0);i=x[31725];x[31725]=0;if((i|0)==1){break I}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[31725]=0;c=P(414,b|0,13895)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}J:{if(!c){break J}x[31725]=0;c=R(153,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){w[d+192>>1]=(c>>>0)/20;w[d+72>>1]=z[a+480188>>1];c=z[Nc(d+192|0,d+72|0)>>1];e=0;while(1){if((c|0)==(e|0)){g=g|16;break J}x[31725]=0;S(426,b|0,((e<<5)+a|0)+480289|0,20);i=x[31725];x[31725]=0;if((i|0)!=1){e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}c=x[b+8>>2];e=x[b>>2];x[31725]=0;c=U(152,e|0,c|0,8)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}if(c){c=x[b+8>>2];x[31725]=0;S(427,d+192|0,a|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break h}g=(c|0)==x[b+8>>2]?g:g|16}K:{if(!(g&16)){break K}if(g&4){x[a+1074308>>2]=17367040;x[31725]=0;c=P(1,d+192|0,14679)|0;e=x[31725];x[31725]=0;if((e|0)!=1){Ab(l,c);tb(c);break K}b=N()|0;break c}if(!(g&2)){break K}x[a+1074308>>2]=18219008;x[31725]=0;c=P(1,d+192|0,14858)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}Ab(l,c);tb(c)}L:{M:{N:{O:{P:{Q:{R:{if((y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))==1852141647&(y[k+4|0]|y[k+5|0]<<8|(y[k+6|0]<<16|y[k+7|0]<<24))==542396493){x[31725]=0;c=U(394,d+72|0,d+542|0,12)|0;e=x[31725];x[31725]=0;if((e|0)==1){break R}x[31725]=0;S(260,d+156|0,1,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break Q}x[31725]=0;e=R(775,d+156|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break P}x[a+1074308>>2]=e;tb(d+156|0);v[a+1074368|0]=A[a+1074308>>2]<19007257?4:5;tb(c);g=24}if(!(!x[a+1074308>>2]|g&8)){v[a+1074368|0]=0;Qv(a+1074312|0)}c=g&32;S:{if(!c){break S}v[a+1074368|0]=5;if(!n){sr(a+901404|0)}if((y[d+554|0]|y[d+555|0]<<8)>>>0<260){break S}x[31725]=0;U(268,a+1074312|0,4,1)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}}if(!Ad(x[l+4>>2],y[l+11|0])){break L}if(!(g&256)|s&255|f+1>>>0>1){break M}x[31725]=0;c=P(1,d+156|0,8292)|0;f=x[31725];x[31725]=0;if((f|0)==1){break N}Ab(l,c);tb(c);break L}b=N()|0;break c}b=N()|0;break O}b=N()|0;tb(d+156|0)}tb(c);break c}b=N()|0;break c}if(c){x[31725]=0;c=P(1,d+156|0,12069)|0;f=x[31725];x[31725]=0;if((f|0)!=1){Ab(l,c);tb(c);break L}b=N()|0;break c}x[31725]=0;c=P(1,d+156|0,9750)|0;f=x[31725];x[31725]=0;if((f|0)==1){break f}Ab(l,c);tb(c)}v[d+67|0]=0;if(z[a+480192>>1]){x[31725]=0;c=P(437,a|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break i}v[d+67|0]=c}x[31725]=0;ba(438,a|0,b|0,1,d+67|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}e=x[a+1074308>>2];T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if(y[d+67|0]){if(e>>>0>18284543){break fa}x[a+1074308>>2]=18284544;break fa}if(e>>>0<18284544){break ea}}x[31725]=0;c=P(1,d+52|0,18237)|0;b=x[31725];x[31725]=0;if((b|0)==1){break da}b=x[a+1074308>>2];x[31725]=0;O(776,d+40|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break ca}x[31725]=0;S(2,d+92|0,c|0,d+40|0);b=x[31725];x[31725]=0;if((b|0)==1){break ba}b=d+92|0;Ab(l,b);tb(b);tb(d+40|0);tb(c);e=x[a+1074308>>2]}ga:{if(e-1>>>0>19005952){break ga}b=x[a+484344>>2];g=x[a+484348>>2];if(!He(b,g,254)){b=y[a+484376|0];c=x[a+484360>>2];x[31725]=0;W(777,Xb(c,b)|0);b=x[31725];x[31725]=0;if((b|0)==1){break i}g=x[a+484348>>2];b=x[a+484344>>2]}if(He(b,g,255)){break ga}RC(Xb(x[a+484360>>2],y[a+484376|0]),255,65535)}x[31725]=0;O(778,d+40|0,4102);b=x[31725];x[31725]=0;if((b|0)==1){break $}b=y[d+554|0]|y[d+555|0]<<8;x[d+12>>2]=b>>>8;x[31725]=0;x[d+24>>2]=b&255;O(446,d+28|0,d+24|0);b=x[31725];x[31725]=0;if((b|0)==1){break _}x[31725]=0;V(432,d+92|0,d+40|0,d+12|0,d+28|0);b=x[31725];x[31725]=0;if((b|0)==1){break Z}b=d+92|0;c=Ab(a+1298344|0,b);tb(b);tb(d+28|0);Eb(d+40|0);f=Ab(a+1298368|0,l);G=a+1298404|0,H=x[Fc(b,x[(x[a+1074308>>2]?41136:q)>>2])>>2],x[G>>2]=H;if(!y[d+483|0]){break U}Ab(a+1298380|0,c);x[31725]=0;b=P(1,d+92|0,15278)|0;e=x[31725];x[31725]=0;if((e|0)==1){break X}Ab(c,b);tb(b);x[31725]=0;b=P(1,d+40|0,10101)|0;c=x[31725];x[31725]=0;if((c|0)==1){break W}Ab(a+1298356|0,b);tb(b);x[31725]=0;b=P(1,d+28|0,10102)|0;c=x[31725];x[31725]=0;if((c|0)==1){break V}Ab(a+1298392|0,b);break T}b=N()|0;break c}b=N()|0;break aa}b=N()|0;tb(d+40|0)}tb(c);break c}b=N()|0;break c}b=N()|0;break Y}b=N()|0;tb(d+28|0)}Eb(d+40|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[31725]=0;b=P(1,d+92|0,10102)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}Ab(a+1298356|0,b)}tb(b);e=1;if(E&1){x[31725]=0;a=P(1,d+12|0,17141)|0;b=x[31725];x[31725]=0;if((b|0)==1){break k}x[31725]=0;P(76,f|0,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break j}tb(a)}uc(m);tb(l)}fb=d+576|0;return e|0}b=N()|0;break c}b=N()|0;tb(a);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}uc(m);break a}b=N()|0}tb(l);Q(b|0);p()}function AR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;a:{if(z[x[x[a+48>>2]+12>>2]+480188>>1]!=z[x[x[b+48>>2]+12>>2]+480188>>1]){break a}if((a|0)!=(b|0)){g=fb-16|0;fb=g;f=x[b>>2];d=x[b+4>>2];c=Pk(f,d);b:{if(cw(a)>>>0>=c>>>0){e=d;h=x[a>>2];i=Pk(h,x[a+4>>2]);k=i>>>0>=c>>>0;if(!k){x[g+12>>2]=f;xR(g+12|0,i);e=x[g+12>>2]}f=uA(f,e,h);if(!k){vu(a,e,d,c-Pk(x[a>>2],x[a+4>>2])|0);break b}sD(a,f);break b}BR(a);OZ(a,oD(a,c));vu(a,f,d,c)}fb=g+16|0}x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=x[b+20>>2];zR(a+24|0,b+24|0);pw(a+36|0,b+36|0);if(x[x[x[a+48>>2]+12>>2]+480180>>2]==x[x[x[b+48>>2]+12>>2]+480180>>2]){break a}c=wb(x[a>>2]);x[l+12>>2]=c;m=wb(x[a+4>>2]);while(1){if(!Ib(c,m)){break a}d=0;g=fb-112|0;fb=g;k=x[x[a+48>>2]+12>>2];f=x[k+480180>>2];h=x[x[x[b+48>>2]+12>>2]+480180>>2];c:{if((f|0)==(h|0)){break c}e=y[c+3|0];d:{e:{if((f|0)!=16){break e}i=y[c+5|0];if(!((e|0)!=19|(i|0)!=144)){v[c+3|0]=0;f=1;break d}d=5;f=1;if((e|0)!=5){break e}v[c+5|0]=i>>>1&7|i&240;break d}if(!((h|0)==67108864|(e|0)!=45)){v[c+5|0]=159;d=20;v[c+3|0]=20;break d}if((e|0)!=46){d=e;break d}d=13;v[c+3|0]=13;v[c+5|0]=y[c+5|0]+3>>>2}n=(f|0)==32|(f|0)==16777216|(f|0)==2;f:{g:{h:{i:{j:{k:{if((h|0)==2){e=9;j=1;i=LD(2);if((d&255)!=9){break k}v[c+5|0]=y[c+5|0]+1>>>1;break h}j=(h|0)==32|(h|0)==16777216;e=9;i=LD(h);if((d&255)!=9){break k}if((f|0)!=2){break h}e=y[c+5|0];if((e|0)!=164){break j}v[c+5|0]=145;d=h&16777248?20:28;v[c+3|0]=d;break g}if((d&255)!=32){e=d;break h}d=x[i+84>>2];if(aj(d,32)){break i}e=31;if(!aj(d,31)){break i}v[c+3|0]=31;break h}o=c,p=zi(e<<1),v[o+5|0]=p;break g}e=32}l:{if((f|0)==16777216){d=y[c|0];m:{if(!Vg(d)){d=e;break m}j=x[i+84>>2];d=(d|0)==252?31:32;if(!aj(j,d)){d=aj(j,31)?31:0}w[g+4>>1]=999;o=g,p=Mj(e,y[c+5|0]),w[o+110>>1]=p;o=c,p=(D(z[Nc(g+4|0,g+110|0)>>1],127)>>>0)/999|0,v[o+5|0]=p;v[c+2|0]=0;v[c+3|0]=d;v[c|0]=0;v[c+1|0]=0}n:{o:{p:{e=d&255;switch(e-33|0){case 1:break g;case 2:case 3:break n;case 0:break o;default:break p}}if((e|0)!=20){break g}d=y[c+5|0];if((d&240)!=112|(d&15)>>>0<13){break l}v[c+5|0]=124;break l}d=20;v[c+3|0]=20;v[c+5|0]=y[c+5|0]>>>4|208;break g}q:{j=v[c+5|0];r:{if((j|0)>=0){v[c+3|0]=3;e=-128-j|0;d=3;break r}e=128;if((j|0)==-128){break q}v[c+3|0]=2;e=j^-128;d=2}v[c+5|0]=e;if((e&255)>>>0>30){break q}v[c+5|0]=e+1>>>1|224;break g}v[g+4|0]=(e&255)+7>>>3;v[g+110|0]=15;o=c,p=y[Rb(g+4|0,g+110|0)|0]|240,v[o+5|0]=p;break g}d=e;s:{switch(f-1|0){case 0:case 3:break s;default:break g}}if(!j){break g}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{d=d&255;switch(d-1|0){case 2:break x;case 1:break y;case 0:break B;default:break C}}D:{switch(d-25|0){case 1:case 2:break f;case 4:break u;case 0:break v;case 3:break w;default:break D}}if((d|0)==13){break z}if((d|0)==19){break A}if((d|0)!=37){break f}v[c+3|0]=0;break f}if(y[c+5|0]){break f}v[c+3|0]=0;break f}rw(c);break f}E:{switch(y[c+2|0]){case 0:case 1:v[c+2|0]=1;v[c+3|0]=0;d=y[c+5|0];v[c+5|0]=0;v[c+4|0]=d>>>0>=64?64:d;break f;case 2:break E;default:break f}}tg(c+4|0,c+5|0);v[c+2|0]=1;if(y[c+4|0]>=65){v[c+4|0]=64}v[c+3|0]=20;v[c+5|0]=y[c+5|0]>>>2|128;break f}if(y[c+5|0]<224){break f}v[c+5|0]=223;break f}if(y[c+5|0]<224){break f}v[c+5|0]=223;break f}d=y[c+5|0];e=(d&240)-16>>>4|0;if(e>>>0>9){break f}if(!(1<<e&880)){if(!e){break t}if((e|0)!=1){break f}v[c+3|0]=3;v[c+5|0]=d&15|224;break f}v[c+3|0]=20;if(!(h&2)|(d|0)!=145){break f}v[c+5|0]=164;v[c+3|0]=9;break f}if(y[c|0]){break f}v[c+3|0]=20;v[c|0]=(h|0)==2?-2:-1;d=y[c+5|0];if(!d){v[c+1|0]=0}v[c+5|0]=d&15|208;break f}d=y[c+5|0];if(d>>>0>=16){v[g+4|0]=14;v[g+110|0]=d>>>4;o=c,p=y[Rb(g+4|0,g+110|0)|0]|240,v[o+5|0]=p;break f}v[g+4|0]=14;v[g+110|0]=d;o=c,p=y[Rb(g+4|0,g+110|0)|0]<<4|15,v[o+5|0]=p;break f}v[c+3|0]=2;v[c+5|0]=d&15|224;break f}d=20}F:{if(!n){break F}G:{switch(h-1|0){case 0:case 3:break G;default:break F}}H:{I:{switch(y[c|0]-253|0){case 1:v[c|0]=0;if(!(d&255?(h|0)==4:0)){v[c+5|0]=0;v[c+3|0]=13;break f}v[c+4|0]=0;v[c+2|0]=1;break H;case 0:break I;default:break H}}v[c|0]=255}J:{K:{L:{M:{N:{O:{P:{Q:{R:{e=d&255;switch(e-2|0){case 2:case 3:case 6:case 7:case 8:case 10:case 11:case 12:case 14:case 16:case 17:break f;case 13:break J;case 15:break L;case 1:break M;case 0:break N;case 9:break O;case 4:case 5:break P;case 18:break Q;default:break R}}if((e|0)!=29){break f}d=y[c+5|0];e=d&15;if((e|0)!=15|d>>>0<16){break K}v[c+5|0]=d>>>4;break f}S:{if(y[c+3|0]!=20){break S}v[c+3|0]=19;T:{U:{V:{W:{X:{Y:{Z:{_:{d=y[c+5|0];switch((d&240)-16>>>4|0){case 4:case 5:case 8:case 9:break T;case 6:break U;case 10:break V;case 7:break W;case 3:break X;case 2:break Y;case 1:break Z;case 0:break _;default:break S}}v[c+5|0]=d&15|48;break S}v[c+5|0]=d&175^120;break S}v[c+5|0]=d&15|64;break S}v[c+5|0]=d&15|112;break S}v[c+3|0]=9;v[c+5|0]=D(d&15,17);break S}v[c+5|0]=d&15|96;break S}v[c+3|0]=0;break S}v[c+3|0]=28}break f}if(y[c+2|0]){break O}e=y[c+5|0];j=e&15;if(!((j|0)==15&e>>>0>=16)&(!j|(e&240)!=240)){break O}e=11;$:{switch((d&255)-6|0){case 1:e=8;case 0:v[c+2|0]=e;break;default:break $}}v[c+4|0]=0}d=y[c+5|0];e=d&15;if(!((e|0)!=15|d>>>0<16)){v[c+3|0]=19;v[c+5|0]=d>>>4|160;break f}if(!e|(d&240)!=240){break f}v[c+3|0]=19;v[c+5|0]=e|176;break f}d=y[c+5|0];if(d>>>0>=240){v[c+3|0]=19;v[c+5|0]=d&15|16;break f}if(d>>>0>=224){d=d&15;if((h|0)==4){v[c+3|0]=28;v[c+5|0]=d|16;break f}v[c+3|0]=19;v[c+5|0]=d+3>>>2|16;break f}v[c+3|0]=2;break f}d=y[c+5|0];if(d>>>0>=240){v[c+3|0]=19;v[c+5|0]=d&15|32;break f}if(d>>>0>=224){d=d&15;if((h|0)==4){v[c+3|0]=28;v[c+5|0]=d|32;break f}v[c+3|0]=19;v[c+5|0]=d+3>>>2|32;break f}v[c+3|0]=3;break f}if(y[c+5|0]>31){break f}v[c+3|0]=0;break f}if(!(!e|(d&240)!=240)){v[c+5|0]=d<<4;break f}if(e){v[c+5|0]=240;break f}if(d>>>0>=16){v[c+5|0]=15;break f}v[c+5|0]=0;break f}d=y[c+5|0];if((d-1&255)>>>0>14){break f}v[c+5|0]=d|128;break f}if((f|0)!=16777216&(f|0)!=32|(h|0)!=2){break f}aa:{switch(y[c|0]-253|0){case 0:case 2:v[c|0]=254;break;default:break aa}}ba:{switch((d&255)-20|0){case 0:d=y[c+5|0];e=d&240;if((e|0)!=144){if((e|0)!=112){break f}v[c+3|0]=0;break f}ca:{switch(d-144|0){case 1:v[c+5|0]=164;v[c+3|0]=9;break f;case 0:break ca;default:break f}}v[c+5|0]=64;v[c+3|0]=9;break f;case 3:break ba;default:break f}}v[g+4|0]=128;o=c,p=y[Rb(g+4|0,c+5|0)|0]+1>>>1|0,v[o+5|0]=p}da:{ea:{fa:{ga:{ha:{ia:{ja:{if(!((f|0)!=16777216&(f|0)!=32)){if((h|0)!=4){break ja}d=y[c+3|0];if((d|0)==23){break ia}if((d|0)!=5){break ga}d=y[c+5|0];v[c+5|0]=(d&15)+1>>>1|d&240;break ha}if((f|0)!=4){break ja}ka:{la:{switch(h-1|0){default:if((h|0)==32|(h|0)==16777216){break ka}break;case 1:case 2:break la;case 0:case 3:break ha}}d=y[c+3|0];break ea}d=y[c+3|0];if((d|0)!=23){if((d|0)!=5){break ja}d=y[c+5|0];v[g+4|0]=d<<1&30;v[g+110|0]=15;o=c,p=y[Rb(g+4|0,g+110|0)|0]|d&240,v[o+5|0]=p;break ja}v[g+4|0]=64;o=c,p=y[Rb(g+4|0,c+5|0)|0]<<1,v[o+5|0]=p}ma:{switch(h-1|0){case 0:case 3:break ha;default:break ma}}d=y[c+3|0];break fa}v[g+4|0]=128;o=c,p=y[Rb(g+4|0,c+5|0)|0]+1>>>1|0,v[o+5|0]=p}d=y[c+3|0]}na:{switch((d&255)-16|0){case 0:v[g+4|0]=31;o=c,p=y[Rb(c+5|0,g+4|0)|0],v[o+5|0]=p;d=16;break fa;case 1:break na;default:break fa}}v[g+4|0]=32;o=c,p=y[ef(c+5|0,g+4|0)|0],v[o+5|0]=p;d=17}oa:{if((f|0)!=1){break oa}pa:{qa:{ra:{sa:{ta:{ua:{va:{e=d&255;switch(e-2|0){case 2:case 3:case 6:case 7:case 8:break oa;case 0:case 1:case 9:break sa;case 5:break ta;case 4:break ua;default:break va}}switch(e-19|0){case 1:break qa;case 0:break ra;default:break oa}}d=6;if(y[c+5|0]){break oa}e=4;break pa}d=7;if(y[c+5|0]){break oa}e=5;break pa}if(y[c+5|0]){break oa}e=0;break pa}d=19;j=y[c+5|0];e=(j<<4|(j<<24)+1610612736>>>28)&255;if(!(e>>>0>8|!(1<<e&387))){v[c+3|0]=0;d=0}e=0;if(j>>>0>239){break pa}break oa}d=20;e=0;if(y[c+5|0]<240){break oa}}v[c+3|0]=e;d=e}if((h|0)!=1){break ea}wa:{xa:{ya:{za:{Aa:{if(Ol(y[c|0])){v[c|0]=0;Ba:{Ca:{e=d&255;switch(e-15|0){case 1:case 2:case 3:break wa;case 0:break Aa;case 4:break Ba;default:break Ca}}if(e){break wa}v[c+5|0]=0;d=13;v[c+3|0]=13;break wa}f=y[c+5|0];if((f&240)!=208){break ya}v[c+5|0]=f&15|192;break wa}Da:{e=d&255;switch(e-15|0){case 1:case 2:case 3:break wa;case 4:break za;case 0:break Aa;default:break Da}}if(!e){break xa}break wa}d=19;v[c+3|0]=19;v[c+5|0]=y[c+5|0]&15|144;break wa}f=y[c+5|0]}if((f&255)>>>0<240){break wa}v[c+3|0]=0}d=0;Ea:{switch(y[c+2|0]-1|0){case 0:d=13;v[c+3|0]=13;v[c+5|0]=y[c+4|0];break wa;case 1:d=9;v[c+3|0]=9;e=y[c+4|0];v[c+5|0]=e>>>0>=64?-1:e<<2;break wa;case 3:d=11;v[c+3|0]=11;v[c+5|0]=y[c+4|0];break wa;case 2:d=11;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4;break wa;case 5:d=19;v[c+3|0]=19;v[c+5|0]=y[c+4|0]|176;break wa;case 4:d=19;v[c+3|0]=19;v[c+5|0]=y[c+4|0]|160;break wa;case 12:d=3;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;break wa;case 11:d=2;v[c+3|0]=2;v[c+5|0]=y[c+4|0]<<2;break wa;case 10:d=4;v[c+3|0]=4;v[c+5|0]=y[c+4|0]<<2;break wa;case 7:d=5;v[c+3|0]=5;v[c+5|0]=y[c+4|0];break wa;case 6:break Ea;default:break wa}}d=5;v[c+3|0]=5;v[c+5|0]=y[c+4|0]<<4}v[c+2|0]=0;break da}if(!(d&255|(h|0)!=2)){d=0;Fa:{switch(y[c+2|0]-3|0){case 1:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0];d=11;break da;case 0:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4;d=11;break da;case 3:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]|240;d=11;break da;case 2:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4|15;d=11;break da;case 10:v[c+2|0]=0;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;d=3;break da;case 9:v[c+2|0]=0;v[c+3|0]=2;d=2;v[c+5|0]=y[c+4|0]<<2;break da;case 8:v[c+2|0]=0;v[c+3|0]=4;v[c+5|0]=y[c+4|0]<<2;d=4;break da;case 5:v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=y[c+4|0];d=5;break da;case 4:v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=y[c+4|0]<<4;d=5;break da;case 6:v[c+2|0]=0;v[c+3|0]=29;v[c+5|0]=y[c+4|0]<<4;d=29;break da;case 7:break Fa;default:break da}}v[c+2|0]=0;v[c+3|0]=29;v[c+5|0]=y[c+4|0];d=29;break da}if((h|0)==4){f=y[c|0];if(!(f|(y[c+5|0]&240)!=208|(d&255)!=19)){f=0;v[c+5|0]=0;v[c+3|0]=0;d=0}Ga:{if(Ol(f)){v[c+1|0]=0;e=d&255;if(!e){break Ga}if((e|0)!=19){break da}d=19;e=y[c+5|0];if((e&240)!=208){break da}d=25;v[c+3|0]=25;v[c|0]=0;v[c+5|0]=e&15;break da}if(d&255){break da}}Ha:{switch(y[c+2|0]-11|0){case 2:v[c+2|0]=0;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;d=3;break da;case 1:v[c+2|0]=0;v[c+3|0]=2;d=2;v[c+5|0]=y[c+4|0]<<2;break da;case 0:break Ha;default:break da}}v[c+2|0]=0;v[c+3|0]=4;v[c+5|0]=y[(y[c+4|0]&15)+42208|0];d=4;break da}if((h|0)!=16777216&(h|0)!=32){break da}Ia:{if(d&255|((f|0)==32|(f|0)==16777216)){break Ia}d=0;Ja:{Ka:{switch(y[c+2|0]-7|0){case 2:v[c+3|0]=29;e=y[c+4|0]<<4;d=29;break Ja;case 3:v[c+3|0]=29;e=y[c+4|0];d=29;break Ja;case 0:v[c+3|0]=5;e=y[c+4|0]<<4;d=5;break Ja;case 4:break Ka;default:break Ia}}v[c+3|0]=4;e=y[c+4|0]<<4;d=4}v[c+2|0]=0;v[c+5|0]=e}e=y[c+2|0];if(e>>>0>15|!(1<<e&47480)){break da}v[g+4|0]=9;o=c,p=y[Rb(c+4|0,g+4|0)|0],v[o+4|0]=p}La:{if(y[c+2|0]!=15){break La}if(Wv(x[i+88>>2],15)){break La}e=d&255;if(!(!e|(e|0)==10)){if(aj(x[i+84>>2],d&255)){break La}}v[c+2|0]=0;v[c+3|0]=10;Ma:{Na:{f=y[c+1|0];if(!f){break Na}d=y[c+5|0];if(z[k+480192>>1]>=f>>>0){h=y[c|0];Oa:{if(!Tc(h)){break Oa}j=x[(k+(f<<2)|0)+900380>>2];if(!j){break Oa}f=z[_b(j+236|0,h-1|0)>>1]}if(!(f&65535)){break Na}}if(z[k+480190>>1]<(f&65535)>>>0){break Na}h=y[c+4|0];Vv(g+4|0);if(h>>>0>9){break Na}d=(e|0)==10?d:0;e=ui(k,f&65535);f=y[c+4|0];if(!f){e=ova(x[e>>2],0,d&255,0);d=hb;e=e+32768|0;d=e>>>0<32768?d+1|0:d;d=zi(Bc((d&65535)<<16|e>>>16,d>>>16|0));break Ma}d=zi((x[yb(e+68|0,f-1|0)>>2]+((d&255)<<8)|0)+128>>>8|0);break Ma}d=y[c+4|0]<<3}v[c+5|0]=d;d=y[c+3|0]}Pa:{Qa:{e=d&255;switch(e-42|0){case 0:case 2:break Qa;default:break Pa}}if(aj(x[i+84>>2],e)){break Pa}d=10;v[c+3|0]=10}f=y[c|0];Ra:{if(f>>>0>=y[i+8|0]){e=1;if(f>>>0<=y[i+9|0]){break Ra}}if(Ol(f)){Sa:{switch(f-253|0){case 1:e=y[i+70|0]!=0;break Ra;case 2:e=y[i+71|0]!=0;break Ra;case 0:e=y[i+72|0]!=0;break Ra;default:break Sa}}e=x[i>>2]==16777216;break Ra}e=!f}if(!e){v[c|0]=0}if(!aj(x[i+84>>2],d&255)){v[c+3|0]=0}if(Wv(x[i+88>>2],y[c+2|0])){break c}v[c+2|0]=0}fb=g+112|0;c=x[vg(l+12|0)>>2];continue}}fb=l+16|0;return a}function Mka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,n=0,o=0,s=0,t=0,u=0,B=0,C=0,F=0,G=E(0),H=E(0),I=0,J=0;g=fb-32|0;fb=g;b=x[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){dg(a+1074312|0,0)}b=g+12|0;h=a+1074312|0;Jb(b,h,0);c=Hb(x[x[g+12>>2]>>2],x[g+16>>2]);d=x[a+480180>>2];Jb(b,h,0);m=c&(d&16777248)!=0;u=Hb(x[x[g+12>>2]>>2],x[g+16>>2]);B=x[a+480180>>2];a:{d=x[a+1074308>>2];if(d>>>0>18874367){break a}e=1;while(1){b:{b=e&65535;if(b>>>0<=z[a+480192>>1]){b=x[((b<<2)+a|0)+900380>>2];if(!b){break b}x[g+12>>2]=D(y[b+20|0],100)>>>6;x[g+24>>2]=100;I=b,J=x[Gb(g+12|0,g+24|0)>>2],v[I+20|0]=J;if(A[a+1074308>>2]>18350079&m){break b}c=v[b+26|0];v[b+26|0]=((c>>31|1)+c|0)/2;if(A[a+1074308>>2]>18285313&m){break b}AD(_h(b,2),x[a+480180>>2]);c=x[a+1074308>>2];c:{if(c>>>0<18284544){break c}if(c>>>0>18285135){break b}if(!y[b+34|0]){break c}if(!Tj(y[b+31|0])){break c}Lb(h,2,1);if(A[a+1074308>>2]>18285135){break b}}if(!(y[b+24|0]|(y[b+23|0]|(y[b+19|0]|y[b+20|0])))){break b}Lb(h,1,1)}d:{if(!(x[a+480180>>2]&16777248)|A[a+1074308>>2]>18285313&m){break d}b=z[a+480190>>1]+1&65535;d=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(d|0)){break d}c=D(b,104)+a|0;e=c+484419|0;if(!(y[e|0]|!(y[c+484421|0]|y[c+484420|0]))){v[e|0]=255}b=b+1|0;continue}}c=a+901404|0;b=c+288|0;d=DV(b);while(1){if((b|0)==(d|0)){e:{b=c+800|0;c=sC(b);while(1){if((b|0)==(c|0)){break e}CV(b);b=b+32|0;continue}}}else{CV(b);b=b+32|0;continue}break}d=x[a+1074308>>2];break a}e=e+1|0;continue}}f:{if(!(x[a+480180>>2]&16777252)|((d|0)==18874368|d>>>0>18874895)){break f}b=z[a+480192>>1]+1&65535;f=b>>>0<=1?1:b;e=0;b=1;while(1){if((b|0)==(f|0)){if(!(e&1)){break f}Lb(h,3,1);d=x[a+1074308>>2]}else{c=x[((b<<2)+a|0)+900380>>2];if(!(!c|!y[c+31|0])){v[c+33|0]=13;e=1}b=b+1|0;continue}break}}g:{if(!(x[a+480180>>2]&16777248)|((d|0)==19005440|d>>>0>19006225)){break g}Jb(g+12|0,h,0);if(!Hb(x[x[g+12>>2]>>2],x[g+16>>2])){Jb(g+24|0,h,1);if(!Hb(x[x[g+24>>2]>>2],x[g+28>>2])){break g}}b=z[a+480192>>1]+1&65535;d=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(d|0)){break g}c=x[((b<<2)+a|0)+900380>>2];if(!(!c|!y[c+19|0]|!(v[c+80|0]&1))){v[c+19|0]=0}b=b+1|0;continue}}c=x[a+1074308>>2];if(c>>>0<=19007232){b=a+906300|0;e=Ij(b);while(1){if((b|0)!=(e|0)){d=g+12|0;c=fb-32|0;fb=c;f=c+8|0;i=b+80|0;lS(f,i);x[31725]=0;S(125,c+20|0,22,f|0);f=x[31725];x[31725]=0;h:{i:{j:{if((f|0)!=1){x[31725]=0;S(246,d|0,0,c+20|0);f=x[31725];x[31725]=0;if((f|0)==1){break j}Qb(c+20|0);tb(c+8|0);fb=c+32|0;break h}a=N()|0;break i}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}mw(i,d);b=b+160|0;tb(d);continue}break}c=x[a+1074308>>2]}k:{l:{m:{n:{o:{if(x[a+480180>>2]!=4){break o}if(c>>>0<19007257){break n}if(y[a+1074368|0]!=4|c>>>0>19071235){break o}SA(a,5);c=x[a+1074308>>2]}if(c>>>0>19202054){break m}d=19202048;if((c|0)==19202048){break l}}b=z[a+480192>>1]+1&65535;f=b>>>0<=1?1:b;d=1;while(1){if((d|0)==(f|0)){break m}e=x[((d<<2)+a|0)+900380>>2];p:{if(!e|!y[e+20|0]|!y[e+31|0]){break p}b=e+236|0;i=Ar(b);while(1){if((b|0)!=(i|0)){k=z[b>>1];b=b+2|0;if(!k){continue}break p}break}v[e+20|0]=0}d=d+1|0;continue}}d=c;if(c>>>0>19267583){break k}}b=z[a+480192>>1]+1&65535;e=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(e|0)){break k}c=x[((b<<2)+a|0)+900380>>2];q:{if(!c){break q}d=v[c+26|0];v[c+26|0]=((d>>31|1)+d|0)/2;d=x[a+1074308>>2];if(d>>>0>18350079&m){break q}v[c+19|0]=y[c+19|0]+3>>>2}b=b+1|0;continue}}r:{if(d>>>0>19398673){break r}c=z[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>c>>>0){break r}e=x[((e<<2)+a|0)+900380>>2];if(!e|y[e+65|0]==255){b=b+1|0;continue}else{Lb(h,94,1);d=x[a+1074308>>2]}break}}s:{if(d>>>0>19399427){break s}c=z[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>c>>>0){break s}e=x[((e<<2)+a|0)+900380>>2];if(!e|y[e+36|0]>1){b=b+1|0;continue}else{Lb(h,101,1);d=x[a+1074308>>2]}break}}t:{if(d>>>0>19923027){break t}d=z[a+480190>>1];b=1;while(1){c=b&65535;if(c>>>0>d>>>0){break t}c=D(c,104)+a|0;if(!je(x[c+484380>>2],x[c+484400>>2])|!(y[c+484414|0]&20)){b=b+1|0;continue}else{Lb(h,116,1)}break}}b=fb-16|0;fb=b;w[g+4>>1]=0;x[g>>2]=a;Jb(b+8|0,a+1074312|0,0);I=g,J=Hb(x[x[b+8>>2]>>2],x[b+12>>2]),v[I+6|0]=J;fb=b+16|0;b=x[g>>2];t=x[g+4>>2];f=fb-32|0;fb=f;c=a+484344|0;e=wb(x[c>>2]);x[f+28>>2]=e;C=wb(x[c+4>>2]);while(1){if(Ib(e,C)){c=wb(x[e>>2]);F=wb(x[e+4>>2]);x[f+16>>2]=b;x[f+20>>2]=t;x[f>>2]=b;x[f+4>>2]=t;o=fb-16|0;fb=o;x[o+12>>2]=c;while(1){if(Ib(c,F)){s=z[f+4>>1];d=s+1|0;w[f+4>>1]=d;e=x[f>>2];w[f+4>>1]=z[e+480188>>1]>(d&65535)>>>0?d:0;u:{if(Vg(y[c|0])){break u}i=x[e+1074308>>2];v:{k=x[e+480180>>2];w:{x:{if((k|0)==2){if(i>>>0>18415615){break x}if(y[c+3|0]!=23){break w}Qf(c+5|0,64);break w}y:{if(k&16777248){z:{A:{if(i>>>0>=18285314){if(y[f+6|0]){break A}d=0;e=0;if(i>>>0>18874367){break z}}B:{switch(y[c+3|0]-20|0){case 3:Qf(c+5|0,128);break A;case 0:break B;default:break A}}d=y[c+5|0];if((d|0)!=208){if((d|0)!=192){break A}v[c|0]=254;v[c+3|0]=0;break A}v[c+3|0]=0}C:{D:{E:{if(i>>>0>=18350080){if(y[f+6|0]){break E}d=0;e=0;if(i>>>0>18874367){break z}}e=y[c+3|0];if(e>>>0>29){break D}d=1;if(!(1<<e&536873152)){break D}break C}d=0;e=0;if(i>>>0>18874367){break z}e=y[c+3|0]}d=0}e=(e|0)==24|(e|0)==22}F:{if(!(d|e)){break F}e=y[c+5|0];d=e&15;if(!d|(d|0)==15){break F}e=e&240;if(!e|(e|0)==240){break F}v[c+5|0]=y[c+3|0]==24?e:d}G:{if((i|0)==19005440|i>>>0>19005699){break G}d=z[x[f>>2]+480192>>1];if(y[f+6|0]|(!d|d>>>0>=y[c+1|0])){break G}v[c+4|0]=0;v[c+2|0]=1}if(y[c+3|0]!=18|y[c+5|0]!=17){break x}if(i>>>0>19468801){break v}if(!Ob(x[f>>2]+1074312|0,22)|y[x[f>>2]+480208|0]&4){break x}d=c+5|0;break y}if((k|0)!=4){break x}d=!y[f+6|0];H:{if((d|i>>>0<18285314)&i>>>0<=18874367){break H}if(i>>>0>19137025){break v}if(y[c+3|0]!=23|y[c+5|0]<65){break H}v[c+3|0]=0}I:{J:{K:{if(!(!(d&i>>>0<18874368)&i>>>0>=18415616)){d=y[c+3|0];e=y[c+2|0];if((d|0)!=10|(e|0)!=11){break K}d=0;v[c+3|0]=0;break I}if(i>>>0>18874639){break J}d=y[c+3|0];e=y[c+2|0]}if((e|0)!=11|(d|0)!=4){break I}e=y[c+4|0];if(!(e|y[f+6|0])){d=4;break I}d=4;n=y[c+5|0];if(!n){break I}v[c+2|0]=0;I=c,J=$v(n+(e<<4)|0),v[I+5|0]=J;break I}if(i>>>0>19007240){break v}d=y[c+3|0]}if(y[c+5|0]|(d|0)!=16){break x}d=c+3|0}v[d|0]=0}if(i>>>0>18874367){break v}}d=y[c+3|0];e=y[c+5|0]&240;L:{M:{if((d|0)!=28|(e|0)!=96){n=0}else{if(!y[f+6|0]|(k|0)!=4){break M}n=i>>>0<18350080}if(!(n|(d|0)==20&(e|0)==96)){break L}}d=D(s,-6)+c|0;while(1){if(c>>>0>d>>>0){if(!((y[d+3|0]|8)!=28|(y[d+5|0]&240)!=96)){v[d+3|0]=0}d=d+6|0;continue}break}d=y[c+3|0]}if((d|0)!=20|(e|0)!=224){break v}d=D(s,-6)+c|0;while(1){if(c>>>0<=d>>>0){break v}if(!(y[d+3|0]!=20|(y[d+5|0]&240)!=224)){v[d+3|0]=0}d=d+6|0;continue}}d=y[c+2|0];if(!((d|0)!=8|i>>>0>19333174|(i|0)==19333120)){e=y[c+4|0];d=y[c+3|0];if(!(!e|(d|0)!=7)){v[c+3|0]=11;break u}N:{O:{switch(d-5|0){default:if((d|0)!=26){break u}break;case 1:break u;case 2:break N;case 0:break O}}i=y[c+5|0];if(!(i&15)){v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=i|e&15;break u}P:{switch(d-5|0){case 1:break u;case 0:case 2:break N;default:break P}}if((d|0)!=26){break u}}v[c+2|0]=0;break u}Q:{if(!((k|0)==16777216|(d|0)!=15)){d=y[c+3|0];if(d){break Q}v[c+2|0]=0;v[c+3|0]=10;v[c+5|0]=y[c+4|0]<<3;break u}if((d|0)!=15){break u}d=y[c+3|0]}if((d&255)!=10|i>>>0>19922963){break u}if(y[c+4|0]?y[c+5|0]:1){v[c+2|0]=0;break u}v[c+3|0]=0}c=x[vg(o+12|0)>>2];continue}break}c=x[f+4>>2];x[f+8>>2]=x[f>>2];x[f+12>>2]=c;fb=o+16|0;e=x[bm(f+28|0)>>2];continue}else{fb=f+32|0}break}R:{b=A[a+1074308>>2]<19267584;if(b&m){b=40304;while(1){if((b|0)==40648){break R}c=x[a+1074308>>2];d=x[b+4>>2];Lb(h,x[b>>2],c>>>0>=d>>>0|(c|0)==(d&-65536));b=b+8|0;continue}}if(!(b&((B|0)==4&u))){break R}b=40656;while(1){if((b|0)==40896){break R}Lb(h,x[b>>2],A[a+1074308>>2]>=A[b+4>>2]);b=b+8|0;continue}}S:{c=x[a+480180>>2];if(c&16777248){b=40896;while(1){if((b|0)==40968){break S}c=x[a+1074308>>2];d=x[b+4>>2];e=d&-65536;if(!(c>>>0>=e>>>0&(c>>>0<=e>>>0|c>>>0>=d>>>0))){dg(h,x[b>>2])}b=b+8|0;continue}}b=41040;e=40976;T:{switch(c-2|0){case 2:while(1){if((e|0)==41040){break S}if(A[a+1074308>>2]<A[e+4>>2]){dg(h,x[e>>2])}e=e+8|0;continue};case 0:break T;default:break S}}while(1){if((b|0)==41136){break S}if(A[a+1074308>>2]<A[b+4>>2]){dg(h,x[b>>2])}b=b+8|0;continue}}e=8;b=x[a+1074308>>2];if(!(x[a+480180>>2]!=4|b>>>0>18415615)){Lb(h,98,1);b=x[a+1074308>>2]}if(b-19333159>>>0<=33){b=0;while(1){if((b|0)!=5){c=b+77|0;Jb(g+12|0,h,c);dg(Lb(h,b+86|0,Hb(x[x[g+12>>2]>>2],x[g+16>>2])),c);b=b+1|0;continue}break}b=x[a+1074308>>2]}U:{if(b>>>0>=18284544){if(b>>>0>18874627){break U}e=6;if((b|0)==18874368){break U}}Lb(h,e,1)}b=x[a+1074308>>2];V:{if(y[a+480208|0]&16){if(b>>>0<=19136511){dg(h,7);break V}if(!(x[a+480180>>2]&16777248)|b>>>0>19267583){break V}Lb(h,7,1);break V}if((b|0)==19922944|b>>>0>19922997){break V}dg(h,7)}Jb(g+12|0,h,31);W:{if(!Hb(x[x[g+12>>2]>>2],x[g+16>>2])){break W}b=x[a+1074308>>2];if(b>>>0<19071234|b>>>0>19398722){break W}d=z[a+480192>>1];b=1;while(1){c=b&65535;if(c>>>0>d>>>0){break W}X:{c=x[((c<<2)+a|0)+900380>>2];if(!c){break X}e=y[c+65|0];if(!(y[c+60|0]&4)|(e|0)==255|e>>>0<=y[c- -64|0]){break X}Lb(h,97,1);break W}b=b+1|0;continue}}c=x[a+480180>>2];Y:{if(!(c&16777218)){break Y}d=z[a+480190>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break Y}b=b+1|0;if(!(y[(D(e,104)+a|0)+484415|0]&2)){continue}break}Z:{_:{$:{if(!(!z[a+480192>>1]|(c|0)!=16777216)){b=x[a+1074308>>2];if(b>>>0<19398688){break _}if(b>>>0>19464277){break $}Lb(h,109,1)}b=x[a+1074308>>2]}if((b|0)==19922944|b>>>0>19922996){break Z}}dg(h,111);b=x[a+1074308>>2]}c=x[a+480180>>2];if(!((c|0)!=2|b>>>0>19464191)){Lb(h,108,1);break Y}if((c|0)==2){break Y}dg(h,108)}e=x[a+1074308>>2];aa:{ba:{if(e>>>0<19333186){break ba}if(e>>>0<=19923013){if(!(x[a+480180>>2]&16777252)){break ba}b=a+906300|0;c=Ij(b);while(1){if((b|0)!=(c|0)){ca:{if((y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24))!=1146637647|(y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))!=-271958638){break ca}if((Sc(x[b+4>>2],x[b+8>>2])|0)!=32){break ca}d=Dc(g+12|0,16862);mw(b+80|0,d);tb(d)}b=b+160|0;continue}break}e=x[a+1074308>>2]}if(e>>>0>19988488){break aa}}if(!(x[a+480180>>2]&16777252)){break aa}b=a+906300|0;d=Ij(b);while(1){if((b|0)==(d|0)){break aa}c=b;b=b+160|0;if(!Ui(x[c+16>>2],x[c+20>>2])){continue}break}Lb(h,117,1);e=x[a+1074308>>2]}da:{if(!(x[a+480180>>2]&16777252)|e-19333120>>>0>591359){break da}a=a+906300|0;d=Ij(a);while(1){if((a|0)==(d|0)){break da}ea:{if((y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))!=1146637647|(y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))!=-281111764){break ea}b=x[a+4>>2];if((Sc(b,x[a+8>>2])|0)!=24){break ea}G=Pd(E(E(E((l(2,y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));H=Pd(E(E(E((l(2,y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));c=(q(G),j(2));v[b+12|0]=c;v[b+13|0]=c>>>8;v[b+14|0]=c>>>16;v[b+15|0]=c>>>24;b=x[a+4>>2];c=(q(H),j(2));v[b+16|0]=c;v[b+17|0]=c>>>8;v[b+18|0]=c>>>16;v[b+19|0]=c>>>24}a=a+160|0;continue}}fb=g+32|0}function JP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-32|0;fb=g;a:{b:{c:{d:{e:{f:{if(Ld(b,22255)){Fb(a);break f}if(Ld(b,9893)){b=fb-96|0;fb=b;f=Fb(a);x[31725]=0;W(130,b- -64|0);a=x[31725];x[31725]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((a|0)!=1){x[31725]=0;x[b+40>>2]=0;O(1123,b+52|0,b+40|0);a=x[31725];x[31725]=0;if((a|0)==1){break C}x[31725]=0;a=P(842,f|0,b+52|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break B}tb(b+52|0);x[31725]=0;a=P(991,a|0,16781)|0;c=x[31725];x[31725]=0;if((c|0)==1){break A}x[31725]=0;x[b+40>>2]=7;O(1123,b+52|0,b+40|0);c=x[31725];x[31725]=0;if((c|0)==1){break z}x[31725]=0;a=P(842,a|0,b+52|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break y}tb(b+52|0);x[31725]=0;a=P(991,a|0,16781)|0;c=x[31725];x[31725]=0;if((c|0)==1){break A}x[31725]=0;x[b+40>>2]=3;O(1123,b+52|0,b+40|0);c=x[31725];x[31725]=0;if((c|0)==1){break x}x[31725]=0;a=P(842,a|0,b+52|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break w}tb(b+52|0);x[31725]=0;a=P(991,a|0,15683)|0;c=x[31725];x[31725]=0;if((c|0)==1){break A}c=Nb(b+52|0);d=x[b+76>>2];if(d){x[31725]=0;x[b+16>>2]=d;O(1123,b+28|0,b+16|0);d=x[31725];x[31725]=0;if((d|0)==1){break v}x[31725]=0;S(1017,b+40|0,8964,b+28|0);d=x[31725];x[31725]=0;if((d|0)==1){break u}x[31725]=0;O(180,c|0,b+40|0);d=x[31725];x[31725]=0;if((d|0)==1){break t}tb(b+40|0);tb(b+28|0)}if(!Ed(y[b+80|0])){break p}x[31725]=0;d=P(36,b+40|0,12838)|0;e=x[31725];x[31725]=0;if((e|0)==1){break r}x[31725]=0;O(180,c|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break q}tb(d);break o}a=N()|0;break h}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break j}a=N()|0;break s}a=N()|0;tb(b+40|0)}tb(b+28|0);break j}a=N()|0;break j}a=N()|0;tb(d);break j}if(!Ed(y[b+81|0])){break o}x[31725]=0;d=P(36,b+40|0,12609)|0;e=x[31725];x[31725]=0;if((e|0)==1){break n}x[31725]=0;O(180,c|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break m}tb(d)}if(Ed(y[b+82|0])){break l}break k}a=N()|0;break j}a=N()|0;tb(d);break j}x[31725]=0;d=P(36,b+28|0,11128)|0;e=x[31725];x[31725]=0;D:{if((e|0)!=1){x[31725]=0;O(180,c|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break D}tb(d);break k}a=N()|0;break j}a=N()|0;tb(d);break j}if(lc(x[c>>2],x[c+4>>2])){break g}x[31725]=0;a=P(991,a|0,16811)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;d=P(36,b+4|0,16781)|0;e=x[31725];x[31725]=0;E:{F:{G:{if((e|0)!=1){x[31725]=0;S(1124,b+16|0,c|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break G}x[31725]=0;P(842,a|0,b+16|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break F}tb(b+16|0);tb(d);break g}a=N()|0;break j}a=N()|0;break E}a=N()|0;tb(b+16|0)}tb(d);break j}a=N()|0}Td(c)}zg(b- -64|0)}tb(f);break a}Td(c);zg(b- -64|0);fb=b+96|0;break f}if(Ld(b,8132)){x[g>>2]=0;jr(a,g);break f}if(Ld(b,8110)){x[g>>2]=7;jr(a,g);break f}if(Ld(b,10853)){x[g>>2]=3;jr(a,g);break f}if(Ld(b,10625)){Dc(a,15683);break f}if(Ld(b,11403)){Dc(a,15844);break f}if(Ld(b,7412)){b=fb-48|0;fb=b;SG(b+24|0);x[31725]=0;W(147,b+12|0);c=x[31725];x[31725]=0;H:{I:{J:{K:{if((c|0)!=1){x[31725]=0;S(148,b+36|0,b+24|0,b+12|0);c=x[31725];x[31725]=0;if((c|0)==1){break K}x[31725]=0;O(1065,a|0,b+36|0);a=x[31725];x[31725]=0;if((a|0)==1){break J}tb(b+36|0);tb(b+12|0);tb(b+24|0);fb=b+48|0;break f}a=N()|0;break H}a=N()|0;break I}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(b+24|0);break a}if(Ld(b,9909)){b=fb-16|0;fb=b;e=fb-16|0;fb=e;x[e+12>>2]=101;i=b+4|0;c=fb-96|0;fb=c;f=Nb(c+84|0);L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{d=x[e+12>>2];if(d&1){x[31725]=0;O(136,c+52|0,19989250);d=x[31725];x[31725]=0;if((d|0)==1){break _}x[31725]=0;O(103,f|0,c+52|0);d=x[31725];x[31725]=0;if((d|0)==1){break Z}tb(c+52|0);d=x[e+12>>2]}if(!(d&4)){break X}x[31725]=0;d=ca(137)|0;h=x[31725];x[31725]=0;if((h|0)==1){break W}if(!d){break Y}break X}d=N()|0;break M}d=N()|0;tb(c+52|0);break M}x[31725]=0;W(138,c+52|0);d=x[31725];x[31725]=0;$:{if((d|0)!=1){x[31725]=0;O(103,f|0,c+52|0);d=x[31725];x[31725]=0;if((d|0)==1){break $}tb(c+52|0);break X}d=N()|0;break M}d=N()|0;tb(c+52|0);break M}aa:{d=x[e+12>>2];if(!(d&32)){break aa}x[31725]=0;W(130,c+52|0);d=x[31725];x[31725]=0;ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{if((d|0)!=1){x[31725]=0;O(139,c+40|0,c+52|0);d=x[31725];x[31725]=0;if((d|0)==1){break ca}d=Ad(x[c+44>>2],y[c+51|0]);tb(c+40|0);if(!d){x[31725]=0;W(140,c+28|0);d=x[31725];x[31725]=0;if((d|0)==1){break ta}x[31725]=0;O(139,c+16|0,c+52|0);d=x[31725];x[31725]=0;if((d|0)==1){break sa}x[31725]=0;S(141,c+40|0,c+28|0,c+16|0);d=x[31725];x[31725]=0;if((d|0)==1){break ra}x[31725]=0;O(103,f|0,c+40|0);d=x[31725];x[31725]=0;if((d|0)==1){break qa}tb(c+40|0);tb(c+16|0);Eb(c+28|0)}d=Vp(c+52|0);if(!Ad(x[d+4>>2],y[d+11|0])){x[31725]=0;W(142,c+28|0);h=x[31725];x[31725]=0;if((h|0)==1){break na}x[31725]=0;S(143,c+40|0,c+28|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break ma}x[31725]=0;O(103,f|0,c+40|0);d=x[31725];x[31725]=0;if((d|0)==1){break la}tb(c+40|0);Eb(c+28|0)}x[31725]=0;O(144,c+40|0,c+52|0);d=x[31725];x[31725]=0;if((d|0)==1){break ja}d=Ad(x[c+44>>2],y[c+51|0]);tb(c+40|0);if(!d){x[31725]=0;W(140,c+28|0);d=x[31725];x[31725]=0;if((d|0)==1){break ia}x[31725]=0;O(144,c+16|0,c+52|0);d=x[31725];x[31725]=0;if((d|0)==1){break ha}x[31725]=0;S(141,c+40|0,c+28|0,c+16|0);d=x[31725];x[31725]=0;if((d|0)==1){break ga}x[31725]=0;O(103,f|0,c+40|0);d=x[31725];x[31725]=0;if((d|0)==1){break fa}tb(c+40|0);tb(c+16|0);Eb(c+28|0)}zg(c+52|0);d=x[e+12>>2];break aa}d=N()|0;break M}d=N()|0;break ba}d=N()|0;break oa}d=N()|0;break pa}d=N()|0;tb(c+40|0)}tb(c+16|0)}Eb(c+28|0);break ba}d=N()|0;break ba}d=N()|0;break ka}d=N()|0;tb(c+40|0)}Eb(c+28|0);break ba}d=N()|0;break ba}d=N()|0;break ba}d=N()|0;break da}d=N()|0;break ea}d=N()|0;tb(c+40|0)}tb(c+16|0)}Eb(c+28|0);break ba}d=N()|0}zg(c+52|0);break M}ua:{if(!(d&64)){break ua}x[31725]=0;d=ca(137)|0;h=x[31725];x[31725]=0;if((h|0)==1){break W}if(d){break ua}d=c+52|0;Fb(d);x[31725]=0;O(103,f|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break N}tb(c+52|0)}if(y[e+12|0]&128){x[31725]=0;W(145,c+52|0);d=x[31725];x[31725]=0;if((d|0)==1){break V}x[31725]=0;O(103,f|0,c+52|0);d=x[31725];x[31725]=0;if((d|0)==1){break U}tb(c+52|0)}x[31725]=0;h=P(1,c+52|0,22255)|0;d=x[31725];x[31725]=0;if((d|0)==1){break T}x[31725]=0;S(146,c+4|0,f|0,h|0);d=x[31725];x[31725]=0;if((d|0)==1){break S}x[31725]=0;W(147,c+40|0);d=x[31725];x[31725]=0;if((d|0)==1){break R}x[31725]=0;S(148,i|0,c+4|0,c+40|0);d=x[31725];x[31725]=0;if((d|0)==1){break Q}tb(c+40|0);tb(c+4|0);tb(h);Td(f);fb=c+96|0;break L}d=N()|0;break M}d=N()|0;break M}d=N()|0;tb(c+52|0);break M}d=N()|0;break M}d=N()|0;break O}d=N()|0;break P}d=N()|0;tb(c+40|0)}tb(c+4|0)}tb(h);break M}d=N()|0;tb(c+52|0)}Td(f);Q(d|0);p()}fb=e+16|0;x[31725]=0;O(1065,a|0,i|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(Ld(b,10525)){b=fb-48|0;fb=b;c=b+4|0;xs(c);x[31725]=0;O(139,b+36|0,c|0);c=x[31725];x[31725]=0;va:{wa:{if((c|0)!=1){x[31725]=0;O(1065,a|0,b+36|0);a=x[31725];x[31725]=0;if((a|0)==1){break wa}tb(b+36|0);zg(b+4|0);fb=b+48|0;break f}a=N()|0;break va}a=N()|0;tb(b+36|0)}zg(b+4|0);break a}if(Ld(b,11366)){b=fb-32|0;fb=b;xs(b);x[31725]=0;O(1125,a|0,Vp(b)|0);a=x[31725];x[31725]=0;if((a|0)!=1){zg(b);fb=b+32|0;break f}a=N()|0;zg(b);break a}if(Ld(b,9922)){b=fb-48|0;fb=b;xs(b+16|0);c=x[b+28>>2];xa:{if(c){x[31725]=0;x[b+12>>2]=c;O(1123,a|0,b+12|0);a=x[31725];x[31725]=0;if((a|0)!=1){break xa}a=N()|0;zg(b+16|0);break a}Fb(a)}zg(b+16|0);fb=b+48|0;break f}if(Ld(b,12828)){xs(g);b=y[g+16|0];x[31725]=0;P(36,a|0,(Ed(b)?15528:15844)|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break e}zg(g);break f}if(Ld(b,9938)){xs(g);b=y[g+17|0];x[31725]=0;P(36,a|0,(Ed(b)?15528:15844)|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){zg(g);break f}break e}if(Ld(b,12281)){xs(g);b=y[g+18|0];x[31725]=0;P(36,a|0,(Ed(b)?15528:15844)|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){zg(g);break f}break e}if(Ld(b,12583)){b=fb-16|0;fb=b;c=fb-32|0;fb=c;f=b+4|0;d=Fb(f);x[31725]=0;W(130,c|0);e=x[31725];x[31725]=0;ya:{za:{if((e|0)!=1){x[31725]=0;O(131,d|0,Vp(c)|0);e=x[31725];x[31725]=0;if((e|0)==1){break za}zg(c);fb=c+32|0;break ya}a=N()|0;break b}a=N()|0;zg(c);break b}x[31725]=0;O(1065,a|0,f|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(Ld(b,8253)){b=fb-16|0;fb=b;c=fb-48|0;fb=c;f=b+4|0;d=Fb(f);x[31725]=0;O(133,c+24|0,4135);e=x[31725];x[31725]=0;Aa:{Ba:{Ca:{Da:{if((e|0)!=1){x[c+20>>2]=17;x[c+16>>2]=0;x[31725]=0;x[c+12>>2]=0;aa(134,c+36|0,c+24|0,c+20|0,c+16|0,c+12|0);e=x[31725];x[31725]=0;if((e|0)==1){break Da}x[31725]=0;P(76,d|0,c+36|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Ca}tb(c+36|0);Eb(c+24|0);fb=c+48|0;break Aa}a=N()|0;break b}a=N()|0;break Ba}a=N()|0;tb(c+36|0)}Eb(c+24|0);break b}x[31725]=0;O(1065,a|0,f|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(Ld(b,6857)){b=fb-16|0;fb=b;d=b+4|0;c=fb-32|0;fb=c;f=c+8|0;Dc(f,20190);x[31725]=0;S(125,c+20|0,0,f|0);f=x[31725];x[31725]=0;Ea:{Fa:{Ga:{if((f|0)!=1){x[31725]=0;O(12,d|0,c+20|0);f=x[31725];x[31725]=0;if((f|0)==1){break Ga}Qb(c+20|0);tb(c+8|0);fb=c+32|0;break Ea}a=N()|0;break Fa}a=N()|0;Qb(c+20|0)}tb(c+8|0);break a}x[31725]=0;O(1065,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(Ld(b,6455)){b=fb-48|0;fb=b;c=tc(b+24|0,18274);x[31725]=0;O(1126,b+12|0,2);d=x[31725];x[31725]=0;Ha:{Ia:{Ja:{Ka:{if((d|0)!=1){x[31725]=0;S(2,b+36|0,c|0,b+12|0);d=x[31725];x[31725]=0;if((d|0)==1){break Ka}x[31725]=0;O(1065,a|0,b+36|0);a=x[31725];x[31725]=0;if((a|0)==1){break Ja}tb(b+36|0);tb(b+12|0);tb(c);fb=b+48|0;break f}a=N()|0;break Ha}a=N()|0;break Ia}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(c);break a}if(Ld(b,11389)){b=fb-16|0;fb=b;c=fb-16|0;fb=c;Dc(c+4|0,18590);e=b+4|0;f=Fb(e);h=y[c+15|0];i=x[c+8>>2];x[31725]=0;O(95,f|0,zh(i,h)|0);h=x[31725];x[31725]=0;La:{if((h|0)!=1){Ma:{while(1){if(zh(x[c+8>>2],y[c+15|0])>>>0>d>>>0){h=y[cc(c+4|0,d)|0];x[31725]=0;O(97,f|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break Ma}d=d+1|0;continue}break}tb(c+4|0);fb=c+16|0;break La}}a=N()|0;tb(f);tb(c+4|0);break a}x[31725]=0;O(1065,a|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(Ld(b,10532)){b=fb-16|0;fb=b;c=b+4|0;ts(c,0);x[31725]=0;O(1065,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(Ld(b,10507)){b=fb-16|0;fb=b;c=b+4|0;ts(c,2);x[31725]=0;O(1065,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(Ld(b,10492)){b=fb-16|0;fb=b;c=b+4|0;ts(c,3);x[31725]=0;O(1065,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}Fb(a)}fb=g+32|0;break d}a=N()|0;zg(g);break a}return}a=N()|0;tb(b+4|0);break a}tb(d)}Q(a|0);p()}function eua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;e=fb-416|0;fb=e;xc(b);f=e+399|0;g=S0(b,f);if(!g){FE(f)}a:{b:{c:{d:{e:{f:{if(!g){break f}if(!n$(e+399|0)){break f}if(!Mb(x[b>>2],x[b+8>>2],Bc(72,0))){break f}if(!c){d=1;break f}Bd(a,1);x[a+480208>>2]=x[a+480208>>2]&-25231361|16842752;j=y[e+408|0];w[a+480190>>1]=63;w[a+480188>>1]=j;g:{h:{i:{while(1){if((j&65535)>>>0<=d>>>0){j:{Tb(e+320|0,0,64);d=1;k:{l:{m:{n:{while(1){o:{f=d&65535;if(f>>>0>z[a+480190>>1]){KE(b,a+1298308|0);o$(e+312|0,b);o=Nb(e+300|0);f=y[e+409|0]|y[e+410|0]<<8;if(f){d=Nb(e+212|0);x[31725]=0;f=U(328,b|0,d|0,D(f,y[e+408|0])<<1)|0;g=x[31725];x[31725]=0;if((g|0)==1){break k}if(!f){break j}oe(e+272|0,x[d>>2],x[d+4>>2]);f=Nd(e+264|0);x[31725]=0;g=x[f+4>>2];x[e+40>>2]=x[f>>2];x[e+44>>2]=g;f=jg(329,e+280|0,x[e+272>>2],x[e+276>>2],e+40|0);g=x[31725];x[31725]=0;if((g|0)==1){break o}g=x[d+4>>2];j=x[d>>2];x[31725]=0;U(215,f|0,o|0,Sc(j,g)>>>1|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break n}ub(f);dc(d)}m=Nb(e+252|0);x[31725]=0;O(330,m|0,(y[e+411|0]|y[e+412|0]<<8)<<8);d=x[31725];x[31725]=0;if((d|0)==1){break i}d=0;while(1){g=y[e+411|0]|y[e+412|0]<<8;f=d&65535;if(g>>>0<=f>>>0){break l}x[e+212>>2]=g-f;x[e+160>>2]=2e3;d=e+212|0;g=x[ud(d,e+160|0)>>2];d=Nb(d);x[31725]=0;g=U(328,b|0,d|0,g<<8)|0;j=x[31725];x[31725]=0;if((j|0)==1){break d}if(!g){break m}g=vb(e+248|0,wb(x[m+4>>2]));j=wb(x[d>>2]);i=wb(x[e+216>>2]);g=x[g>>2];x[31725]=0;V(331,m|0,g|0,j|0,i|0);g=x[31725];x[31725]=0;if((g|0)==1){break d}dc(d);d=f+2e3|0;continue}}g=(D(f,104)+a|0)+484380|0;ld(g,1);h=f+(e+320|0)|0;f=Zd(b);v[h|0]=f;if(f<<24>>24>=0){B=g,C=j$(b)<<1,x[B>>2]=C}d=d+1|0;continue}break}a=N()|0;break b}a=N()|0;ub(f);break b}dc(d);d=0;break h}oe(e+232|0,x[m>>2],x[m+4>>2]);mf(e+240|0,x[e+232>>2],x[e+236>>2]);d=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;O(332,Xb(f,d)|0,y[e+409|0]|y[e+410|0]<<8);d=x[31725];x[31725]=0;if((d|0)==1){break e}q=a+484344|0;s=c&1;i=0;while(1){if((y[e+409|0]|y[e+410|0]<<8)>>>0<=i>>>0){g=c&2;j=1;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{while(1){c=j&65535;if(c>>>0>z[a+480190>>1]){break w}x[31725]=0;d=y[c+(e+320|0)|0];S(333,b|0,((c<<5)+a|0)+946304|0,d&63);f=x[31725];x[31725]=0;if((f|0)==1){break u}B:{C:{if(d<<24>>24<0){break C}x[31725]=0;d=R(334,b|0)|0;f=x[31725];x[31725]=0;D:{E:{F:{G:{H:{I:{J:{K:{if((f|0)==1){break K}c=D(c,104)+a|0;f=c+484392|0;x[f>>2]=d<<1;x[31725]=0;d=R(334,b|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break J}if(d>>>0>=2){x[c+484396>>2]=x[f>>2]+(d<<1);d=c+484414|0;w[d>>1]=z[d>>1]|8}x[31725]=0;d=R(199,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break t}v[e+80|0]=d;v[e+180|0]=64;B=c+484410|0,C=y[Rb(e+80|0,e+180|0)|0]<<2,w[B>>1]=C;x[31725]=0;d=R(199,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break K}v[c+484417|0]=d<<4;c=c+484380|0;np(c);if(!x[c>>2]){break C}x[31725]=0;f=R(199,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break E}d=0;switch(f|0){case 4:case 5:break D;case 2:case 3:break G;case 1:break H;case 0:break I;default:break h}}a=N()|0;break c}a=N()|0;break c}if(g){f=Nb(e+80|0);i=x[b+8>>2];h=x[b>>2];k=x[c>>2];x[31725]=0;i=U(152,h|0,i|0,k|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break s}if(!i){break x}d=x[c>>2];x[31725]=0;S(335,b|0,f|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break s}B=e,C=wb(x[f>>2]),x[B+180>>2]=C;i=wb(x[e+84>>2]);while(1){d=x[e+180>>2];if(Ib(d,i)){h=d;d=y[d|0];v[h|0]=d<<7|(d^-1)>>>1&127;me(e+180|0);continue}break}oe(e+200|0,x[f>>2],x[e+84>>2]);d=Nd(e+192|0);x[31725]=0;i=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=i;d=jg(329,e+212|0,x[e+200>>2],x[e+204>>2],e+16|0);i=x[31725];x[31725]=0;L:{if((i|0)!=1){i=Xc(e+180|0,16,1,0,16);x[31725]=0;U(217,i|0,c|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break L}ub(d);dc(f);break C}a=N()|0;break p}a=N()|0;ub(d);break p}c=x[c>>2];break F}f=Nb(e+80|0);d=x[c>>2];x[31725]=0;S(336,e+180|0,b|0,d|0);d=x[31725];x[31725]=0;M:{N:{O:{if((d|0)!=1){d=e+180|0;i=Fn(f,d);dc(d);if(g){oe(e+152|0,x[i>>2],x[e+84>>2]);d=Nd(e+144|0);x[31725]=0;h=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=h;d=jg(329,e+160|0,x[e+152>>2],x[e+156>>2],e+24|0);h=x[31725];x[31725]=0;if((h|0)==1){break O}h=Xc(e+180|0,8,1,0,2);x[31725]=0;U(217,h|0,c|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break N}ub(d)}dc(i);break C}a=T(28848)|0;if((gb|0)!=($(28848)|0)){break M}Y(a|0)|0;d=0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){break v}a=N()|0;break M}a=N()|0;break M}a=N()|0;ub(d)}dc(f);break c}if(g){d=Xc(e+80|0,(f|0)==2?8:16,1,0,0);x[31725]=0;U(217,d|0,c|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break C}a=N()|0;break c}c=D(x[c>>2],f-1|0)}x[31725]=0;P(185,b|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break C}}a=N()|0;break c}i=Nb(e+80|0);d=x[c>>2];x[31725]=0;S(337,e+180|0,b|0,d|0);d=x[31725];x[31725]=0;P:{Q:{if((d|0)!=1){h=e+180|0;d=Fn(i,h);dc(h);if(!g){break P}if((f|0)!=5){break Q}B=e,C=wb(x[d>>2]),x[B+180>>2]=C;k=wb(x[e+84>>2]);while(1){h=x[e+180>>2];if(!Ib(h,k)){break Q}l=h;h=y[h|0];v[l|0]=y[(h>>>7|0)+24721|0]^h;me(e+180|0);continue}}a=T(28848)|0;if((gb|0)!=($(28848)|0)){break y}Y(a|0)|0;d=0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){break B}a=N()|0;break y}oe(e+112|0,x[d>>2],x[e+84>>2]);h=Nd(e+104|0);x[31725]=0;k=x[h+4>>2];x[e+32>>2]=x[h>>2];x[e+36>>2]=k;h=jg(329,e+124|0,x[e+112>>2],x[e+116>>2],e+32|0);k=x[31725];x[31725]=0;if((k|0)==1){break A}f=(f|0)==5;f=Xc(e+180|0,f?16:8,1,0,f?16:1);x[31725]=0;U(217,f|0,c|0,h|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break z}ub(h)}dc(d)}j=j+1|0;continue}break}dc(i);break h}a=N()|0;break y}a=N()|0;ub(h)}dc(i);break c}dc(f);break h}d=0;v[e+182|0]=0;w[e+180>>1]=0;w[e+80>>1]=y[e+413|0]|y[e+414|0]<<8;v[e+82|0]=y[e+415|0];while(1){if((d|0)!=3){c=y[xb(e+80|0,d)|0];B=xb(e+180|0,d),C=c,v[B|0]=C;d=d+1|0;continue}break}R:{S:{T:{U:{d=eg(e+180|0);if(d){c=Nb(e+180|0);x[31725]=0;b=U(328,b|0,c|0,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break r}if(!b){break S}oe(e+72|0,x[c>>2],x[c+4>>2]);b=Nd(e- -64|0);x[31725]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=jg(329,e+80|0,x[e+72>>2],x[e+76>>2],e+8|0);f=x[31725];x[31725]=0;if((f|0)==1){break U}x[31725]=0;V(338,a+1298332|0,b|0,d|0,1);d=x[31725];x[31725]=0;if((d|0)==1){break T}ub(b);dc(c)}x[31725]=0;W(339,e+52|0);b=x[31725];x[31725]=0;if((b|0)!=1){break R}a=N()|0;break c}a=N()|0;break q}a=N()|0;ub(b);break q}dc(c);d=0;break h}x[31725]=0;S(340,e+180|0,e+52|0,y[e+407|0]);b=x[31725];x[31725]=0;V:{W:{if((b|0)!=1){b=e+180|0;Ab(a+1298344|0,b);tb(b);Eb(e+52|0);x[31725]=0;b=P(1,b|0,10096)|0;c=x[31725];x[31725]=0;if((c|0)==1){break W}Ab(a+1298356|0,b);tb(b);x[31725]=0;b=P(1,e+52|0,5101)|0;c=x[31725];x[31725]=0;if((c|0)==1){break V}Ab(a+1298368|0,b);tb(b);B=a+1298404|0,C=x[Fc(e+48|0,24)>>2],x[B>>2]=C;d=1;break h}a=N()|0;Eb(e+52|0);break c}a=N()|0;break c}a=N()|0;break c}dc(f);break h}a=N()|0;break c}a=N()|0;break c}a=N()|0;break p}a=N()|0}dc(c);break c}dc(f);break c}B=_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],i),C=i,w[B>>1]=C;X:{Y:{if(!s){break Y}x[31725]=0;r=i&65535;d=U(198,q|0,r|0,64)|0;f=x[31725];x[31725]=0;if((f|0)==1){break X}if(!d){break Y}f=z[a+480188>>1];h=0;while(1){d=f&65535;if(d>>>0<=h>>>0){break Y}d=_b(x[o>>2],D(d,i)+h|0);d=y[d|0]|y[d+1|0]<<8;Z:{if(d>>>0>=(y[e+411|0]|y[e+412|0]<<8)>>>0){break Z}j=0;t=0-h|0;u=d<<8;d=Wb(x[q>>2],i);d=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,h&65535);while(1){if((j|0)==64){break Z}Er(e+212|0,x[e+240>>2],x[e+244>>2],(j<<2)+u|0,4);f=x[e+212>>2];g=xb(f,0);n=y[g|0]&63;v[d|0]=n?n+48|0:0;k=xb(f,1);v[d+1|0]=y[k|0]<<2&60|y[g|0]>>>6;l=y[k|0];g=xb(f,2);k=y[xb(f,3)|0];f=y[g|0];g=k<<4|f>>>4;w[e+80>>1]=g;A=l>>>6|0;l=f<<2&60;f=A|l;_:{if(!(y[xb(e+312|0,l>>>3|0)|0]>>>(f&7)&1)|!(f|g)){break _}v[d+5|0]=g;l=k>>>4|0;v[d+4|0]=l;$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{switch(f|0){case 0:case 1:case 2:case 32:case 33:case 34:Bf(d,f&15,g&255);if(!y[d+4|0]){break _}v[d+2|0]=f>>>0<32?3:4;break _;case 9:v[d+3|0]=10;v[d+5|0]=g>>>1;if(g>>>0<512){break _}v[d+2|0]=15;v[d+4|0]=k>>>5;break _;case 10:case 42:if(g>>>0>254){break ja}f=f&15;break;case 50:break aa;case 48:break ba;case 43:break ca;case 47:break da;case 17:case 18:case 26:case 27:break ea;case 22:case 25:case 28:case 29:case 30:break fa;case 16:case 19:case 20:case 21:case 23:case 31:break ga;case 13:break ha;case 11:case 15:break ia;case 3:case 4:case 5:case 6:case 7:case 12:break ka;default:break $}}Bf(d,f,g&255);break _}v[d+3|0]=19;v[d+5|0]=l|(f>>>0<32?16:32);if(k&15){v[d+2|0]=3;v[d+4|0]=(g&240)>>>4;break _}v[d+2|0]=4;v[d+4|0]=g&15;break _}v[d+3|0]=(f|0)==11?12:16;B=d,C=$v(g),v[B+5|0]=C;break _}v[d+3|0]=14;if((g&255)>>>0<64){break _}v[d+5|0]=0;break _}v[d+3|0]=19;v[d+5|0]=g&15|f<<4;break _}v[d+3|0]=19;w[e+160>>1]=15;B=d,C=y[Nc(e+80|0,e+160|0)|0]|f<<4,v[B+5|0]=C;break _}v[d+3|0]=19;if(g&255){v[d+5|0]=g&15|((f|0)==17?16:(f|0)==26?16:32);if(k>>>0<16){break _}v[d+2|0]=f>>>0>25?6:5;break _}v[d+5|0]=l|(f>>>0>25?-80:-96);break _}if(!g){break $}v[d+3|0]=17;x[e+160>>2]=8;x[e+124>>2]=g+4;B=d,C=bh(x[Ze(e+160|0,e+124|0)>>2]/8|0),v[B+5|0]=C;break _}v[d+3|0]=14;k=D(t,6)+d|0;n=z[a+480188>>1];f=0;while(1){if((f|0)==(n|0)){break _}g=k+D(f,6)|0;if(!y[g+3|0]){v[g+3|0]=12;B=g,C=$v(r),v[B+5|0]=C}f=f+1|0;continue}}v[d+3|0]=9;f=g&7;if(f){v[d+5|0]=y[f+24713|0];break _}f=g>>>4|0;if((f|0)==128){break $}v[d+5|0]=f;if(g>>>0<=2047){v[d+5|0]=f^128;break _}v[d+5|0]=f^-1;break _}v[d+5|0]=0;v[d+3|0]=0;if(!n){v[d|0]=255;break _}v[d+3|0]=25;break _}v[d+3|0]=0}j=j+1|0;f=z[a+480188>>1];d=D(f,6)+d|0;continue}}h=h+1|0;continue}}i=i+1|0;continue}break}a=N()|0;break c}a=N()|0;break b}}else{ZD(a,d&65535);w[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;j=z[a+480188>>1];continue}break}dc(d);d=0;break g}a=N()|0;break c}dc(m)}md(o)}fb=e+416|0;return d|0}a=N()|0;break c}a=N()|0;dc(d)}dc(m);break a}dc(d)}md(o);Q(a|0);p()}function F1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;a:{n=kk(b,13869);if(!n){break a}b:while(1){if(!Mb(x[b>>2],x[b+8>>2],6)){break a}f=Pg(b);if(!(!((f|0)==(Ln(13719)|0)|!(f&1616928864)|f&-2139062144)&(f|0)!=70791730)){Gh(b,4);break a}l=1;c=ih(b);while(1){e=l&65535;if(e>>>0>z[a+480192>>1]){continue b}e=x[((e<<2)+a|0)+900380>>2];if(e){c:{g=0;if((Ln(16765)|0)==(f|0)){Vb(b,c);break c}h=fb-48|0;fb=h;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{switch(f-1349079874|0){default:if((f|0)==1095062094){break t}if((f|0)==1095126087){break q}if((f|0)==1129524782){break z}if((f|0)==1145263150){break W}if((f|0)==1145979182){break V}if((f|0)==1179463214){break x}if((f|0)==1851469358){break D}if((f|0)==1179931728){break l}Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if((f|0)!=1196830254){if((f|0)==1229341486){break S}if((f|0)==1229345326){break R}if((f|0)==1264266798){break E}if((f|0)==1296182830){break Q}if((f|0)==1296248366){break O}if((f|0)==1297100334){break P}if((f|0)==1297110852){break o}if((f|0)==1298747438){break B}if((f|0)==1313692462){break F}if((f|0)==1313751342){break X}if((f|0)==1345203758){break ha}if((f|0)==1346711086){break j}if((f|0)==1346720334){break u}if((f|0)==1346722606){break H}if((f|0)==1346784327){break r}if((f|0)==1347175726){break ba}if((f|0)==1347179310){break ca}if((f|0)==1347437358){break M}if((f|0)==1347441454){break N}if((f|0)==1347443502){break K}if((f|0)==1347628590){break U}if((f|0)==1347633710){break aa}if((f|0)==1347634478){break $}if((f|0)==1347703884){break m}if((f|0)==1347831112){break w}if((f|0)==1347833672){break v}if((f|0)==1349076270){break i}if((f|0)==1349076315){break G}if((f|0)==1349078085){break Z}if((f|0)==1349078099){break _}if((f|0)==1349079131){break J}if((f|0)==1378758190){break n}if((f|0)==1381183022){break y}if((f|0)==1447374382){break k}if((f|0)==1447383630){break s}if((f|0)==1447385902){break I}if((f|0)==1447447623){break p}if((f|0)==1447839022){break fa}if((f|0)==1447842606){break ga}if((f|0)==1448106798){break L}if((f|0)==1448226350){break A}if((f|0)==1448291886){break T}if((f|0)==1448297006){break ea}if((f|0)==1448297774){break da}if((f|0)!=1682320942){if((f|0)==1718508334){break C}if((f|0)!=1179594286|c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Mw(b,c),x[o>>2]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+15|0]=q;break e}if(c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Mw(b,c),x[o+4>>2]=q;break e}if(c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Mw(b,c),x[o+8>>2]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+61|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+62|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+63|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e- -64|0,q=Jd(b,c),v[o|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+81|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+82|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+83|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+84|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+101|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+102|0]=q;break e;case 0:if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+103|0]=q;break e;case 3:break Y;case 1:case 2:break d}}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+104|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+16|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+17|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+18|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+19|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+20|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+21|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+22|0]=q;break e}if(c>>>0>2){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=FF(b,c),w[o+28>>1]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+30|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+31|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=EF(b,c),v[o+26|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+27|0]=q;break e}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=_h(e,0);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31725]=0;k=R(194,j|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break h}g=x[i>>2];o=yb(g,d),q=k,w[o>>1]=q;d=d+1|0;continue}}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=_h(e,1);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31725]=0;k=R(194,j|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,w[o>>1]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=_h(e,2);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31725]=0;k=R(194,j|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,w[o>>1]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=_h(e,0);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31725]=0;k=R(195,j|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,v[o+2|0]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=_h(e,1);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31725]=0;k=R(195,j|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,v[o+2|0]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=_h(e,2);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31725]=0;k=R(195,j|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,v[o+2|0]=q;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>128){break d}g=e+108|0;d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);d=0;while(1){if((d|0)==128){ub(j);break e}x[31725]=0;i=R(195,j|0)|0;k=x[31725];x[31725]=0;if((k|0)!=1){o=xb(g,d),q=i,v[o|0]=q;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>256){break d}g=e+236|0;d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);d=0;while(1){if((d|0)==128){ub(j);break e}x[31725]=0;i=R(194,j|0)|0;k=x[31725];x[31725]=0;if((k|0)!=1){o=_b(g,d),q=i,w[o>>1]=q;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>32){break d}i=e+492|0;d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);g=Fb(d);d=0;while(1){if((c|0)==(d|0)){break f}x[31725]=0;k=R(196,j|0)|0;m=x[31725];x[31725]=0;ia:{if((m|0)==1){break ia}x[31725]=0;P(197,g|0,k|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break ia}d=d+1|0;continue}break}d=N()|0;tb(g);break g}if(c>>>0>32){break d}i=e+524|0;d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);g=Fb(d);d=0;ja:{while(1){if((c|0)!=(d|0)){x[31725]=0;k=R(196,j|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break ja}x[31725]=0;P(197,g|0,k|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break ja}d=d+1|0;continue}break}zc(i,g);tb(g);ub(j);break e}d=N()|0;tb(g);break g}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+34|0]=q;break e}if(c>>>0>2){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=FF(b,c),w[o+12>>1]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+23|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+24|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+25|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+35|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+36|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+105|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+85|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+65|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+100|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+80|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+60|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=EF(b,c),v[o+33|0]=q;break e}g=1;d=Cp(b,c);if(!Bp(d)){break d}v[e+14|0]=d;break d}o=e,q=D(Kw(b,c),1e4)+(A[e+40>>2]%1e4|0)|0,x[o+40>>2]=q;break e}g=(Kw(b,c)>>>0)%1e4|0;d=x[e+40>>2];x[e+40>>2]=g+d-(d>>>0)%1e4;break e}x[h+28>>2]=240;o=h,q=Cp(b,c),x[o+8>>2]=q;hh(e+48|0,x[Gb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;o=h,q=Cp(b,c),x[o+8>>2]=q;hh(e+68|0,x[Gb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;o=h,q=Cp(b,c),x[o+8>>2]=q;hh(e+88|0,x[Gb(h+28|0,h+8|0)>>2]);break e}d=N()|0}ub(j);Q(d|0);p()}zc(i,g);tb(g);ub(j)}g=1}fb=h+48|0;if(!g){Vb(b,c);break c}if((Ln(16770)|0)==(f|0)){d=y[e+15|0];v[e+15|0]=0;v[e+100|0]=y[e+100|0]&224|(d>>>5&4|d>>>6&1);v[e+60|0]=d>>>1&2|(d<<1&4|(y[e+60|0]&240|d&1));v[e+80|0]=y[e+80|0]&240|(d>>>4&2|(d>>>2&4|d>>>3&1))}}}l=l+1|0;continue}}}return n|0}function Fd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(a>>>0<=244){g=x[31601];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=g>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+126444|0;d=x[a+126452>>2];a=x[d+8>>2];o:{if((b|0)==(a|0)){m=126404,n=rva(-2,c)&g,x[m>>2]=n;break o}x[a+12>>2]=b;x[b+8>>2]=a}a=d+8|0;b=c<<3;x[d+4>>2]=b|3;b=b+d|0;x[b+4>>2]=x[b+4>>2]|1;break a}k=x[31603];if(k>>>0>=h>>>0){break n}if(b){a=2<<c;a=(0-a|a)&b<<c;d=nva(0-a&a);a=d<<3;b=a+126444|0;e=x[a+126452>>2];a=x[e+8>>2];p:{if((b|0)==(a|0)){g=rva(-2,d)&g;x[31601]=g;break p}x[a+12>>2]=b;x[b+8>>2]=a}x[e+4>>2]=h|3;c=e+h|0;a=d<<3;d=a-h|0;x[c+4>>2]=d|1;x[a+e>>2]=d;if(k){b=(k&-8)+126444|0;f=x[31606];a=1<<(k>>>3);q:{if(!(a&g)){x[31601]=a|g;a=b;break q}a=x[b+8>>2]}x[b+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=b;x[f+8>>2]=a}a=e+8|0;x[31606]=c;x[31603]=d;break a}j=x[31602];if(!j){break n}c=x[(nva(0-j&j)<<2)+126708>>2];f=(x[c+4>>2]&-8)-h|0;b=c;while(1){r:{a=x[b+16>>2];if(!a){a=x[b+20>>2];if(!a){break r}}b=(x[a+4>>2]&-8)-h|0;d=b>>>0<f>>>0;f=d?b:f;c=d?a:c;b=a;continue}break}i=x[c+24>>2];d=x[c+12>>2];if((d|0)!=(c|0)){a=x[c+8>>2];x[a+12>>2]=d;x[d+8>>2]=a;break b}b=c+20|0;a=x[b>>2];if(!a){a=x[c+16>>2];if(!a){break m}b=c+16|0}while(1){e=b;d=a;b=a+20|0;a=x[b>>2];if(a){continue}b=d+16|0;a=x[d+16>>2];if(a){continue}break}x[e>>2]=0;break b}h=-1;if(a>>>0>4294967231){break n}a=a+11|0;h=a&-8;j=x[31602];if(!j){break n}f=0-h|0;g=0;s:{if(h>>>0<256){break s}g=31;if(h>>>0>16777215){break s}a=G(a>>>8|0);g=((h>>>38-a&1)-(a<<1)|0)+62|0}b=x[(g<<2)+126708>>2];t:{u:{v:{if(!b){a=0;break v}a=0;c=h<<((g|0)!=31?25-(g>>>1|0)|0:0);while(1){w:{e=(x[b+4>>2]&-8)-h|0;if(e>>>0>=f>>>0){break w}d=b;f=e;if(e){break w}f=0;a=b;break u}e=x[b+20>>2];b=x[((c>>>29&4)+b|0)+16>>2];a=e?(e|0)==(b|0)?a:e:a;c=c<<1;if(b){continue}break}}if(!(a|d)){d=0;a=2<<g;a=(0-a|a)&j;if(!a){break n}a=x[(nva(a&0-a)<<2)+126708>>2]}if(!a){break t}}while(1){b=(x[a+4>>2]&-8)-h|0;c=b>>>0<f>>>0;f=c?b:f;d=c?a:d;b=x[a+16>>2];if(b){a=b}else{a=x[a+20>>2]}if(a){continue}break}}if(!d|x[31603]-h>>>0<=f>>>0){break n}g=x[d+24>>2];c=x[d+12>>2];if((d|0)!=(c|0)){a=x[d+8>>2];x[a+12>>2]=c;x[c+8>>2]=a;break c}b=d+20|0;a=x[b>>2];if(!a){a=x[d+16>>2];if(!a){break l}b=d+16|0}while(1){e=b;c=a;b=a+20|0;a=x[b>>2];if(a){continue}b=c+16|0;a=x[c+16>>2];if(a){continue}break}x[e>>2]=0;break c}a=x[31603];if(a>>>0>=h>>>0){d=x[31606];b=a-h|0;x:{if(b>>>0>=16){c=d+h|0;x[c+4>>2]=b|1;x[a+d>>2]=b;x[d+4>>2]=h|3;break x}x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;c=0;b=0}x[31603]=b;x[31606]=c;a=d+8|0;break a}i=x[31604];if(i>>>0>h>>>0){b=i-h|0;x[31604]=b;c=x[31607];a=c+h|0;x[31607]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(x[31719]){c=x[31721]}else{x[31722]=-1;x[31723]=-1;x[31720]=4096;x[31721]=4096;x[31719]=l+12&-16^1431655768;x[31724]=0;x[31712]=0;c=4096}e=j+c|0;f=0-c|0;b=e&f;if(b>>>0<=h>>>0){break a}d=x[31711];if(d){c=x[31709];g=c+b|0;if(d>>>0<g>>>0|c>>>0>=g>>>0){break a}}y:{if(!(y[126848]&4)){z:{A:{B:{C:{d=x[31607];if(d){a=126852;while(1){c=x[a>>2];if(c>>>0<=d>>>0&d>>>0<c+x[a+4>>2]>>>0){break C}a=x[a+8>>2];if(a){continue}break}}c=kp(0);if((c|0)==-1){break z}g=b;d=x[31720];a=d-1|0;if(a&c){g=(b-c|0)+(a+c&0-d)|0}if(g>>>0<=h>>>0){break z}d=x[31711];if(d){a=x[31709];f=a+g|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break z}}a=kp(g);if((c|0)!=(a|0)){break B}break y}g=f&e-i;c=kp(g);if((c|0)==(x[a>>2]+x[a+4>>2]|0)){break A}a=c}if((a|0)==-1){break z}if(h+48>>>0<=g>>>0){c=a;break y}c=x[31721];c=c+(j-g|0)&0-c;if((kp(c)|0)==-1){break z}g=c+g|0;c=a;break y}if((c|0)!=-1){break y}}x[31712]=x[31712]|4}c=kp(b);a=kp(0);if((c|0)==-1|(a|0)==-1|a>>>0<=c>>>0){break i}g=a-c|0;if(g>>>0<=h+40>>>0){break i}}a=x[31709]+g|0;x[31709]=a;if(a>>>0>A[31710]){x[31710]=a}D:{e=x[31607];if(e){a=126852;while(1){d=x[a>>2];b=x[a+4>>2];if((d+b|0)==(c|0)){break D}a=x[a+8>>2];if(a){continue}break}break k}a=x[31605];if(!(a>>>0<=c>>>0?a:0)){x[31605]=c}a=0;x[31714]=g;x[31713]=c;x[31609]=-1;x[31610]=x[31719];x[31716]=0;while(1){d=a<<3;b=d+126444|0;x[d+126452>>2]=b;x[d+126456>>2]=b;a=a+1|0;if((a|0)!=32){continue}break}d=g-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[31604]=b;a=a+c|0;x[31607]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[31608]=x[31723];break j}if(x[a+12>>2]&8|(c>>>0<=e>>>0|d>>>0>e>>>0)){break k}x[a+4>>2]=b+g;a=e+8&7?-8-e&7:0;c=a+e|0;x[31607]=c;b=x[31604]+g|0;a=b-a|0;x[31604]=a;x[c+4>>2]=a|1;x[(b+e|0)+4>>2]=40;x[31608]=x[31723];break j}d=0;break b}c=0;break c}if(A[31605]>c>>>0){x[31605]=c}b=c+g|0;a=126852;E:{F:{G:{while(1){if((b|0)!=x[a>>2]){a=x[a+8>>2];if(a){continue}break G}break}if(!(y[a+12|0]&8)){break F}}a=126852;while(1){b=x[a>>2];if(b>>>0<=e>>>0){f=b+x[a+4>>2]|0;if(f>>>0>e>>>0){break E}}a=x[a+8>>2];continue}}x[a>>2]=c;x[a+4>>2]=x[a+4>>2]+g;j=(c+8&7?-8-c&7:0)+c|0;x[j+4>>2]=h|3;g=b+(b+8&7?-8-b&7:0)|0;i=h+j|0;a=g-i|0;if((e|0)==(g|0)){x[31607]=i;a=x[31604]+a|0;x[31604]=a;x[i+4>>2]=a|1;break d}if(x[31606]==(g|0)){x[31606]=i;a=x[31603]+a|0;x[31603]=a;x[i+4>>2]=a|1;x[a+i>>2]=a;break d}f=x[g+4>>2];if((f&3)!=1){break e}e=f&-8;if(f>>>0<=255){c=x[g+12>>2];b=x[g+8>>2];if((c|0)==(b|0)){m=126404,n=x[31601]&rva(-2,f>>>3|0),x[m>>2]=n;break f}x[b+12>>2]=c;x[c+8>>2]=b;break f}h=x[g+24>>2];c=x[g+12>>2];if((g|0)!=(c|0)){b=x[g+8>>2];x[b+12>>2]=c;x[c+8>>2]=b;break g}b=g+20|0;f=x[b>>2];if(!f){f=x[g+16>>2];if(!f){break h}b=g+16|0}while(1){d=b;c=f;b=c+20|0;f=x[b>>2];if(f){continue}b=c+16|0;f=x[c+16>>2];if(f){continue}break}x[d>>2]=0;break g}d=g-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[31604]=b;a=a+c|0;x[31607]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[31608]=x[31723];a=(f+(f-39&7?39-f&7:0)|0)-47|0;d=a>>>0<e+16>>>0?e:a;x[d+4>>2]=27;a=x[31716];x[d+16>>2]=x[31715];x[d+20>>2]=a;a=x[31714];x[d+8>>2]=x[31713];x[d+12>>2]=a;x[31715]=d+8;x[31714]=g;x[31713]=c;x[31716]=0;a=d+24|0;while(1){x[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((d|0)==(e|0)){break j}x[d+4>>2]=x[d+4>>2]&-2;f=d-e|0;x[e+4>>2]=f|1;x[d>>2]=f;if(f>>>0<=255){b=(f&-8)+126444|0;c=x[31601];a=1<<(f>>>3);H:{if(!(c&a)){x[31601]=a|c;a=b;break H}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break j}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+126708|0;I:{d=x[31602];c=1<<a;J:{if(!(d&c)){x[31602]=c|d;x[b>>2]=e;break J}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);d=x[b>>2];while(1){b=d;if((f|0)==(x[b+4>>2]&-8)){break I}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=x[c+16>>2];if(d){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break j}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=x[31604];if(a>>>0<=h>>>0){break i}b=a-h|0;x[31604]=b;c=x[31607];a=c+h|0;x[31607]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}x[31600]=48;a=0;break a}c=0}if(!h){break f}d=x[g+28>>2];b=(d<<2)+126708|0;K:{if(x[b>>2]==(g|0)){x[b>>2]=c;if(c){break K}m=126408,n=x[31602]&rva(-2,d),x[m>>2]=n;break f}x[h+(x[h+16>>2]==(g|0)?16:20)>>2]=c;if(!c){break f}}x[c+24>>2]=h;b=x[g+16>>2];if(b){x[c+16>>2]=b;x[b+24>>2]=c}b=x[g+20>>2];if(!b){break f}x[c+20>>2]=b;x[b+24>>2]=c}a=a+e|0;g=e+g|0;f=x[g+4>>2]}x[g+4>>2]=f&-2;x[i+4>>2]=a|1;x[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+126444|0;c=x[31601];a=1<<(a>>>3);L:{if(!(c&a)){x[31601]=a|c;a=b;break L}a=x[b+8>>2]}x[b+8>>2]=i;x[a+12>>2]=i;x[i+12>>2]=b;x[i+8>>2]=a;break d}f=31;if(a>>>0<=16777215){b=G(a>>>8|0);f=((a>>>38-b&1)-(b<<1)|0)+62|0}x[i+28>>2]=f;x[i+16>>2]=0;x[i+20>>2]=0;b=(f<<2)+126708|0;M:{d=x[31602];c=1<<f;N:{if(!(d&c)){x[31602]=c|d;x[b>>2]=i;break N}f=a<<((f|0)!=31?25-(f>>>1|0)|0:0);c=x[b>>2];while(1){b=c;if((x[c+4>>2]&-8)==(a|0)){break M}c=f>>>29|0;f=f<<1;d=(c&4)+b|0;c=x[d+16>>2];if(c){continue}break}x[d+16>>2]=i}x[i+24>>2]=b;x[i+12>>2]=i;x[i+8>>2]=i;break d}a=x[b+8>>2];x[a+12>>2]=i;x[b+8>>2]=i;x[i+24>>2]=0;x[i+12>>2]=b;x[i+8>>2]=a}a=j+8|0;break a}O:{if(!g){break O}b=x[d+28>>2];a=(b<<2)+126708|0;P:{if(x[a>>2]==(d|0)){x[a>>2]=c;if(c){break P}j=rva(-2,b)&j;x[31602]=j;break O}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break O}}x[c+24>>2]=g;a=x[d+16>>2];if(a){x[c+16>>2]=a;x[a+24>>2]=c}a=x[d+20>>2];if(!a){break O}x[c+20>>2]=a;x[a+24>>2]=c}Q:{if(f>>>0<=15){a=f+h|0;x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;break Q}x[d+4>>2]=h|3;e=d+h|0;x[e+4>>2]=f|1;x[e+f>>2]=f;if(f>>>0<=255){b=(f&-8)+126444|0;c=x[31601];a=1<<(f>>>3);R:{if(!(c&a)){x[31601]=a|c;a=b;break R}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break Q}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+126708|0;S:{c=1<<a;T:{if(!(c&j)){x[31602]=c|j;x[b>>2]=e;break T}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);h=x[b>>2];while(1){b=h;if((x[b+4>>2]&-8)==(f|0)){break S}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=x[c+16>>2];if(h){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break Q}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=d+8|0;break a}U:{if(!i){break U}b=x[c+28>>2];a=(b<<2)+126708|0;V:{if(x[a>>2]==(c|0)){x[a>>2]=d;if(d){break V}m=126408,n=rva(-2,b)&j,x[m>>2]=n;break U}x[i+(x[i+16>>2]==(c|0)?16:20)>>2]=d;if(!d){break U}}x[d+24>>2]=i;a=x[c+16>>2];if(a){x[d+16>>2]=a;x[a+24>>2]=d}a=x[c+20>>2];if(!a){break U}x[d+20>>2]=a;x[a+24>>2]=d}W:{if(f>>>0<=15){a=f+h|0;x[c+4>>2]=a|3;a=a+c|0;x[a+4>>2]=x[a+4>>2]|1;break W}x[c+4>>2]=h|3;d=c+h|0;x[d+4>>2]=f|1;x[d+f>>2]=f;if(k){b=(k&-8)+126444|0;e=x[31606];a=1<<(k>>>3);X:{if(!(a&g)){x[31601]=a|g;a=b;break X}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a}x[31606]=d;x[31603]=f}a=c+8|0}fb=l+16|0;return a|0}function kva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=fb-272|0;fb=e;xc(b);if(Tr(b,18431)){o=Fb(e+260|0);x[31725]=0;g=P(232,b|0,o|0)|0;d=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{if((d|0)!=1){if(!g){break a}x[31725]=0;g=P(247,b|0,e+253|0)|0;d=x[31725];x[31725]=0;g:{if((d|0)==1){break g}if(!g){break a}if(!P0(y[e+253|0],y[e+254|0])){break a}h=Bc(O0(e+253|0),hb);g=x[b+8>>2];d=x[b>>2];x[31725]=0;g=U(152,d|0,g|0,h|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}if(!g){break a}if(!c){break b}x[31725]=0;O(248,a|0,4096);d=x[31725];x[31725]=0;if((d|0)==1){break g}x[31725]=0;O(249,a+1298308|0,o|0);d=x[31725];x[31725]=0;if((d|0)==1){break g}d=y[e+255|0];w[a+480188>>1]=32;w[a+480192>>1]=d;Yh(a,1);x[31725]=0;f=P(1,e+240|0,9476)|0;d=x[31725];x[31725]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((d|0)!=1){Ab(a+1298344|0,f);tb(f);x[31725]=0;f=P(1,e+228|0,7105)|0;d=x[31725];x[31725]=0;if((d|0)==1){break p}Ab(a+1298356|0,f);tb(f);x[31725]=0;W(250,e+32|0);d=x[31725];x[31725]=0;if((d|0)==1){break o}v[e+204|0]=y[e+254|0];x[31725]=0;v[e|0]=y[e+253|0];O(251,e+216|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break n}x[31725]=0;V(252,e+80|0,e+32|0,e+204|0,e+216|0);d=x[31725];x[31725]=0;if((d|0)==1){break m}d=e+80|0;Ab(a+1298368|0,d);tb(d);tb(e+216|0);Eb(e+32|0);r=a+1298404|0,s=x[Fc(d,4)>>2],x[r>>2]=s;if(y[e+253|0]<2){break i}w[e+80>>1]=8192;x[31725]=0;f=R(191,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break k}w[e+32>>1]=f;r=a,s=D(z[qe(e+80|0,e+32|0)>>1],1e4)>>>8|0,x[r+480204>>2]=s;x[31725]=0;v[e+80|0]=1;f=R(199,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break j}v[e+32|0]=f;r=a,s=y[ef(e+80|0,e+32|0)|0],x[r+480196>>2]=s;x[31725]=0;P(185,b|0,3)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;f=R(191,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break h}}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break l}b=N()|0;tb(e+216|0)}Eb(e+32|0);break c}b=N()|0;break c}b=N()|0;break c}v[e+80|0]=32;x[31725]=0;f=R(199,b|0)|0;d=x[31725];x[31725]=0;q:{if((d|0)!=1){v[e+32|0]=f;r=a,s=D(y[ef(e+80|0,e+32|0)|0],1e4),x[r+480204>>2]=s;x[31725]=0;v[e+80|0]=1;f=R(199,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break q}v[e+32|0]=f;r=a,s=y[ef(e+80|0,e+32|0)|0],x[r+480196>>2]=s;x[31725]=0;f=R(199,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break h}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[a+480208>>2]=f>>>2&16|12;m=Nb(e+216|0);k=e+80|12;n=Nb(e+204|0);q=1;while(1){r:{s:{d=q&65535;if(d>>>0>z[a+480192>>1]){break s}x[31725]=0;i=U(253,a|0,d|0,0)|0;d=x[31725];x[31725]=0;t:{if((d|0)==1){break t}if(!i){break s}x[31725]=0;f=P(242,b|0,i+492|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break t}if(!f){break s}x[31725]=0;l=R(199,b|0)|0;d=x[31725];x[31725]=0;u:{v:{w:{if((d|0)!=1){Tb(e+80|0,0,120);if(!l){break r}x:{if(y[e+253|0]){x[31725]=0;f=P(254,b|0,e+80|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break w}if(!f){break r}if(y[e+253|0]){break x}}d=gc(e+72|0,k,96);f=x[d>>2];d=x[d+4>>2];x[31725]=0;co(161,e+32|0,b,f,d);d=x[31725];x[31725]=0;if((d|0)==1){break v}if(!x[e+36>>2]){break r}}h=i+236|0;f=0;break u}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}while(1){if((f|0)!=120){g=z[a+480190>>1];d=y[(e+80|0)+f|0];r=_b(h,f),s=(d+g|0)+1|0,w[r>>1]=s;f=f+1|0;continue}break}x[31725]=0;f=i+48|0;S(255,e|0,f|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;j=i+68|0;S(255,e+16|0,j|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;h=i+88|0;S(255,e- -64|0,h|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;O(256,b|0,e+56|0);d=x[31725];x[31725]=0;if((d|0)==1){break f}x[i>>2]=(y[e+57|0]|y[e+58|0]<<8)&4095;d=y[e+57|0]|y[e+58|0]<<8;AE(y[e+59|0]|y[e+60|0]<<8,f,0);AE(y[e+59|0]|y[e+60|0]<<8,j,1);AE(y[e+59|0]|y[e+60|0]<<8,h,2);r=e,s=wb(x[f>>2]),x[r+32>>2]=s;f=d>>>12|0;d=wb(x[i+52>>2]);while(1){g=x[e+32>>2];if(Ib(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)- -64>>>0)/127;r=g,s=y[Rb(e+28|0,e+54|0)|0],v[r+2|0]=s;Je(e+32|0);continue}else{r=e,s=wb(x[j>>2]),x[r+32>>2]=s;d=wb(x[i+72>>2])}break}while(1){g=x[e+32>>2];if(Ib(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)+128>>>0)/255;r=g,s=y[Rb(e+28|0,e+54|0)|0],v[r+2|0]=s;Je(e+32|0);continue}break}r=e,s=wb(x[h>>2]),x[r+32>>2]=s;j=f&3;h=wb(x[i+92>>2]);while(1){f=x[e+32>>2];if(Ib(f,h)){g=v[f+2|0];d=g>>31^-1;g=g^-128;i=j&31;if((j&63)>>>0>=32){d=g<<i;i=0}else{d=(1<<i)-1&g>>>32-i|d<<i;i=g<<i}y:{if((d|0)>=-1&i>>>0>=4294967292|(d|0)>=0){g=i+4|0;d=(((g>>>0<4?d+1|0:d)&7)<<29|g>>>3)&536870911;g=0;break y}g=0-((i>>>0>3)+d|0)|0;d=3-i|0;g=((g&7)<<29|d>>>3)&536870911;d=0-g|0;g=0-((g|0)!=0)|0}r=f,s=Gc(d,g)^128,v[r+2|0]=s;Je(e+32|0);continue}else{d=z[a+480190>>1]+1|0;w[e+54>>1]=d;f=0;j=d&65535;d=4e3-j|0;h=d>>>0<=4e3?d:0;z:{A:{B:{while(1){if((f|0)==(l|0)){break A}if((f|0)==(h|0)){x[31725]=0;P(185,b|0,20)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break A}b=N()|0;break d}x[31725]=0;g=f+j|0;P(242,b|0,((g<<5)+a|0)+946304|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break z}x[31725]=0;O(257,b|0,e+32|0);d=x[31725];x[31725]=0;C:{if((d|0)==1){break C}x[31725]=0;O(258,e+32|0,(D(g,104)+a|0)+484380|0);d=x[31725];x[31725]=0;if((d|0)==1){break C}x[31725]=0;w[e+28>>1]=y[e+56|0]|f<<8&32512|((y[e+51|0]&3)!=0)<<15;O(259,n|0,e+28|0);d=x[31725];x[31725]=0;if((d|0)==1){break B}f=f+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}x[31725]=0;O(259,m|0,e+54|0);d=x[31725];x[31725]=0;if((d|0)!=1){x[e+32>>2]=3999;x[e+28>>2]=l+z[a+480190>>1];r=a,s=x[ud(e+32|0,e+28|0)>>2],w[r+480190>>1]=s;break r}b=N()|0;break d}b=N()|0;break d}}}b=N()|0;break d}g=Fb(e+80|0);x[31725]=0;f=P(232,b|0,g|0)|0;d=x[31725];x[31725]=0;D:{E:{F:{G:{H:{if((d|0)!=1){I:{if(f){x[31725]=0;S(260,e+32|0,21,g|0);d=x[31725];x[31725]=0;if((d|0)==1){break I}d=e+32|0;Ab(a+1298320|0,d);tb(d)}tb(g);f=0;J:{while(1){if((f|0)==32){x[31725]=0;f=P(261,b|0,e+16|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break G}if(!f){break F}g=x[e+16>>2];if(g>>>0<12){break H}f=x[b+8>>2];d=x[b>>2];x[31725]=0;f=U(152,d|0,f|0,g-11|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break G}if(f){break J}break H}d=(f<<5)+a|0;Xe(d+480280|0);x[31725]=0;O(233,b|0,d+480289|0);d=x[31725];x[31725]=0;if((d|0)!=1){f=f+1|0;continue}break}b=N()|0;break d}d=x[e+16>>2]-11|0;x[e+64>>2]=d;k=Nb(e+80|0);x[31725]=0;S(236,b|0,k|0,d|0);d=x[31725];x[31725]=0;K:{if((d|0)!=1){x[e+32>>2]=50529027;d=e+32|0;r=e,s=D(x[Gb(e- -64|0,d)>>2],85),x[r+56>>2]=s;l=Fb(d);x[e>>2]=x[e+20>>2];d=x[Gb(e+56|0,e)>>2];x[31725]=0;O(116,l|0,d|0);d=x[31725];x[31725]=0;L:{if((d|0)==1){break L}f=0;M:{while(1){d=x[e+64>>2];if(d>>>0<=f>>>0){break M}j=x[k>>2];g=y[xb(j,f)|0];i=d;d=f+1|0;if(!((g|0)!=255|i-d>>>0<2)){h=v[xb(j,d)|0];g=y[xb(j,f+2|0)|0];d=x[vb(e+12|0,Df(l))>>2];x[31725]=0;V(239,l|0,d|0,g|0,h|0);d=x[31725];x[31725]=0;if((d|0)!=1){f=f+3|0;continue}break L}x[31725]=0;O(117,l|0,g<<24>>24);g=x[31725];x[31725]=0;f=d;if((g|0)!=1){continue}break}break L}x[31725]=0;S(237,e|0,21,l|0);d=x[31725];x[31725]=0;if((d|0)!=1){N:{h=Ab(l,e);tb(e);g=Kb(h);f=y[h+11|0];d=x[h+4>>2];x[31725]=0;aa(238,a+1298332|0,g|0,Yc(d,f)|0,74,0);d=x[31725];x[31725]=0;if((d|0)==1){break N}tb(h);dc(k);break H}}}b=N()|0;tb(l);break K}b=N()|0}dc(k);break d}}b=N()|0;tb(g);break d}f=y[a+484376|0];d=x[a+484360>>2];x[31725]=0;S(240,Xb(d,f)|0,b|0,y[e+258|0]|y[e+259|0]<<8);d=x[31725];x[31725]=0;if((d|0)==1){break G}h=c&1;if(h){x[31725]=0;O(225,a+484344|0,y[e+256|0]|y[e+257|0]<<8);d=x[31725];x[31725]=0;if((d|0)==1){break G}}j=a+484344|0;f=0;while(1){O:{if((y[e+256|0]|y[e+257|0]<<8)>>>0>f>>>0){g=x[b+8>>2];d=x[b>>2];x[31725]=0;g=U(152,d|0,g|0,4)|0;d=x[31725];x[31725]=0;if((d|0)==1){break D}if(g){break O}}if(!(c&2)){break F}f=0;while(1){c=z[a+480190>>1];if(f>>>0>=c>>>0){f=0;while(1){if(c>>>0<=f>>>0){break F}g=z[_b(x[n>>2],f)>>1];b=g&255;P:{if(!b){break P}d=x[m>>2];b=b-1&65535;if(Zc(d,x[m+4>>2])>>>0<=b>>>0){break P}b=z[_b(d,b)>>1]+(g>>>8&127)&65535;if(b>>>0>c>>>0){break P}c=D(b,104);b=c+a|0;h=b+484380|0;g=x[h>>2];if(!je(g,x[b+484400>>2])){break P}d=a+484380|0;c=d+c|0;b=z[c+34>>1];d=d+D(f+1|0,104)|0;x[d>>2]=g;w[d+34>>1]=z[d+34>>1]&65534|b&1;if(!Fh(d)){break P}yc(x[d+20>>2],x[c+20>>2],Xk(x[h>>2],z[h+34>>1]))}f=f+1|0;c=z[a+480190>>1];continue}}c=z[_b(x[n>>2],f)>>1];if(c&255){f=f+1|0;continue}f=f+1|0;d=D(f,104)+a|0;c=Xc(e+80|0,w[d+484414>>1]&1?16:8,1,0,c<<16>>16<0?6:0);x[31725]=0;U(217,c|0,d+484380|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}break}b=N()|0;break d}x[31725]=0;g=R(153,b|0)|0;d=x[31725];x[31725]=0;Q:{R:{S:{T:{if((d|0)!=1){x[31725]=0;S(187,e+32|0,b|0,g|0);d=x[31725];x[31725]=0;if((d|0)==1){break T}d=e+32|0;k=ic(e+80|0,d);ub(d);if(!h){break R}x[31725]=0;g=R(199,k|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Q}x[31725]=0;P(185,k|0,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Q}x[31725]=0;g=U(198,j|0,f&65535,g+1|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break Q}if(!g){break R}x[31725]=0;g=P(234,k|0,e+32|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break E}if(!g){break S}d=x[j>>2];x[31725]=0;O(235,Wb(d,f)|0,e+32|0);d=x[31725];x[31725]=0;if((d|0)!=1){break S}break E}b=N()|0;break d}b=N()|0;break d}d=x[j>>2];x[31725]=0;S(241,Wb(d,f)|0,1,k|0);d=x[31725];x[31725]=0;if((d|0)==1){break E}}ub(k);f=f+1|0;continue}break}break E}b=N()|0;break d}md(n);md(m);break b}b=N()|0;ub(k);break d}b=N()|0;break d}q=q+1|0;continue}}b=N()|0;break c}b=N()|0;break c}b=N()|0;break d}b=N()|0}md(n);md(m)}tb(o);Q(b|0);p()}f=1}tb(o)}fb=e+272|0;return f|0}function MK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,F=0,G=0,H=E(0),I=0;d=fb-144|0;fb=d;while(1){v[d+f|0]=0;f=f+1|0;g=f?g:g+1|0;if(!g&f>>>0<144){continue}break}x[d+76>>2]=-1;x[d+44>>2]=a;x[d+32>>2]=1199;x[d+84>>2]=a;t=c;a=0;j=fb-304|0;fb=j;a:{b:{c:{d:{if(x[d+4>>2]){break d}Wy(d);if(x[d+4>>2]){break d}break c}i=y[b|0];if(!i){break a}e:{f:{g:{h:{while(1){i:{c=i&255;j:{if(zl(c)){while(1){i=b;b=b+1|0;if(zl(y[i+1|0])){continue}break}Ji(d,0,0);while(1){b=x[d+4>>2];k:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break k}b=sd(d)}if(zl(b)){continue}break}b=x[d+4>>2];c=x[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;c=b;g=n+x[d+124>>2]|0;e=b>>31;b=m+x[d+120>>2]|0;g=e+(b>>>0<m>>>0?g+1|0:g)|0;m=b+c|0;n=m>>>0<b>>>0?g+1|0:g;break j}l:{m:{n:{if((c|0)==37){c=y[b+1|0];if((c|0)==42){break n}if((c|0)!=37){break m}}Ji(d,0,0);o:{if(y[b|0]==37){while(1){c=x[d+4>>2];p:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;i=y[c|0];break p}i=sd(d)}if(zl(i)){continue}break}b=b+1|0;break o}c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;i=y[c|0];break o}i=sd(d)}if(y[b|0]!=(i|0)){b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}if((i|0)>=0){break a}h=0;if(u){break a}break c}c=x[d+4>>2]-x[d+44>>2]|0;f=c;i=c>>31;c=n+x[d+124>>2]|0;e=m+x[d+120>>2]|0;h=(e>>>0<m>>>0?c+1|0:c)+i|0;m=e+f|0;n=m>>>0<e>>>0?h+1|0:h;i=b;break j}l=0;b=b+2|0;break l}if(!(!Oh(c)|y[b+2|0]!=36)){e=fb-16|0;x[e+12>>2]=t;c=c-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+t|0;x[e+8>>2]=c+4;l=x[c>>2];b=b+3|0;break l}l=x[t>>2];t=t+4|0;b=b+1|0}c=0;while(1){e=y[b|0];if(Oh(e)){b=b+1|0;c=(D(c,10)+e|0)-48|0;continue}break}r=0;if((e|0)==109){o=0;r=(l|0)!=0;e=y[b+1|0];b=b+1|0;a=0}i=b+1|0;k=3;h=r;q:{r:{switch((e&255)-65|0){case 39:e=b+2|0;b=y[b+1|0]==104;i=b?e:i;k=b?-2:-1;break q;case 43:e=b+2|0;b=y[b+1|0]==108;i=b?e:i;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;i=b}b=y[i|0];e=(b&47)==3;z=e?1:k;q=e?b|32:b;s:{if((q|0)==91){break s}t:{if((q|0)!=110){if((q|0)!=99){break t}c=(c|0)<=1?1:c;break s}NK(l,z,m,n);break j}Ji(d,0,0);while(1){b=x[d+4>>2];u:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break u}b=sd(d)}if(zl(b)){continue}break}b=x[d+4>>2];e=x[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;e=b;g=n+x[d+124>>2]|0;f=b>>31;b=m+x[d+120>>2]|0;n=f+(b>>>0<m>>>0?g+1|0:g)|0;m=b+e|0;n=m>>>0<b>>>0?n+1|0:n}s=c;p=c>>31;Ji(d,c,p);b=x[d+4>>2];v:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;break v}if((sd(d)|0)<0){break f}}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(q-88|0){default:b=q-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:PK(j+8|0,d,z,0);b=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]!=(0-b|0)|x[d+124>>2]!=(0-((b>>31)+((b|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((q|16)==115){Tb(j+32|0,-1,257);v[j+32|0]=0;if((q|0)!=115){break x}v[j+65|0]=0;v[j+46|0]=0;w[j+42>>1]=0;w[j+44>>1]=0;break x}e=y[i+1|0];f=(e|0)==94;Tb(j+32|0,f,257);v[j+32|0]=0;b=f?i+2|0:i+1|0;B:{C:{D:{f=y[(f?2:1)+i|0];if((f|0)!=45){if((f|0)==93){break D}k=(e|0)!=94;break B}k=(e|0)!=94;v[j+78|0]=k;break C}k=(e|0)!=94;v[j+126|0]=k}b=b+1|0}i=b;while(1){e=y[i|0];E:{if((e|0)!=45){if(!e){break f}if((e|0)==93){break x}break E}e=45;f=y[i+1|0];if(!f|(f|0)==93){break E}g=i+1|0;b=y[i-1|0];F:{if(f>>>0<=b>>>0){e=f;break F}while(1){b=b+1|0;v[b+(j+32|0)|0]=k;e=y[g|0];if(e>>>0>b>>>0){continue}break}}i=g}v[(e+j|0)+33|0]=k;i=i+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}f=0;g=0;e=0;h=0;s=0;A=fb-16|0;fb=A;G:{if((b|0)==1){x[31600]=28;break G}while(1){c=x[d+4>>2];H:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break H}c=sd(d)}if(zl(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}s=(c|0)==45?-1:0;c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break I}c=sd(d)}K:{L:{M:{N:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=x[d+4>>2];O:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break O}c=sd(d)}if((c&-33)==88){b=16;c=x[d+4>>2];P:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break P}c=sd(d)}if(y[c+95393|0]<16){break M}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}Ji(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>y[c+95393|0]){break N}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}Ji(d,0,0);x[31600]=28;break G}if((b|0)!=10){break M}e=c-48|0;if(e>>>0<=9){b=0;while(1){b=D(b,10)+e|0;f=b>>>0<429496729;c=x[d+4>>2];Q:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break Q}c=sd(d)}e=c-48|0;if(f&e>>>0<=9){continue}break}f=b}R:{if(e>>>0>9){break R}h=ova(f,0,10,0);k=hb;b=e;while(1){g=k;f=b+h|0;g=f>>>0<b>>>0?g+1|0:g;b=(g|0)==429496729&f>>>0>=2576980378|g>>>0>429496729;c=x[d+4>>2];S:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break S}c=sd(d)}e=c-48|0;if(b|e>>>0>9){break R}h=ova(f,g,10,0);k=hb;b=e;if((k|0)==-1&(b^-1)>>>0>=h>>>0|(k|0)!=-1){continue}break}b=10;break L}b=10;if(e>>>0<=9){break L}break K}if(b-1&b){h=y[c+95393|0];if(h>>>0<b>>>0){while(1){e=D(b,e)+h|0;f=e>>>0<119304647;c=x[d+4>>2];T:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break T}c=sd(d)}h=y[c+95393|0];if(f&h>>>0<b>>>0){continue}break}f=e}if(b>>>0<=h>>>0){break L}while(1){e=ova(f,g,b,0);k=hb;h=h&255;if((k|0)==-1&(h^-1)>>>0<e>>>0){break L}g=k;f=e+h|0;g=f>>>0<h>>>0?g+1|0:g;c=x[d+4>>2];U:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break U}c=sd(d)}h=y[c+95393|0];if(b>>>0<=h>>>0){break L}Of(A,b,0,0,0,f,g,0,0);if(!(x[A+8>>2]|x[A+12>>2])){continue}break}break L}k=v[(D(b,23)>>>5&7)+95649|0];e=y[c+95393|0];if(e>>>0<b>>>0){while(1){h=h<<k|e;f=h>>>0<134217728;c=x[d+4>>2];V:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break V}c=sd(d)}e=y[c+95393|0];if(f&e>>>0<b>>>0){continue}break}f=h}if(b>>>0<=e>>>0){break L}p=k&31;if((k&63)>>>0>=32){h=0;p=-1>>>p|0}else{h=-1>>>p|0;p=h|(1<<p)-1<<32-p}if(!h&f>>>0>p>>>0){break L}while(1){F=e&255;e=f;c=k&31;if((k&63)>>>0>=32){g=e<<c;c=0}else{g=(1<<c)-1&e>>>32-c|g<<c;c=e<<c}f=F|c;c=x[d+4>>2];W:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break W}c=sd(d)}e=y[c+95393|0];if(b>>>0<=e>>>0){break L}if((g|0)==(h|0)&f>>>0<=p>>>0|g>>>0<h>>>0){continue}break}}if(y[c+95393|0]>=b>>>0){break K}while(1){c=x[d+4>>2];X:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break X}c=sd(d)}if(y[c+95393|0]<b>>>0){continue}break}x[31600]=68;f=-1;g=-1;s=0}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=f^s;f=b-s|0;c=s>>31;g=(c^g)-((b>>>0<s>>>0)+c|0)|0}fb=A+16|0;b=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]==(0-b|0)&x[d+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break g}if(!(!l|(q|0)!=112)){x[l>>2]=f;break w}NK(l,z,f,g);break w}if(!l){break w}b=x[j+16>>2];e=x[j+20>>2];c=x[j+8>>2];f=x[j+12>>2];Y:{switch(z|0){case 0:G=l,H=TG(c,f,b,e),B[G>>2]=H;break w;case 1:G=l,I=wx(c,f,b,e),C[G>>3]=I;break w;case 2:break Y;default:break w}}x[l>>2]=c;x[l+4>>2]=f;x[l+8>>2]=b;x[l+12>>2]=e;break w}f=(q|0)!=99;c=f?31:c+1|0;Z:{if((z|0)==1){e=l;if(r){e=Fd(c<<2);if(!e){break h}}x[j+296>>2]=0;x[j+300>>2]=0;b=0;while(1){a=e;_:{while(1){e=x[d+4>>2];$:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break $}e=sd(d)}if(!y[(e+j|0)+33|0]){break _}v[j+27|0]=e;e=yt(j+28|0,j+27|0,1,j+296|0);if((e|0)==-2){continue}o=0;if((e|0)==-1){break f}if(a){x[(b<<2)+a>>2]=x[j+28>>2];b=b+1|0}if(!r|(b|0)!=(c|0)){continue}break}h=1;b=c;c=b<<1|1;e=Fv(a,c<<2);if(e){continue}break e}break}o=0;c=a;if(j+296|0?x[j+296>>2]:0){break f}break Z}if(r){b=0;e=Fd(c);if(!e){break h}while(1){a=e;while(1){e=x[d+4>>2];aa:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break aa}e=sd(d)}if(!y[(e+j|0)+33|0]){c=0;o=a;break Z}v[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}h=1;b=c;c=b<<1|1;e=Fv(a,c);if(e){continue}break}o=a;a=0;break e}b=0;if(l){while(1){a=x[d+4>>2];ba:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ba}a=sd(d)}if(y[(a+j|0)+33|0]){v[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;o=a;break Z}}}while(1){a=x[d+4>>2];ca:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ca}a=sd(d)}if(y[(a+j|0)+33|0]){continue}break}a=0;o=0;c=0}e=x[d+4>>2];g=x[d+116>>2];if((g|0)>0|(g|0)>=0){e=e-1|0;x[d+4>>2]=e}g=e-x[d+44>>2]|0;e=g+x[d+120>>2]|0;h=x[d+124>>2]+(g>>31)|0;h=e>>>0<g>>>0?h+1|0:h;if(!(h|e)|!(f|(e|0)==(s|0)&(h|0)==(p|0))){break i}if(r){x[l>>2]=a}da:{if((q|0)==99){break da}if(c){x[(b<<2)+c>>2]=0}if(!o){o=0;break da}v[b+o|0]=0}a=c}b=x[d+4>>2]-x[d+44>>2]|0;e=b;c=n+x[d+124>>2]|0;f=b>>31;b=m+x[d+120>>2]|0;g=f+(b>>>0<m>>>0?c+1|0:c)|0;m=b+e|0;n=m>>>0<b>>>0?g+1|0:g;u=((l|0)!=0)+u|0}b=i+1|0;i=y[i+1|0];if(i){continue}break a}break}a=c;break g}h=1;o=0;a=0;break e}h=r;break b}h=r}if(u){break b}}u=-1}if(!h){break a}Db(o);Db(a)}fb=j+304|0;fb=d+144|0;return u}function Xoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=fb-192|0;fb=j;if(!ov(a)){e=j+40|0;uW(e,a);f=j+168|0;df(f,e,128,2);e=j+180|0;Cc(e,f);zc(b+492|0,e);tb(e)}w[c+34>>1]=z[c+34>>1]&65489;p=j+180|0;g=fb-32|0;fb=g;a:{b:{switch(y[a+128|0]-4|0){default:x[g+28>>2]=0;xn(p,0,g+28|0);break a;case 0:case 4:break b}}v[g+28|0]=y[a+129|0];v[g+24|0]=100;f=g+24|0;e=y[Rb(g+28|0,f)|0];v[g+24|0]=y[a+130|0];v[g+20|0]=100;l=y[Rb(f,g+20|0)|0];x[g+28>>2]=l;c:{if(y[a+140|0]&16){i=Bb(y[a+150|0]|y[a+151|0]<<8);h=Bb(y[a+152|0]|y[a+153|0]<<8);f=x[c>>2];s=+(f>>>0)/6553600;e=Br(s*+((i|e<<16)>>>0));x[g+24>>2]=f-e;t=g,u=Br(s*+((h|l<<16)>>>0)),x[t+20>>2]=u;t=g,u=x[Gb(g+24|0,g+20|0)>>2],x[t+28>>2]=u;break c}i=x[c>>2];k=x[c+20>>2];if(!je(i,k)){break c}f=i>>>7|0;e=D(f,(e<<7>>>0)/100|0);x[g+24>>2]=i-e;x[g+20>>2]=D(f,(l<<7>>>0)/100|0);f=x[Gb(g+24|0,g+20|0)>>2];h=z[c+34>>1];i=D(_d(h),i);d:{if(h&1){bc(g+12|0,k,i);k=x[g+12>>2];i=_d(z[c+34>>1]);h=k+(D(i,e+f|0)<<1)|0;l=w[k+(D(e,i)<<1)>>1];k=0-i<<1;while(1){e:{f:{if(f){i=w[h>>1]-l|0;m=i>>31;if((i^m)-m>>>0>=1536){break f}}else{f=0}break e}f=f-1|0;h=h+k|0;continue}break}break d}bc(g+4|0,k,i);k=x[g+4>>2];i=_d(z[c+34>>1]);l=0-i|0;h=k+D(i,e+f|0)|0;k=v[k+D(e,i)|0];while(1){g:{h:{if(f){i=v[h|0]-k|0;m=i>>31;if((i^m)-m>>>0>=6){break h}}else{f=0}break g}f=f-1|0;h=h+l|0;continue}break}}x[g+28>>2]=f}xn(p,e,g+28|0)}fb=g+32|0;r=ec(p);if(!(!x[r>>2]|y[a+128|0]!=4)){w[c+34>>1]=z[c+34>>1]|2;f=x[j+180>>2];x[c+4>>2]=f;x[c+8>>2]=f+x[r>>2]}e=y[a+134|0];if((e-1&255)>>>0<=198){v[j+40|0]=e;v[j+168|0]=100;g=(y[Rb(j+40|0,j+168|0)|0]<<7>>>0)/100|0}else{g=128}v[j+39|0]=g;v[j+40|0]=64;e=j+39|0;f=j+40|0;t=c,u=y[ef(e,f)|0]>>>1|0,w[t+32>>1]=u;v[j+40|0]=64;t=b,u=y[Rb(e,f)|0],x[t+4>>2]=u;x[c+24>>2]=40460;hm(c,+v[a+139|0]/12+ +(0-y[a+143|0]|0)+ +v[a+138|0]/1536);v[b+34|0]=y[a+142|0]&2?2:1;if(y[a+142|0]&2){mk(b,127,1);lk(b,0,1)}i:{if(!je(x[c>>2],x[c+20>>2])){break i}b=y[a+140|0];if(b&1){g=x[c>>2];f=x[c+20>>2];j:{if(!je(g,f)|g>>>0<2){break j}k:{l:{switch(el(z[c+34>>1])-1|0){case 3:e=0;b=g>>>1|0;while(1){if((b|0)!=(e|0)){Ub(f+(e<<2)|0,f+(g+(e^-1)<<2)|0);e=e+1|0;continue}break};break k;case 1:e=0;b=g>>>1|0;while(1){if((b|0)!=(e|0)){VR(f+(e<<1)|0,f+(g+(e^-1)<<1)|0);e=e+1|0;continue}break};break k;case 0:break l;default:break j}}e=0;b=g>>>1|0;while(1){if((b|0)!=(e|0)){tg(e+f|0,f+(g+(e^-1)|0)|0);e=e+1|0;continue}break}}Sj(c,d)}b=y[a+140|0]}if(b&4){m:{f=x[c>>2];g=x[c+20>>2];if(!je(f,g)){break m}b=z[c+34>>1];f=D(_d(b),f);n:{o:{switch(Qn(b)-1|0){case 1:e=0;while(1){if((e|0)!=(f|0)){b=g+(e<<1)|0;w[b>>1]=z[b>>1]^-1;e=e+1|0;continue}break};break n;case 0:break o;default:break m}}e=0;while(1){if((e|0)!=(f|0)){b=e+g|0;v[b|0]=y[b|0]^-1;e=e+1|0;continue}break}}Sj(c,d)}}o=y[a+170|0]!=2|y[a+171|0]>100?o:y[a+172|0]<101;b=z[c+34>>1];if(!(!(o|y[a+160|0]!=0|y[a+141|0])|b&1)){f=nv(x[c>>2],_d(b)<<1&254);if(!f){break i}b=f;h=x[c>>2];e=z[c+34>>1];g=D(_d(e),h);m=x[c+20>>2];e=Xk(h,e);i=fb-16|0;fb=i;x[i+12>>2]=g;wc(i+12|0,e);h=x[i+12>>2];while(1){if(h){w[b>>1]=v[m|0]<<8;m=m+1|0;b=b+2|0;h=h-1|0;continue}break}fb=i+16|0;w[c+34>>1]=z[c+34>>1]|1;sW(c,f,x[c>>2],d);b=z[c+34>>1]}f=x[c>>2];e=x[c+20>>2];p:{if(v[a+141|0]>=0){break p}bc(j+40|0,e,D(_d(b),f));q:while(1){if((0-v[a+141|0]|0)<=(n|0)){f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1];break p}b=x[j+40>>2];f=w[b>>1];t=j,u=wb(b),x[t+168>>2]=u;b=on(x[j+40>>2],x[j+44>>2]);while(1){e=x[j+168>>2];if(Ib(e,b)){f=qd(w[e>>1]-qd(f,1)|0,1);w[e>>1]=f;Md(j+168|0);continue}else{n=n+1|0;continue q}}}}if(o){bc(j+40|0,e,D(_d(b),f));h=x[j+44>>2];b=(h|0)/2|0;g=b;e=g>>31;f=y[a+172|0];i=y[a+171|0];b=f-i|0;l=g;g=0-(f>>>0<i>>>0)<<24|b>>>8;b=b<<24;f=l+b|0;e=e+g|0;b=Gc(pva(f,b>>>0>f>>>0?e+1|0:e,h,h>>31),hb);t=j,u=wb(x[j+40>>2]),x[t+168>>2]=u;g=b;k=g>>31;b=i<<24;f=b>>31;i=on(x[j+40>>2],x[j+44>>2]);while(1){e=x[j+168>>2];if(Ib(e,i)){h=w[e>>1];h=ova(b,f,h,h>>31);m=hb;h=h+838860800|0;m=h>>>0<838860800?m+1|0:m;t=e,u=Gc(pva(h,m,1677721600,0),hb),w[t>>1]=u;f=f+k|0;b=b+g|0;f=b>>>0<g>>>0?f+1|0:f;Md(j+168|0);continue}break}f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1]}if(y[a+160|0]){bc(j+168|0,e,D(_d(b),f));l=y[a+163|0];k=y[a+162|0];b=0;o=0;m=0;if(y[a+161|0]>=2){i=x[j+172>>2];f=(i|0)/2|0;h=f;g=f>>31;f=y[a+164|0];e=0-(f>>>0<k>>>0)|0;f=f-k|0;m=e<<23|f>>>9;f=f<<23;e=f+h|0;g=g+m|0;o=Gc(pva(e,e>>>0<f>>>0?g+1|0:g,i,i>>31),hb);i=x[j+172>>2];f=(i|0)/2|0;h=f;g=f>>31;f=y[a+165|0];e=0-(f>>>0<l>>>0)|0;f=f-l|0;m=e<<23|f>>>9;f=f<<23;e=f+h|0;g=g+m|0;m=Gc(pva(e,e>>>0<f>>>0?g+1|0:g,i,i>>31),hb)}f=l<<23;e=k<<23;g=y[a+160|0];t=j,u=wb(x[j+168>>2]),x[t+32>>2]=u;i=(j+40|0)+((g&2)<<2)|0;h=on(x[j+168>>2],x[j+172>>2]);n=0;while(1){k=x[j+32>>2];if(Ib(k,h)){g=(w[k>>1]>>1)-n|0;x[j+48>>2]=g;l=g;g=(e|0)/8388608|0;b=qd(D(l,g),8)+b|0;x[j+44>>2]=b;g=qd(D(b,g),6)+n|0;n=qd(qd(D(g,(f|0)/8388608|0),6)+g|0,2);x[j+40>>2]=n;t=k,u=ed(x[i>>2]),w[t>>1]=u;f=f+m|0;e=e+o|0;Md(j+32|0);continue}else{f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1]}break}}r:{if(v[a+141|0]<=0){break r}bc(j+40|0,e,D(_d(b),f));n=0;s:while(1){if(v[a+141|0]<=(n|0)){f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1];break r}b=x[j+40>>2];f=w[b>>1];t=j,u=wb(b),x[t+168>>2]=u;b=on(x[j+40>>2],x[j+44>>2]);while(1){e=x[j+168>>2];if(Ib(e,b)){f=((w[e>>1]<<1)+f|0)/3|0;w[e>>1]=f;Md(j+168|0);continue}else{n=n+1|0;continue s}}}}f=D(_d(b),f);t:{if(b&1){bc(j+24|0,e,f);m=x[j+28>>2];b=fb-16|0;fb=b;o=x[j+24>>2];f=wb(o);n=on(o,m);p=fb-16|0;fb=p;q=fb-16|0;fb=q;x[q+12>>2]=f;gc(q+4|0,p+15|0,p+14|0);l=b+8|0;h=xn(l,f,q+12|0);u:{if(lc(f,n)){break u}k=Md(q+12|0);g=x[k>>2];if(lc(g,n)){break u}e=x[h>>2];f=Zl(g,e);x[(f?0:4)+h>>2]=g;f=f?g:e;i=h+4|0;while(1){g=Md(k);e=x[g>>2];if(!Ib(e,n)){break u}g=x[Md(g)>>2];if(lc(g,n)){if(!Zl(e,f)){h=i;if(Zl(e,x[i>>2])){break u}}x[h>>2]=e;break u}v:{if(Zl(g,e)){if(Zl(g,f)){x[h>>2]=g;f=g}if(Zl(e,x[i>>2])){continue}break v}if(Zl(e,f)){x[h>>2]=e;f=e}e=g;if(Zl(e,x[i>>2])){continue}}x[i>>2]=e;continue}}fb=q+16|0;fb=p+16|0;x[b+4>>2]=0-w[x[b+8>>2]>>1];t=b,u=w[x[ec(l)>>2]>>1],x[t>>2]=u;w:{g=x[Ze(b+4|0,b)>>2];if((g|0)>32766|!g){break w}e=wb(o);x[b+4>>2]=e;f=on(o,m);while(1){if(!Ib(e,f)){break w}w[e>>1]=(D(w[e>>1],32767)|0)/(g|0);e=x[Md(b+4|0)>>2];continue}}break t}bc(j+16|0,e,f);m=x[j+20>>2];b=fb-16|0;fb=b;o=x[j+16>>2];f=wb(o);n=Yk(o,m);p=fb-16|0;fb=p;q=fb-16|0;fb=q;x[q+12>>2]=f;gc(q+4|0,p+15|0,p+14|0);l=b+8|0;h=xn(l,f,q+12|0);x:{if(lc(f,n)){break x}k=me(q+12|0);g=x[k>>2];if(lc(g,n)){break x}e=x[h>>2];f=_l(g,e);x[(f?0:4)+h>>2]=g;f=f?g:e;i=h+4|0;while(1){g=me(k);e=x[g>>2];if(!Ib(e,n)){break x}g=x[me(g)>>2];if(lc(g,n)){if(!_l(e,f)){h=i;if(_l(e,x[i>>2])){break x}}x[h>>2]=e;break x}y:{if(_l(g,e)){if(_l(g,f)){x[h>>2]=g;f=g}if(_l(e,x[i>>2])){continue}break y}if(_l(e,f)){x[h>>2]=e;f=e}e=g;if(_l(e,x[i>>2])){continue}}x[i>>2]=e;continue}}fb=q+16|0;fb=p+16|0;x[b+4>>2]=0-v[x[b+8>>2]];t=b,u=v[x[ec(l)>>2]],x[t>>2]=u;z:{g=x[Ze(b+4|0,b)>>2];if((g|0)>126|!g){break z}e=wb(o);x[b+4>>2]=e;f=Yk(o,m);while(1){if(!Ib(e,f)){break z}v[e|0]=(D(v[e|0],127)|0)/(g|0);e=x[me(b+4|0)>>2];continue}}}fb=b+16|0;A:{if((y[a+134|0]-101&255)>>>0>98){break A}b=z[c+34>>1];f=D(x[c>>2],_d(b));e=x[c+20>>2];if(b&1){x[j+8>>2]=e;x[j+12>>2]=(e+(f<<1)|0)-e>>1;g=x[j+12>>2];f=y[a+134|0];h=fb-16|0;fb=h;b=x[j+8>>2];e=wb(b);x[h+12>>2]=e;k=(3276800-(f<<14)|0)/100|0;f=0-k|0;i=32768-k|0;b=on(b,g);while(1){if(Ib(e,b)){g=w[e>>1];B:{if((g|0)>(k|0)){l=i+((D(k,g-k|0)|0)/(i|0)|0)|0;break B}l=((D(k,g+k|0)|0)/(i|0)|0)-i|0;if((f|0)>(g|0)){break B}l=(D(g,i)|0)/(k|0)|0}t=e,u=ed(l),w[t>>1]=u;e=x[Md(h+12|0)>>2];continue}break}fb=h+16|0;break A}b=yo(j,e,e+f|0);h=x[b>>2];g=x[b+4>>2];b=y[a+134|0];i=fb-16|0;fb=i;e=wb(h);x[i+12>>2]=e;l=(3276800-(b<<14)|0)/100|0;f=0-l|0;k=32768-l|0;b=Yk(h,g);while(1){if(Ib(e,b)){g=v[e|0]<<8;C:{if((g|0)>(l|0)){h=k+((D(l,g-l|0)|0)/(k|0)|0)|0;break C}h=((D(l,g+l|0)|0)/(k|0)|0)-k|0;if((f|0)>(g|0)){break C}h=(D(g,k)|0)/(l|0)|0}t=e,u=wY((h|0)/256|0),v[t|0]=u;e=x[me(i+12|0)>>2];continue}break}fb=i+16|0}rW(c);if(y[a+128|0]!=8){break i}e=y[a+131|0];if(!e){break i}f=x[r>>2];if(!f){break i}b=x[j+180>>2];t=yb(c+68|0,0),u=b+D(f,e+1|0)|0,x[t>>2]=u;h=x[j+180>>2];x[c+12>>2]=h;x[c+16>>2]=h+x[r>>2];e=x[r>>2];g=y[a+131|0];if(e>>>0>268435456/(g>>>0)>>>0){break i}b=x[c>>2];f=D(e,g);if(b>>>0>268435456-f>>>0){break i}l=b+f|0;m=el(z[c+34>>1]);b=nv(l,m);if(!b){break i}h=h+D(e,g+1|0)|0;x[c>>2]=l;g=x[c+20>>2];k=x[j+180>>2];i=yc(b,g,D(m,k+x[r>>2]|0));e=g+D(k,m)|0;f=y[a+131|0];b=0;while(1){if((b|0)==(f|0)){yc(i+D(h,m)|0,g+D(m,k+x[r>>2]|0)|0,D(m,l-h|0));sW(c,i,l,d)}else{b=b+1|0;a=x[r>>2];yc(i+D(m,k+D(b,a)|0)|0,e,D(a,m));continue}break}}fb=j+192|0}function kka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-720|0;fb=d;xc(b);a:{b:{c:{d:{if(!Ci(b,d+712|0)){break d}if(!JR(x[d+712>>2],x[d+716>>2])){break d}if(!Ur(b,d+708|0)){break d}i=x[d+708>>2];if(!IR(i)){break d}e:{if((i|0)==1179012417){f=1;e=1313423693;break e}if((i|0)!=538987841){break d}f=2;e=1414090313}m=Ge(d+688|0,b);j=Nb(d+676|0);f:{g:{h:{i:{j:{k:{l:{if(!c){x[31725]=0;V(898,d+112|0,m|0,f|0,e|0);b=x[31725];x[31725]=0;if((b|0)!=1){break l}a=N()|0;break a}x[31725]=0;S(899,d+112|0,m|0,f|0);b=x[31725];x[31725]=0;if((b|0)==1){break k}}b=d+112|0;zv(j,b);ie(b);x[31725]=0;S(900,d+656|0,j|0,e|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;b=R(174,x[d+656>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}f=0;if(!b){break f}x[31725]=0;b=P(901,d+656|0,d+583|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}if(!b){break f}b=y[d+648|0];if(!b){break f}x[31725]=0;f=U(152,x[d+656>>2],x[d+664>>2],b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break j}if(!((c|0)!=0&f)){break f}x[31725]=0;O(248,a|0,8388608);b=x[31725];x[31725]=0;if((b|0)==1){break j}x[a+480208>>2]=y[d+647|0]<<4&16^28;w[d+112>>1]=y[d+648|0];w[d+464>>1]=127;o=a,q=z[Nc(d+112|0,d+464|0)>>1],w[o+480188>>1]=q;x[a+480196>>2]=y[d+649|0];x[a+480204>>2]=D(y[d+650|0],1e4);x[a+480200>>2]=y[d+655|0]<<1;x[31725]=0;O(132,a+1298344|0,((i|0)!=1179012417?16946:16980)|0);b=x[31725];x[31725]=0;if((b|0)==1){break j}x[31725]=0;b=P(1,d+568|0,13318)|0;e=x[31725];x[31725]=0;if((e|0)==1){break h}Ab(a+1298356|0,b);tb(b);b=d+112|0;o=a+1298404|0,q=x[Fc(b,4)>>2],x[o>>2]=q;e=d+464|0;HC(e,2,d+583|0);x[31725]=0;O(220,b|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break i}b=d+112|0;Ab(a+1298308|0,b);tb(b);l=(i|0)==1179012417;b=0;while(1){m:{n:{o:{if(z[a+480188>>1]<=b>>>0){b=wb(x[j>>2]);f=wb(x[j+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=b;while(1){p:{if(!Ib(b,f)){break p}if(I$(1380209231,x[b>>2],x[b+4>>2])){break p}b=x[nm(e+12|0)>>2];continue}break}fb=e+16|0;if(Ib(b,wb(x[j+4>>2]))){break o}break g}f=(b<<5)+a|0;g=f+480280|0;Xe(g);x[31725]=0;e=R(199,d+656|0)|0;k=x[31725];x[31725]=0;q:{r:{if((k|0)!=1){if(l){break q}if(e>>>0<129){break r}break n}a=N()|0;break b}w[f+480284>>1]=e<<1;break m}if(e<<24>>24<0){break n}x[d+112>>2]=e<<2;x[d+464>>2]=256;o=f+480284|0,q=x[ud(d+112|0,d+464|0)>>2],w[o>>1]=q;break m}x[31725]=0;S(900,d+112|0,j|0,1380209231);b=x[31725];x[31725]=0;s:{if((b|0)!=1){x[31725]=0;b=R(199,d+112|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break s}e=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;aa(350,Xb(f,e)|0,d+112|0,b+1&255,255,254);b=x[31725];x[31725]=0;if((b|0)==1){break s}ub(d+112|0);break g}a=N()|0;break b}a=N()|0;ub(d+112|0);break b}x[g>>2]=1024}b=b+1|0;continue}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}t:{if(!(c&1)){break t}w[d+48>>1]=0;x[31725]=0;S(902,d+528|0,j|0,1414807888);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=x[d+532>>2];e=x[d+528>>2];x[31725]=0;f=a+484344|0;O(225,f|0,Uf(e,b)&65535);b=x[31725];x[31725]=0;u:{if((b|0)!=1){o=d,q=wb(x[d+528>>2]),x[o+76>>2]=q;l=wb(x[d+532>>2]);g=(i|0)!=1179012417;v:{w:{x:{y:{z:{while(1){b=x[d+76>>2];if(!Ib(b,l)){b=0;break v}b=Ge(d+112|0,b);x[31725]=0;e=R(199,b|0)|0;k=x[31725];x[31725]=0;if((k|0)!=1){x[31725]=0;w[d+452>>1]=e;e=R(153,b|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break z}x[31725]=0;S(187,d+464|0,b|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break y}e=ic(d+548|0,d+464|0);x[31725]=0;k=x[e+12>>2];x[d+8>>2]=x[e+8>>2];x[d+12>>2]=k;x[d+16>>2]=x[e+16>>2];k=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=k;V(903,d|0,z[d+452>>1],g|0,a|0);e=x[31725];x[31725]=0;if((e|0)==1){break x}ub(d+464|0);o=d,q=z[qe(d+48|0,d+452|0)>>1],w[o+48>>1]=q;ub(b);Sf(d+76|0);continue}break}a=N()|0;break w}a=N()|0;break w}a=N()|0;break w}a=N()|0;ub(d+464|0)}ub(b);break u}while(1){e=b&65535;if(e>>>0>=z[d+48>>1]){Qc(d+528|0);break t}A:{if(!He(x[a+484344>>2],x[a+484348>>2],e)){x[31725]=0;U(198,f|0,e|0,64)|0;e=x[31725];x[31725]=0;if((e|0)==1){break A}}b=b+1|0;continue}break}a=N()|0;break u}a=N()|0}Qc(d+528|0);break b}B:{C:{D:{if((i|0)==1179012417){x[31725]=0;S(902,d+76|0,j|0,1414745673);b=x[31725];x[31725]=0;if((b|0)==1){break C}o=d,q=wb(x[d+76>>2]),x[o+100>>2]=q;f=c&2;i=d+472|0;l=wb(x[d+80>>2]);while(1){b=x[d+100>>2];if(!Ib(b,l)){Qc(d+76|0);break B}c=Ge(d+528|0,b);x[31725]=0;b=P(904,c|0,d+112|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){E:{if(!b){break E}b=y[d+113|0];if((b|0)==255){break E}x[31725]=0;e=U(253,a|0,b+1|0,0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break D}if(!e){break E}g=z[a+480190>>1];b=0;x[31725]=0;S(905,d+112|0,e|0,g|0);e=x[31725];x[31725]=0;if((e|0)==1){break D}while(1){if(y[d+142|0]<=b>>>0){break E}F:{if(!vi(z[a+480190>>1])){break F}x[31725]=0;e=P(906,c|0,d+464|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break D}if(!e){break F}e=z[a+480190>>1]+1|0;w[a+480190>>1]=e;if(x[d+464>>2]!=1347240275){break F}g=d+452|0;bj(g,2,i);x[31725]=0;O(220,d+48|0,g|0);g=x[31725];x[31725]=0;G:{if((g|0)!=1){e=e&65535;g=d+48|0;zc(((e<<5)+a|0)+946304|0,g);tb(g);x[31725]=0;e=(D(e,104)+a|0)+484380|0;S(907,d+464|0,d+112|0,e|0);g=x[31725];x[31725]=0;if((g|0)==1){break D}if(!f){break G}g=d+48|0;HR(g,z[d+502>>1]);x[31725]=0;U(217,g|0,e|0,c|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break F}break D}break D}g=z[e+34>>1];e=x[e>>2];x[31725]=0;P(185,c|0,Xk(e,g)|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break D}}b=b+1|0;continue}}ub(c);Sf(d+100|0);continue}break}break D}x[31725]=0;S(902,d+452|0,j|0,1179011410);b=x[31725];x[31725]=0;if((b|0)!=1){o=d,q=wb(x[d+452>>2]),x[o+448>>2]=q;i=c&2;l=d+468|0;g=wb(x[d+456>>2]);H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{while(1){b=x[d+448>>2];if(!Ib(b,g)){Qc(d+452|0);break B}c=Ge(d+528|0,b);x[31725]=0;b=R(153,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break Q}R:{S:{if((b|0)!=538986817){break S}x[31725]=0;b=P(908,c|0,d+440|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break P}if(!(b&x[d+440>>2]==1414745673)){break S}x[31725]=0;b=P(909,c|0,d+112|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break O}if(!b){break S}b=y[d+117|0];if((b|0)==255){break S}x[31725]=0;b=U(253,a|0,b+1|0,0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break N}if(!b){break S}e=z[a+480190>>1];x[31725]=0;S(910,d+112|0,b|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break N}x[31725]=0;S(899,d+464|0,c|0,2);b=x[31725];x[31725]=0;if((b|0)==1){break R}x[31725]=0;S(902,d+100|0,d+464|0,1179011410);b=x[31725];x[31725]=0;if((b|0)==1){break M}ie(d+464|0);o=d,q=wb(x[d+100>>2]),x[o+96>>2]=q;k=wb(x[d+104>>2]);T:{U:{while(1){b=x[d+96>>2];if(!Ib(b,k)){break T}b=Ge(d+76|0,b);x[31725]=0;e=R(153,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break L}V:{W:{if((e|0)!=538989377){break W}e=z[a+480190>>1];if(!vi(e)){break W}f=y[d+436|0]|y[d+437|0]<<8;h=f-1|0;v[d+436|0]=h;v[d+437|0]=h>>>8;if(!f){ub(b);break T}h=e+1|0;w[a+480190>>1]=h;x[31725]=0;e=P(908,b|0,d+68|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break K}if(!(e&x[d+68>>2]==1347240275)){break U}x[31725]=0;S(187,d+464|0,b|0,x[d+72>>2]);e=x[31725];x[31725]=0;X:{if((e|0)!=1){f=d+464|0;e=ic(d+48|0,f);ub(f);x[31725]=0;f=P(911,e|0,f|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break V}if(f){break X}ub(e);ub(b);break T}a=N()|0;break I}f=d+24|0;We(f,2,l);x[31725]=0;O(220,d+36|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break J}f=h&65535;h=d+36|0;zc(((f<<5)+a|0)+946304|0,h);tb(h);x[31725]=0;f=(D(f,104)+a|0)+484380|0;S(912,d+464|0,d+112|0,f|0);h=x[31725];x[31725]=0;if((h|0)==1){break V}Y:{if(!i){break Y}x[31725]=0;P(151,e|0,x[d+464>>2]+4|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break V}h=d+36|0;HR(h,z[d+504>>1]);x[31725]=0;U(217,h|0,f|0,e|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break Y}break J}ub(e)}ub(b);Sf(d+96|0);continue}break}break J}ub(b)}Qc(d+100|0)}ub(c);Sf(d+448|0);continue}break}a=N()|0;break H}a=N()|0;break H}a=N()|0;break H}a=N()|0;break H}a=N()|0;break H}a=N()|0;ie(d+464|0);break H}a=N()|0;break I}a=N()|0;break I}a=N()|0;ub(e)}ub(b);Qc(d+100|0)}ub(c);Qc(d+452|0);break b}a=N()|0;break b}a=N()|0;ub(c);Qc(d+76|0);break b}a=N()|0;break b}f=1}ub(d+656|0);ie(j);ub(m)}fb=d+720|0;return f|0}a=N()|0}ub(d+656|0)}ie(j);ub(m);Q(a|0);p()}function w1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;e=fb-208|0;fb=e;xc(b);a:{if(!Ur(b,e+204|0)){break a}x[e+184>>2]=0;x[e+188>>2]=0;x[e+176>>2]=0;x[e+180>>2]=0;x[e+168>>2]=0;x[e+172>>2]=0;x[e+160>>2]=0;x[e+164>>2]=0;b:{c:{if(!dF(e+204|0)){break c}if(!Mb(x[b>>2],x[b+8>>2],32)){break c}Cw(b,e+160|0);break b}m=1;if(!cF(e+204|0)){break a}}j=e+155|0;f=bF(y[e+207|0]);d=fb-32|0;fb=d;x[d+28>>2]=f;x[d+8>>2]=5;g=x[b>>2];h=x[b+8>>2];f=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(g,h,f)){f=lf(b)}l=d+8|0;ik(l,j);k=gc(d+16|0,x[d+8>>2],f);g=x[k>>2];kc(d,x[b>>2],x[b+8>>2],g,x[k+4>>2]);ik(l,j);Tb(x[d+8>>2]+f|0,0,5-f|0);Vb(b,x[d+28>>2]);fb=d+32|0;if(!f){break a}if(!aF(e+155|0,y[e+207|0])){break a}if(!c){n=1;break a}j=e+207|0;Bd(a,2048);gg(a);d:{e:{f:{g:{h:{i:{j:{k:{if(m){d=fb-16|0;fb=d;f=e+4|0;l=tc(d+4|0,3893);_c(f,l);tb(l);fb=d+16|0;x[31725]=0;S(211,e+72|0,f|0,j|0);d=x[31725];x[31725]=0;if((d|0)==1){break j}d=e+72|0;Ab(a+1298344|0,d);tb(d);Eb(e+4|0);f=tc(d,11144);Ab(a+1298356|0,f);break k}d=e+4|0;We(d,2,e+160|0);f=e+72|0;Cc(f,d);Ab(a+1298308|0,f);tb(f);l=fb-16|0;fb=l;k=tc(l+4|0,3944);_c(d,k);tb(k);fb=l+16|0;x[31725]=0;S(211,f|0,d|0,j|0);d=x[31725];x[31725]=0;if((d|0)==1){break i}d=e+72|0;Ab(a+1298344|0,d);tb(d);Eb(e+4|0);f=tc(d,11148);Ab(a+1298356|0,f)}tb(f);A=a+1298404|0,B=x[Fc(e+72|0,4)>>2],x[A>>2]=B;w[a+480188>>1]=y[e+159|0];w[a+480190>>1]=y[e+155|0];l:{f=y[e+207|0];if(f>>>0>8){break l}w[a+480188>>1]=4;d=0;while(1){if((d|0)==4){break l}w[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;continue}}m:{if(f>>>0>=11){f=(f|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break m}j=Lw(b);n:{if((j|0)==100){x[((d<<5)+a|0)+480280>>2]=256;break n}x[e+72>>2]=(j<<1)+128;x[e+4>>2]=0;x[e+140>>2]=256;A=((d<<5)+a|0)+480284|0,B=x[hk(e+72|0,e+4|0,e+140|0)>>2],w[A>>1]=B}d=d+1|0;continue}}if(f>>>0<9){break m}Vb(b,16);d=0;while(1){if((d|0)==16){break m}w[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;continue}}o:{if(y[e+207|0]>=13){d=e+72|0;Iw(d,b);f=Jc(d);d=y[e+72|0];if(d>>>0<=31){v[e+72|0]=125;d=125}x[a+480204>>2]=D(d,1e4);x[a+480196>>2]=y[f|0];break o}x[a+480196>>2]=6;x[a+480204>>2]=125e4}xg(Xb(x[a+484360>>2],y[a+484376|0]),y[e+156|0]);l=Nb(e+140|0);d=x[b+8>>2];f=y[e+207|0]>13;if(!f){break h}x[31725]=0;O(212,l|0,y[e+156|0]);j=x[31725];x[31725]=0;if((j|0)!=1){break h}d=N()|0;break g}d=N()|0;Eb(e+4|0);break f}d=N()|0;Eb(e+4|0);break f}s=d+(f<<1)|0;d=0;p:{q:{while(1){if(y[e+156|0]<=d>>>0){j=0;if(y[e+207|0]!=10){break p}g=x[b+8>>2];d=1;while(1){j=z[a+480190>>1]>=(d&65535)>>>0;if(!j){break q}x[31725]=0;f=P(213,b|0,e+72|0)|0;k=x[31725];x[31725]=0;if((k|0)!=1){if(f){f=0;r:{if(y[e+155|0]<(y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24))>>>0|y[e+72|0]>1){break r}k=y[e+122|0]|y[e+123|0]<<8|(y[e+124|0]<<16|y[e+125|0]<<24);if(k>>>0>1048576|y[e+128|0]>64|k>>>0<(y[e+129|0]|y[e+130|0]<<8|(y[e+131|0]<<16|y[e+132|0]<<24))>>>0){break r}f=k>>>0>=(y[e+133|0]|y[e+134|0]<<8|(y[e+135|0]<<16|y[e+136|0]<<24))>>>0}if(!f){break q}}d=d+1|0;continue}break}d=N()|0;break g}A=_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],d),B=d,w[A>>1]=B;s:{if(y[e+207|0]>=14){x[31725]=0;f=R(191,b|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break s}A=_b(x[l>>2],d),B=f,w[A>>1]=B}f=z[a+480188>>1];x[31725]=0;P(185,b|0,f<<1)|0;f=x[31725];x[31725]=0;if((f|0)==1){break s}d=d+1|0;continue}break}d=N()|0;break g}x[31725]=0;P(151,b|0,g|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break p}d=N()|0;break g}d=z[a+480190>>1];x[31725]=0;x[e+72>>2]=0;k=U(214,e+60|0,d|0,e+72|0)|0;d=x[31725];x[31725]=0;t:{u:{v:{w:{if((d|0)!=1){n=j?59:65;g=e+73|0;d=1;x:{while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){j=Nb(e+48|0);x[31725]=0;n=U(215,b|0,j|0,y[e+157|0]|y[e+158|0]<<8)|0;d=x[31725];x[31725]=0;y:{if((d|0)!=1){if(!n){break d}d=0;f=0;g=x[j>>2];if(!lc(g,x[j+4>>2])){f=wb(g);i=wb(x[j+4>>2]);g=fb-16|0;fb=g;z:{if(!Ib(f,i)){break z}x[g+12>>2]=f;while(1){h=x[Md(g+12|0)>>2];if(!Ib(h,i)){break z}f=dl(y[f|0]|y[f+1|0]<<8,y[h|0]|y[h+1|0]<<8)?h:f;continue}}fb=g+16|0;f=y[f|0]|y[f+1|0]<<8}x[31725]=0;h=P(216,e+24|0,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break y}A:{while(1){if((d|0)==(f|0)){if(!(c&2)){break w}r=Xc(e+4|0,8,1,0,m?2:1);d=z[a+480190>>1];i=1;B:{C:{D:while(1){o=i&65535;if(o>>>0>(d&65535)>>>0){break w}d=x[b+8>>2];g=x[b>>2];x[31725]=0;d=U(152,g|0,d|0,1)|0;g=x[31725];x[31725]=0;if((g|0)==1){break B}if(!d){break w}t=x[b+8>>2];g=0;E:while(1){d=z[a+480190>>1];if(g>>>0>=d>>>0){i=i+1|0;continue D}if((o|0)!=x[yb(x[k>>2],g)>>2]){g=g+1|0;continue}x[31725]=0;P(151,b|0,t|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;g=g+1|0;d=D(g,104)+a|0;q=d+484380|0;U(217,r|0,q|0,b|0)|0;u=x[31725];x[31725]=0;if((u|0)==1){break C}if(!m){continue}bc(e+72|0,x[d+484400>>2],x[q>>2]);A=e,B=wb(x[e+72>>2]),x[A>>2]=B;q=Yk(x[e+72>>2],x[e+76>>2]);while(1){d=x[e>>2];if(!Ib(d,q)){continue E}v[d|0]=y[d|0]^128;me(e);continue}}break}break}d=N()|0;break v}d=N()|0;break v}d=N()|0;break v}x[31725]=0;g=R(191,b|0)|0;i=x[31725];x[31725]=0;F:{if((i|0)==1){break F}x[31725]=0;P(185,b|0,1)|0;i=x[31725];x[31725]=0;if((i|0)==1){break F}if(g){x[31725]=0;S(187,e+4|0,b|0,D(g,3)+(y[e+207|0]==1?3:0)|0);g=x[31725];x[31725]=0;if((g|0)==1){break A}i=e+4|0;g=ic(e+72|0,i);hd(eh(x[h>>2],d),g);ub(g);ub(i)}d=d+1|0;continue}break}d=N()|0;break v}d=N()|0;break v}d=N()|0;break u}d=N()|0;break u}G:{H:{if(y[e+207|0]<=9){x[31725]=0;O(218,b|0,e+72|0);h=x[31725];x[31725]=0;I:{J:{if((h|0)==1){break J}x[31725]=0;O(219,e+72|0,(D(f,104)+a|0)+484380|0);h=x[31725];x[31725]=0;if((h|0)==1){break J}h=e+48|0;We(h,2,g);x[31725]=0;O(220,e+4|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break I}h=e+4|0;zc(((f<<5)+a|0)+946304|0,h);tb(h);A=yb(x[k>>2],f-1|0),B=y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24),x[A>>2]=B;break H}d=N()|0;break t}d=N()|0;break t}if(m){x[31725]=0;O(221,b|0,e+72|0);h=x[31725];x[31725]=0;K:{L:{if((h|0)==1){break L}x[31725]=0;O(222,e+72|0,(D(f,104)+a|0)+484380|0);h=x[31725];x[31725]=0;if((h|0)==1){break L}x[31725]=0;h=P(36,e+36|0,22255)|0;i=x[31725];x[31725]=0;if((i|0)==1){break K}zc(((f<<5)+a|0)+946304|0,h);tb(h);A=yb(x[k>>2],f-1|0),B=y[e+74|0]|y[e+75|0]<<8|(y[e+76|0]<<16|y[e+77|0]<<24),x[A>>2]=B;break H}d=N()|0;break t}d=N()|0;break t}x[31725]=0;S(223,b|0,e+72|0,n|0);h=x[31725];x[31725]=0;if((h|0)==1){break G}x[31725]=0;S(224,e+72|0,(D(f,104)+a|0)+484380|0,j|0);h=x[31725];x[31725]=0;if((h|0)==1){break G}h=e+48|0;We(h,2,g);x[31725]=0;O(220,e+4|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break x}h=e+4|0;zc(((f<<5)+a|0)+946304|0,h);tb(h);A=yb(x[k>>2],f-1|0),B=y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24),x[A>>2]=B}d=d+1|0;continue}break}d=N()|0;break t}d=N()|0;break t}d=N()|0;break g}if(!(c&1)){break e}x[31725]=0;m=a+484344|0;O(225,m|0,y[e+156|0]);c=x[31725];x[31725]=0;M:{if((c|0)!=1){c=0;while(1){N:{if(y[e+156|0]<=c>>>0){break e}d=64;g=x[l>>2];if(Zc(g,x[l+4>>2])>>>0>c>>>0){d=z[_b(g,c)>>1]}x[31725]=0;d=U(198,m|0,c&65535,d&65535)|0;g=x[31725];x[31725]=0;if((g|0)==1){break M}O:{if(d){d=z[a+480188>>1];x[31725]=0;P(151,b|0,D(((y[e+207|0]>13)<<1)+(d<<1)|0,c)+s|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break M}g=Nb(e+72|0);d=z[a+480188>>1];x[31725]=0;i=U(215,b|0,g|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break O}d=0;P:{if(!i){break P}while(1){if(z[a+480188>>1]<=d>>>0){break P}Q:{i=_b(x[g>>2],d);i=(y[i|0]|y[i+1|0]<<8)-1|0;if((i&65535)>>>0>=(y[e+157|0]|y[e+158|0]<<8)>>>0){break Q}i=_b(x[j>>2],i);i=(y[i|0]|y[i+1|0]<<8)-1&65535;if(i>>>0>=f>>>0){break Q}r=x[m>>2];o=x[h>>2];x[31725]=0;S(226,Wb(r,c)|0,d&65535,eh(o,i)|0);i=x[31725];x[31725]=0;if((i|0)!=1){break Q}break N}d=d+1|0;continue}}md(g)}c=c+1|0;continue}}break}d=N()|0;md(g);break v}d=N()|0;break v}d=N()|0}Qc(h)}md(j)}uc(k)}md(l)}Q(d|0);p()}Qc(h)}md(j);uc(k);md(l)}fb=e+208|0;return n|0}function G2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0;e=fb-1456|0;fb=e;xc(b);Tp(a);a:{b:{c:{if(!ss(b,e+1432|0)){break c}if(!OG(e+1432|0)){break c}if(!c){j=1;break c}if(!Dm(x[b>>2],y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))){break c}if(!Dm(x[b>>2],(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+((y[e+1444|0]|y[e+1445|0]<<8)<<2)|0)){break c}px(a);w=e,B=ox(),x[w+68>>2]=B;c=e+68|0;nx(mj(x[a+4>>2])+32|0,c);rs(c);m=x[mj(x[a+4>>2])+32>>2];x[e+1428>>2]=y[e+1446|0]|y[e+1447|0]<<8|(y[e+1448|0]<<16|y[e+1449|0]<<24);w=e,B=lh(x[b>>2]),x[w+1168>>2]=B;x[e+1136>>2]=214748364;d=e+1168|0;w=e,B=D(x[Gb(d,e+1136|0)>>2],20),x[w+68>>2]=B;xo(m,x[Gb(e+1428|0,c)>>2]);Tb(d,0,256);s=Nb(e+1156|0);while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{j=(y[e+1444|0]|y[e+1445|0]<<8)>>>0<=t>>>0;if(!j){x[31725]=0;c=P(151,b|0,(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+(t<<2)|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break r}if(!c){break h}c=x[b+8>>2];d=x[b>>2];x[31725]=0;c=U(152,d|0,c|0,4)|0;d=x[31725];x[31725]=0;if((d|0)==1){break r}if(!c){break h}x[31725]=0;c=R(153,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break q}x[31725]=0;d=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break q}if(!d){break h}x[31725]=0;d=P(154,b|0,e+1136|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break p}if(!d){break h}x[31725]=0;d=U(155,b|0,s|0,y[e+1148|0]|y[e+1149|0]<<8)|0;f=x[31725];x[31725]=0;if((f|0)==1){break p}if(!d){break h}f=x[s>>2];g=x[b>>2];x[31725]=0;d=y[e+1148|0]|y[e+1149|0]<<8;g=R(156,g|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break o}i=c+20|0;if(g>>>0<=i+(d<<3)>>>0){break h}c=d?f:0;f=y[e+1148|0]|y[e+1149|0]<<8;g=i+(f<<3)|0;d=0;i=y[e+1150|0]|y[e+1151|0]<<8;if(!(i&1)){while(1){if(d>>>0>=f>>>0){break d}if(!c){break h}f=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);i=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31725]=0;f=ba(157,i|0,f|0,m|0,x[e+1428>>2])|0;i=x[31725];x[31725]=0;s:{if((i|0)==1){break s}if(!f){break h}x[31725]=0;f=P(151,b|0,g|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break s}if(!f){break h}f=gc(e+1128|0,xb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24));i=x[f>>2];f=x[f+4>>2];x[31725]=0;co(158,e+68|0,b,i,f);f=x[31725];x[31725]=0;if((f|0)==1){break n}if(x[e+72>>2]!=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))){break h}d=d+1|0;c=c+8|0;f=y[e+1148|0]|y[e+1149|0]<<8;continue}break}j=N()|0;break a}t:{if(i&4){if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31725]=0;d=ba(157,f|0,d|0,m|0,x[e+1428>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break m}if(!d){break h}n=xb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))&-2;if(!l){break h}x[31725]=0;f=y[e+1154|0]|y[e+1155|0]<<8;d=P(151,b|0,g+(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break l}if(!d){break h}d=x[b+8>>2];g=x[b>>2];x[31725]=0;d=U(152,g|0,d|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break l}if(!d){break h}x[31725]=0;S(159,e+48|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}d=e+48|0;k=qs(e+68|0,d);ub(d);r=0;i=0;while(1){g=0;u:{while(1){if((i&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}x[31725]=0;d=P(160,k|0,f+1|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break u}h=f&15;o=z[(h<<1)+24352>>1];v:{w:{if(o>>>0<=d>>>0){x[31725]=0;h=y[h+24400|0];q=P(160,k|0,h|0)|0;u=x[31725];x[31725]=0;if((u|0)==1){break u}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&15;break v}x[31725]=0;d=P(160,k|0,4)|0;h=x[31725];x[31725]=0;if((h|0)==1){break u}if((d|0)==15){x[31725]=0;h=P(160,k|0,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break u}d=65535;if(!h){break w}break e}d=d+65520|0}if(d>>>0>65535){break v}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;q=g+n|0;h=y[e+1150|0]|y[e+1151|0]<<8;x:{if(h&2){r=d+r|0;d=r;break x}d=h&512?d:d^32768}o=d>>>8|0;h=h&1024;v[q+1|0]=h?d:o;v[q|0]=h?o:d;g=g+2|0}if(g>>>0<l>>>0){continue}break}i=i+1|0;if(i>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}d=(i<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);l=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[31725]=0;g=ba(157,g|0,l|0,m|0,x[e+1428>>2])|0;l=x[31725];x[31725]=0;if((l|0)==1){break u}if(!g){break t}l=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))&-2;if(!l){break t}n=xb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=T(28848)|0;if((gb|0)==($(28848)|0)){Y(j|0)|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){break e}j=N()|0}ub(k);break a}if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31725]=0;d=ba(157,f|0,d|0,m|0,x[e+1428>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break k}if(!d){break h}r=xb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));if((y[e+1152|0]|y[e+1153|0]<<8)>>>0>256){break h}n=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[e+1154|0]|y[e+1155|0]<<8;x[31725]=0;d=P(151,b|0,g|0)|0;g=x[31725];x[31725]=0;y:{z:{if((g|0)!=1){if(!d){break h}d=gc(e+40|0,e+1168|0,y[e+1152|0]|y[e+1153|0]<<8);g=x[d>>2];d=x[d+4>>2];x[31725]=0;co(161,e+68|0,b,g,d);d=x[31725];x[31725]=0;if((d|0)==1){break z}d=y[e+1152|0]|y[e+1153|0]<<8;if(d>>>0>A[e+72>>2]){break h}g=x[b+8>>2];i=x[b>>2];x[31725]=0;d=U(152,i|0,g|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-d|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){break y}}j=N()|0;break a}j=N()|0;break a}if(!d){break h}x[31725]=0;S(159,e+48|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);d=x[31725];x[31725]=0;if((d|0)==1){break f}d=e+48|0;k=qs(e+68|0,d);ub(d);l=0;i=0;while(1){g=0;A:{while(1){if((l&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}x[31725]=0;d=P(160,k|0,f+1|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}h=f&7;o=y[h+24384|0];B:{C:{if(o>>>0<=d>>>0){x[31725]=0;h=y[h+24392|0];q=P(160,k|0,h|0)|0;u=x[31725];x[31725]=0;if((u|0)==1){break A}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&7;break B}x[31725]=0;d=P(160,k|0,3)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}if((d|0)==7){x[31725]=0;h=P(160,k|0,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break A}d=255;if(!h){break C}break g}d=d+248|0}if(d>>>0>255){break B}}d=y[(e+1168|0)+d|0];h=d+i|0;q=d;d=(y[e+1150|0]|y[e+1151|0]<<8)&2;v[g+r|0]=d?h:q;i=d?h:i;g=g+1|0}if(g>>>0<n>>>0){continue}break}l=l+1|0;if(l>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}d=(l<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[31725]=0;g=ba(157,g|0,n|0,m|0,x[e+1428>>2])|0;n=x[31725];x[31725]=0;if((n|0)==1){break A}if(!g){break j}n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);r=xb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=T(28848)|0;if((gb|0)==($(28848)|0)){Y(j|0)|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){break g}j=N()|0}ub(k);break a}ub(k);break h}oe(e+24|0,x[m>>2],x[m+4>>2]);mf(e+32|0,x[e+24>>2],x[e+28>>2]);b=Nd(e+16|0);x[31725]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;b=jg(162,e+68|0,x[e+32>>2],x[e+36>>2],e+8|0);c=x[31725];x[31725]=0;if((c|0)==1){break i}hd(mj(x[a+4>>2])+12|0,b);ub(b);break h}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}ub(k);break h}j=N()|0;break a}Ae(s);break c}ub(k);break d}j=N()|0;break a}ub(k)}t=t+1|0;continue}}fb=e+1456|0;return j|0}j=N()|0}Ae(s);Q(j|0);p()}function Iqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;e=fb-368|0;fb=e;a:{if(!cd(b,1080)){break a}if(!rr(b,e+364|0)){break a}l=tY(e+344|0);if(!sY(e+364|0,l)){break a}d=z[l+10>>1];if(!d|d>>>0>127){break a}if(!c){R=1;break a}T=1;Bd(a,1);g=z[l+10>>1];w[a+480188>>1]=g;I=y[l+14|0];V=y[l+13|0];m=y[l+12|0];if(!ne(e+364|0,25242)){T=ne(e+364|0,25247)}if(y[l+15|0]){Lb(a+1074312|0,5,1);g=z[a+480188>>1]}d=e+364|0;s=ne(d,16755);n=1;if(!ne(d,17517)){n=ne(e+364|0,13686)}u=a+480188|0;B=(g&65535)==8&(V|0)!=0;cd(b,0);k=y[l+16|0];g=fb-16|0;fb=g;b:{f=e+324|0;d=f;if(!gx(b,d)|!k){break b}ex(g+8|0,d);while(1){if(i>>>0>=20){break b}d=x[g+8>>2];tg(xb(d,i),xb(d,i|1));i=i+2|0;continue}}fb=g+16|0;d=e+312|0;df(d,f,20,3);f=e+180|0;Cc(f,d);Ab(a+1298308|0,f);tb(f);w[a+480190>>1]=31;m=(m|0)!=0;g=1;f=0;i=s;while(1){if((g|0)==32){R=A[l+4>>2]>=o>>>0;if(!R){break a}}else{d=y[l+16|0];q=fb-16|0;fb=q;c:{j=e+180|0;if(!iY(b,j)|!d){break c}Ev(q+8|0,j);d=0;while(1){if(d>>>0>=30){break c}k=x[q+8>>2];tg(xb(k,d),xb(k,d|1));d=d+2|0;continue}}fb=q+16|0;k=j;j=D(g,104)+a|0;d=j+484380|0;k=UC(k,d,((g<<5)+a|0)+946304|0,z[a+480188>>1]==4);q=x[d>>2];d:{if(n){v[j+484417|0]=0-(y[e+204|0]<<3);break d}m=q>>>0<65536&m}j=Bb(y[e+202|0]|y[e+203|0]<<8);e:{if(j){Y=!Bb(y[e+208|0]|y[e+209|0]<<8)|Y;break e}Z=y[e+205|0]==64|Z}d=i&1;i=0;f:{if(!d){break f}h=(j<<1)+h|0;d=y[e+204|0];i=!d;if(d|!j){break f}i=y[e+205|0]==64}o=k+o|0;f=f+q|0;g=g+1|0;continue}break}k=y[l+16|0];j=fb-16|0;fb=j;g:{d=e+180|0;if(!OC(b,d)|!k){break g}TC(j+8|0,d);g=0;while(1){if(g>>>0>=130){break g}d=x[j+8>>2];tg(xb(d,g),xb(d,g|1));g=g+2|0;continue}}fb=j+16|0;cd(b,z[l+8>>1]);k=y[e+181|0];d=128;jw(Xb(x[a+484360>>2],y[a+484376|0]),e+182|0,128);j=!k&i;i=j?h:0;k=y[e+180|0];h:{if(k>>>0>=129){o=y[a+484376|0];h=x[a+484360>>2];break h}o=y[a+484376|0];h=x[a+484360>>2];if(k){d=k;break h}k=x[Xb(h,o)>>2];g=128;while(1){d=g;if(d>>>0<2){d=1;break h}g=d-1|0;if(!z[_b(k,g)>>1]){continue}break}}q=qY(b,Xb(h,o),d&65535,f,u,i,0);J=1;i:{if(!(j&z[u>>1]==8)){J=(I|0)!=0;break i}x[l>>2]=11263}j:{if(!B){break j}f=Xb(x[a+484360>>2],y[a+484376|0]);aa=e,ba=wb(x[f>>2]),x[aa+312>>2]=ba;f=wb(x[f+4>>2]);while(1){h=x[e+312>>2];if(!Ib(h,f)){break j}w[h>>1]=z[h>>1]>>>1;Md(e+312|0);continue}}bf(Xb(x[a+484360>>2],y[a+484376|0]),y[e+181|0]);I=d-1|0;d=y[e+181|0];k:{if((I&65535)>>>0>=d>>>0){g=z[u>>1];if((d|0)!=120|(g|0)!=4){break k}}bf(Xb(x[a+484360>>2],y[a+484376|0]),0);g=z[a+480188>>1]}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;x[a+480208>>2]=0;aa=a,ba=Yb(256/((g&65535)>>>0)|0,32,128),x[aa+480228>>2]=ba;Yh(a,0);v[e+179|0]=0;l:{if(m&1){E=1;k=1;break l}E=1;n=0;m=0;h=s;m:while(1){k=m&65535;if(k>>>0<q>>>0){d=0;g=0;while(1)if((g|0)==256){m=m+1|0;continue m}else{i=ch(e+312|0);pY(e+160|0,b,!k&y[l+16|0]!=0);f=x[e+160>>2];x[e+172>>2]=f;x[e+64>>2]=f;f=e+92|0;lp(f,e- -64|0,i);j=Jc(f);i=KD(y[i|0]);n:{o:{p:{q:{t=y[e+92|0];if((t-7&255)>>>0<3){h=0;break q}f=y[j|0];if(!((t|0)!=14|f>>>0<=1)){h=0;break p}if(!((t|0)==15&(f&255)>>>0>31)){h=i?h:0;if((t|0)!=13){break q}d=d+1|0;if((d&65535)>>>0<2){break n}}h=0;break n}if((t|0)==8){break o}if((t|0)!=14){break n}f=y[j|0]}if((f&240)!=128){break n}v[e+80|0]=f<<4;aa=e,ba=y[ef(e+179|0,e+80|0)|0],v[aa+179|0]=ba;break n}aa=e,ba=y[ef(e+179|0,j)|0],v[aa+179|0]=ba;f=v[j|0];if((f|0)>=0){F=1;break n}n=(f|0)!=-92&f>>>0>4294967183|n}E=i&E;g=g+1|0;continue}}break}d=F^-1;F=0;F=(d|n)&1?F:y[e+179|0]>47;k=h&1}cd(b,z[l+8>>1]);d=z[a+480188>>1];G=a+484344|0;W=q+B&65535;Vf(G,W);t=B?4:d;H=a+1074312|0;j=c&1;n=0;m=0;r:{s:{t:{u:{while(1){if((n|0)==(W|0)){break t}v:{if(B){f=(n&65534)>>>1|0;d=n&1;if(!d){if(!Ng(G,f,64)){break t}}i=d<<2;d=Wb(x[G>>2],f);break v}if(!Ng(G,n&65535,64)){break t}i=0;d=Wb(x[G>>2],n)}h=0;i=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,i);if(!j){K=0;L=0;break s}d=z[u>>1];v[e+92|0]=0;f=e+92|0;M=ew(e+312|0,d,f);d=z[u>>1];x[31725]=0;v[e+92|0]=0;O=U(601,e+160|0,d|0,f|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){X=0;w:{x:while(1){y:{if((X|0)==64){break w}g=0;f=0;q=0;while(1){if((g|0)==(t|0)){X=X+1|0;K=f&q|K;i=D(z[u>>1],6)+i|0;continue x}d=y[l+16|0];x[31725]=0;S(602,e+92|0,b|0,!n&(d|0)!=0);d=x[31725];x[31725]=0;if((d|0)!=1){d=x[e+92>>2];x[e+156>>2]=d;x[e+60>>2]=d;h=e+80|0;r=D(g,6)+i|0;lp(h,e+60|0,r);d=y[e+80|0];h=Jc(h);o=y[h|0];if(d|o){z:{if(!(!V|(d&255)!=14)){d=0;v[h|0]=0;v[e+80|0]=0;o=y[h|0];break z}if(!V|(d&255)!=15|(o&255)>>>0<32){break z}o=31;v[h|0]=31;d=y[e+80|0]}Bf(r,d&255,o&255)}d=1;A:{B:{C:{D:{E:{h=y[r+3|0];switch(h-14|0){case 2:break A;case 0:break D;case 3:break E;default:break C}}m=y[r+5|0]<100|m;q=1;break B}if(!k){break B}v[r+5|0]=0;break B}if((h|0)==9&F){d=y[r+5|0];if((d|0)==164){v[r+3|0]=20;v[r+5|0]=145;break B}aa=r,ba=bh(d<<1),v[aa+5|0]=ba;break B}if((h|0)!=19){break B}d=y[r+5|0];if(d>>>0>15){break B}d=!(d&1);h=(d^_)&1;_=h?d:_;L=h+L|0}d=f}F:{if(!y[r|0]){h=y[r+1|0];if(!h|B){break F}f=y[xb(x[M>>2],g)|0];if(!f|(f|0)==(h|0)){break F}f=xb(x[O>>2],g);h=y[f|0]+1|0;v[f|0]=h;if((h&255)>>>0<4){break F}x[31725]=0;U(268,H|0,85,1)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break F}break y}aa=xb(x[O>>2],g),ba=0,v[aa|0]=ba}f=y[r+1|0];if(f){aa=xb(x[M>>2],g),ba=f,v[aa|0]=ba}g=g+1|0;f=d;continue}break}}break}i=N()|0;dc(O);break u}dc(O);dc(M);n=n+1|0;continue}break}i=N()|0}dc(M);break r}h=m}G:{H:{I:{f=E^1;if((f|Y)&1){break I}J:{if(ne(e+364|0,16755)){break J}if(ne(e+364|0,17522)){break J}if(!ne(e+364|0,13681)){break I}}x[a+480208>>2]=x[a+480208>>2]|2162688;d=Lb(Lb(Lb(H,85,1),91,1),92,1);K:{if(y[e+179|0]>47){break K}d=Lb(d,84,1);if(y[e+181|0]==127){break K}Lb(d,83,1)}if(!((L|0)>6|J)){break H}break G}if(!(E&1)){if(!(y[e+181|0]==127&(I&65535)>>>0<129&s)){break G}x[l>>2]=8494;break G}if((L|0)>6|J){break G}}x[a+480208>>2]=x[a+480208>>2]|8388608}if((s|J)==1){Lb(H,89,1)}if(T){Lb(H,84,1)}i=0;L:{if(!(c&2)){break L}cd(b,z[l+8>>1]+(D(t,W)<<8)|0);m=(f|s^1|Z)&1;g=1;while(1){if((g|0)==32){i=i&1;break L}k=D(g,104)+a|0;j=k+484380|0;d=x[j>>2];if(d){o=2;if(!T){c=oY(b,13884);o=c?10:0;i=c?1:i;d=x[j>>2]}f=Xc(e+312|0,8,1,0,o);c=wD(f,d)+x[b+8>>2]|0;if(!m){aa=j,ba=x[ad(j,k+484388|0)>>2],x[aa>>2]=ba}fg(f,j,b);cd(b,c)}g=g+1|0;continue}}M:{N:{if(!s){if(!((ne(e+364|0,17522)&h^-1|K)&1)){break N}break M}if((h^-1|K)&1){break M}}c=nY(e+128|0,0);b=x[c+20>>2];x[e+48>>2]=x[c+16>>2];x[e+52>>2]=b;b=x[c+12>>2];x[e+40>>2]=x[c+8>>2];x[e+44>>2]=b;b=x[c+4>>2];x[e+32>>2]=x[c>>2];x[e+36>>2]=b;b=e+312|0;Dv(b,a,0,e+32|0);$=C[x[e+312>>2]>>3];Yi(b);if(!($>=480)){break M}d=Lb(H,5,1);c=mY(e+104|0,$);b=x[c+20>>2];x[e+24>>2]=x[c+16>>2];x[e+28>>2]=b;b=x[c+12>>2];x[e+16>>2]=x[c+8>>2];x[e+20>>2]=b;b=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=b;c=e+312|0;Dv(c,a,0,e+8|0);b=y[x[e+312>>2]+26|0];Yi(c);if(b){dg(d,5);break M}x[l>>2]=17089}d=e+364|0;f=d;s=ec(d);b=d;while(1){if((f|0)!=(s|0)){c=y[f|0];v[b|0]=c>>>0<=32?32:c;b=b+1|0;f=f+1|0;continue}break}ig(e+92|0,16842);x[31725]=0;c=U(44,e+68|0,d|0,s|0)|0;b=x[31725];x[31725]=0;O:{P:{Q:{R:{S:{if((b|0)!=1){x[31725]=0;S(603,e+80|0,1,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break S}x[31725]=0;S(141,e+312|0,e+92|0,e+80|0);b=x[31725];x[31725]=0;if((b|0)==1){break R}b=e+312|0;Ab(a+1298344|0,b);tb(b);tb(e+80|0);tb(c);Eb(e+92|0);b=tc(b,12386);Ab(a+1298356|0,b);tb(b);b=x[l>>2];if(b){ci(a+1298368|0,b)}aa=a+1298404|0,ba=x[Fc(e+312|0,28)>>2],x[aa>>2]=ba;if(!i){break a}b=tc(e+312|0,17141);x[31725]=0;P(76,a+1298368|0,b|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break O}tb(b);break a}i=N()|0;break P}i=N()|0;break Q}i=N()|0;tb(e+80|0)}tb(c)}Eb(e+92|0);break r}i=N()|0;tb(b)}Q(i|0);p()}fb=e+368|0;return R|0}function pua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;e=fb+-64|0;fb=e;xc(a);a:{b:{if(b>>>0<=2){H=e,I=Zd(a),v[H+56|0]=I;Vb(a,2);b=ih(a);v[e+58|0]=b;v[e+59|0]=b>>>8;b=Pg(a);v[e+60|0]=b;v[e+61|0]=b>>>8;v[e+62|0]=b>>>16;v[e+63|0]=b>>>24;break b}qp(a,e+56|0);if(b>>>0>5){break a}}v[e+57|0]=0}c:{t=d+484344|0;F=Kd(y[e+58|0]|y[e+59|0]<<8,1,1024);q=eE(t,F);if((q|0)==65535){break c}b=Wb(x[d+484344>>2],q);h=jd(x[b>>2],x[x[b+48>>2]+12>>2],0,0);f=z[d+480188>>1];w[e+12>>1]=f-1;w[e+44>>1]=y[e+56|0];G=z[Nc(e+12|0,e+44|0)>>1];g=G+1|0;b=g&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){v[c+13|0]=y[e+57|0]>>>4;b=y[c+12|0];v[e+12|0]=0;b=(b|0)!=0;B=ew(e+44|0,g,e+12|0);d:while(1){if((l|0)==(F|0)){dc(B);break c}e:{f:{g=xb(x[B>>2],0);f=y[g|0];g:{if(!f){x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}h=g<<24>>24;if((h|0)<0){x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}H=xb(x[B>>2],0),I=g,v[H|0]=I}v[e+12|0]=0;h:{i:{g=h&63;if(!g){break i}x[31725]=0;k=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break h}v[e+12|0]=k;j:{k:{switch(g-1|0){case 0:v[c+12|0]=0;v[e+40|0]=1;H=c,I=y[ef(e+40|0,e+12|0)|0],v[H+14|0]=I;v[c+15|0]=0;break j;case 1:if(!k){break i}v[c+15|0]=k;v[c+12|0]=1;b=y[c+13|0];if(!b){break j}v[c+14|0]=D(D(b,k),15);break j;case 2:v[c+13|0]=k>>>4;if(k>>>0>=16){b=y[c+12|0];k=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(b){break g}break f}k=0;v[c+12|0]=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(b&1){break g}break f;case 3:u=0;x[e+40>>2]=0;x[e+36>>2]=0;if(b&1){break g}break f;case 5:if(!k){break i}b=(y[c+12|0]?15:14)+c|0;f=y[b|0];v[b|0]=f>>>0>=256-k>>>0?-1:f+k|0;break j;case 6:break k;default:break i}}if(!k){break i}b=(y[c+12|0]?15:14)+c|0;f=y[b|0];v[b|0]=f>>>0<=k+1>>>0?1:f-k|0}k=0;x[e+40>>2]=0;x[e+36>>2]=0;break g}k=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(b&1){break g}break f}break e}v[g|0]=f-1;k=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(!(b&1)){break f}}f=y[c+13|0];b=y[c+12|0];if(b){u=0;if(!f){break f}}l:{if(b){x[e+12>>2]=1;x[e+32>>2]=D(f,y[c+15|0])<<1;f=x[Ze(e+12|0,e+32|0)>>2];break l}f=D(y[c+14|0],30)+30|0}b=255;g=0;s=0;while(1){m:{if(b){h=D(b,f);s=(h|0)/48|0;if(h-1536>>>0>=10752){break m}g=b}x[e+36>>2]=s;x[e+40>>2]=g;Fe(e+36|0,32,255);u=1;x[e+12>>2]=1;H=c,I=x[Ze(e+12|0,e+40|0)>>2],v[H+16|0]=I;break f}b=b-1|0;continue}}C=l-1|0;E=1;b=Wb(x[t>>2],q);b=jd(x[b>>2],x[x[b+48>>2]+12>>2],l,1);while(1){i=E&65535;if(i>>>0>G>>>0){if(u){b=e+12|0;ye(Wb(x[t>>2],q),Zh(pp(Ye(Ne(b,17,y[e+36|0]),l),0)));ye(Wb(x[t>>2],q),Zh(Ye(Ne(b,16,y[e+40|0]),l)))}if(k>>>0>=16){ye(Wb(x[t>>2],q),S$(Ye(Ne(e+12|0,20,k>>>4|224),l)))}b=k&15;if(b){ye(Wb(x[t>>2],q),S$(Ye(Ne(e+12|0,20,Kd((D(b,y[c+16|0])>>>0)/15&255,1,15)|96),l)))}l=l+1|0;b=0;continue d}n:{o:{p:{q:{r:{g=xb(x[B>>2],i);f=y[g|0];if(!f){x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}h=g<<24>>24;if((h|0)<0){x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}H=xb(x[B>>2],i),I=g,v[H|0]=I}s=1;m=h&255;if(m&64){x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}v[b+1|0]=g;s=!g}if(!(m&32)){g=y[b|0];break r}x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}v[b|0]=g;if((g-1&255)>>>0<=107){f=km(g+24|0);v[b|0]=f;H=Wc(x[c>>2],i),I=f,v[H+1|0]=I;g=y[b|0];break o}if((g+127&255)>>>0<=107){f=km((g&127)+24|0);H=Wc(x[c>>2],i),I=f,v[H|0]=I;v[b|0]=0;break q}if((g|0)!=255){break r}g=254;break p}v[g|0]=f-1;break n}if(g&255){break o}}if(!y[b+1|0]){g=0;break o}g=y[Wc(x[c>>2],i)+1|0];v[b+1|0]=0}v[b|0]=g}if(Tc(g)){H=Wc(x[c>>2],i),I=0,v[H+5|0]=I}v[e+31|0]=0;v[e+30|0]=0;if(m&16){v[b+2|0]=1;x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}v[b+4|0]=g+2>>>2}g=0;r=0;A=0;s:{if(!(m&8)){break s}x[31725]=0;h=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;A=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}t:{switch(h-1|0){case 0:v[b|0]=254;break s;case 1:v[b|0]=255;break s;case 2:f=Wc(x[c>>2],i);v[b|0]=y[f+1|0];v[f+5|0]=0;break s;case 3:f=dw(A,y[c+16|0]);A=f?f|-48:0;r=f?20:0;if(y[b|0]){break s}f=Wc(x[c>>2],i);v[b|0]=y[f+1|0];v[f+5|0]=0;break s;case 4:v[e+12|0]=1;H=e,I=dw(A,y[c+16|0]),v[H+32|0]=I;A=y[ef(e+12|0,e+32|0)|0];H=Wc(x[c>>2],i),I=0,v[H+5|0]=I;r=15;break s;case 5:case 6:case 7:case 8:r=x[c>>2];u:{if(!l){break u}if((h|0)==y[Wc(r,i)+4|0]){break u}f=ye(Wb(x[t>>2],q),Gn(pp(Ye(Ne(e+12|0,20,(h+122|160)&255),C),i)));r=x[c>>2];if(!f){break u}H=Wc(r,i),I=h,v[H+4|0]=I}f=Wc(r,i);if(!y[b|0]){v[b|0]=y[f+1|0]}v[f+5|0]=0;r=10;break s;case 9:break t;default:break s}}f=Wc(x[c>>2],i);h=y[f+5|0];v[f+5|0]=h^1;A=h?-98:-97;r=20}v:{w:{x:{if(!(m&4)){break x}x[31725]=0;n=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;j=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}v[e+31|0]=j;h=1;g=1;y:{switch(n-1|0){case 0:dE(e+12|0,j<<24>>24<<3,128);f=y[b|0];if(Tc(f)){H=b,I=km(f+x[e+12>>2]|0),v[H|0]=I}v[e+31|0]=y[e+16|0]^128;g=35;break x;case 1:f=dw(j,y[c+16|0]);v[e+31|0]=f;if(!f){break w}v[e+31|0]=f|208;g=20;break v;case 3:case 4:H=e,I=R$(j,y[c+16|0],1),v[H+31|0]=I;g=(n|0)==4?2:3;break v;case 5:if(!y[b|0]){H=b,I=y[Wc(x[c>>2],i)|0],v[H|0]=I}H=e,I=R$(j,y[c+16|0],0),v[H+31|0]=I;g=4;break v;case 6:H=b,I=km(j+25|0),v[H|0]=I;v[e+31|0]=255;g=4;break v;case 7:case 8:case 9:z:{if(!l){break z}if((n|0)==y[Wc(x[c>>2],i)+2|0]){break z}if(!ye(Wb(x[t>>2],q),Gn(pp(Ye(Ne(e+12|0,20,(n-8|48)&255),C),i)))){break z}H=Wc(x[c>>2],i),I=n,v[H+2|0]=I}H=e,I=cE(j,y[c+16|0]),v[H+31|0]=I;g=5;break v;case 10:H=e,I=Q$(j,y[c+16|0]),v[H+31|0]=I;g=18;break v;case 11:f=dw(j,y[c+16|0]);v[e+31|0]=f;if(f){v[e+31|0]=f|192;g=20;break v}v[b|0]=254;break w;case 2:break v;default:break y}}g=0}h=0;break v}g=0}o=0;f=1;A:{if(m&2){x[31725]=0;m=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}x[31725]=0;n=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}v[e+30|0]=n;o=9;f=0;j=0;B:{switch(m-1|0){case 0:case 1:j=1;H=e,I=P$(n,y[c+16|0],(m|0)==1),v[H+30|0]=I;o=11;break A;case 2:H=e,I=Q$(n,y[c+16|0]),v[H+30|0]=I;j=1;o=18;break A;case 3:case 4:case 5:C:{if(!l){break C}if((m|0)==y[Wc(x[c>>2],i)+3|0]){break C}if(!ye(Wb(x[t>>2],q),Gn(pp(Ye(Ne(e+12|0,20,(m-4|64)&255),C),i)))){break C}H=Wc(x[c>>2],i),I=m,v[H+3|0]=I}H=e,I=cE(n,y[c+16|0]),v[H+30|0]=I;j=1;o=8;break A;case 7:case 8:H=e,I=P$(n,y[c+16|0],(m|0)==8),v[H+30|0]=I;j=1;o=29;break A;case 9:H=e,I=cE(n,y[c+16|0]),v[H+30|0]=I;j=1;o=27;break A;case 6:break A;default:break B}}o=0;f=1}j=0}if(h){O$(b,l,z[d+480188>>1],g,e+31|0)}if(j){O$(b,l,z[d+480188>>1],o,e+30|0)}D:{E:{F:{G:{H:{if(!s){break H}if(!Tc(y[b|0])){break H}if(!g){break G}if(!f|(g|0)==4){break H}v[e+30|0]=255;o=4}j=b+2|0;if(y[b+2|0]!=1){break D}if(g){break F}v[e+31|0]=y[b+4|0];g=13;break E}v[e+31|0]=255;j=b+2|0;g=4;if(y[b+2|0]!=1){break D}}if(o){break D}v[e+30|0]=y[b+4|0];o=13}v[j|0]=0}h=ch(e+12|0);Hn(e+32|0,h,g,y[e+31|0],o,y[e+30|0]);I:{if(y[j|0]){break I}f=y[e+14|0];if(!f){break I}v[b+2|0]=f;v[b+4|0]=y[e+16|0]}s=y[e+15|0];J:{if(r){Hn(e+32|0,h,s&255,y[e+17|0],r,A&255);K:{if(y[j|0]){break K}f=y[e+14|0];if(!f){break K}v[b+2|0]=f;v[b+4|0]=y[e+16|0]}s=y[e+15|0];break J}if(!(s&255)){break n}}v[b+3|0]=s;v[b+5|0]=y[e+17|0]}b=b+6|0;E=E+1|0;continue}}break}a=N()|0;dc(B);Q(a|0);p()}else{v[h+D(b,6)|0]=254;b=b+1|0;continue}}fb=e- -64|0;return q|0}function aP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-32|0;fb=f;d=Dc(f+20|0,11600);e=sh(c,d);tb(d);a:{b:{c:{d:{e:{if(e){wo(a,x[b+24>>2]+1298356|0);break e}d=Dc(f+20|0,11005);e=sh(c,d);tb(d);if(e){wo(a,x[b+24>>2]+1298344|0);break e}d=Dc(f+20|0,11430);e=sh(c,d);tb(d);if(e){wo(a,x[b+24>>2]+1298392|0);break e}d=Dc(f+20|0,10997);e=sh(c,d);tb(d);if(e){wo(a,x[b+24>>2]+1298380|0);break e}d=Dc(f+20|0,8243);e=sh(c,d);tb(d);if(e){d=f+20|0;c=x[x[b+24>>2]+480184>>2];b=31056;f:{g:{while(1){if((b|0)==31104){break g}if((c|0)!=x[b>>2]){b=b+12|0;continue}break}c=fb-32|0;fb=c;e=c+8|0;Rw(e,x[b+8>>2]);x[31725]=0;S(125,c+20|0,0,e|0);b=x[31725];x[31725]=0;h:{i:{j:{if((b|0)!=1){x[31725]=0;O(12,d|0,c+20|0);b=x[31725];x[31725]=0;if((b|0)==1){break j}Qb(c+20|0);tb(c+8|0);fb=c+32|0;break h}a=N()|0;break i}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}break f}Fb(d)}x[31725]=0;O(1065,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}tb(f+20|0);break e}d=Dc(f+20|0,10982);e=sh(c,d);tb(d);if(e){i=x[x[b+24>>2]+480184>>2];c=fb-48|0;fb=c;b=31056;h=qg(c+36|0);l=f+20|0;d=Fb(l);while(1){if((b|0)!=31104){if(x[b>>2]==(i|0)){x[31725]=0;e=P(1,c+24|0,x[b+4>>2])|0;g=x[31725];x[31725]=0;k:{l:{m:{n:{o:{p:{if((g|0)!=1){x[31725]=0;S(892,c+16|0,h|0,e|0);g=x[31725];x[31725]=0;if((g|0)==1){break n}if(!y[c+20|0]){break k}if(!Ad(x[d+4>>2],y[d+11|0])){x[31725]=0;g=P(1,c+4|0,18385)|0;k=x[31725];x[31725]=0;if((k|0)==1){break p}x[31725]=0;P(76,d|0,g|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break o}tb(g)}x[31725]=0;P(76,d|0,e|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){break k}b=N()|0;break m}b=N()|0;break l}b=N()|0;break m}b=N()|0;tb(g);break m}b=N()|0}tb(e)}tb(d);RR(h);Q(b|0);p()}tb(e)}b=b+12|0;continue}break}RR(h);fb=c+48|0;x[31725]=0;O(1065,a|0,l|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(f+20|0);break e}c=N()|0;tb(f+20|0);break a}d=Dc(f+20|0,8309);e=sh(c,d);tb(d);if(e){wo(a,x[b+24>>2]+1298368|0);break e}d=Dc(f+20|0,5620);e=sh(c,d);tb(d);if(e){wo(a,x[b+24>>2]+1298320|0);break e}d=Dc(f+20|0,12004);e=sh(c,d);tb(d);if(e){c=f+20|0;lg(c,x[b+24>>2]+1298308|0);b=x[b+24>>2];x[31725]=0;S(1059,a|0,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(f+20|0);break e}c=N()|0;tb(f+20|0);break a}d=Dc(f+20|0,11373);e=sh(c,d);tb(d);if(e){d=pM(x[b+24>>2]);c=x[d+4>>2];q:{if(!lc(x[d>>2],c)){e=bw(c);d=fb-32|0;fb=d;x[d+8>>2]=0;x[d+12>>2]=0;x[d+16>>2]=0;x[d>>2]=0;x[d+4>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;c=fb-48|0;fb=c;HF(c+24|0,e,e+4|0,e+8|0,e+12|0,e+16|0,e+24|0);HF(c,d,d+4|0,d+8|0,d+12|0,d+16|0,d+24|0);e=x[c+28>>2];h=x[c+4>>2];fb=c+48|0;fb=d+32|0;if(x[e>>2]==x[h>>2]&x[x[c+24>>2]>>2]==x[x[c>>2]>>2]&x[x[c+32>>2]>>2]==x[x[c+8>>2]>>2]&x[x[c+36>>2]>>2]==x[x[c+12>>2]>>2]&x[x[c+40>>2]>>2]==x[x[c+16>>2]>>2]){e=x[c+44>>2];h=x[c+20>>2];c=x[e>>2]==x[h>>2]&x[e+4>>2]==x[h+4>>2]}else{c=0}if(c^1){break q}}Fb(a);break e}h=f+20|0;b=x[b+24>>2];e=bw(x[pM(b)+4>>2]);g=x[b+1298408>>2];d=fb-512|0;fb=d;i=x[e+32>>2];r:{if(i){c=2147483647;j=Ee(+(i>>>0)/18.2);b=-1;s:{if(j>=0x8000000000000000){break s}c=-2147483648;b=0;if(j<=-0x8000000000000000){break s}if(F(j)<0x8000000000000000){c=F(j)>=1?~~(j>0?H(J(j*2.3283064365386963e-10),4294967295):K((j-+(~~j>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~j>>>0;break s}b=0}if((g|0)==1){g=x[e+28>>2];x[d+184>>2]=x[e+24>>2];x[d+188>>2]=g;g=x[e+20>>2];x[d+176>>2]=x[e+16>>2];x[d+180>>2]=g;g=x[e+12>>2];x[d+168>>2]=x[e+8>>2];x[d+172>>2]=g;g=x[e+4>>2];x[d+160>>2]=x[e>>2];x[d+164>>2]=g;Gu(d+480|0,d+160|0);e=x[d+508>>2];x[d+152>>2]=x[d+504>>2];x[d+156>>2]=e;e=x[d+500>>2];x[d+144>>2]=x[d+496>>2];x[d+148>>2]=e;e=x[d+492>>2];x[d+136>>2]=x[d+488>>2];x[d+140>>2]=e;e=x[d+484>>2];x[d+128>>2]=x[d+480>>2];x[d+132>>2]=e;e=d+448|0;g=_A(PS(d+128|0),hb);c=c+hb|0;i=b;b=b+g|0;c=i>>>0>b>>>0?c+1|0:c;NS(e,OS(b,c),hb);b=x[d+476>>2];x[d+120>>2]=x[d+472>>2];x[d+124>>2]=b;b=x[d+468>>2];x[d+112>>2]=x[d+464>>2];x[d+116>>2]=b;b=x[d+460>>2];x[d+104>>2]=x[d+456>>2];x[d+108>>2]=b;b=x[d+452>>2];x[d+96>>2]=x[d+448>>2];x[d+100>>2]=b;sN(h,d+96|0);break r}g=x[e+28>>2];x[d+312>>2]=x[e+24>>2];x[d+316>>2]=g;g=x[e+20>>2];x[d+304>>2]=x[e+16>>2];x[d+308>>2]=g;g=x[e+12>>2];x[d+296>>2]=x[e+8>>2];x[d+300>>2]=g;g=x[e+4>>2];x[d+288>>2]=x[e>>2];x[d+292>>2]=g;Gu(d+416|0,d+288|0);e=x[d+444>>2];x[d+280>>2]=x[d+440>>2];x[d+284>>2]=e;e=x[d+436>>2];x[d+272>>2]=x[d+432>>2];x[d+276>>2]=e;e=x[d+428>>2];x[d+264>>2]=x[d+424>>2];x[d+268>>2]=e;e=x[d+420>>2];x[d+256>>2]=x[d+416>>2];x[d+260>>2]=e;e=d+352|0;g=_A(PS(d+256|0),hb);c=c+hb|0;i=b;b=b+g|0;c=i>>>0>b>>>0?c+1|0:c;NS(e,OS(b,c),hb);b=x[d+380>>2];x[d+248>>2]=x[d+376>>2];x[d+252>>2]=b;b=x[d+372>>2];x[d+240>>2]=x[d+368>>2];x[d+244>>2]=b;b=x[d+364>>2];x[d+232>>2]=x[d+360>>2];x[d+236>>2]=b;b=x[d+356>>2];x[d+224>>2]=x[d+352>>2];x[d+228>>2]=b;Gu(d+384|0,d+224|0);b=x[d+412>>2];x[d+216>>2]=x[d+408>>2];x[d+220>>2]=b;b=x[d+404>>2];x[d+208>>2]=x[d+400>>2];x[d+212>>2]=b;b=x[d+396>>2];x[d+200>>2]=x[d+392>>2];x[d+204>>2]=b;b=x[d+388>>2];x[d+192>>2]=x[d+384>>2];x[d+196>>2]=b;CO(h,d+192|0);break r}if((g|0)==1){b=x[e+28>>2];x[d+56>>2]=x[e+24>>2];x[d+60>>2]=b;b=x[e+20>>2];x[d+48>>2]=x[e+16>>2];x[d+52>>2]=b;b=x[e+12>>2];x[d+40>>2]=x[e+8>>2];x[d+44>>2]=b;b=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=b;Gu(d+320|0,d+32|0);b=x[d+348>>2];x[d+24>>2]=x[d+344>>2];x[d+28>>2]=b;b=x[d+340>>2];x[d+16>>2]=x[d+336>>2];x[d+20>>2]=b;b=x[d+332>>2];x[d+8>>2]=x[d+328>>2];x[d+12>>2]=b;b=x[d+324>>2];x[d>>2]=x[d+320>>2];x[d+4>>2]=b;sN(h,d);break r}b=x[e+28>>2];x[d+88>>2]=x[e+24>>2];x[d+92>>2]=b;b=x[e+20>>2];x[d+80>>2]=x[e+16>>2];x[d+84>>2]=b;b=x[e+12>>2];x[d+72>>2]=x[e+8>>2];x[d+76>>2]=b;b=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=b;CO(h,d- -64|0)}fb=d+512|0;x[31725]=0;O(1065,a|0,h|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(f+20|0);break e}c=N()|0;tb(f+20|0);break a}d=Dc(f+20|0,12273);e=sh(c,d);tb(d);if(e){AV(f+20|0,x[b+24>>2]+1298332|0);t:{if(!Ad(x[f+24>>2],y[f+31|0])){break t}c=x[x[b+24>>2]+480180>>2];u:{v:{if((c|0)==33554432){break v}d=1;if((c|0)==32){break u}if((c|0)==16384){break v}if((c|0)==16777216){break u}}d=2}w:{switch(d-1|0){case 0:x[31725]=0;O(1066,f+8|0,b|0);c=x[31725];x[31725]=0;if((c|0)!=1){c=f+8|0;Ab(f+20|0,c);tb(c);break t}break b;case 1:break w;default:break t}}x[31725]=0;O(1067,f+8|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=f+8|0;d=Ab(f+20|0,c);tb(c);if(!Ad(x[f+24>>2],y[f+31|0])){break t}x[31725]=0;O(1066,f+8|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=f+8|0;Ab(d,c);tb(c)}b=x[b+24>>2];x[31725]=0;S(1059,a|0,b|0,f+20|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(f+20|0);break e}break b}d=Dc(f+20|0,5472);e=sh(c,d);tb(d);if(e){c=f+20|0;AV(c,x[b+24>>2]+1298332|0);b=x[b+24>>2];x[31725]=0;S(1059,a|0,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(f+20|0);break e}c=N()|0;tb(f+20|0);break a}i=c;c=Dc(f+20|0,7335);d=sh(i,c);tb(c);if(d){a=Fb(a);m=f,n=wb(x[b+68>>2]),x[m+20>>2]=n;b=wb(x[b+72>>2]);c=1;while(1){d=x[f+20>>2];if(!Ib(d,b)){break e}if(!(c&1)){x[31725]=0;P(991,a|0,22230)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}}x[31725]=0;P(842,a|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}jl(f+20|0);c=0;continue}}Dc(a,22255)}fb=f+32|0;return}c=N()|0;tb(f+20|0);break a}c=N()|0;tb(a);break a}c=N()|0;tb(f+20|0)}Q(c|0);p()}function tR(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=fb-336|0;fb=k;n=h;p=i&65535;o=d;m=e&65535;u=(e^i)&-2147483648;s=i>>>16&32767;q=e>>>16&32767;a:{b:{if(s-32767>>>0>4294934529&q-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){r=d;u=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){r=h;u=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;u=2147450880;break a}u=u|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));r=b?0:r;u=b?2147450880:u;b=0;c=0;break a}if(!(f|h|(e|g))){u=u|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){d=!(m|o);i=d;j=d?b:o;d=d<<6;i=G(i?c:m);d=d+((i|0)==32?G(j)+32|0:i)|0;bg(k+320|0,b,c,o,m,d-15|0);v=16-d|0;o=x[k+328>>2];m=x[k+332>>2];c=x[k+324>>2];b=x[k+320>>2]}if(e>>>0>65535){break b}d=!(n|p);h=d;i=d?f:n;d=d<<6;h=G(h?g:p);d=d+((h|0)==32?G(i)+32|0:h)|0;bg(k+304|0,f,g,n,p,d-15|0);v=(d+v|0)-16|0;n=x[k+312>>2];p=x[k+316>>2];f=x[k+304>>2];g=x[k+308>>2]}e=p|65536;C=e;D=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=e;i=0-d|0;h=j;j=1963258675-(j+((d|0)!=0)|0)|0;Of(k+288|0,d,h,0,0,i,j,0,0);d=x[k+296>>2];Of(k+272|0,0-d|0,0-(x[k+300>>2]+((d|0)!=0)|0)|0,0,0,i,j,0,0);d=x[k+280>>2];i=d<<1|x[k+276>>2]>>>31;d=x[k+284>>2]<<1|d>>>31;Of(k+256|0,i,d,0,0,e,h,0,0);j=x[k+264>>2];Of(k+240|0,i,d,0,0,0-j|0,0-(x[k+268>>2]+((j|0)!=0)|0)|0,0,0);i=x[k+248>>2];j=i<<1|x[k+244>>2]>>>31;d=x[k+252>>2]<<1|i>>>31;Of(k+224|0,j,d,0,0,e,h,0,0);i=x[k+232>>2];Of(k+208|0,j,d,0,0,0-i|0,0-(x[k+236>>2]+((i|0)!=0)|0)|0,0,0);d=x[k+216>>2];i=d<<1|x[k+212>>2]>>>31;d=x[k+220>>2]<<1|d>>>31;Of(k+192|0,i,d,0,0,e,h,0,0);j=x[k+200>>2];Of(k+176|0,i,d,0,0,0-j|0,0-(x[k+204>>2]+((j|0)!=0)|0)|0,0,0);i=e;e=x[k+184>>2];d=h;n=e<<1|x[k+180>>2]>>>31;h=n-1|0;e=(x[k+188>>2]<<1|e>>>31)-!n|0;Of(k+160|0,i,d,0,0,h,e,0,0);d=h;Of(k+144|0,f<<15,g<<15|f>>>17,0,0,d,e,0,0);t=k+112|0;z=x[k+168>>2];h=x[k+172>>2];n=x[k+160>>2];i=x[k+152>>2];l=n+i|0;p=x[k+164>>2];j=p+x[k+156>>2]|0;j=i>>>0>l>>>0?j+1|0:j;i=j;j=(p|0)==(j|0)&l>>>0<n>>>0|j>>>0<p>>>0;p=j+z|0;j=j>>>0>p>>>0?h+1|0:h;n=!i&l>>>0>1|(i|0)!=0;h=n+p|0;j=n>>>0>h>>>0?j+1|0:j;Of(t,d,e,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);Of(k+128|0,1-l|0,0-((l>>>0>1)+i|0)|0,0,0,d,e,0,0);K=(q-s|0)+v|0;e=x[k+116>>2];t=e;d=x[k+112>>2];j=e<<1|d>>>31;n=d<<1;q=j;d=j;h=x[k+140>>2];B=h;e=x[k+136>>2];j=h<<1|e>>>31;i=e<<1|x[k+132>>2]>>>31;h=i+n|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;y=d;z=d;l=0;j=m|65536;L=j;M=o;d=o;j=j<<1|d>>>31;O=d<<1;P=j;F=j;d=ova(y,l,j,0);j=hb;H=d;w=j;v=b<<1;d=c<<1|b>>>31;s=d;j=0;p=j;i=h-13927|0;y=(e|0)==(y|0)&i>>>0<h>>>0|e>>>0>y>>>0;e=(e|0)==(q|0)&h>>>0<n>>>0|e>>>0<q>>>0;d=x[k+120>>2];h=x[k+124>>2]<<1|d>>>31;d=d<<1|t>>>31;j=h;l=B>>>31|0;d=l+d|0;j=d>>>0<l>>>0?j+1|0:j;h=d;d=d+e|0;l=h>>>0>d>>>0?j+1|0:j;e=d;d=d+y|0;l=e>>>0>d>>>0?l+1|0:l;e=d-1|0;y=l-!d|0;q=0;j=ova(s,p,y,q);d=j+H|0;h=hb+w|0;h=d>>>0<j>>>0?h+1|0:h;t=(w|0)==(h|0)&d>>>0<H>>>0|h>>>0<w>>>0;j=0;B=e;N=c>>>31|0;E=N|o<<1;w=0;e=ova(e,j,E,w);o=e+d|0;j=hb+h|0;l=0;j=e>>>0>o>>>0?j+1|0:j;n=j;d=(j|0)==(h|0)&d>>>0>o>>>0|h>>>0>j>>>0;e=d;d=d+t|0;l=e>>>0>d>>>0?1:l;e=ova(F,p,y,q);d=e+d|0;j=hb+l|0;t=d;d=d>>>0<e>>>0?j+1|0:j;e=ova(F,p,B,w);m=hb;h=e;e=ova(E,w,y,q);l=h+e|0;j=hb+m|0;j=e>>>0>l>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&h>>>0>l>>>0|j>>>0<m>>>0;m=t+e|0;d=d+j|0;d=m>>>0<e>>>0?d+1|0:d;t=m;m=d;e=0;d=e+o|0;j=l+n|0;j=d>>>0<e>>>0?j+1|0:j;e=j;h=(j|0)==(n|0)&d>>>0<o>>>0|j>>>0<n>>>0;j=m;l=h;h=h+t|0;j=l>>>0>h>>>0?j+1|0:j;I=h;l=j;t=d;m=d;o=e;H=i;d=ova(i,0,E,w);h=hb;e=d;i=ova(z,r,s,r);d=d+i|0;j=hb+h|0;j=d>>>0<i>>>0?j+1|0:j;i=(h|0)==(j|0)&d>>>0<e>>>0|h>>>0>j>>>0;h=j;J=v&-2;e=ova(B,w,J,0);n=e+d|0;j=hb+j|0;j=e>>>0>n>>>0?j+1|0:j;e=j;d=(j|0)==(h|0)&d>>>0>n>>>0|h>>>0>j>>>0;h=0;i=d+i|0;d=(i>>>0<d>>>0?1:h)+o|0;j=l;m=i+m|0;d=m>>>0<i>>>0?d+1|0:d;i=d;d=(d|0)==(o|0)&m>>>0<t>>>0|d>>>0<o>>>0;h=d;d=d+I|0;j=h>>>0>d>>>0?j+1|0:j;Q=d;t=j;d=ova(F,p,H,r);I=hb;F=d;h=ova(y,q,J,r);d=d+h|0;j=hb+I|0;o=d;p=ova(z,r,E,w);l=d+p|0;h=d>>>0<h>>>0?j+1|0:j;d=h+hb|0;d=l>>>0<p>>>0?d+1|0:d;q=l;j=ova(s,r,B,w);p=l+j|0;l=hb+d|0;l=j>>>0>p>>>0?l+1|0:l;B=0;E=(d|0)==(l|0)&p>>>0<q>>>0|d>>>0>l>>>0;j=(h|0)==(I|0)&o>>>0<F>>>0|h>>>0<I>>>0;d=(d|0)==(h|0)&o>>>0>q>>>0|d>>>0<h>>>0;d=d+j|0;d=d+E|0;h=l;q=h+m|0;j=(d|B)+i|0;j=h>>>0>q>>>0?j+1|0:j;o=j;d=(i|0)==(j|0)&m>>>0>q>>>0|i>>>0>j>>>0;j=t;h=d;d=d+Q|0;j=h>>>0>d>>>0?j+1|0:j;B=d;i=j;d=ova(z,r,J,r);z=hb;m=d;h=ova(s,r,H,r);d=d+h|0;j=hb+z|0;j=d>>>0<h>>>0?j+1|0:j;t=0;h=(j|0)==(z|0)&d>>>0<m>>>0|j>>>0<z>>>0;m=j;d=j+n|0;j=(h|t)+e|0;j=d>>>0<m>>>0?j+1|0:j;h=j;m=(e|0)==(j|0)&d>>>0<n>>>0|e>>>0>j>>>0;j=p;p=0;n=p+d|0;l=h+j|0;j=0;l=n>>>0<p>>>0?l+1|0:l;d=(h|0)==(l|0)&d>>>0>n>>>0|h>>>0>l>>>0;e=d;d=d+m|0;j=(e>>>0>d>>>0?1:j)+o|0;l=i;e=d;d=d+q|0;j=e>>>0>d>>>0?j+1|0:j;e=j;h=(o|0)==(j|0)&d>>>0<q>>>0|j>>>0<o>>>0;i=h;h=h+B|0;l=i>>>0>h>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){M=O|N;L=w|P;Of(k+80|0,d,e,h,i,f,g,D,C);l=x[k+84>>2];p=l;j=b<<17;n=0;m=x[k+88>>2];c=n-m|0;b=x[k+80>>2];l=(l|b)!=0;o=c-l|0;m=(j-(x[k+92>>2]+(m>>>0>n>>>0)|0)|0)-(c>>>0<l>>>0)|0;n=0-b|0;p=0-(((b|0)!=0)+p|0)|0;b=K+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;Of(k+96|0,d,e,h,i,f,g,D,C);o=x[k+100>>2];s=o;v=x[k+104>>2];n=0-v|0;l=x[k+96>>2];m=(o|l)!=0;o=n-m|0;m=((b<<16)-(x[k+108>>2]+(p>>>0<v>>>0)|0)|0)-(m>>>0>n>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+s|0)|0;v=b;s=c;b=K+16383|0}if((b|0)>=32767){u=u|2147418112;b=0;c=0;break a}d:{if((b|0)>0){l=m<<1|o>>>31;o=o<<1|p>>>31;m=l;v=h;s=i&65535|b<<16;l=p<<1|n>>>31;i=n<<1;break d}if((b|0)<=-113){b=0;c=0;break a}gn(k- -64|0,d,e,h,i,1-b|0);bg(k+48|0,v,s,M,L,b+112|0);d=x[k+64>>2];e=x[k+68>>2];v=x[k+72>>2];s=x[k+76>>2];Of(k+32|0,f,g,D,C,d,e,v,s);b=x[k+40>>2];c=x[k+56>>2];l=x[k+36>>2];o=b<<1|l>>>31;n=c-o|0;m=x[k+60>>2]-((x[k+44>>2]<<1|b>>>31)+(c>>>0<o>>>0)|0)|0;b=x[k+32>>2];h=l<<1|b>>>31;j=b<<1;i=x[k+52>>2];c=x[k+48>>2];b=(h|0)==(i|0)&j>>>0>c>>>0|h>>>0>i>>>0;o=n-b|0;m=m-(b>>>0>n>>>0)|0;l=i-((c>>>0<j>>>0)+h|0)|0;i=c-j|0}b=i;Of(k+16|0,f,g,D,C,3,0,0,0);Of(k,f,g,D,C,5,0,0,0);c=0;h=l+c|0;j=d&1;b=b+j|0;h=i>>>0>b>>>0?h+1|0:h;i=b;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;l=m;b=(c|0)==(h|0)&b>>>0<j>>>0|c>>>0>h>>>0;f=b+o|0;l=b>>>0>f>>>0?l+1|0:l;j=e;b=(l|0)==(C|0);b=b&(f|0)==(D|0)?g:b&f>>>0>D>>>0|l>>>0>C>>>0;c=b;b=b+d|0;j=c>>>0>b>>>0?j+1|0:j;c=j;d=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;j=s;e=d;d=d+v|0;j=e>>>0>d>>>0?j+1|0:j;g=d;e=x[k+20>>2];m=(e|0)==(h|0)&A[k+16>>2]<i>>>0|e>>>0<h>>>0;e=x[k+28>>2];d=x[k+24>>2];e=j>>>0<2147418112&((d|0)==(f|0)&(e|0)==(l|0)?m:(e|0)==(l|0)&d>>>0<f>>>0|e>>>0<l>>>0);d=c;m=e;e=b+e|0;d=m>>>0>e>>>0?d+1|0:d;b=(c|0)==(d|0)&b>>>0>e>>>0|c>>>0>d>>>0;c=b;b=b+g|0;j=c>>>0>b>>>0?j+1|0:j;g=b;c=x[k+4>>2];h=(c|0)==(h|0)&A[k>>2]<i>>>0|c>>>0<h>>>0;c=x[k+12>>2];b=x[k+8>>2];b=j>>>0<2147418112&((b|0)==(f|0)&(c|0)==(l|0)?h:(c|0)==(l|0)&b>>>0<f>>>0|c>>>0<l>>>0);c=b;b=b+e|0;l=c>>>0>b>>>0?d+1|0:d;c=l;e=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;d=j;f=e;e=e+g|0;d=f>>>0>e>>>0?d+1|0:d;r=e|r;u=d|u}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=r;x[a+12>>2]=u;fb=k+336|0}function hqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;d=fb-1328|0;fb=d;xc(b);e=fb-16|0;fb=e;RX(e+8|0,d+220|0);h=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);i=x[e+4>>2];if((i|0)==(h|0)){Vb(b,x[e+12>>2])}fb=e+16|0;a:{if((h|0)!=(i|0)){break a}if(!TX(d+220|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(SX(y[d+1324|0]|y[d+1325|0]<<8|(y[d+1326|0]<<16|y[d+1327|0]<<24)),hb))){break a}if(!c){m=1;break a}xc(b);b=Ge(d+220|0,b);x[31725]=0;O(643,d+208|0,b|0);e=x[31725];x[31725]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){ub(b);x[31725]=0;S(644,d+196|0,d+208|0,1196314451);b=x[31725];x[31725]=0;if((b|0)==1){break i}x[31725]=0;S(644,d+184|0,d+208|0,1280331091);b=x[31725];x[31725]=0;if((b|0)==1){break h}if(lc(x[d+196>>2],x[d+200>>2])){break b}if(!lc(x[d+184>>2],x[d+188>>2])){break g}break b}c=N()|0;ub(b);break d}c=N()|0;break e}c=N()|0;break f}x[31725]=0;O(248,a|0,1);b=x[31725];x[31725]=0;j:{if((b|0)!=1){gg(a);x[a+480188>>2]=4;x[a+480208>>2]=25231360;C=d,E=wb(x[d+184>>2]),x[C+52>>2]=E;k=c&2;f=wb(x[d+188>>2]);k:{l:{while(1){e=x[d+52>>2];if(!Ib(e,f)){break l}b=z[a+480190>>1];if(!vi(b)){break l}b=b+1|0;w[a+480190>>1]=b;x[31725]=0;b=D(b&65535,104)+a|0;h=b+484380|0;O(281,h|0,1);i=x[31725];x[31725]=0;m:{n:{if((i|0)!=1){x[31725]=0;i=P(645,e|0,d+220|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break n}if(!i){break c}if(Bv(d+220|0)){break m}break c}c=N()|0;break j}c=N()|0;break j}x[31725]=0;i=P(36,d+172|0,d+220|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break k}zc(((z[a+480190>>1]<<5)+a|0)+946304|0,i);tb(i);i=y[d+256|0]|y[d+257|0]<<8|(y[d+258|0]<<16|y[d+259|0]<<24);x[h>>2]=i;x[b+484388>>2]=i;x[b+484384>>2]=y[d+252|0]|y[d+253|0]<<8|(y[d+254|0]<<16|y[d+255|0]<<24);i=b+484414|0;w[i>>1]=z[i>>1]|2;w[b+484410>>1]=255;o:{if(k){b=Xc(d+24|0,8,1,0,0);x[31725]=0;U(217,b|0,h|0,e|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break o}}Sf(d+52|0);continue}break}c=N()|0;break j}C=d,E=wb(x[d+196>>2]),x[C+168>>2]=E;n=a+484344|0;o=c&1;q=a+484360|0;A=wb(x[d+200>>2]);r=a+484380|0;s=a+946304|0;c=1;m=1;while(1){p:{q:{r:{s:{t:{u:{v:{b=x[d+168>>2];if(!Ib(b,A)){break v}if(!(c&1)){x[31725]=0;c=R(276,q|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break u}if(!c){break v}}lj(Xb(x[a+484360>>2],y[a+484376|0]));x[31725]=0;c=P(646,b|0,d+220|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break t}if(!(c&!(y[d+1306|0]|y[d+1307|0]<<8))|(y[d+1308|0]|y[d+1309|0]<<8|(y[d+1310|0]<<16|y[d+1311|0]<<24))-5>>>0<4294967292){break c}c=y[a+484376|0];e=x[a+484360>>2];x[31725]=0;O(647,d+156|0,d+220|0);h=x[31725];x[31725]=0;if((h|0)==1){break t}e=Xb(e,c);c=d+156|0;wp(e,c);tb(c);w:{if(o){x[31725]=0;S(187,d+52|0,b|0,y[d+1316|0]|y[d+1317|0]<<8|(y[d+1318|0]<<16|y[d+1319|0]<<24));b=x[31725];x[31725]=0;if((b|0)!=1){break w}c=N()|0;break j}x[31725]=0;b=R(170,d+116|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break s}zG(d+52|0,b)}b=d+52|0;l=ic(d+136|0,b);ub(b);if(!o){ub(d+116|0)}Tb(d+52|0,0,64);c=1;x:{y:{z:{while(1){if((c|0)==32){break z}b=(D(c,34)+d|0)+186|0;e=b+32|0;Mn(d+8|0,e);A:{B:{if(Vj(y[x[d+8>>2]])){break B}h=y[b- -64|0];if(h>>>0>15){break y}b=y[b+65|0];if(b>>>0>64){break y}if(!Bv(e)){break y}i=b<<2;k=h<<4;h=0;b=1;while(1){f=b&65535;e=z[a+480190>>1];if(f>>>0<=e>>>0){x[31725]=0;S(648,d+24|0,x[d+8>>2],x[d+12>>2]);e=x[31725];x[31725]=0;if((e|0)==1){break A}e=fb-32|0;fb=e;g=d+24|0;ee(e+24|0,g);OX(e+16|0,((f<<5)+a|0)+946304|0);j=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=j;j=Ic(x[e+24>>2],x[e+28>>2],e+8|0);fb=e+32|0;tb(g);C:{if(j^1){break C}C=_b(d+52|0,c),E=b,w[C>>1]=E;e=D(f,104)+a|0;f=e+484410|0;g=z[f>>1];if((g|0)!=255){h=b;if(y[e+484417|0]!=(k&255)|(g|0)!=(i|0)){break C}}v[e+484417|0]=k;w[f>>1]=i;break B}b=b+1|0;continue}break}h=h&65535;if(!h){break B}if(!vi(e)){break B}b=e+1|0;w[a+480190>>1]=b;C=_b(d+52|0,c),E=b,w[C>>1]=E;b=D(z[a+480190>>1],104)+r|0;vn(b);e=D(h,104)+r|0;f=bp(b,e);w[b+30>>1]=i;v[b+37|0]=k;HY(f,e);e=(h<<5)+s|0;h=x[e+4>>2];b=(z[a+480190>>1]<<5)+s|0;x[b>>2]=x[e>>2];x[b+4>>2]=h;h=x[e+28>>2];x[b+24>>2]=x[e+24>>2];x[b+28>>2]=h;h=x[e+20>>2];x[b+16>>2]=x[e+16>>2];x[b+20>>2]=h;h=x[e+12>>2];x[b+8>>2]=x[e+8>>2];x[b+12>>2]=h}c=c+1|0;continue}break}break r}k=0;x[d+48>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;e=64;i=65535;B=y[d+1308|0]|y[d+1309|0]<<8;h=0;D:while(1){E:{if(h){break E}b=x[l>>2];x[31725]=0;b=U(152,b|0,x[d+144>>2],1)|0;c=x[31725];x[31725]=0;if((c|0)==1){break x}if(b){break E}c=i;b=e;break q}b=e+1|0;F:{if(e>>>0<63){e=b;break F}x[31725]=0;i=P(369,n|0,64)|0;c=x[31725];x[31725]=0;if((c|0)==1){break x}c=65535;if((i|0)==65535){break q}b=y[a+484376|0];c=x[a+484360>>2];e=0;x[31725]=0;O(538,Xb(c,b)|0,i|0);b=x[31725];x[31725]=0;if((b|0)==1){break x}}b=0;c=Wb(x[n>>2],i&65535);c=jd(x[c>>2],x[x[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(B|0)){continue D}f=(d+24|0)+D(b,7)|0;g=y[f+6|0];G:{if(g){v[f+6|0]=g-1;g=y[f+4|0]|y[f+5|0]<<8;v[c+4|0]=g;v[c+5|0]=g>>>8;f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[c|0]=f;v[c+1|0]=f>>>8;v[c+2|0]=f>>>16;v[c+3|0]=f>>>24;h=h-1|0;break G}g=x[l>>2];x[31725]=0;g=U(152,g|0,x[d+144>>2],1)|0;j=x[31725];x[31725]=0;if((j|0)==1){break r}if(!g){break G}if(x[d+144>>2]==(y[d+1312|0]|y[d+1313|0]<<8|(y[d+1314|0]<<16|y[d+1315|0]<<24))){k=Xb(x[a+484360>>2],y[a+484376|0]);bf(k,hE(x[k>>2],x[k+4>>2]));k=e}x[31725]=0;g=R(199,l|0)|0;j=x[31725];x[31725]=0;H:{if((j|0)!=1){g=g<<24>>24;if((g|0)>=0){break H}g=g&127;v[f+6|0]=g;j=y[f+4|0]|y[f+5|0]<<8;v[c+4|0]=j;v[c+5|0]=j>>>8;f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[c|0]=f;v[c+1|0]=f>>>8;v[c+2|0]=f>>>16;v[c+3|0]=f>>>24;h=g+h|0;break G}break r}if((g-1&255)>>>0<=35){v[c|0]=g+48}x[31725]=0;g=R(199,l|0)|0;j=x[31725];x[31725]=0;I:{J:{if((j|0)!=1){g=g<<24>>24;C=c,E=y[_b(d+52|0,g&31)|0],v[C+1|0]=E;if((g|0)>=0){break J}v[c+3|0]=y[f+3|0];v[c+5|0]=y[f+5|0];break I}break r}x[31725]=0;O(200,d+8|0,l|0);g=x[31725];x[31725]=0;K:{if((g|0)!=1){g=y[d+8|0];if(g>>>0>19){break I}t=g<<1;u=y[t+25312|0];v[c+3|0]=u;j=y[Jc(d+8|0)|0];v[c+5|0]=j;if((u|0)!=16|j>>>0<32){break K}v[c+3|0]=17;break I}break r}if(819137>>>g&1){break I}v[c+5|0]=y[t+25313|0]|j&15}g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[f|0]=g;v[f+1|0]=g>>>8;v[f+2|0]=g>>>16;v[f+3|0]=g>>>24;g=y[c+4|0]|y[c+5|0]<<8;v[f+4|0]=g;v[f+5|0]=g>>>8}c=c+6|0;b=b+1|0;continue}}}m=0;break p}break r}ek(q,0);x[31725]=0;b=P(1,d+220|0,6467)|0;c=x[31725];x[31725]=0;L:{if((c|0)!=1){Ab(a+1298344|0,b);tb(b);x[31725]=0;b=P(1,d+52|0,6804)|0;c=x[31725];x[31725]=0;if((c|0)==1){break L}Ab(a+1298356|0,b);tb(b);C=a+1298404|0,E=x[Fc(d+24|0,4)>>2],x[C>>2]=E;m=1;break b}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;ub(l);break j}c=c&65535;if(!(!((k|0)!=0|b>>>0<63)|(c|0)==65535)){ye(Wb(x[n>>2],c),Zh(Ye(Ne(d+8|0,14,k&255),b)))}c=32}ub(l);if(c>>>0<32){break b}Sf(d+168|0);c=0;continue}}c=N()|0;break j}c=N()|0}Qc(d+184|0)}Qc(d+196|0)}ie(d+208|0)}Q(c|0);p()}m=0}Qc(d+184|0);Qc(d+196|0);ie(d+208|0)}fb=d+1328|0;return m|0}function Qoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;g=fb-256|0;fb=g;d=fb-112|0;fb=d;f=Ge(g+76|0,c);x[31725]=0;n=R(170,f+20|0)|0;c=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){x[31725]=0;q=R(170,f+40|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break B}x[31725]=0;r=R(170,f+60|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break A}x[31725]=0;i=R(170,f+80|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break z}x[31725]=0;o=R(170,f+100|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break y}x[31725]=0;k=R(170,f+120|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break x}j=Nb(f+140|0);xc(f);x[f+172>>2]=1873739776;w[f+176>>1]=0;x[31725]=0;e=P(810,f|0,d+100|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break w}if(!e){break n}e=x[d+100>>2];if((e|0)!=1414744396&(e|0)!=1179011410){break n}c=x[d+108>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}v[f+176|0]=(e|0)==1414744396;x[31725]=0;S(811,d+88|0,f|0,2);c=x[31725];x[31725]=0;if((c|0)==1){break v}h=x[d+88>>2];C:{if(Pr(h,x[d+92>>2])>>>0<4){break C}c=xA(h,1);e=x[c>>2];c=x[c+4>>2];xi(d+36|0,e,c);if(x[d+36>>2]!=1635017060){break C}xi(d+60|0,e,c);if(!(v[d+64|0]&1)){break C}c=xA(h,2);xi(d+16|0,x[c>>2],x[c+4>>2]);if(y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24)){break C}c=xA(h,3);xi(d+80|0,x[c>>2],x[c+4>>2]);if(x[d+80>>2]){break C}x[31725]=0;P(151,f|0,12)|0;c=x[31725];x[31725]=0;if((c|0)==1){break u}x[31725]=0;S(811,d+36|0,f|0,1);c=x[31725];x[31725]=0;if((c|0)==1){break t}c=d+36|0;zv(d+88|0,c);ie(c)}x[31725]=0;S(812,d+60|0,d+88|0,544501094);c=x[31725];x[31725]=0;if((c|0)==1){break s}x[31725]=0;e=P(813,d+60|0,f+156|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}if(!e){break o}e=z[f+156>>1];if((e|0)!=1){break q}x[31725]=0;e=R(204,d+60|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break r}break k}e=N()|0;break b}e=N()|0;break c}e=N()|0;break d}e=N()|0;break e}e=N()|0;break f}e=N()|0;break g}e=N()|0;break h}e=N()|0;break h}e=N()|0;break i}e=N()|0;break i}e=N()|0;break i}if((e|0)==4){x[31725]=0;h=R(194,d+60|0)|0;c=x[31725];x[31725]=0;D:{if((c|0)!=1){x[31725]=0;e=R(194,d+60|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break D}if((h|0)!=2|(e|0)!=1){break p}v[f+177|0]=1;break p}e=N()|0;break j}e=N()|0;break j}e=z[f+156>>1]}if((e&65535)!=65534){break p}x[31725]=0;e=P(814,d+60|0,d+36|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break l}if(!e){break o}c=y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24);x[d+8>>2]=y[d+52|0]|y[d+53|0]<<8|(y[d+54|0]<<16|y[d+55|0]<<24);x[d+12>>2]=c;c=y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24);x[d>>2]=y[d+44|0]|y[d+45|0]<<8|(y[d+46|0]<<16|y[d+47|0]<<24);x[d+4>>2]=c;c=d+16|0;x[c>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);w[c+4>>1]=y[d+4|0]|y[d+5|0]<<8;w[c+6>>1]=y[d+6|0]|y[d+7|0]<<8;s=c,t=sA(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24),y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24)),x[s+8>>2]=t;x[c+12>>2]=hb;w[f+172>>1]=x[c>>2]}x[31725]=0;S(812,d+36|0,d+88|0,1635017060);c=x[31725];x[31725]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){c=d+36|0;m=hd(n,c);ub(c);c=x[m>>2];x[31725]=0;e=R(174,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}if(!e){x[31725]=0;S(812,d+36|0,d+88|0,544039792);c=x[31725];x[31725]=0;if((c|0)==1){break J}c=d+36|0;hd(m,c);ub(c)}x[31725]=0;S(812,d+36|0,d+88|0,1952670054);c=x[31725];x[31725]=0;if((c|0)==1){break I}x[31725]=0;e=R(153,d+36|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break H}x[f+152>>2]=e;ub(d+36|0);if(x[f+152>>2]?z[f+156>>1]==17:0){break E}h=z[f+158>>1];e=MR(h,z[f+170>>1]);if(!e){break E}c=z[f+168>>1];if((c>>>0)/(h>>>0)>>>0<e<<1>>>0?c:0){break G}c=x[m>>2];x[31725]=0;e=R(156,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}c=MR(z[f+158>>1],z[f+170>>1]);break F}e=N()|0;break j}e=N()|0;break j}e=N()|0;break j}e=N()|0;ub(d+36|0);break j}c=x[m>>2];x[31725]=0;e=R(156,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}c=z[f+168>>1]}x[f+152>>2]=(e>>>0)/((c&65535)>>>0)}x[31725]=0;e=P(815,f|0,d+88|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}w[f+174>>1]=e;x[31725]=0;O(816,f|0,d+88|0);c=x[31725];x[31725]=0;if((c|0)==1){break k}x[31725]=0;S(812,d+36|0,d+88|0,1886221175);c=x[31725];x[31725]=0;if((c|0)==1){break m}c=d+36|0;hd(o,c);ub(c)}ub(d+60|0);ie(d+88|0)}fb=d+112|0;break a}e=N()|0;break j}e=N()|0;break j}e=N()|0}ub(d+60|0)}ie(d+88|0)}ie(j);ub(k)}ub(o)}ub(i)}ub(r)}ub(q)}ub(n)}ub(f);Q(e|0);p()}c=x[f+20>>2];x[31725]=0;e=R(746,c|0)|0;c=x[31725];x[31725]=0;K:{L:{if((c|0)!=1){M:{if(!e|(z[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=z[f+170>>1];P:{if(!c){if((Kk(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((Kk(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}e=Kk(f);c=28608;while(1){Q:{R:{if((c|0)!=28632){if((e|0)!=x[c>>2]){break R}}else{c=28632}break Q}c=c+4|0;continue}break}if((c|0)==28632){break M}Vu(a,b);x[31725]=0;e=P(36,g- -64|0,22255)|0;c=x[31725];x[31725]=0;S:{T:{U:{V:{W:{if((c|0)!=1){h=zc(((b<<5)+a|0)+946304|0,e);tb(e);x[31725]=0;e=D(b,104)+a|0;i=e+484380|0;O(281,i|0,0);c=x[31725];x[31725]=0;if((c|0)==1){break W}x[i>>2]=x[f+152>>2];x[e+484404>>2]=x[f+160>>2];c=x[a+1298404>>2];x[31725]=0;V(747,f|0,i|0,c|0,h|0);c=x[31725];x[31725]=0;if((c|0)==1){break W}Ge(g+44|0,f+20|0);e=z[f+158>>1];j=Xc(g+40|0,8,e>>>0>1?2:1,0,0);c=Kk(f);if((c|0)!=17|e>>>0>2){break U}wc(i,268435456);c=D(b,104)+a|0;b=c+484414|0;w[b>>1]=z[b>>1]&65470|((e|0)==2)<<6|1;if(Fh(i)){break V}break S}l=N()|0;break K}l=N()|0;break K}j=x[c+484400>>2];h=x[i>>2];k=Ge(g+20|0,g+44|0);e=z[f+158>>1];c=z[f+168>>1];x[31725]=0;b=x[k+12>>2];x[g+8>>2]=x[k+8>>2];x[g+12>>2]=b;x[g+16>>2]=x[k+16>>2];b=x[k+4>>2];x[g>>2]=x[k>>2];x[g+4>>2]=b;aa(748,j|0,h|0,g|0,c|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break L}Sj(i,a);break T}if((c|0)==85){x[31725]=0;c=U(575,a|0,b|0,g+44|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(QV(z[f+156>>1])){break Z}_:{if(!Ed(y[f+177|0])){break _}if((Kk(f)|0)!=1|z[f+170>>1]!=32|z[f+168>>1]!=e<<2){break _}fd(j,32);b=12;break Y}if((Kk(f)|0)!=1|z[f+170>>1]!=24|z[f+168>>1]!=e<<2){break Z}fd(j,32);b=13;break Y}if((Kk(f)&65534)!=6){break X}fd(j,16);b=(Kk(f)|0)==6?17:16}yg(j,b);x[31725]=0;U(217,j|0,i|0,g+44|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break T}break L}e=z[f+170>>1];c=e-1|0;b=c&-8;h=b&31;fd(j,(c>>>0>=64?8:(b&63)>>>0>=32?1074268168>>>h|0:((1<<h)-1&1074268168)<<32-h|538447880>>>h)&120);if(e>>>0<9){yg(j,1)}if((Kk(f)|0)==3){yg(j,3)}x[31725]=0;U(217,j|0,i|0,g+44|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break L}}bC(i,x[a+480180>>2]);Sj(i,a);l=1}ub(g+44|0)}PV(f);fb=g+256|0;return l|0}l=N()|0;break K}l=N()|0;ub(g+44|0)}PV(f);Q(l|0);p()}function dha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=E(0),k=E(0),l=0,m=0,n=0,o=E(0),p=0,q=0,r=0,s=0,t=0,u=E(0),w=E(0),z=0,A=0,C=E(0),D=0,F=0,G=E(0),H=0,I=0,J=E(0);a:{if(!y[a+5046|0]){break a}g=B[a+4268>>2];dQ(a);if(g==B[a+4268>>2]){break a}Sz(a)}b:{if(!y[a+5045|0]){break b}if(!Ai(a+44|0)){break b}i=x[a+44>>2];p=Hc(i,0);q=Hc(i,1);i=x[a+56>>2];l=Hc(i,0);m=Hc(i,1);c:{if(!(!y[a+5044|0]|(!d|y[a+4264|0]&2))){B[l>>2]=B[a+5036>>2];B[m>>2]=B[a+5040>>2];v[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;t=a+4864|0;D=a+4504|0;F=a+4960|0;d:{while(1){if(!r){break d}g=B[p>>2];g=E(E(E(B[a+5008>>2]-g)*B[a+4276>>2])+g);B[a+5008>>2]=g;I=Oc(x[a+4864>>2],x[a+4868>>2],x[a+4880>>2]),J=g,B[I>>2]=J;g=B[q>>2];g=E(E(E(B[a+5012>>2]-g)*B[a+4276>>2])+g);B[a+5012>>2]=g;I=Oc(x[a+4888>>2],x[a+4892>>2],x[a+4904>>2]),J=g,B[I>>2]=J;g=E(E(E(E(E(pi(t,x[a+4356>>2])*E(.6800000071525574))+E(pi(t,x[a+4360>>2])*E(-.5)))-E(pi(t,x[a+4364>>2])*E(.6200000047683716)))+E(pi(t,x[a+4368>>2])*E(-.5)))-E(pi(t,x[a+4372>>2])*E(.6200000047683716)));if(v[a+4264|0]&1){e=g;g=E(B[Oc(x[a+4816>>2],x[a+4820>>2],x[a+4836>>2])>>2]+E(e*E(.6180340051651001)));I=Oc(x[a+4816>>2],x[a+4820>>2],x[a+4832>>2]),J=E(e-E(g*E(.6180340051651001))),B[I>>2]=J}u=B[a+4280>>2];I=a,J=E(pi(t,x[a+4352>>2])+B[a+5020>>2]),B[I+5020>>2]=J;e=E(pi(s,x[a+4376>>2])+B[a+5024>>2]);B[a+5024>>2]=e;f=B[a+5020>>2];h=E(E(E(B[a+4980>>2]-B[Oc(x[a+4624>>2],x[a+4628>>2],x[a+4644>>2])>>2])*B[a+4444>>2])+B[Oc(x[a+4624>>2],x[a+4628>>2],x[a+4644>>2])>>2]);B[a+4980>>2]=h;C=E(h*B[a+4440>>2]);k=E(e*E(.7070000171661377));j=E(f*E(-.7070000171661377));f=E(k+j);h=B[a+4272>>2];e=E(C+E(f*h));I=Oc(x[a+4624>>2],x[a+4628>>2],x[a+4640>>2]),J=E(f-E(h*e)),B[I>>2]=J;f=E(E(E(B[a+4976>>2]-B[Oc(x[a+4600>>2],x[a+4604>>2],x[a+4620>>2])>>2])*B[a+4436>>2])+B[Oc(x[a+4600>>2],x[a+4604>>2],x[a+4620>>2])>>2]);B[a+4976>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4432>>2])+E(e*h));I=Oc(x[a+4600>>2],x[a+4604>>2],x[a+4616>>2]),J=E(e-E(h*f)),B[I>>2]=J;w=E(E(e*E(-.15000000596046448))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){e=E(E(E(B[a+4972>>2]-B[Oc(x[a+4576>>2],x[a+4580>>2],x[a+4596>>2])>>2])*B[a+4428>>2])+B[Oc(x[a+4576>>2],x[a+4580>>2],x[a+4596>>2])>>2]);B[a+4972>>2]=e;h=B[a+4272>>2];e=E(E(e*B[a+4424>>2])+E(f*h));I=Oc(x[a+4576>>2],x[a+4580>>2],x[a+4592>>2]),J=E(f-E(h*e)),B[I>>2]=J;f=E(E(E(B[a+4968>>2]-B[Oc(x[a+4552>>2],x[a+4556>>2],x[a+4572>>2])>>2])*B[a+4420>>2])+B[Oc(x[a+4552>>2],x[a+4556>>2],x[a+4572>>2])>>2]);B[a+4968>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4416>>2])+E(e*h));I=Oc(x[a+4552>>2],x[a+4556>>2],x[a+4568>>2]),J=E(e-E(h*f)),B[I>>2]=J;w=E(E(E(e*E(.3499999940395355))+w)+E(f*E(-.3799999952316284)))}I=Oc(x[a+4912>>2],x[a+4916>>2],x[a+4928>>2]),J=f,B[I>>2]=J;e=E(B[Oc(x[a+4912>>2],x[a+4916>>2],x[a+4932>>2])>>2]*B[a+4496>>2]);B[a+5028>>2]=E(E(B[a+5028>>2]-e)*B[a+4500>>2])+e;e=E(E(E(B[a+4964>>2]-B[Oc(x[a+4528>>2],x[a+4532>>2],x[a+4548>>2])>>2])*B[a+4412>>2])+B[Oc(x[a+4528>>2],x[a+4532>>2],x[a+4548>>2])>>2]);B[a+4964>>2]=e;f=B[a+5028>>2];o=B[a+4272>>2];h=E(E(f*o)+E(e*B[a+4408>>2]));I=Oc(x[a+4528>>2],x[a+4532>>2],x[a+4544>>2]),J=E(f-E(o*h)),B[I>>2]=J;e=E(E(E(B[a+4960>>2]-B[Oc(x[a+4504>>2],x[a+4508>>2],x[a+4524>>2])>>2])*B[a+4404>>2])+B[Oc(x[a+4504>>2],x[a+4508>>2],x[a+4524>>2])>>2]);B[a+4960>>2]=e;f=E(e*B[a+4400>>2]);e=B[a+4272>>2];o=E(f+E(h*e));I=Oc(x[a+4504>>2],x[a+4508>>2],x[a+4520>>2]),J=E(h-E(e*o)),B[I>>2]=J;B[a+5020>>2]=o;e=E(E(E(E(E(pi(s,x[a+4380>>2])*E(.7070000171661377))+E(pi(s,x[a+4384>>2])*E(-.6000000238418579)))-E(pi(s,x[a+4388>>2])*E(.5)))+E(pi(s,x[a+4392>>2])*E(-.6000000238418579)))-E(pi(s,x[a+4396>>2])*E(.5)));if(v[a+4264|0]&1){f=e;e=E(B[Oc(x[a+4840>>2],x[a+4844>>2],x[a+4860>>2])>>2]+E(e*E(.6180340051651001)));I=Oc(x[a+4840>>2],x[a+4844>>2],x[a+4856>>2]),J=E(f-E(e*E(.6180340051651001))),B[I>>2]=J}G=B[a+4280>>2];f=E(E(E(B[a+5004>>2]-B[Oc(x[a+4768>>2],x[a+4772>>2],x[a+4788>>2])>>2])*B[a+4492>>2])+B[Oc(x[a+4768>>2],x[a+4772>>2],x[a+4788>>2])>>2]);B[a+5004>>2]=f;C=E(f*B[a+4488>>2]);f=E(j-k);j=B[a+4272>>2];k=E(C+E(f*j));I=Oc(x[a+4768>>2],x[a+4772>>2],x[a+4784>>2]),J=E(f-E(j*k)),B[I>>2]=J;f=E(E(E(B[a+5e3>>2]-B[Oc(x[a+4744>>2],x[a+4748>>2],x[a+4764>>2])>>2])*B[a+4484>>2])+B[Oc(x[a+4744>>2],x[a+4748>>2],x[a+4764>>2])>>2]);B[a+5e3>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4480>>2])+E(k*j));I=Oc(x[a+4744>>2],x[a+4748>>2],x[a+4760>>2]),J=E(k-E(j*f)),B[I>>2]=J;k=E(E(E(h*E(.3799999952316284))+E(k*E(-.15000000596046448)))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){h=E(E(E(B[a+4996>>2]-B[Oc(x[a+4720>>2],x[a+4724>>2],x[a+4740>>2])>>2])*B[a+4476>>2])+B[Oc(x[a+4720>>2],x[a+4724>>2],x[a+4740>>2])>>2]);B[a+4996>>2]=h;j=B[a+4272>>2];h=E(E(h*B[a+4472>>2])+E(f*j));I=Oc(x[a+4720>>2],x[a+4724>>2],x[a+4736>>2]),J=E(f-E(j*h)),B[I>>2]=J;f=E(E(E(B[a+4992>>2]-B[Oc(x[a+4696>>2],x[a+4700>>2],x[a+4716>>2])>>2])*B[a+4468>>2])+B[Oc(x[a+4696>>2],x[a+4700>>2],x[a+4716>>2])>>2]);B[a+4992>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4464>>2])+E(h*j));I=Oc(x[a+4696>>2],x[a+4700>>2],x[a+4712>>2]),J=E(h-E(j*f)),B[I>>2]=J;k=E(E(E(h*E(.3499999940395355))+k)+E(f*E(-.3799999952316284)))}H=q+4|0;n=p+4|0;h=E(g*u);w=E(w-E(o*E(.3799999952316284)));o=E(e*G);I=Oc(x[a+4936>>2],x[a+4940>>2],x[a+4952>>2]),J=f,B[I>>2]=J;g=E(B[Oc(x[a+4936>>2],x[a+4940>>2],x[a+4956>>2])>>2]*B[a+4496>>2]);B[a+5032>>2]=E(E(B[a+5032>>2]-g)*B[a+4500>>2])+g;g=E(E(E(B[a+4988>>2]-B[Oc(x[a+4672>>2],x[a+4676>>2],x[a+4692>>2])>>2])*B[a+4460>>2])+B[Oc(x[a+4672>>2],x[a+4676>>2],x[a+4692>>2])>>2]);B[a+4988>>2]=g;e=B[a+5032>>2];f=B[a+4272>>2];g=E(E(e*f)+E(g*B[a+4456>>2]));I=Oc(x[a+4672>>2],x[a+4676>>2],x[a+4688>>2]),J=E(e-E(f*g)),B[I>>2]=J;f=B[a+4284>>2];e=E(E(E(B[a+4984>>2]-B[Oc(x[a+4648>>2],x[a+4652>>2],x[a+4668>>2])>>2])*B[a+4452>>2])+B[Oc(x[a+4648>>2],x[a+4652>>2],x[a+4668>>2])>>2]);B[a+4984>>2]=e;u=B[a+4272>>2];e=E(E(e*B[a+4448>>2])+E(g*u));I=Oc(x[a+4648>>2],x[a+4652>>2],x[a+4664>>2]),J=E(g-E(u*e)),B[I>>2]=J;B[a+5024>>2]=e;e=E(-e);u=B[a+4288>>2];i=D;e:{f:{while(1){if((i|0)==(F|0)){g:{e=E(o+E(E(E(e*E(.3799999952316284))+k)*u));g=E(h+E(E(E(g*E(.3799999952316284))+w)*f));if(!(y[a+4264|0]&2)){break g}p=n;n=H;break f}}else{z=x[i+16>>2];A=z-1|0;x[i+16>>2]=A;if((z|0)<=0){x[i+16>>2]=A+x[i+12>>2]}z=x[i+20>>2];A=z-1|0;x[i+20>>2]=A;if((z|0)<=0){x[i+20>>2]=A+x[i+12>>2]}i=i+24|0;continue}break}B[l>>2]=E(g+B[a+5036>>2])*E(.5);B[m>>2]=E(e+B[a+5040>>2])*E(.5);B[a+5040>>2]=e;B[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;B[l>>2]=g;B[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}v[a+5044|0]=1}n=a;a=x[a+56>>2];Qi(n,b,c,Hc(a,0),Hc(a,1),d)}}function tua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-272|0;fb=e;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if(!U$(b,e+206|0)){break m}if(!V$(e+206|0)){break m}if(!c){d=1;break m}Bd(a,131072);d=fb-16|0;fb=d;h=e+120|0;f=tc(d+4|0,3910);_c(h,f);tb(f);fb=d+16|0;x[31725]=0;S(211,e+160|0,h|0,e+210|0);d=x[31725];x[31725]=0;n:{o:{p:{if((d|0)!=1){d=e+160|0;Ab(a+1298344|0,d);tb(d);h=e+120|0;Eb(h);f=tc(d,11144);Ab(a+1298356|0,f);tb(f);o=a+1298404|0,q=x[Fc(d,4)>>2],x[o>>2]=q;vE(h,3,e+219|0);Cc(d,h);Ab(a+1298308|0,d);tb(d);wi(h,3,e+249|0);Mr(d,4,h);Ab(a+1298320|0,d);tb(d);d=rp(d);o=d,q=Kd(y[e+269|0],1,31),x[o+8>>2]=q;o=d,q=Kd(y[e+270|0],1,12),x[o+4>>2]=q;x[d>>2]=y[e+271|0]+1900;h=a+1298412|0;fw(h);iE(h,d);m=e+128|0;h=Nb(e+148|0);q:{r:{s:{while(1){d=x[b+8>>2];f=x[b>>2];x[31725]=0;d=U(152,f|0,d|0,8)|0;f=x[31725];x[31725]=0;t:{u:{v:{w:{x:{if((f|0)!=1){if(!d){break q}x[31725]=0;O(312,b|0,e- -64|0);d=x[31725];x[31725]=0;if((d|0)==1){break x}d=x[e+68>>2];y:{g=y[e+210|0];switch(g-3|0){case 1:break w;case 0:break y;default:break v}}f=2;if(x[e+64>>2]!=1431389523){break u}break t}b=N()|0;break b}b=N()|0;break b}f=4;if(x[e+64>>2]!=1431389523){break u}break t}f=0;if(g>>>0>7){break t}}d=x[e+64>>2]==1146113363?-1:d;f=0}g=x[e+68>>2];x[e+120>>2]=x[e+64>>2];x[e+124>>2]=g;x[31725]=0;S(187,e+100|0,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break s}ic(m,e+100|0);x[31725]=0;O(313,h|0,e+120|0);d=x[31725];x[31725]=0;if((d|0)==1){break r}Gd(e+120|0);ub(e+100|0);x[31725]=0;P(185,b|0,f|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}b=N()|0;break b}b=N()|0;break b}b=N()|0;Gd(e+120|0);ub(e+100|0);break b}x[31725]=0;m=R(170,e+120|0)|0;b=x[31725];x[31725]=0;z:{A:{B:{if((b|0)!=1){x[31725]=0;S(314,e+100|0,h|0,1431389523);b=x[31725];x[31725]=0;if((b|0)==1){break B}d=e+100|0;b=hd(m,d);ub(d);w[e+98>>1]=0;w[e+96>>1]=65534;if(y[e+210|0]<3){break z}x[31725]=0;d=R(191,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break A}break d}b=N()|0;break b}b=N()|0;break c}w[e+98>>1]=d;if(y[e+210|0]<4){break z}x[31725]=0;d=R(191,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}w[e+96>>1]=y[e+210|0]==4?d?d:-2:d}d=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;g=R(204,b|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break d}x[31725]=0;S(240,Xb(f,d)|0,b|0,g>>>1|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}d=Xb(x[a+484360>>2],y[a+484376|0]);d=hE(x[d>>2],x[d+4>>2]);Gf(e+98|0,d);Gf(e+96|0,d);x[31725]=0;S(314,e+100|0,h|0,1414807888);d=x[31725];x[31725]=0;if((d|0)==1){break e}d=e+100|0;b=hd(b,d);ub(d);d=x[b>>2];x[31725]=0;d=R(174,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}if(!(c&1)|d^1){break n}x[31725]=0;O(315,b|0,e+8|0);d=x[31725];x[31725]=0;if((d|0)==1){break f}o=a,q=Kd(y[e+10|0],1,32)+1|0,w[o+480188>>1]=q;x[31725]=0;d=P(216,e+84|0,z[e+8>>1])|0;f=x[31725];x[31725]=0;if((f|0)==1){break g}o=e,q=wb(x[d>>2]),x[o+44>>2]=q;g=wb(x[d+4>>2]);C:{D:{E:{while(1){j=x[e+44>>2];if(!Ib(j,g)){f=z[a+480188>>1];x[31725]=0;f=P(316,e+100|0,f|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){break C}b=N()|0;break o}x[31725]=0;f=y[e+210|0]<3?9:8;P(185,b|0,f-4|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){x[31725]=0;i=R(153,b|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break E}Gh(b,f);x[31725]=0;S(187,e- -64|0,b|0,f+i|0);f=x[31725];x[31725]=0;if((f|0)==1){break D}i=j;f=e- -64|0;j=ic(e+100|0,f);hd(i,j);ub(j);ub(f);Sf(e+44|0);continue}break}b=N()|0;break o}b=N()|0;break o}b=N()|0;break o}g=Xb(x[a+484360>>2],y[a+484376|0]);g=mm(x[g>>2],x[g+4>>2]);x[31725]=0;l=a+484344|0;O(225,l|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){g=Xb(x[a+484360>>2],y[a+484376|0]);o=e,q=wb(x[g>>2]),x[o+64>>2]=q;j=wb(x[g+4>>2]);while(1){g=x[e+64>>2];if(!Ib(g,j)){g=Xb(x[a+484360>>2],y[a+484376|0]);j=z[e+96>>1];F:{if(!cj(g,j)){break F}i=x[g>>2];k=z[e+98>>1];if(!k){if(hE(i,x[g+4>>2])>>>0<=j>>>0){break F}}g=Wb(x[l>>2],z[_b(i,j)>>1]);ye(g,Gn(Ye(Ne(e- -64|0,12,k&255),x[g+12>>2]-1|0)))}Sk(f);Qc(d);break n}i=x[d>>2];n=Uf(i,x[d+4>>2]);k=z[g>>1];if(n>>>0>k>>>0){x[31725]=0;i=ba(317,eh(i,k)|0,y[e+210|0],f|0,a|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break p}w[g>>1]=i}Md(e- -64|0);continue}}break p}b=N()|0;Eb(e+120|0);break a}b=N()|0;Sk(f)}Qc(d);break c}x[31725]=0;S(314,e- -64|0,h|0,1196641603);d=x[31725];x[31725]=0;if((d|0)==1){break k}d=e- -64|0;b=hd(b,d);ub(d);d=x[b>>2];x[31725]=0;d=R(174,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}if(d){x[31725]=0;P(185,b|0,1)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}x[31725]=0;d=R(204,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}x[31725]=0;aa(318,a+1298332|0,b|0,d|0,40,0);d=x[31725];x[31725]=0;if((d|0)==1){break d}}x[31725]=0;S(314,e- -64|0,h|0,1146113363);d=x[31725];x[31725]=0;if((d|0)==1){break h}x[31725]=0;S(314,e+44|0,h|0,1229999443);d=x[31725];x[31725]=0;if((d|0)==1){break l}d=e+44|0;b=hd(b,d);ub(d);x[31725]=0;d=R(199,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break j}w[a+480190>>1]=d;j=!(c&2);f=1;G:{while(1){H:{c=f&65535;if(c>>>0>(d&65535)>>>0){break G}d=30;I:{J:{K:{if(y[e+210|0]>=2){x[31725]=0;d=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break K}}x[31725]=0;S(319,b|0,((c<<5)+a|0)+946304|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break K}x[31725]=0;O(320,b|0,e+28|0);d=x[31725];x[31725]=0;if((d|0)==1){break J}x[31725]=0;g=D(c,104)+a|0;i=g+484380|0;O(321,e+28|0,i|0);c=x[31725];x[31725]=0;if((c|0)==1){break J}d=y[e+210|0];if(d>>>0>=8){x[31725]=0;O(322,b|0,g+484423|0);c=x[31725];x[31725]=0;if((c|0)==1){break J}d=y[e+210|0]}x[31725]=0;P(185,b|0,((d&255)>>>0>1?6:2)|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break J}x[31725]=0;c=R(153,e- -64|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;S(187,e+8|0,e- -64|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){break I}}b=N()|0;break i}b=N()|0;break i}b=N()|0;break i}d=e+8|0;c=ic(e+44|0,d);ub(d);d=x[c>>2];x[31725]=0;d=R(174,d|0)|0;l=x[31725];x[31725]=0;if((l|0)!=1){L:{if(j|d^1){break L}d=Xc(e+8|0,w[g+484414>>1]&1?16:8,1,0,(y[e+43|0]&12)==4?7:0);x[31725]=0;U(217,d|0,i|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break L}break H}ub(c);f=f+1|0;d=z[a+480190>>1];continue}}break}b=N()|0;ub(c);break i}gg(a);x[a+480204>>2]=12e5;x[a+480208>>2]=24;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+480228>>2]=48;x[a+480232>>2]=48;x[31725]=0;d=1;U(268,a+1074312|0,114,1)|0;a=x[31725];x[31725]=0;if((a|0)==1){break j}ub(e- -64|0);ub(b);ie(h)}fb=e+272|0;return d|0}b=N()|0;break i}b=N()|0;break c}b=N()|0}ub(e- -64|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}ub(m)}ie(h)}Q(b|0);p()}function Xpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0;d=fb-288|0;fb=d;xc(b);a:{b:{c:{d:{if(!Av(b,d+192|0)){break d}if(!KX(d+192|0)){break d}if(!Mb(x[b>>2],x[b+8>>2],Bc(JX(d+192|0),hb))){break d}if(!c){h=1;break d}if(!cd(b,y[d+196|0])){break d}Bd(a,268435456);gg(a);x[a+480208>>2]=4;Lb(a+1074312|0,114,1);f=d+84|0;i=tc(f,15312);Ab(a+1298344|0,i);tb(i);i=tc(f,10282);Ab(a+1298356|0,i);tb(i);E=a+1298404|0,F=x[Fc(f,4)>>2],x[E>>2]=F;i=d+16|0;df(i,d+198|0,48,3);Cc(f,i);Ab(a+1298308|0,f);tb(f);f=y[d+246|0];w[a+480188>>1]=f+1;x[a+480228>>2]=y[d+249|0];x[a+480204>>2]=D(y[d+250|0],1e4);x[a+480196>>2]=y[d+251|0];while(1){if((e|0)==(f|0)){e:{w[a+480190>>1]=y[d+284|0];e=y[d+286|0]|y[d+287|0]<<8;i=fb-16|0;fb=i;f=d+180|0;x[f>>2]=0;x[f+4>>2]=0;sc(f+8|0);Rd(i+8|0,x[vb(i+4|0,f)>>2]);f:{g:{if(e){x[31725]=0;O(663,f|0,e|0);g=x[31725];x[31725]=0;if((g|0)==1){break g}jD(f,e)}e=i+8|0;Qd(e);dh(e);fb=i+16|0;break f}a=N()|0;dh(i+8|0);Q(a|0);p()}x[31725]=0;i=f;S(658,b|0,f|0,y[d+286|0]|y[d+287|0]<<8);f=x[31725];x[31725]=0;if((f|0)==1){break b}A=Nb(d+168|0);q=Nb(d+156|0);x[31725]=0;U(422,b|0,A|0,y[d+285|0])|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;U(422,b|0,q|0,y[d+284|0])|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}r=c&2;s=d+122|0;n=d+90|0;f=0;h:{while(1){e=f;if(e>>>0>=y[d+284|0]){h=1;if(!(c&1)){break e}x[d+68>>2]=0;lj(Xb(x[a+484360>>2],y[a+484376|0]));E=d,F=wb(x[i>>2]),x[E+64>>2]=F;r=a+484344|0;B=wb(x[i+4>>2]);break h}x[31725]=0;f=e+1|0;g=D(f,104)+a|0;j=g+484380|0;O(281,j|0,0);h=x[31725];x[31725]=0;i:{if((h|0)!=1){h=yb(x[q>>2],e);h=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);if(!h){continue}x[31725]=0;h=P(151,b|0,h|0)|0;k=x[31725];x[31725]=0;j:{if((k|0)==1){break j}if(!h){continue}x[31725]=0;h=P(659,b|0,d+84|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break j}if(!h){continue}h=d+72|0;We(h,2,n);x[31725]=0;O(220,d+16|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break c}h=d+16|0;zc(((f<<5)+a|0)+946304|0,h);tb(h);k=d+72|0;Rk(k,2,s);x[31725]=0;O(220,h|0,k|0);h=x[31725];x[31725]=0;if((h|0)==1){break c}h=d+16|0;ze(g+484423|0,h);tb(h);h=y[d+134|0];if(h>>>0<=15){w[g+484408>>1]=D(h,17);h=g+484414|0;w[h>>1]=z[h>>1]|32}v[d+16|0]=y[d+135|0];v[d+72|0]=64;E=g+484412|0,F=y[Rb(d+16|0,d+72|0)|0],w[E>>1]=F;x[g+484404>>2]=y[d+137|0]|y[d+138|0]<<8;o=g+484384|0;k=y[d+143|0]|y[d+144|0]<<8|(y[d+145|0]<<16|y[d+146|0]<<24);x[o>>2]=k;m=g+484388|0;h=y[d+147|0]|y[d+148|0]<<8|(y[d+149|0]<<16|y[d+150|0]<<24);x[m>>2]=h;l=y[d+151|0]|y[d+152|0]<<8|(y[d+153|0]<<16|y[d+154|0]<<24);x[j>>2]=l;t=y[d+136|0];if(t&1){k=k>>>1|0;x[o>>2]=k;h=h>>>1|0;x[m>>2]=h;x[j>>2]=l>>>1}k:{if(h>>>0<=k>>>0){break k}g=g+484414|0;h=z[g>>1];w[g>>1]=h|2;if(!(t&2)){break k}w[g>>1]=h|6}al(j);if(!r){continue}e=yb(x[q>>2],e);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[31725]=0;P(151,b|0,e+y[d+88|0]|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break i}}break c}break c}e=Xc(d+16|0,v[d+136|0]&1?16:8,1,0,1);x[31725]=0;U(217,e|0,j|0,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){continue}break}break c}while(1){k=x[d+64>>2];if(!Ib(k,B)){e=y[a+484376|0];f=x[a+484360>>2];l:{b=x[d+68>>2];c=b&63;m:{if(!c){break m}g=Xb(f,e);b=b>>>6&65535;if(!cj(g,b)){break m}b=z[_b(x[g>>2],b)>>1];f=x[r>>2];x[31725]=0;O(660,Wb(f,b)|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break l}e=y[a+484376|0];f=x[a+484360>>2]}a=Xb(f,e);E=d,F=wb(x[a>>2]),x[E+84>>2]=F;b=wb(x[a+4>>2]);g=65535;while(1){a=x[d+84>>2];if(!Ib(a,b)){break e}if(z[a>>1]==65535){n:{if((g&65535)!=65535){break n}x[31725]=0;g=P(369,r|0,64)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break n}break c}w[a>>1]=g}Md(d+84|0);continue}}break c}o:{c=y[k+3|0];if(y[k+2|0]>y[d+246|0]|c>>>0>=y[d+285|0]){break o}c=yb(x[A>>2],c);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31725]=0;c=P(151,b|0,c|0)|0;f=x[31725];x[31725]=0;p:{if((f|0)!=1){if(!c){break o}x[31725]=0;O(661,b|0,d+84|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}e=y[d+88|0];if(!e){break o}c=y[k|0]|y[k+1|0]<<8;v[d+16|0]=y[d+89|0];v[d+72|0]=y[d+246|0]-y[k+2|0];s=y[Rb(d+16|0,d+72|0)|0];x[d+60>>2]=c+e;E=d,F=x[ad(d+68|0,d+60|0)>>2],x[E+68>>2]=F;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;g=c&63;n=c>>>6|0;o=0;while(1){if((e&255)>>>0<=o>>>0){break o}e=Xb(x[a+484360>>2],y[a+484376|0]);j=g>>>0>63;n=j+n|0;c=n&65535;if(Zc(x[e>>2],x[e+4>>2])>>>0<=c>>>0){x[31725]=0;O(332,e|0,n+1&65535);f=x[31725];x[31725]=0;if((f|0)==1){break p}x[31725]=0;f=P(369,r|0,64)|0;e=x[31725];x[31725]=0;if((e|0)==1){break p}e=Xb(x[a+484360>>2],y[a+484376|0]);E=_b(x[e>>2],c),F=f,w[E>>1]=F}l=x[a+484344>>2];f=x[a+484348>>2];m=z[_b(x[e>>2],c)>>1];if(!He(l,f,m)){break o}f=0;c=Wb(l,m);l=j?0:g;e=jd(x[c>>2],x[x[c+48>>2]+12>>2],l,y[k+2|0]);q:{while(1){if((f|0)==(s|0)){c=y[d+89|0];if(c>>>0<=s>>>0){break q}x[31725]=0;P(185,b|0,D(c-s|0,5)|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break q}break c}x[31725]=0;O(662,d+72|0,b|0);c=x[31725];x[31725]=0;if((c|0)!=1){c=d+72|0;j=Jc(c);C=af(c);t=fj(c);u=ec(c);g=0;c=y[d+72|0];if((c-1&255)>>>0<=142){g=(D((c&240)>>>4|0,12)+(c&15)|0)+13|0;v[(d+16|0)+f|0]=g}v[e|0]=g;c=y[j|0];v[e+2|0]=1;v[e+1|0]=c;c=y[C|0];r:{if((c|0)!=255){v[e+4|0]=c;break r}v[e+2|0]=0}c=y[t|0];s:{if(c>>>0>22){break s}v[e+3|0]=y[c+25360|0];j=y[u|0];v[e+5|0]=j;c=e+5|0;t:{switch(y[t|0]-4|0){case 3:v[c|0]=j&3|64;break s;case 4:v[c|0]=j&3|48;break s;case 7:g=x[i>>2];if(oc(g,x[i+4>>2])>>>0<=j>>>0){break s}u=c;c=yb(g,j);c=y[c|0]|y[c+1|0]<<8;v[u|0]=c>>>6;g=Wb(x[a+484344>>2],m);g=jd(x[g>>2],x[x[g+48>>2]+12>>2],l,z[a+480188>>1]-1&65535);v[g+5|0]=c&63;v[g+3|0]=14;break s;case 8:u=c;c=x[d+60>>2];v[u|0]=c>>>6;g=Wb(x[a+484344>>2],m);g=jd(x[g>>2],x[x[g+48>>2]+12>>2],l,z[a+480188>>1]-1&65535);v[g+5|0]=c&63;v[g+3|0]=14;break s;case 10:v[c|0]=j&15|128;break s;case 12:v[d+15|0]=15;E=c,F=y[Rb(c,d+15|0)|0]|208,v[E|0]=F;break s;case 13:v[d+15|0]=15;E=c,F=y[Rb(c,d+15|0)|0]|192,v[E|0]=F;break s;case 14:v[d+15|0]=15;E=c,F=y[Rb(c,d+15|0)|0]|224,v[E|0]=F;break s;case 0:case 16:case 17:if(!(j&15)){break s}g=j&240;if(!g|(g|0)==240){break s}v[c|0]=j|15;break s;case 9:case 18:break t;default:break s}}if(g&255){break s}v[e|0]=y[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}g=l+1|0;o=o+1|0;e=y[d+88|0];continue}}break c}break c}Je(d- -64|0);continue}}}else{w[((e<<5)+a|0)+480284>>1]=D(y[(d+e|0)+252|0],17);e=e+1|0;continue}break}uc(q);uc(A);uc(i)}fb=d+288|0;return h|0}a=N()|0;uc(q);uc(A);break a}a=N()|0}uc(i);Q(a|0);p()}function nM(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;i=fb-208|0;fb=i;a:{b:{if(g){rf(i+196|0,f,32);x[31725]=0;U(543,i+184|0,f|0,32)|0;h=x[31725];x[31725]=0;if((h|0)!=1){break b}f=N()|0;break a}Fb(i+196|0);Fb(i+184|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(St(c)){h=x[b+24>>2];j=x[h+484344>>2];if(He(j,x[h+484348>>2],c&65535)){break j}}x[31725]=0;S(1169,a|0,i+196|0,i+184|0);a=x[31725];x[31725]=0;if((a|0)!=1){break i}f=N()|0;break c}c=Wb(j,c);if(!(!((e|0)<0|x[c+12>>2]<=(d|0)|(d|0)<0)&z[h+480188>>1]>e>>>0)){x[31725]=0;S(1169,a|0,i+196|0,i+184|0);a=x[31725];x[31725]=0;if((a|0)!=1){break i}f=N()|0;break c}c=jd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);tf(i+196|0);tf(i+184|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=y[c|0];if(!Tc(d)){if(!Ol(d)){break A}}e=y[c+1|0];h=x[b+24>>2];x[31725]=0;V(1170,i+160|0,h|0,d|0,e|0);d=x[31725];x[31725]=0;e=1;if((d|0)==1){break y}x[31725]=0;O(1065,i+172|0,i+160|0);d=x[31725];x[31725]=0;if((d|0)!=1){break z}f=N()|0;break v}e=0;x[31725]=0;P(36,i+172|0,16775)|0;d=x[31725];x[31725]=0;if((d|0)==1){break x}}x[31725]=0;d=P(842,i+196|0,i+172|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break w}tb(i+172|0);if(e){tb(i+160|0)}e=9968;h=y[c|0];if(!Tc(h)){e=Ol(h)?10278:16775}x[31725]=0;h=P(36,i+172|0,e|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break u}x[31725]=0;e=P(842,i+184|0,h|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break t}tb(h);if(f-6>>>0>4294967290){break l}x[31725]=0;h=P(36,i+148|0,18429)|0;j=x[31725];x[31725]=0;if((j|0)==1){break s}x[31725]=0;j=P(842,d|0,h|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break r}tb(h);x[31725]=0;h=P(36,i+136|0,18429)|0;l=x[31725];x[31725]=0;if((l|0)==1){break q}x[31725]=0;l=P(842,e|0,h|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break p}tb(h);h=c+1|0;B:{if(y[c+1|0]){x[31725]=0;O(560,i+124|0,h|0);k=x[31725];x[31725]=0;if((k|0)!=1){break B}break d}x[31725]=0;P(36,i+124|0,16780)|0;k=x[31725];x[31725]=0;if((k|0)==1){break d}}x[31725]=0;k=P(842,j|0,i+124|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break o}j=i+124|0;tb(j);h=y[h|0];x[31725]=0;h=P(36,j|0,(h?10801:16780)|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break n}x[31725]=0;l=P(842,l|0,h|0)|0;j=x[31725];x[31725]=0;if((j|0)!=1){break m}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;tb(i+172|0);if(!e){break c}}tb(i+160|0);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;tb(i+124|0);break c}f=N()|0;break c}tb(h);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{j=Vg(y[c|0]);O:{if(j){x[31725]=0;m=P(36,i+100|0,18429)|0;h=x[31725];x[31725]=0;if((h|0)==1){break N}h=y[c+4|0];n=y[c+2|0];x[31725]=0;o=i,q=Mj(n,h)&255,x[o+76>>2]=q;O(559,i+88|0,i+76|0);h=x[31725];x[31725]=0;if((h|0)==1){break M}h=0;x[31725]=0;S(1021,i+112|0,m|0,i+88|0);m=x[31725];x[31725]=0;if((m|0)!=1){break O}f=N()|0;break G}h=y[c+2|0];if(h){h=ER(x[x[x[b+24>>2]+8>>2]+88>>2],h);x[31725]=0;h=U(543,i+100|0,1,h|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break E}x[31725]=0;O(560,i+88|0,c+4|0);m=x[31725];x[31725]=0;if((m|0)==1){break L}x[31725]=0;S(1021,i+112|0,h|0,i+88|0);m=x[31725];x[31725]=0;h=1;if((m|0)!=1){break O}f=N()|0;break J}h=0;x[31725]=0;P(36,i+112|0,16779)|0;m=x[31725];x[31725]=0;if((m|0)==1){break e}}x[31725]=0;k=P(842,k|0,i+112|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break K}tb(i+112|0);if(h){tb(i+88|0);tb(i+100|0)}if(j){tb(i+88|0);tb(i+100|0)}h=5488;if(!Vg(y[c|0])){h=y[c+2|0]?5484:16779}x[31725]=0;h=P(36,i+112|0,h|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break D}x[31725]=0;j=P(842,l|0,h|0)|0;l=x[31725];x[31725]=0;if((l|0)!=1){break C}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break F}f=N()|0;break I}f=N()|0;tb(i+112|0);if(!h){break H}}tb(i+88|0)}tb(i+100|0)}if(!j){break c}}tb(i+88|0)}tb(i+100|0);break c}f=N()|0;break c}f=N()|0;break c}tb(h);if(f-13>>>0>4294967283){break l}x[31725]=0;h=P(36,i+76|0,18429)|0;l=x[31725];x[31725]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((l|0)!=1){x[31725]=0;l=P(842,k|0,h|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break Z}tb(h);x[31725]=0;h=P(36,i- -64|0,18429)|0;k=x[31725];x[31725]=0;if((k|0)==1){break Y}x[31725]=0;j=P(842,j|0,h|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break X}tb(h);_:{if(Vg(y[c|0])){h=y[c+5|0];k=y[c+3|0];b=0;x[31725]=0;o=i,q=Mj(k,h)&4095,x[o+16>>2]=q;O(1171,i+52|0,i+16|0);h=x[31725];x[31725]=0;if((h|0)!=1){break _}f=N()|0;break c}h=y[c+3|0];if(h){b=DR(x[x[x[b+24>>2]+8>>2]+84>>2],h);x[31725]=0;b=U(543,i+40|0,1,b|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break W}x[31725]=0;O(560,i+28|0,c+5|0);h=x[31725];x[31725]=0;if((h|0)==1){break V}x[31725]=0;S(1021,i+52|0,b|0,i+28|0);h=x[31725];x[31725]=0;b=1;if((h|0)!=1){break _}f=N()|0;break S}b=0;x[31725]=0;P(36,i+52|0,16775)|0;h=x[31725];x[31725]=0;if((h|0)==1){break U}}x[31725]=0;P(842,l|0,i+52|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break T}tb(i+52|0);if(b){tb(i+28|0);tb(i+40|0)}b=11161;if(!Vg(y[c|0])){b=y[c+3|0]?11161:16775}x[31725]=0;b=P(36,i+52|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break Q}x[31725]=0;P(842,j|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break P}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break R}f=N()|0;break c}f=N()|0;tb(i+52|0);if(!b){break c}}tb(i+28|0)}tb(i+40|0);break c}f=N()|0;break c}tb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=Yc(x[d+4>>2],y[d+11|0]);da:{if(b>>>0>f>>>0){x[31725]=0;V(123,i+16|0,d|0,0,f|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=i+16|0;Ab(d,b);tb(b);break da}f=N()|0;break c}if(!g){break da}x[31725]=0;b=U(543,i+16|0,f-b|0,32)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ca}x[31725]=0;P(842,d|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break ba}tb(b)}b=Yc(x[e+4>>2],y[e+11|0]);if(b>>>0<=f>>>0){break $}x[31725]=0;V(123,i+4|0,e|0,0,f|0);b=x[31725];x[31725]=0;if((b|0)==1){break aa}b=i+4|0;Ab(e,b);tb(b);break k}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}if(!g){break k}x[31725]=0;b=U(543,i+4|0,f-b|0,32)|0;c=x[31725];x[31725]=0;if((c|0)==1){break h}x[31725]=0;P(842,e|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break g}tb(b)}x[31725]=0;S(1169,a|0,d|0,e|0);a=x[31725];x[31725]=0;if((a|0)==1){break f}}tb(i+184|0);tb(i+196|0);fb=i+208|0;return}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0}tb(i+184|0)}tb(i+196|0);Q(f|0);p()}function Bta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-256|0;fb=d;xc(b);f=fb-16|0;fb=f;h=d+99|0;I_(f+8|0,h);i=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);j=x[f+4>>2];if((j|0)==(i|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(i|0)==(j|0);if(!f){H_(h)}a:{if(!f){break a}if(!J_(d+99|0)){break a}if(!c){e=1;break a}Bd(a,x[((y[d+215|0]|y[d+216|0]<<8)<<2)+24752>>2]);x[a+480208>>2]=x[a+480208>>2]|16777216;e=d+36|0;f=tc(e,13171);Ab(a+1298344|0,f);tb(f);f=tc(e,10313);Ab(a+1298356|0,f);tb(f);f=fb-16|0;fb=f;i=d+4|0;h=tc(f+4|0,4389);_c(i,h);tb(h);fb=f+16|0;x[31725]=0;V(231,e|0,i|0,y[d+178|0],d+175|0);e=x[31725];x[31725]=0;b:{if((e|0)!=1){e=d+36|0;Ab(a+1298368|0,e);tb(e);f=d+4|0;Eb(f);ci(a+1298392|0,((y[d+215|0]|y[d+216|0]<<8)<<2)+24800|0);ci(a+1298380|0,x[((y[d+215|0]|y[d+216|0]<<8)<<2)+24848>>2]);t=a+1298404|0,u=x[Fc(e,4)>>2],x[t>>2]=u;We(f,2,d+103|0);Cc(e,f);Ab(a+1298308|0,e);tb(e);We(f,2,d+135|0);Cc(e,f);c:{if(!Ld(e,9750)){x[31725]=0;S(260,d+4|0,4,d+36|0);e=x[31725];x[31725]=0;if((e|0)==1){break c}e=d+4|0;Ab(a+1298320|0,e);tb(e)}tb(d+36|0);w[a+480188>>1]=32;d:{while(1){if((g|0)!=32){f=(g<<5)+a|0;i=f+480280|0;Xe(i);e=y[(d+g|0)+180|0];e:{if(e>>>0<=15){x[d+36>>2]=e<<4|8;x[d+4>>2]=256;t=f+480284|0,u=x[ud(d+36|0,d+4|0)>>2],w[t>>1]=u;break e}if((e|0)!=16){if((e|0)!=255){break e}w[a+480188>>1]=g;break d}w[f+480284>>1]=128;x[i>>2]=256}g=g+1|0;continue}break}g=z[a+480188>>1]}e=0;if(!(g&65535)){break a}x[d+36>>2]=y[d+212|0]<<2;x[d+4>>2]=256;t=a,u=x[Gb(d+36|0,d+4|0)>>2],x[t+480200>>2]=u;x[a+480196>>2]=y[d+213|0];x[a+480204>>2]=D(y[d+214|0],1e4);if(cd(b,y[d+217|0]|y[d+218|0]<<8|(y[d+219|0]<<16|y[d+220|0]<<24))){jk(Xb(x[a+484360>>2],y[a+484376|0]),b,y[d+221|0]+1|0,255,254)}if(!cd(b,y[d+227|0]|y[d+228|0]<<8|(y[d+229|0]<<16|y[d+230|0]<<24))){break a}g=y[d+235|0]+1|0;w[a+480190>>1]=g;l=d+68|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(g&65535)>>>0){break g}e=fb-16|0;fb=e;f=d+36|0;bc(e+8|0,f,62);g=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){Tb(f,0,62)}if(!e){break g}g=0;e=D(j,104)+a|0;k=e+484380|0;ld(k,0);h=d+24|0;We(h,2,d+36|0);f=d+4|0;Cc(f,h);zc(((j<<5)+a|0)+946304|0,f);tb(f);Rk(h,2,l);Cc(f,h);ze(e+484423|0,f);tb(f);f=y[d+94|0]|y[d+95|0]<<8;x[e+484404>>2]=f;if(!En(x[a+480180>>2])){break f}while(1){if((g|0)==16){break f}if((f|0)==z[(g<<1)+24896>>1]){v[e+484417|0]=g<<4;break f}else{g=g+1|0;continue}}}h:{if(!(c&2)){break h}if(!cd(b,y[d+231|0]|y[d+232|0]<<8|(y[d+233|0]<<16|y[d+234|0]<<24))){break h}g=1;while(1){e=g&65535;if(e>>>0>z[a+480190>>1]){break h}e=D(e,104)+a|0;fg(Xc(d+36|0,w[e+484414>>1]&1?16:8,1,0,1),e+484380|0,b);g=g+1|0;continue}}n=a+484344|0;Vf(n,y[d+226|0]+1|0);j=LD(zr(a));cd(b,y[d+222|0]|y[d+223|0]<<8|(y[d+224|0]<<16|y[d+225|0]<<24));s=c&1;h=0;l=1;i:{j:{k:{while(1){if(y[d+226|0]<h>>>0){if(x[a+480180>>2]==1){break k}c=x[a+480208>>2]&-8454145;break j}l:{e=ih(b);if(e>>>0>=3){c=d+4|0;fe(c,b,e-2|0);i=ic(d+36|0,c);ub(c);m:{if(!s){break m}c=x[i>>2];x[31725]=0;c=R(174,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}if(!c){break m}x[31725]=0;c=U(198,n|0,h&65535,64)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}k=0;if(!c){break m}while(1){if((k|0)==64){break m}c=Wb(x[n>>2],h);cf(d+4|0,x[c>>2],x[x[c+48>>2]+12>>2],k);n:{o:while(1){x[31725]=0;c=R(199,i|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}if(!c){break n}e=c&31;if(e>>>0>=z[a+480188>>1]){break n}g=Wc(x[d+4>>2],e);if(c&32){x[31725]=0;O(200,d+24|0,i|0);e=x[31725];x[31725]=0;if((e|0)==1){break i}f=Jc(d+24|0);e=y[d+24|0];if(e){e=(e&127)-1|0;v[d+24|0]=e;e=(D((e&240)>>>4|0,12)+(e&15)|0)+13|0;v[g|0]=e;l=KD(e)&l}v[g+1|0]=y[f|0]}if(!(c&64)){continue}v[g+2|0]=0;v[g+3|0]=0;o=g+5|0;while(1){c=x[i>>2];x[31725]=0;c=U(152,c|0,x[d+44>>2],2)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}if(!c){continue o}q=y[g+5|0];c=y[g+3|0];x[31725]=0;O(200,d+24|0,i|0);e=x[31725];x[31725]=0;if((e|0)!=1){f=y[Jc(d+24|0)|0];v[g+5|0]=f;r=y[d+24|0];e=y[(r&31)+24928|0];v[g+3|0]=e;p:{q:{r:{s:{t:{switch(e-2|0){case 0:case 1:if(f>>>0<224){break p}m=223;if(x[a+480180>>2]!=1){break s}break p;case 11:v[d+3|0]=64;e=y[Rb(o,d+3|0)|0];v[o|0]=e;if(!Wv(x[j+88>>2],1)){break p}v[g+4|0]=e;v[g+2|0]=1;v[g+5|0]=q;v[g+3|0]=c;e=c;break r;case 17:u:{switch(((f&240)>>>4|0)-8|0){case 0:v[g+3|0]=2;v[g+5|0]=f&15|224;break p;case 1:v[g+3|0]=3;v[g+5|0]=f&15|224;break p;default:break u}}if(aj(x[j+84>>2],19)){break p}rw(g);e=y[g+3|0];break r;case 13:c=x[j+84>>2];if(aj(c,15)){break p}if(!aj(c,19)){break p}v[g+3|0]=19;v[g+5|0]=f&15|144;break p;case 18:m=145;if((f|0)==1){break s}if((f&240)==128){if(aj(x[j+84>>2],20)){break q}v[g+3|0]=19;break p}v[g+3|0]=0;break p;case 4:case 5:break t;default:break r}}m=f&240;if(!m){break p}}v[o|0]=m}if((e&255)!=20){break p}}e=y[g+5|0];if(y[g+2|0]|(e&240)!=128){break p}v[g+2|0]=2;v[g+5|0]=q;v[g+3|0]=c;v[g+4|0]=(((e&15)<<6|8)>>>0)/15}if(!(r&32)){continue o}continue}break}break}break i}k=k+1|0;continue}}ub(i)}h=h+1|0;continue}break}break i}c=x[a+480208>>2]&-8454145|(z[a+480188>>1]==4?l&1?8454144:0:0)}x[a+480208>>2]=c;e=1;if(!(y[d+240|0]|y[d+241|0]<<8|(y[d+242|0]<<16|y[d+243|0]<<24))){break a}if(!cd(b,y[d+236|0]|y[d+237|0]<<8|(y[d+238|0]<<16|y[d+239|0]<<24))){break a}_D(a+1298332|0,b,y[d+240|0]|y[d+241|0]<<8|(y[d+242|0]<<16|y[d+243|0]<<24),4);break a}g=N()|0;ub(i);break b}w[e+484412>>1]=64;f=y[d+81|0]|y[d+82|0]<<8|(y[d+83|0]<<16|y[d+84|0]<<24);x[k>>2]=f;g=y[d+93|0];if(g&2){h=e+484414|0;w[h>>1]=z[h>>1]|1;x[k>>2]=f>>>1}x[e+484384>>2]=y[d+85|0]|y[d+86|0]<<8|(y[d+87|0]<<16|y[d+88|0]<<24);x[e+484388>>2]=(y[d+89|0]|y[d+90|0]<<8|(y[d+91|0]<<16|y[d+92|0]<<24))-1;if(g&1){f=e+484414|0;w[f>>1]=z[f>>1]|2}v:{w:{if(!(g&4)){break w}f=y[d+96|0];if((f|0)==255){break w}v[d+4|0]=f;v[d+24|0]=64;t=e+484410|0,u=y[Rb(d+4|0,d+24|0)|0]<<2,w[t>>1]=u;break v}f=e+484414|0;w[f>>1]=z[f>>1]|32768}x:{if(g&8){g=e+484414|0;f=z[g>>1]|32;w[g>>1]=f;j=e+484408|0;e=y[d+97|0];if(e>>>0<=15){x[d+24>>2]=256;x[d+4>>2]=e<<4|8;h=x[ud(d+4|0,d+24|0)>>2]}else{h=128}w[j>>1]=h;w[g>>1]=f&65279|((e|0)==16)<<8;break x}w[e+484408>>1]=128}i=i+1|0;g=z[a+480190>>1];continue}}g=N()|0;tb(d+36|0);break b}g=N()|0;Eb(d+4|0)}Q(g|0);p()}fb=d+256|0;return e|0}function R7(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;l=fb-528|0;fb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(mi(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+72>>2]=1238;b=l+72|0;t=Be(l+104|0,l+112|0,b);m=x[t>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Fb(b);q=Fb(l+60|0);n=Fb(l+48|0);o=Fb(l+36|0);s=Fb(l+24|0);b=x[d>>2];x[31725]=0;ka(1248,c|0,b|0,l+92|0,l+88|0,l+84|0,u|0,q|0,n|0,o|0,l+20|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;w=x[l+20>>2];e=0;while(1){c:{d:{e:{f:{g:{if((e|0)==4){break g}x[31725]=0;b=P(1222,a|0,l+524|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(b){break g}h:{i:{j:{k:{l:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=U(1249,h|0,1,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(b){x[31725]=0;O(1250,l+12|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;O(35,s|0,x[l+12>>2]);b=x[31725];x[31725]=0;if((b|0)!=1){break k}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break h;case 2:break i;case 3:break j;case 0:break l;default:break c}}if((e|0)==3){break c}}while(1){x[31725]=0;b=P(1222,a|0,l+524|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=U(1249,h|0,1,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(!b){break c}x[31725]=0;O(1250,l+12|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;O(35,s|0,x[l+12>>2]);b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break a}m:{if(!Cb(x[n+4>>2],y[n+11|0])){break m}b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if((b|0)!=x[Wd(n,0)>>2]){break m}x[31725]=0;R(1225,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}v[g|0]=0;r=Cb(x[n+4>>2],y[n+11|0])>>>0>1?n:r;break c}n:{o:{k=x[o+4>>2];b=y[o+11|0];if(Cb(k,b)){b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if((b|0)==x[Wd(o,0)>>2]){break o}k=x[o+4>>2];b=y[o+11|0]}c=Cb(x[n+4>>2],y[n+11|0]);if(!c){break n}if(!Cb(k,b)){break n}x[f>>2]=x[f>>2]|4;a=0;break d}x[31725]=0;R(1225,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}v[g|0]=1;r=Cb(x[o+4>>2],y[o+11|0])>>>0>1?o:r;break c}b=Cb(k,b);if(!(b|c)){break c}v[g|0]=!b;break c}if(!((e|0)==2&y[l+95|0]!=0|(e>>>0<2|r|A))){r=0;break c}c=vb(l+12|0,zd(q));p:{if(!e|y[(e+l|0)+91|0]>1){break p}q:{while(1){b=ul(q);d=x[c>>2];if(!Ib(d,b)){break q}b=x[d>>2];x[31725]=0;b=U(1249,h|0,1,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){if(!b){break q}Je(c);continue}break}break a}b=zd(q);b=Iv(x[c>>2],b);if(Cb(x[s+4>>2],y[s+11|0])>>>0>=b>>>0){d=Mk(ul(s),0-b|0);k=ul(s);z=zd(q);b=fb-16|0;fb=b;x[b+8>>2]=z;x[b+12>>2]=d;while(1){r:{z=Ib(d,k);if(!z){break r}if(!lc(x[d>>2],x[x[b+8>>2]>>2])){break r}d=Je(b+12|0);Je(b+8|0);d=x[d>>2];continue}break}fb=b+16|0;if(z^1){break p}}C=c,D=x[vb(l+8|0,zd(q))>>2],x[C>>2]=D}x[l+8>>2]=x[c>>2];s:{while(1){b=ul(q);if(!Ib(x[l+8>>2],b)){break s}x[31725]=0;b=P(1222,a|0,l+524|0)|0;c=x[31725];x[31725]=0;t:{if((c|0)==1){break t}if(b){break s}b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break t}if((b|0)!=x[x[l+8>>2]>>2]){break s}x[31725]=0;R(1225,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}Je(l+8|0);continue}break}break a}if(!A){break c}b=ul(q);if(!Ib(x[l+8>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}b=0;z=x[l+84>>2];c=m;u:{while(1){v:{x[31725]=0;d=P(1222,a|0,l+524|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break v}if(d){break u}d=x[a>>2];x[31725]=0;k=R(1223,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[31725]=0;d=U(1249,h|0,64,k|0)|0;B=x[31725];x[31725]=0;if((B|0)==1){break a}w:{if(d){d=x[j>>2];if((d|0)==x[l+520>>2]){x[31725]=0;S(1251,i|0,j|0,l+520|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}d=x[j>>2]}x[j>>2]=d+4;x[d>>2]=k;b=b+1|0;break w}if(!Cb(x[u+4>>2],y[u+11|0])|!b|(k|0)!=(z|0)){break u}if(x[l+96>>2]==(m|0)){x[31725]=0;S(1244,t|0,l+100|0,l+96|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c;b=0}x[31725]=0;R(1225,a|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){continue}}break}break a}if(!b|x[t>>2]==(c|0)){break f}if(x[l+96>>2]==(c|0)){x[31725]=0;S(1244,t|0,l+100|0,l+96|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}c=x[l+100>>2]}m=c+4|0;x[l+100>>2]=m;x[c>>2]=b;break e}x[l+20>>2]=w;x:{if(!r){break x}k=1;while(1){if(Cb(x[r+4>>2],y[r+11|0])>>>0<=k>>>0){break x}x[31725]=0;b=P(1222,a|0,l+524|0)|0;c=x[31725];x[31725]=0;y:{if((c|0)==1){break y}z:{if(!b){b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break y}if((b|0)==x[Wd(r,k)>>2]){break z}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31725]=0;R(1225,a|0)|0;b=x[31725];x[31725]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+12>>2]=0;Xf(u,b,m,l+12|0);if(x[l+12>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}m=c}A:{if((w|0)<=0){break A}x[31725]=0;b=P(1222,a|0,l+524|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}B:{if(!b){b=x[a>>2];x[31725]=0;b=R(1223,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if((b|0)==x[l+88>>2]){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31725]=0;b=R(1225,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break A}x[31725]=0;c=P(1222,b|0,l+524|0)|0;d=x[31725];x[31725]=0;C:{if((d|0)==1){break C}D:{if(!c){c=x[b>>2];x[31725]=0;c=R(1223,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break C}x[31725]=0;c=U(1249,h|0,64,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break C}if(c){break D}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[31725]=0;S(1251,i|0,j|0,l+520|0);c=x[31725];x[31725]=0;if((c|0)==1){break C}}c=x[b>>2];x[31725]=0;c=R(1223,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break C}d=x[j>>2];x[j>>2]=d+4;x[d>>2]=c;x[31725]=0;R(1225,b|0)|0;c=x[31725];x[31725]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}Qb(s);Qb(o);Qb(n);Qb(q);tb(u);Lc(t);break b}e=e+1|0;continue}}break a}fb=l+528|0;return a|0}a=N()|0;Qb(s);Qb(o);Qb(n);Qb(q);tb(u);Lc(t);Q(a|0);p()}function wT(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=E(0),R=E(0),S=0,T=0,U=E(0),V=0;k=fb-48|0;fb=k;_j(b+223848|0,Yj(e,Mi(e,Yo(e),0))+1|0);oe(k+40|0,x[b+223848>>2],x[b+223852>>2]);gc(k+32|0,e,Yj(e,Mi(e,Yo(e),0)));F=x[k+32>>2];G=x[k+36>>2];o=fb-16|0;fb=o;H=a+906300|0;u=a+1074312|0;g=D(c,872)+b|0;I=g+1415|0;J=g+1304|0;K=g+1392|0;q=g+1368|0;s=g+1364|0;L=g+1336|0;M=g+1308|0;N=g+1300|0;O=g+1280|0;P=g+1402|0;l=g+1466|0;Q=E(y[l|0]);R=E(f>>>0);C=g+616|0;i=x[g+1272>>2];p=1;m=255;while(1){if((n|0)!=(G|0)&A[k+44>>2]>j>>>0){h=y[xb(F,n)|0];e=h-48|0;a:{b:{if((e&255)>>>0<=9){break b}if((h-65&255)>>>0<=5){e=h-55|0;break b}c:{d:{e:{switch(h-97|0){case 2:f:{e=wm(a,b,c,3,0)-1|0;if((e&255)>>>0>249){break f}e=x[vd(H,e)>>2];if(!e){break f}e=gB(e,45960,43016);if(!e){break f}e=ib[x[x[e>>2]+192>>2]](e,C,c)|0;h=(e|0)!=255;e=h?e:0;if(h|!i){break b}break c}if(i){break c}e=0;break b;case 21:g:{if(!Ob(u,28)){e=0;if(!Ob(u,1)){break g}}e=w[K>>1]}h=D(x[q>>2],x[s>>2]);e=D(x[a+1074456>>2],e+x[J>>2]|0);e=Yb((Gc(pva(ova(h,h>>31,e,e>>31),hb,1048576,0),hb)|0)/2|0,1,127);break d;case 20:e=D(x[q>>2],x[s>>2]);h=e;t=e>>31;e=D(x[a+1074456>>2],x[L>>2]);e=Yb((Gc(pva(ova(h,t,e,e>>31),hb,67108864,0),hb)|0)/2|0,1,127);break d;case 23:x[o>>2]=x[M>>2]/2;x[o+12>>2]=127;e=x[ud(o,o+12|0)>>2];break d;case 24:x[o>>2]=x[N>>2]/2;x[o+12>>2]=127;e=x[ud(o,o+12|0)>>2];break d;case 0:e=0;if(!i){break d}h=z[i+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!i){break d}h=z[i+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=x[O>>2]>>>8|0;break d;case 7:e=(z[a+480188>>1]<=c>>>0?y[P|0]-1|0:c)&127;break d;case 12:e=y[g+704|0]>>>7|0;break d;case 15:e=0;if(!i){break d}h=y[i+30|0];if(!h){break d}e=h-1&127;break d;case 25:h:{if(!d|v[l|0]<0){break h}i:{if(j>>>0<3){break i}e=x[k+40>>2];if(y[xb(e,j-3|0)|0]!=240){break i}if(y[xb(e,j-2|0)|0]>239){break h}}r=Lq(b,Q,R);j:{if(r<E(4294967296)&r>=E(0)){e=~~r>>>0;break j}e=0}v[l|0]=e;m=128;break d}m=(m&255)==255?f:m;e=f;break d;case 18:k:{if(!j){e=0;break k}h=x[k+40>>2];e=j;while(1){e=e-1|0;t=xb(h,e);if(!e){break k}if(y[t|0]!=240){continue}break}}if(j-e>>>0<5){break a}t=x[k+40>>2];if(y[xb(t,e)|0]!=240){break a}e=e+5|0;h=0;while(1){if((e|0)!=(j|0)){h=y[xb(t,e)|0]+h|0;e=e+1|0;continue}break};e=0-h&127;break d;case 13:break e;default:break a}}e=y[I|0];e=Tc(e)?e-1|0:0}h=p^-1;p=1;j=(h&1)+j|0;S=xb(x[k+40>>2],j),T=e,v[S|0]=T;j=j+1|0;break a}e=z[C+786>>1];h=y[i+31|0];e=(e?e-1|0:c)&15;l:{if((h|0)==17){break l}e=Tj(h)?h-1&15:0}}h=xb(x[k+40>>2],j);v[h|0]=(p&1?0:y[h|0]<<4)|e;p=p^1;j=(p&1)+j|0}n=n+1|0;continue}else{if(m<<24>>24>=0){v[l|0]=m}bc(o,x[k+40>>2],((p^-1)&1)+j|0);e=x[o+4>>2];x[k+40>>2]=x[o>>2];x[k+44>>2]=e;fb=o+16|0}break}o=x[k+44>>2];j=0;m:while(1){p=0;while(1){e=j;n:{o:{p:{q:{while(1){if(A[k+44>>2]<=e>>>0){break n}f=x[k+40>>2];g=xb(f,e);l=v[g|0];if((l|0)==-16){if(o-e>>>0>=4){j=4;if((y[xb(f,e+1|0)|0]&254)==240){break o}}j=e;r:{while(1){j=j+1|0;if(o>>>0<=j>>>0){break r}if(y[xb(f,j)|0]!=247){continue}break}j=(j-e|0)+1|0;if(j){break o}}S=xb(f,o),T=247,v[S|0]=T;o=o+1|0;j=o-e|0;break p}if((l|0)<0){break q}if(p&255){e=e-1|0;S=xb(f,e),T=p,v[S|0]=T;continue}break}j=j+1|0;continue m}S=k,T=FV(l&255),x[S+20>>2]=T;x[k+28>>2]=o-e;j=x[Gb(k+20|0,k+28|0)>>2]}if(!j){break n}f=x[k+40>>2];g=xb(f,e)}u=y[g|0];Er(k+20|0,f,x[k+44>>2],e,j);f=gc(k+12|0,x[k+20>>2],x[k+24>>2]);l=x[f+4>>2];x[k>>2]=x[f>>2];x[k+4>>2]=l;l=fb-32|0;fb=l;i=x[k+4>>2];s:{if(!i){break s}m=Ed(y[b+223884|0]);t:{f=x[k>>2];n=xb(f,0);g=y[n|0]-250|0;if(g>>>0>5|!(1<<g&37)){break t}h=z[a+480188>>1];g=0;while(1){if((g|0)==(h|0)){break t}q=(D(g,872)+b|0)+1453|0;v[q|0]=127;v[q+1|0]=0;g=g+1|0;continue}}u:{if((i|0)!=4|y[n|0]!=240){break u}g=y[xb(f,1)|0];if((g&254)!=240){break u}i=(D(c,872)+b|0)+616|0;n=xb(f,2);q=y[xb(f,3)|0];f=q<<24>>24;s=(g|0)!=241&(f|0)>=0;n=y[n|0];if(!(!s|n)){g=D(c,872)+b|0;n=g+1453|0;if(d){f=Bh(Lq(b,E(y[n|0]),E((f&255)>>>0)))}v[n|0]=f;v[g+1412|0]=0;f=Pq(a,i,!(x[g+704>>2]&32768),256);if((f|0)<0|!(y[g+705|0]&2)){break s}g=x[a+1298300>>2];if(m|Dd(g)^1){break s}Vq(g,c,f>>>2&255,1);break s}h=n<<24>>24;if(s&(h|0)==1){g=D(c,872)+b|0;m=g+1454|0;if(d){f=Bh(Lq(b,E(y[m|0]),E((f&255)>>>0)))}v[m|0]=f;v[g+1411|0]=0;Pq(a,i,!(x[g+704>>2]&32768),256);break s}if(!((g|0)==241|(h|0)!=2)){if(f>>>0>31){break s}g=D(c,872)+b|0;v[g+1461|0]=(f&240)>>>4;Pq(a,i,!(x[g+704>>2]&32768),256);break s}if(!((g|0)==241|(h|0)!=3)){h=(f|0)<0;f=wm(a,b,c,3,0)-1|0;if(h|(f&255)>>>0>249){break s}v[l+24|0]=f;g=a+906300|0;i=f&255;f=x[vd(g,i)>>2];if(!f){break s}r=E(E(127-q|0)/E(127));if(m){m=0;g=fb-16|0;fb=g;S=g,T=$j(l+24|0),x[S+4>>2]=T;f=fb-16|0;fb=f;i=b+223860|0;h=fB(i,f+12|0,y[l+24|0]);n=x[h>>2];if(!n){m=fb-16|0;fb=m;n=ec(i);q=Dh(f,Ec(24),Mg(m+8|0,n));n=x[q>>2];s=y[x[g+4>>2]];x[n+20>>2]=0;v[n+16|0]=s;S=ec(q),T=1,v[S+4|0]=T;fb=m+16|0;$g(i,x[f+12>>2],h,x[f>>2]);n=le(f);em(f);m=1}_g(g+8|0,x[vb(f,n)>>2],m);fb=f+16|0;f=td(x[g+8>>2]);fb=g+16|0;B[f+4>>2]=r;break s}if(!d){Iu(x[f+20>>2],r);break s}g=vd(g,i);Iu(x[f+20>>2],Lq(b,B[g+144>>2],r));break s}if((g|0)!=241&(h|0)>=0){break s}h=wm(a,b,c,3,0)-1|0;if((f|0)<0|(h&255)>>>0>249){break s}i=x[vd(a+906300|0,h&255)>>2];if(!i){break s}g=(g|0)!=241?n&127:n+128|0;r=E(E((f&255)>>>0)/E(127));if(m){S=MT(b+223872|0,bT(l+24|0,h,g)),U=r,B[S>>2]=U;break s}f=x[i>>2];if(!d){ib[x[f+44>>2]](i,g,r);break s}T=i,V=g,U=Lq(b,E(ib[x[f+48>>2]](i,g)),r),S=x[x[i>>2]+44>>2],ib[S](T|0,V|0,E(U));break s}if(m){break s}m=z[a+480188>>1];v:{if(m>>>0>c>>>0){g=c+1|0;break v}g=z[(D(c,872)+b|0)+1402>>1];if(!g){break s}}if(y[(D(c,872)+b|0)+707|0]&4|m>>>0<(g&65535)>>>0){break s}g=wm(a,b,c,3,0)-1|0;if((g&255)>>>0>249){break s}g=x[vd(a+906300|0,g)>>2];if(!g){break s}m=y[n|0];if((m|0)==240){mf(l+16|0,x[k>>2],x[k+4>>2]);f=x[x[g>>2]+72>>2];i=x[l+20>>2];x[l>>2]=x[l+16>>2];x[l+4>>2]=i;ib[f|0](g,l)|0;break s}S=l,V=FV(m),x[S+24>>2]=V;x[l+12>>2]=i;i=l+24|0;m=x[Gb(i,l+12|0)>>2];x[l+24>>2]=0;yc(i,f,m);ib[x[x[g>>2]+68>>2]](g,x[l+24>>2])|0}fb=l+32|0;p=u>>>0<240?u:p;j=e+j|0;continue}break}break}fb=k+48|0}function Y7(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;l=fb-528|0;fb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(uh(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+76>>2]=1238;b=l+76|0;t=Be(l+104|0,l+112|0,b);m=x[t>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Fb(b);q=Fb(l- -64|0);n=Fb(l+52|0);o=Fb(l+40|0);s=Fb(l+28|0);b=x[d>>2];x[31725]=0;ka(1241,c|0,b|0,l+92|0,l+91|0,l+90|0,u|0,q|0,n|0,o|0,l+24|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;w=x[l+24>>2];B=y[l+95|0];C=y[l+91|0];D=y[l+90|0];d=m;e=0;while(1){c:{d:{e:{f:{if((e|0)==4){break f}x[31725]=0;b=P(1207,a|0,l+524|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(b){break f}b=0;g:{h:{i:{j:{k:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(Kf(x[h+8>>2],1,b)){x[31725]=0;O(1242,l+16|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;O(117,s|0,v[l+16|0]);b=x[31725];x[31725]=0;if((b|0)!=1){break j}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break c}}while(1){x[31725]=0;b=P(1207,a|0,l+524|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(!Kf(x[h+8>>2],1,b)){break c}x[31725]=0;O(1242,l+16|0,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;O(117,s|0,v[l+16|0]);b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Cb(x[n+4>>2],y[n+11|0])){break l}b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(y[cc(n,0)|0]!=(b&255)){break l}x[31725]=0;R(1210,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}v[g|0]=0;r=Cb(x[n+4>>2],y[n+11|0])>>>0>1?n:r;break c}m:{n:{k=x[o+4>>2];b=y[o+11|0];if(Cb(k,b)){b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if(y[cc(o,0)|0]==(b&255)){break n}k=x[o+4>>2];b=y[o+11|0]}c=Cb(x[n+4>>2],y[n+11|0]);if(!c){break m}if(!Cb(k,b)){break m}x[f>>2]=x[f>>2]|4;a=0;break d}x[31725]=0;R(1210,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}v[g|0]=1;r=Cb(x[o+4>>2],y[o+11|0])>>>0>1?o:r;break c}b=Cb(k,b);if(!(b|c)){break c}v[g|0]=!b;break c}if(!(e>>>0<2|r|((e|0)==2&(B|0)!=0|A))){r=0;break c}c=vb(l+16|0,zd(q));o:{if(!e|y[(e+l|0)+91|0]>1){break o}while(1){p:{b=Df(q);k=x[c>>2];if(!Ib(k,b)){break p}if(!Kf(x[h+8>>2],1,v[k|0])){break p}me(c);continue}break}b=zd(q);b=Hk(x[c>>2],b);if(Cb(x[s+4>>2],y[s+11|0])>>>0>=b>>>0){k=YC(Df(s),b);E=Df(s);z=zd(q);b=fb-16|0;fb=b;x[b+8>>2]=z;x[b+12>>2]=k;while(1){q:{z=Ib(k,E);if(!z){break q}if(!F0(y[k|0],y[x[b+8>>2]])){break q}k=me(b+12|0);me(b+8|0);k=x[k>>2];continue}break}fb=b+16|0;if(z^1){break o}}F=c,G=x[vb(l+12|0,zd(q))>>2],x[F>>2]=G}x[l+12>>2]=x[c>>2];r:{while(1){b=Df(q);if(!Ib(x[l+12>>2],b)){break r}x[31725]=0;b=P(1207,a|0,l+524|0)|0;c=x[31725];x[31725]=0;s:{if((c|0)==1){break s}if(b){break r}b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break s}if(y[x[l+12>>2]]!=(b&255)){break r}x[31725]=0;R(1210,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}me(l+12|0);continue}break}break a}if(!A){break c}b=Df(q);if(!Ib(x[l+12>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}t:{while(1){u:{x[31725]=0;c=P(1207,a|0,l+524|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break u}if(c){break t}c=x[a>>2];x[31725]=0;k=R(1208,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}v:{if(Kf(x[h+8>>2],64,k)){c=x[j>>2];if((c|0)==x[l+520>>2]){x[31725]=0;S(1243,i|0,j|0,l+520|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}c=x[j>>2]}x[j>>2]=c+1;v[c|0]=k;b=b+1|0;break v}if(!Cb(x[u+4>>2],y[u+11|0])|!b|(k&255)!=(D|0)){break t}if(x[l+96>>2]==(d|0)){x[31725]=0;S(1244,t|0,l+100|0,l+96|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}d=x[l+100>>2]}m=d+4|0;x[l+100>>2]=m;x[d>>2]=b;d=m;b=0}x[31725]=0;R(1210,a|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}}break}break a}if(!(!b|x[t>>2]==(m|0))){if(x[l+96>>2]==(m|0)){x[31725]=0;S(1244,t|0,l+100|0,l+96|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c}if((w|0)<=0){break e}x[31725]=0;b=P(1207,a|0,l+524|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}w:{if(!b){b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}if((b&255)==(C|0)){break w}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31725]=0;b=R(1210,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break e}x[31725]=0;c=P(1207,b|0,l+524|0)|0;d=x[31725];x[31725]=0;x:{if((d|0)==1){break x}y:{if(!c){c=x[b>>2];x[31725]=0;c=R(1208,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break x}if(Kf(x[h+8>>2],64,c)){break y}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[31725]=0;S(1243,i|0,j|0,l+520|0);c=x[31725];x[31725]=0;if((c|0)==1){break x}}c=x[b>>2];x[31725]=0;c=R(1208,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break x}d=x[j>>2];x[j>>2]=d+1;v[d|0]=c;x[31725]=0;R(1210,b|0)|0;c=x[31725];x[31725]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}x[l+24>>2]=w;z:{if(!r){break z}k=1;while(1){if(Cb(x[r+4>>2],y[r+11|0])>>>0<=k>>>0){break z}x[31725]=0;b=P(1207,a|0,l+524|0)|0;c=x[31725];x[31725]=0;A:{if((c|0)==1){break A}B:{if(!b){b=x[a>>2];x[31725]=0;b=R(1208,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break A}if(y[cc(r,k)|0]==(b&255)){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31725]=0;R(1210,a|0)|0;b=x[31725];x[31725]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+16>>2]=0;Xf(u,b,m,l+16|0);if(x[l+16>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}d=m;if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}tb(s);tb(o);tb(n);tb(q);tb(u);Lc(t);break b}e=e+1|0;continue}}break a}fb=l+528|0;return a|0}a=N()|0;tb(s);tb(o);tb(n);tb(q);tb(u);Lc(t);Q(a|0);p()}function Fpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-272|0;fb=d;xc(b);e=fb-16|0;fb=e;f=d+126|0;sX(e+8|0,f);g=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){rX(f)}a:{b:{c:{d:{if(!e){break d}if(!tX(d+126|0)){break d}if(!c){i=1;break d}Bd(a,4194304);e=d+40|0;g=tc(e,17048);Ab(a+1298344|0,g);tb(g);g=tc(e,10137);Ab(a+1298356|0,g);tb(g);n=a+1298404|0,o=x[Fc(e,4)>>2],x[n>>2]=o;n=a,o=Kd(y[d+204|0]|y[d+205|0]<<8,y[d+206|0]|y[d+207|0]<<8,127),w[n+480188>>1]=o;g=y[d+195|0];x[a+480228>>2]=(g|0)==255?48:g;x[a+480196>>2]=y[d+193|0];x[a+480204>>2]=D(y[d+194|0],1e4);g=d+104|0;df(g,d+130|0,59,3);Cc(e,g);Ab(a+1298308|0,e);tb(e);e=y[d+208|0]|y[d+209|0]<<8|(y[d+210|0]<<16|y[d+211|0]<<24);e:{if(e>>>0<5){break e}if(!cd(b,e-4|0)){break e}if(!kk(b,14233)){break e}jk(Xb(x[a+484360>>2],y[a+484376|0]),b,y[d+198|0]|y[d+199|0]<<8,65535,65535)}f:{e=y[d+212|0]|y[d+213|0]<<8|(y[d+214|0]<<16|y[d+215|0]<<24);if(e>>>0<5){break f}if(!cd(b,e-4|0)){break f}if(!kk(b,13843)){break f}e=0;while(1){if((e|0)==32){break f}g=(e<<5)+a|0;Xe(g+480280|0);n=g+480284|0,o=((((Zd(b)^-1)&15)<<8|8)>>>0)/15|0,w[n>>1]=o;e=e+1|0;continue}}e=y[d+220|0]|y[d+221|0]<<8|(y[d+222|0]<<16|y[d+223|0]<<24);g:{if(e>>>0<5){break g}if(!cd(b,e-4|0)){break g}if(!kk(b,14128)){break g}e=d+40|0;fe(e,b,(y[d+202|0]|y[d+203|0]<<8)<<6);k=c&2;h=a+480190|0;g=ic(d+104|0,e);ub(e);j=d+53|0;e=0;h:{while(1){if((e&65535)>>>0>=(y[d+202|0]|y[d+203|0]<<8)>>>0){break h}x[31725]=0;f=P(691,g|0,d+40|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}if(!f){break h}f=y[d+85|0]|y[d+86|0]<<8;w[d+38>>1]=f;i:{j:{if((f-1&65535)>>>0>3998){break j}f=D(f,104)+a|0;i=f+484380|0;if(je(x[i>>2],x[f+484400>>2])){break j}n=h,o=z[qe(h,d+38|0)>>1],w[n>>1]=o;x[31725]=0;O(692,d+40|0,i|0);f=x[31725];x[31725]=0;if((f|0)==1){break i}f=d+12|0;t_(f,1,j);x[31725]=0;O(220,d+24|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break b}f=d+24|0;zc(((z[d+38>>1]<<5)+a|0)+946304|0,f);tb(f);if(!k){break j}x[31725]=0;P(151,b|0,y[d+77|0]|y[d+78|0]<<8|(y[d+79|0]<<16|y[d+80|0]<<24))|0;f=x[31725];x[31725]=0;if((f|0)==1){break i}i=1;l=d+24|0;f=y[d+87|0];m=Xc(l,f&4?16:8,1,0,0);k:{l:{if(f&8){break l}i=2;if(f&16){break l}if(f&127){break k}}yg(m,i)}x[31725]=0;U(217,l|0,(D(z[d+38>>1],104)+a|0)+484380|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){break j}break b}e=e+1|0;continue}break}break b}ub(g)}i=1;if(!(c&1)){break d}m:{c=y[d+216|0]|y[d+217|0]<<8|(y[d+218|0]<<16|y[d+219|0]<<24);if(c>>>0<5){break m}if(!cd(b,c-4|0)){break m}if(!kk(b,13714)){break m}k=a+484344|0;Vf(k,y[d+200|0]|y[d+201|0]<<8);f=0;while(1){if((y[d+200|0]|y[d+201|0]<<8)>>>0<=f>>>0){break m}if(!Ur(b,d+24|0)){break m}n:{e=z[d+24>>1];if(e>>>0>3){c=d+104|0;fe(c,b,(e+15&131056)-4|0);g=ic(d+40|0,c);ub(c);x[31725]=0;c=U(198,k|0,f&65535,y[d+26|0])|0;e=x[31725];x[31725]=0;if((e|0)==1){break n}h=0;o:{if(!c){break o}while(1){p:{c=x[g>>2];x[31725]=0;e=U(152,c|0,x[d+48>>2],1)|0;c=x[31725];x[31725]=0;q:{if((c|0)!=1){c=y[d+26|0];if(!(e&c>>>0>(h&255)>>>0)){break p}x[31725]=0;c=R(199,g|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}e=c<<24>>24;if(e){break q}h=h+1|0;continue}break c}c=x[a+484344>>2];w[d+104>>1]=e&31;w[d+12>>1]=z[a+480188>>1]-1;c=Wb(c,f);c=jd(x[c>>2],x[x[c+48>>2]+12>>2],h,z[Nc(d+104|0,d+12|0)>>1]);if((e|0)<0){x[31725]=0;O(200,d+104|0,g|0);j=x[31725];x[31725]=0;if((j|0)==1){break c}v[c|0]=y[d+104|0]+36;n=c,o=y[Jc(d+104|0)|0],v[n+1|0]=o}e=e&255;if(e&64){v[c+2|0]=1;x[31725]=0;j=R(199,g|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break c}v[d+104|0]=j;v[d+12|0]=64;n=c,o=y[Rb(d+104|0,d+12|0)|0],v[n+4|0]=o}if(!(e&32)){continue}x[31725]=0;O(200,d+104|0,g|0);e=x[31725];x[31725]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((e|0)!=1){e=y[Jc(d+104|0)|0];v[c+5|0]=e;switch(y[d+104|0]-1|0){case 71:break s;case 70:break t;case 69:break u;case 60:break v;case 59:break w;case 52:break x;case 51:break y;case 50:break z;case 49:break A;case 42:break B;case 41:break C;case 40:break D;case 39:break E;case 30:break F;case 29:break G;case 22:break H;case 21:break I;case 20:break J;case 19:break K;case 16:break L;case 15:break M;case 14:break N;case 13:break O;case 12:break P;case 11:break Q;case 10:break R;case 9:break S;case 3:break T;case 2:break U;case 1:break V;case 0:break W;default:break r}}break c}v[c+3|0]=11;v[c+5|0]=e<<4|15;continue}v[c+3|0]=11;v[c+5|0]=e<<4;continue}v[c+3|0]=11;v[c+5|0]=e|240;continue}v[c+3|0]=11;v[c+5|0]=e&15;continue}v[c+3|0]=2;v[c+5|0]=e|240;continue}v[c+3|0]=2;continue}v[c+3|0]=3;v[c+5|0]=e|240;continue}v[c+3|0]=3;continue}v[c+3|0]=4;continue}v[c+3|0]=20;v[c+5|0]=e|16;continue}v[c+3|0]=6;v[c+5|0]=e<<4;continue}v[c+3|0]=6;v[c+5|0]=e&15;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=e|48;continue}v[c+3|0]=7;v[c+5|0]=e<<4;continue}v[c+3|0]=7;v[c+5|0]=e&15;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=e|64;continue}v[c+3|0]=10;x[31725]=0;e=R(199,g|0)|0;j=x[31725];x[31725]=0;if((j|0)!=1){v[c+5|0]=e;x[31725]=0;P(185,g|0,1)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}}break c}v[c+3|0]=15;v[c+5|0]=e&15;continue}v[c+3|0]=20;v[c+5|0]=e|192;continue}v[c+3|0]=20;v[c+5|0]=e|208;continue}v[c+3|0]=12;continue}v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=e|176;continue}v[c+3|0]=20;v[c+5|0]=e|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=e&15|32;continue}v[c+3|0]=20;v[c+5|0]=e&15|128;continue}v[c+3|0]=0;continue}break}if((c|0)==64){break o}ye(Wb(x[k>>2],f),Zh(Ye(Ne(d+104|0,14,0),c-1|0)))}ub(g)}f=f+1|0;continue}break}break c}c=y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24);if(!c){break d}cd(b,c);_D(a+1298332|0,b,ih(b),4)}fb=d+272|0;return i|0}a=N()|0;break a}a=N()|0}ub(g);Q(a|0);p()}function Pka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=fb-48|0;fb=i;d=x[b>>2];x[31725]=0;e=R(174,d|0)|0;d=x[31725];x[31725]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(e){j=Nb(i+36|0);x[31725]=0;h=(c|0)!=0;f=U(866,j|0,b|0,h|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}e=2;g:{h:{i:{j:{if(f){break j}x[31725]=0;f=U(867,j|0,b|0,h|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}e=3;if(f){break j}x[31725]=0;f=U(868,j|0,b|0,h|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}e=4;if(f){break j}f=0;x[31725]=0;h=U(869,j|0,b|0,h|0)|0;d=x[31725];x[31725]=0;e=1;if((d|0)==1){break e}if(!h){break i}}if(!c){e=1;d=0;break h}d=x[j>>2];if(!lc(d,x[j+4>>2])){Xw(b,d+12|0)}f=e}d=29920;k:{while(1){e=d;if((d|0)!=30496){h=x[e+8>>2];g=(h>>1)+a|0;d=x[e+4>>2];d=h&1?x[x[g>>2]+d>>2]:d;x[31725]=0;h=U(d|0,g|0,b|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}d=e+12|0;if(!h){continue}break k}break}x[a+480180>>2]=0;x[a+480184>>2]=0}if(!c){e=(e|0)!=30496;d=0;break h}if(!(x[a+480184>>2]|!f)){x[a+480184>>2]=f}x[31725]=0;d=1;O(805,a+1298264|0,1);f=x[31725];x[31725]=0;e=1;if((f|0)==1){break g}}qS(j);if(d){break f}break a}break c}x[31725]=0;O(248,a|0,0);d=x[31725];x[31725]=0;if((d|0)==1){break d}x[31725]=0;O(805,a+1298264|0,1);d=x[31725];x[31725]=0;if((d|0)==1){break d}x[a+1074304>>2]=19989250;x[a+1298408>>2]=0}e=0;while(1){if((e|0)==127){d=1;while(1){e=d&65535;if(e>>>0>z[a+480190>>1]){d=0;e=0;l:{while(1){f=e&65535;if(f>>>0>z[a+480192>>1]){m:{w[a+480192>>1]=d;d=a+480204|0;if(A[a+480204>>2]>=1e4){break m}x[d>>2]=125e4;break l}}else{g=x[((f<<2)+a|0)+900380>>2];if(g){f=x[a+480180>>2];wc(g,65536);wc(g+4|0,64);wc(g+8|0,256);Gf(g+28|0,16384);Qf(g+30|0,128);Qf(g+31|0,17);if(y[g+16|0]>=4){v[g+16|0]=0}if(y[g+17|0]>=5){v[g+17|0]=0}if(y[g+18|0]>=3){v[g+18|0]=0}Qf(g+19|0,64);Qf(g+20|0,100);h=224;d=v[g+26|0];n:{if((d|0)>=-32){h=32;if((d|0)<33){break n}}v[g+26|0]=h}Qf(g+23|0,64);Qf(g+24|0,64);dC(g+48|0,64);dC(g+68|0,64);dC(g+88|0,(f|0)==4096?255:64);d=g+108|0;f=0;while(1){if((f|0)==128){if(!Bp(y[g+14|0])){v[g+14|0]=5}if(y[g+34|0]>=251){v[g+34|0]=0}}else{o:{if(y[xb(d,f)|0]){if(y[xb(d,f)|0]<121){break o}}l=xb(d,f),m=f+1|0,v[l|0]=m}f=f+1|0;continue}break}d=e}e=e+1|0;continue}break}wc(d,65535e4)}if(!x[a+480196>>2]){x[a+480196>>2]=6}f=a+480216|0;e=a+480220|0;d=x[a+480216>>2];if(!(d|y[a+480224|0]!=2)){x[f>>2]=1;d=1}if(A[a+480220>>2]<d>>>0){x[e>>2]=d}wc(f,65536);wc(e,65536);wc(a+480200|0,256);p:{if(!lc(x[a+480248>>2],x[a+480252>>2])){d=x[f>>2];x[31725]=0;O(870,a+480248|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break p}}x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];d=x[a+480220>>2];e=a+1074408|0;x[e>>2]=x[a+480216>>2];x[e+4>>2]=d;x[a+1074456>>2]=x[a+480200>>2];sB(a+1074376|0);d=a+1074446|0;w[d>>1]=0;w[d+2>>1]=0;w[d+4>>1]=0;w[d+6>>1]=65535;x[a+1074392>>2]=-2;d=a+1074384|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074380>>2]=0;d=a+1074424|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074432>>2]=0;d=a+1074396|0;x[d>>2]=0;x[d+4>>2]=0;if(En(x[a+480180>>2])){x[31725]=0;P(269,a+1074312|0,7)|0;d=x[31725];x[31725]=0;if((d|0)==1){break p}}w[a+480276>>1]=0;Iq(a);l=i,m=wb(x[a+484360>>2]),x[l+36>>2]=m;e=wb(x[a+484364>>2]);q:{while(1){r:{f=x[i+36>>2];if(!Ib(f,e)){if(x[a+480180>>2]){break r}e=0;break a}x[31725]=0;W(871,f|0);d=x[31725];x[31725]=0;if((d|0)==1){break q}if(Zc(x[f>>2],x[f+4>>2])>>>0<=z[f+28>>1]){bf(f,0)}er(i+36|0);continue}break}Bu(a+8|0,zr(a));if(x[a+1074308>>2]){x[31725]=0;W(872,a|0);d=x[31725];x[31725]=0;if((d|0)==1){break p}}j=Nb(i+36|0);s:{t:{if((c&12)!=12){break t}f=a+906300|0;e=0;u:{v:{w:{x:{y:{z:{while(1){if((e|0)==250){break t}A:{k=vd(f,e);B:{if(!Ui(x[k+16>>2],x[k+20>>2])){break B}x[31725]=0;O(873,k|0,a|0);c=x[31725];x[31725]=0;C:{if((c|0)!=1){h=x[k>>2];if(!h){break C}d=x[k+148>>2];c=x[x[h>>2]+56>>2];x[31725]=0;O(c|0,h|0,d|0);c=x[31725];x[31725]=0;if((c|0)!=1){break B}}a=N()|0;break s}g=wb(x[j>>2]);c=wb(x[j+4>>2]);h=fb-16|0;fb=h;x[h+12>>2]=g;while(1){D:{if(!Ib(g,c)){break D}d=x[g>>2];if((y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))==(y[k+20|0]|y[k+21|0]<<8|(y[k+22|0]<<16|y[k+23|0]<<24))){d=(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))==(y[k+16|0]|y[k+17|0]<<8|(y[k+18|0]<<16|y[k+19|0]<<24))}else{d=0}if(d){break D}g=x[Je(h+12|0)>>2];continue}break}fb=h+16|0;if(Ib(g,wb(x[j+4>>2]))){break B}x[31725]=0;x[i+24>>2]=k+16;O(874,j|0,i+24|0);c=x[31725];x[31725]=0;if((c|0)==1){break A}x[31725]=0;d=P(1,i+12|0,18314)|0;c=x[31725];x[31725]=0;if((c|0)==1){break z}x[31725]=0;O(875,i|0,k|0);c=x[31725];x[31725]=0;if((c|0)==1){break y}x[31725]=0;S(2,i+24|0,d|0,i|0);c=x[31725];x[31725]=0;if((c|0)==1){break x}c=x[a+1298472>>2];x[31725]=0;S(387,c|0,2,i+24|0);c=x[31725];x[31725]=0;if((c|0)==1){break w}tb(i+24|0);tb(i);tb(d)}e=e+1|0;continue}break}a=N()|0;break s}a=N()|0;break s}a=N()|0;break u}a=N()|0;break v}a=N()|0;tb(i+24|0)}tb(i)}tb(d);break s}c=y[a+1074368|0];x[31725]=0;O(876,a|0,c|0);a=x[31725];x[31725]=0;e=1;if((a|0)!=1){uc(j);break a}a=N()|0}uc(j);break b}a=N()|0;break b}a=N()|0;break b}h=D(e,104)+a|0;g=h+484380|0;E:{if(je(x[g>>2],x[h+484400>>2])){Sj(g,a);break E}f=h+484414|0;e=z[f>>1];if(e&16384){break E}x[g>>2]=0;x[g+4>>2]=0;x[g+16>>2]=0;x[g+8>>2]=0;x[g+12>>2]=0;w[f>>1]=e&65505}e=h+484412|0;if(z[e>>1]>=65){w[e>>1]=64}F:{G:{if(!(y[h+484415|0]&2)){break G}if(!Pj(x[a+1298300>>2])){break G}x[31725]=0;W(877,a|0);e=x[31725];x[31725]=0;if((e|0)==1){break F}}d=d+1|0;continue}break}a=N()|0;break b}f=(e<<5)+a|0;Gf(f+480286|0,64);d=f+480284|0;if(z[d>>1]>=257){w[d>>1]=128}d=f+480288|0;if(y[d|0]>=251){v[d|0]=0}Wo((D(e,872)+a|0)+1074992|0,a,e&65535,134217728);e=e+1|0;continue}}break c}a=N()|0;break b}a=N()|0;qS(j)}ub(b);Q(a|0);p()}ub(b);fb=i+48|0;return e|0}function Su(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;n=fb-16|0;fb=n;x[n+12>>2]=c;a:{if((c|0)<=0){break a}i=x[b+104>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{j=x[b+656>>2];k:{if(!(!j|x[a+480180>>2]!=16777216)){l=x[j+44>>2]!=0;break k}if(!j){break j}}if((c|0)>128){break i}m=c-1|0;h=z[_b(j+236|0,m)>>1];l:{if((h-1&65535)>>>0<=3998){i=(D(h,104)+a|0)+484380|0;break l}if(!Ob(a+1074312|0,43)){break l}if(!Lj(x[b+656>>2])){break a}}m=y[xb(j+108|0,m)|0];x[n+12>>2]=m;if(m>>>0<=120){break h}c=m;break i}m=c;h=0;if(c>>>0<121){break g}}m:{if(!(x[a+480180>>2]&16777248?(c|0)!=255:0)){Lo(a,b);if(d){break m}if(!Ob(a+1074312|0,100)|!(y[a+480208|0]&4)|!y[b+789|0]){break m}x[b+88>>2]=x[b+88>>2]&-6145;break m}if(!z[a+480192>>1]){break m}x[b+88>>2]=x[b+88>>2]|4096}n:{if((c|0)!=254){break n}c=x[b+88>>2];if(!(!(c&512)|x[a+480180>>2]!=2)){x[b+88>>2]=c|2048;break n}x[b+88>>2]=c|2101248;o:{if(x[a+480180>>2]&16777248){if(!z[a+480192>>1]){break o}if(Ob(a+1074312|0,50)){break o}}x[b+688>>2]=0}if(Ob(a+1074312|0,50)){x[b+8>>2]=0;x[b+12>>2]=0}x[b+696>>2]=0}if(!Ob(a+1074312|0,20)){break a}v[b+797|0]=0;v[b+802|0]=0;break a}h=0;if(!l){break g}if(d){h=y[b+797|0];if(h){break f}}x[b+708>>2]=0;h=1}if(d){break e}if(!(!(x[a+480180>>2]&1048588)|!i)){w[b+770>>1]=v[i+36|0];w[b+772>>1]=v[i+37|0];break d}if(i){break d}i=0;p=1;break c}h=D((x[x[j+44>>2]+36>>2]<<16>>16)+1|0,(m<<16>>16)-(h<<16>>16)|0)-x[b+852>>2]|0;x[b+708>>2]=h;x[b+852>>2]=0-h;h=1}p=!i;l=1;if(Ui(x[b+8>>2],x[b+12>>2])){break b}p:{l=a+1074312|0;if(!Ob(l,54)){break p}if(Lj(x[b+656>>2])){if(!Ob(l,117)){break p}}x[b+700>>2]=0;break a}l=(Ob(l,39)^-1)&d;break b}if(!Ob(a+1074312|0,24)){break c}x[b+704>>2]=x[i+24>>2]}l=0}q:{if(En(x[a+480180>>2])){x[n+12>>2]=w[b+770>>1]+m;Fe(n+12|0,12,131);break q}WX(n+12|0)}k=a+1074312|0;r:{if(Ob(k,34)){d=km(c);break r}d=x[n+12>>2]}v[b+797|0]=d;v[b+851|0]=y[b+851|0]&183|64;if(!(x[a+480180>>2]&16777250?0:l)){v[b+803|0]=0}o=yh(a,x[n+12>>2],w[b+772>>1],x[b+704>>2]);v[b+831|0]=0;if(Ob(k,48)){rT(a,b,j,i)}s:{if(!Ob(k,115)|!j){break s}d=y[j+26|0];if(!d){break s}if(!z[b+784>>1]){w[b+784>>1]=z[b+692>>1]+1}qT(b+692|0,c,d,y[j+27|0])}t:{if(l|e^1){break t}x[b+776>>2]=0;x[b+780>>2]=0;if(!j){break t}if(Ob(k,29)){v[b+798|0]=y[j+16|0]}if(!(y[j+60|0]&8)){Kj(b+724|0)}if(!(y[j+80|0]&8)){Kj(b+732|0)}if(!(y[j+100|0]&8)){Kj(b+740|0)}if(y[j+20|0]){c=((D(Pu(Ko(a)),y[j+20|0])<<16>>16)/64|0)+1<<16>>16;u:{if(Ob(k,28)){d=x[b+752>>2];break u}d=(x[b+688>>2]+1|0)/2|0}w[b+776>>1]=(D(d,c)|0)/199}v:{if(!y[j+19|0]){break v}r=b,s=(D(Pu(Ko(a)),y[j+19|0])<<16>>16)/32|0,w[r+778>>1]=s;if(Ob(k,28)|z[b+784>>1]){break v}w[b+784>>1]=z[b+692>>1]+1}m=y[j+23|0];if(m){d=Pu(Ko(a));c=y[b+837|0];v[b+796|0]=c+1;w[b+780>>1]=(D((D(m,d+1|0)<<16>>16)/128<<16>>16,c)+1|0)/128}m=y[j+24|0];if(!m){break t}d=Pu(Ko(a));c=y[b+838|0];v[b+795|0]=c+1;w[b+782>>1]=(D(c,(D(m,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(p){break a}w:{x:{if(!o){d=0;break x}if(!(l&x[b+700>>2]!=0)){x[b+700>>2]=o}y:{z:{if(!h){if(!l){if(Ob(k,69)){break z}if(Ob(k,46)|x[a+480180>>2]==1){break z}}x[b+708>>2]=o;v[b+851|0]=y[b+851|0]&239}if(!l){break z}if(x[b+76>>2]|y[a+480180|0]&2){break y}}x[b+104>>2]=i;c=x[i>>2];x[b+84>>2]=c;x[b+76>>2]=c;x[b+80>>2]=0;x[b>>2]=0;x[b+4>>2]=0;A:{B:{C:{if(!(y[a+480210|0]&32)){if(!Ob(k,96)|y[b+789|0]){break B}q=x[b>>2];c=x[b+76>>2];break C}if(y[b+789|0]){break B}}x[n+8>>2]=c-1;c=x[Gb(b+660|0,n+8|0)>>2];x[b>>2]=q;x[b+4>>2]=c;break A}x[b+660>>2]=0}c=z[i+34>>1];h=c&1023;d=h|x[b+88>>2]&-525056;x[b+88>>2]=d;D:{E:{if(c&8){x[b+80>>2]=x[i+12>>2];c=x[i+16>>2];x[b+88>>2]=(h&16?d|4:d&-524295)|2;x[b+84>>2]=c;if(A[b+76>>2]>c>>>0){break E}break D}if(!(h&2)){break D}x[b+80>>2]=x[i+4>>2];c=x[i+8>>2];x[b+84>>2]=c;if(A[b+76>>2]<=c>>>0){break D}}x[b+76>>2]=c}F:{if(!(r=0,s=Ob(k,83),t=x[b+80>>2],t?r:s)){c=x[b+76>>2];break F}c=x[i>>2];x[b+84>>2]=c;x[b+76>>2]=c}d=x[b+88>>2];if(!(!(d&128)|!c)){x[b+4>>2]=c-1;x[b+88>>2]=d|128}G:{if(y[b+822|0]>3){break G}c=Ob(k,21);h=x[a+480180>>2];H:{I:{if(!(c|!(h&16777248))){d=16;if(y[a+480208|0]&4){break I}break H}d=32;if((h|0)==16){break H}}if(h&67633152){break G}d=0}v[b+819|0]=d}if(Ob(k,21)|y[b+825|0]>3){break y}v[b+820|0]=0}d=x[b>>2];if(A[b+76>>2]<=A[b+4>>2]){c=x[b+80>>2];x[b>>2]=d;x[b+4>>2]=c}d=0;if(!l){break x}d=1;if(!(x[a+480180>>2]&17301536)|(x[b+696>>2]?0:y[b+89|0]&16)){break x}c=1;if(!(y[a+480208|0]&8)){break w}c=1;if(!y[b+789|0]){break w}}if(!(x[b+696>>2]|(!(x[a+480180>>2]&17301536)|!(y[b+89|0]&16)))){en(b);if(!Ob(k,21)){v[b+818|0]=0;x[b+756>>2]=0}x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}J:{if(!d){i=y[b+789|0];break J}i=y[b+789|0];if(!(y[a+480208|0]&8)){break J}c=1;if(!(i&255)){break w}}if(!(i&255?0:x[a+480180>>2]&1048580)){x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}c=d}d=c;K:{if(!(!d|!Ob(k,40)|(y[b+789|0]?y[a+480208|0]&8:0))){c=x[b+88>>2]&-4194305;break K}c=x[b+88>>2]&-4196353}x[b+88>>2]=c;L:{if(d){break L}w[b+842>>1]=65535;v[b+851|0]=y[b+851|0]|2;x[b+88>>2]=c&-6324225|2097152;M:{if(Ob(k,23)){break M}if(Ob(k,22)){break M}if(Ob(k,52)){break M}if(Ob(k,71)){break M}v[b+839|0]=0;v[b+808|0]=0}if(e){v[b+818|0]=0;x[b+756>>2]=0}x[b+20>>2]=0;x[b+24>>2]=0;if(!(y[b+89|0]&2)){break L}if(!Dd(x[a+1298300>>2])|(g|0)==65535){break L}if(Ob(k,111)){Gk(x[a+1298300>>2],g);break L}if(!Ob(k,110)){break L}SB(x[a+1298300>>2],g,0,1,0)}c=x[b+88>>2];N:{O:{P:{if(f){x[b+88>>2]=c&-1025;break P}if(!(c&1024)){break P}if(y[a+24618|0]&16){break O}}a=x[b+104>>2];if(!(!a|!(y[a+35|0]&4)|f)){break O}a=x[b+656>>2];if(!a|(!(y[a+15|0]&2)|f)){break N}}x[b+700>>2]=0}if(d){break a}w[b+136>>1]=0;x[b+132>>2]=4194304;x[b+112>>2]=0;x[b+116>>2]=0}fb=n+16|0}function P5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a=xd(a,c);x[a>>2]=111976;f=DJ(a+8|0);x[31725]=0;e=P(72,a+152|0,b|0)|0;b=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((b|0)!=1){x[31725]=0;b=ca(106)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=x[b>>2];c=0;x[31725]=0;b=P(1307,f|0,b+8|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}while(1){f:{d=x[b>>2];if(oc(d,x[a+12>>2])>>>0<=c>>>0){x[31725]=0;c=R(856,12)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break f}break e}d=x[yb(d,c)>>2];if(d){hl(d)}c=c+1|0;continue}break}x[31725]=0;b=U(1308,c|0,e|0,0)|0;d=x[31725];x[31725]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((d|0)!=1){x[31725]=0;O(1309,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,12)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=U(1310,c|0,e|0,0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break t}x[31725]=0;O(1311,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,20)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=U(1312,c|0,e|0,0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break s}x[31725]=0;O(1313,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,12)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=U(1314,c|0,e|0,0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break r}x[31725]=0;O(1315,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=xd(b,0);x[b>>2]=113924;x[b>>2]=119536;x[31725]=0;O(1316,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,12)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1317,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break q}x[31725]=0;O(1318,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=xd(b,0);x[b>>2]=114072;x[b>>2]=119744;x[31725]=0;O(1319,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=xd(b,0);x[b>>2]=114304;x[b>>2]=119848;x[31725]=0;O(1320,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=xd(b,0);x[b>>2]=114188;x[b>>2]=119952;x[31725]=0;O(1321,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=xd(b,0);x[b>>2]=114420;x[b>>2]=120056;x[31725]=0;O(1322,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,24)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=U(1323,c|0,e|0,0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break p}x[31725]=0;O(1324,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,28)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=U(1325,c|0,e|0,0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break o}x[31725]=0;O(1326,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,72)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1327,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break n}x[31725]=0;O(1328,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,72)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1329,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break m}x[31725]=0;O(1330,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,76)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1331,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break l}x[31725]=0;O(1332,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,76)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1333,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break k}x[31725]=0;O(1334,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,544)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1335,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break j}x[31725]=0;O(1336,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,544)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1337,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break i}x[31725]=0;O(1338,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,12)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1339,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break h}x[31725]=0;O(1340,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;c=R(856,12)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=P(1341,c|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}x[31725]=0;O(1342,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=mJ(b,0);x[b>>2]=119384;x[31725]=0;O(1343,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;b=R(856,8)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}b=lJ(b,0);x[b>>2]=119460;x[31725]=0;O(1344,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}return a|0}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}a=N()|0;break c}b=T(0)|0}Y(b|0)|0;c=0;while(1){b=x[f>>2];if(oc(b,x[a+12>>2])>>>0<=c>>>0){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}tb(e);break c}b=x[yb(b,c)>>2];if(b){Bm(b)}c=c+1|0;continue}}dy(f);Q(a|0);p()}T(0)|0;Sb()}p()}function gaa(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,E=0;n=fb-560|0;fb=n;x[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){u=1;C=5296;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){u=1;C=5299;break a}u=e&1;C=u?5302:5297;E=!u}b:{if((g&2146435072)==2146435072){g=u+3|0;Yf(a,32,c,g,e&-65537);Lf(a,C,u);d=f&32;Lf(a,b!=b?d?9978:13848:d?11132:14166,3);Yf(a,32,c,g,e^8192);p=(c|0)<(g|0)?g:c;break b}z=n+16|0;c:{d:{e:{b=HL(b,n+44|0);b=b+b;if(b!=0){g=x[n+44>>2];x[n+44>>2]=g-1;A=f|32;if((A|0)!=97){break e}break c}A=f|32;if((A|0)==97){break c}l=x[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;x[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}s=(n+48|0)+((l|0)>=0?288:0)|0;h=s;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}x[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;i=s;break f}i=s;d=l;while(1){q=(d|0)>=29?29:d;g=h-4|0;g:{if(i>>>0>g>>>0){break g}d=0;while(1){k=x[g>>2];B=d;d=q&31;if((q&63)>>>0>=32){p=k<<d;d=0}else{p=(1<<d)-1&k>>>32-d;d=k<<d}B=B+d|0;k=p+r|0;d=qva(B,d>>>0>B>>>0?k+1|0:k,1e9,0);k=ova(d,hb,-1e9,0)+B|0;x[g>>2]=k;g=g-4|0;if(i>>>0<=g>>>0){continue}break}if(!d){break g}i=i-4|0;x[i>>2]=d}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!x[h>>2]){continue}}break}d=x[n+44>>2]-q|0;x[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){w=((m+25>>>0)/9|0)+1|0;r=(A|0)==102;while(1){d=0-d|0;p=(d|0)>=9?9:d;h:{if(g>>>0<=i>>>0){h=x[i>>2];break h}q=1e9>>>p|0;k=-1<<p^-1;d=0;h=i;while(1){B=d;d=x[h>>2];x[h>>2]=B+(d>>>p|0);d=D(q,d&k);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=x[i>>2];if(!d){break h}x[g>>2]=d;g=g+4|0}d=p+x[n+44>>2]|0;x[n+44>>2]=d;i=(!h<<2)+i|0;h=r?s:i;g=g-h>>2>(w|0)?h+(w<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=i>>>0){break i}d=D(s-i>>2,9);h=10;k=x[i>>2];if(k>>>0<10){break i}while(1){d=d+1|0;h=D(h,10);if(k>>>0>=h>>>0){continue}break}}h=(m-((A|0)!=102?d:0)|0)-((A|0)==103&(m|0)!=0)|0;if((h|0)<(D(g-s>>2,9)-9|0)){q=h+9216|0;k=(q|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(k<<2)|0)-4048|0;h=10;p=q+D(k,-9)|0;if((p|0)<=7){while(1){h=D(h,10);p=p+1|0;if((p|0)!=8){continue}break}}q=x[l>>2];w=(q>>>0)/(h>>>0)|0;r=D(w,h);k=l+4|0;j:{if((q|0)==(r|0)&(k|0)==(g|0)){break j}q=q-r|0;k:{if(!(w&1)){b=9007199254740992;if(!(v[l-4|0]&1)|((h|0)!=1e9|i>>>0>=l>>>0)){break k}}b=9007199254740994}t=(g|0)==(k|0)?1:1.5;k=h>>>1|0;t=k>>>0>q>>>0?.5:(k|0)==(q|0)?t:1.5;if(!(y[C|0]!=45|E)){t=-t;b=-b}x[l>>2]=r;if(b+t==b){break j}d=h+r|0;x[l>>2]=d;if(d>>>0>=1e9){while(1){x[l>>2]=0;l=l-4|0;if(l>>>0<i>>>0){i=i-4|0;x[i>>2]=0}d=x[l>>2]+1|0;x[l>>2]=d;if(d>>>0>999999999){continue}break}}d=D(s-i>>2,9);h=10;k=x[i>>2];if(k>>>0<10){break j}while(1){d=d+1|0;h=D(h,10);if(k>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){k=g;q=g>>>0<=i>>>0;if(!q){g=k-4|0;if(!x[g>>2]){continue}}break}l:{if((A|0)!=103){l=e&8;break l}h=m?m:1;g=(h|0)>(d|0)&(d|0)>-5;m=(g?d^-1:-1)+h|0;f=(g?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(q){break m}l=x[k-4>>2];if(!l){break m}p=10;g=0;if((l>>>0)%10|0){break m}while(1){h=g;g=g+1|0;p=D(p,10);if(!((l>>>0)%(p>>>0)|0)){continue}break}g=h^-1}h=D(k-s>>2,9);if((f&-33)==70){l=0;g=(g+h|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+h|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}p=-1;q=l|m;if(((q?2147483645:2147483646)|0)<(m|0)){break b}r=(((q|0)!=0)+m|0)+1|0;h=f&-33;n:{if((h|0)==70){if((r^2147483647)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=qo((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;v[g|0]=48;if((z-g|0)<2){continue}break}}w=g-2|0;v[w|0]=f;v[g-1|0]=(d|0)<0?45:43;g=z-w|0;if((g|0)>(r^2147483647)){break b}}d=g+r|0;if((d|0)>(u^2147483647)){break b}r=d+u|0;Yf(a,32,c,r,e);Lf(a,C,u);Yf(a,48,c,r,e^65536);o:{p:{q:{if((h|0)==70){f=n+16|0;d=f|8;l=f|9;h=i>>>0>s>>>0?s:i;i=h;while(1){g=qo(x[i>>2],0,l);r:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}v[n+24|0]=48;g=d}Lf(a,g,l-g|0);i=i+4|0;if(s>>>0>=i>>>0){continue}break}if(q){Lf(a,16781,1)}if((m|0)<=0|i>>>0>=k>>>0){break q}while(1){g=qo(x[i>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}Lf(a,g,(m|0)>=9?9:m);g=m-9|0;i=i+4|0;if(k>>>0<=i>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}s=i>>>0<k>>>0?k:i+4|0;f=n+16|0;d=f|8;k=f|9;h=i;while(1){g=qo(x[h>>2],0,k);if((k|0)==(g|0)){v[n+24|0]=48;g=d}t:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}Lf(a,g,1);g=g+1|0;if(!(l|m)){break t}Lf(a,16781,1)}f=k-g|0;Lf(a,g,(f|0)<(m|0)?f:m);m=m-f|0;h=h+4|0;if(s>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}Yf(a,48,m+18|0,18,0);Lf(a,w,z-w|0);break o}g=m}Yf(a,48,g+9|0,9,0)}Yf(a,32,c,r,e^8192);p=(c|0)<(r|0)?r:c;break b}l=(f<<26>>31&9)+C|0;u:{if(d>>>0>11){break u}g=12-d|0;t=16;while(1){t=t*16;g=g-1|0;if(g){continue}break}if(y[l|0]==45){b=-(t+(-b-t));break u}b=b+t-t}s=u|2;i=f&32;h=x[n+44>>2];g=h>>31;g=qo((g^h)-g|0,0,z);if((z|0)==(g|0)){v[n+15|0]=48;g=n+15|0}m=g-2|0;v[m|0]=f+15;v[g-1|0]=(h|0)<0?45:43;g=e&8;h=n+16|0;while(1){f=h;if(F(b)<2147483648){k=~~b}else{k=-2147483648}v[h|0]=i|y[k+93488|0];b=(b-+(k|0))*16;h=f+1|0;if(!(!(g|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){v[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}p=-1;g=z-m|0;f=g+s|0;if((2147483645-f|0)<(d|0)){break b}k=f;f=n+16|0;i=h-f|0;d=d?(i-2|0)<(d|0)?d+2|0:i:i;h=k+d|0;Yf(a,32,c,h,e);Lf(a,l,s);Yf(a,48,c,h,e^65536);Lf(a,f,i);Yf(a,48,d-i|0,0,0);Lf(a,m,g);Yf(a,32,c,h,e^8192);p=(c|0)<(h|0)?h:c}fb=n+560|0;return p|0}function uta(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;v[j+127|0]=d;a:{if(!c|(e|0)<0&c>>>0>=176){break a}v[b+5|0]=d;v[j+8|0]=15;l=j+127|0;p=j+8|0;k=p;o=y[Rb(l,k)|0];v[j+8|0]=14;l=y[Rb(l,k)|0];x[j+8>>2]=d+31>>>5;x[j+120>>2]=14;r=j+120|0;n=x[ud(k,r)>>2];x[j+8>>2]=d+127>>>7;x[j+120>>2]=14;q=c&15;k=q<<8|d;p=ud(p,r);b:{switch((c>>>4|0)-2|0){case 0:v[b+2|0]=1;x[j+8>>2]=k>>>2;x[j+120>>2]=64;s=b,t=x[ud(j+8|0,j+120|0)>>2],v[s+4|0]=t;break a;case 1:v[b+2|0]=1;if(!k){v[b+4|0]=0;break a}s=j,t=ID(k)>>>2|0,x[s+8>>2]=t;x[j+120>>2]=64;s=b,t=x[ud(j+8|0,j+120|0)>>2],v[s+4|0]=t;break a;case 2:v[b+3|0]=9;v[b+5|0]=k>>>4;break a;case 3:v[b+3|0]=23;v[b+5|0]=k+1>>>5;break a;case 4:v[b+3|0]=23;if(k){a=bh(ID(k)>>>5|0)}else{a=0}v[b+5|0]=a;break a;case 5:v[b+5|0]=q;v[b+3|0]=15;break a;case 6:v[b+3|0]=15;if((e|0)>=0){if(y[b+2|0]){break a}v[b+2|0]=2;s=b,t=Gc(((q<<6|7)>>>0)/15|0,0),v[s+4|0]=t;break a}v[b+2|0]=1;v[b+5|0]=q;v[b+4|0]=d+3>>>2;break a;case 7:v[b+3|0]=10;c:{if((e|0)>5){break c}if(!k){v[b+5|0]=1;break a}c=xr(a,f,g);if(!c){break c}a=ui(a,c);c=z[a+34>>1];if(c&1){k=k>>>1|0;x[j+120>>2]=k}if(!(c&2)){break c}c=x[a>>2];if(c>>>0>=k<<8>>>0){break c}x[j+120>>2]=x[a+4>>2]+8>>>8;wc(j+120|0,c-1>>>8|0);k=x[j+120>>2]}v[b+5|0]=k;if(y[b+2|0]|k>>>0<256){break a}v[b+2|0]=15;x[j+116>>2]=k>>>8;Vv(j+8|0);x[j+112>>2]=9;s=b,t=x[Gb(j+116|0,j+112|0)>>2],v[s+4|0]=t;break a;default:break b}}k=x[p>>2];d:{switch(c-160|0){default:e:{switch(c-1|0){case 0:case 1:case 2:case 3:case 6:case 10:case 14:Bf(b,c,d);f:{switch(y[b+3|0]-16|0){case 1:x[h>>2]=D(y[b+5|0],1e4);break a;case 0:break f;default:break a}}a=y[b+5|0];if(!a){break a}x[i>>2]=a;break a;case 4:v[b+3|0]=4;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=8;break a;case 5:v[b+3|0]=5;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=11;break a;case 7:if(!Tc(y[b|0])|!d){break a}v[b+3|0]=35;v[b+5|0]=(d>>>1&120|128)-(d<<3&120);if(z[a+480192>>1]){break a}w[j+8>>1]=255;c=z[Nc(a+480190|0,j+8|0)>>1];w[a+480192>>1]=c;b=1;while(1){d=b&65535;if(d>>>0>(c&65535)>>>0){break a}c=BE(a,d,d);if(c){v[c+33|0]=2;d=(d<<5)+a|0;e=d+946304|0;f=x[e+4>>2];x[c+492>>2]=x[e>>2];x[c+496>>2]=f;e=d+946312|0;f=x[e+4>>2];x[c+500>>2]=x[e>>2];x[c+504>>2]=f;e=d+946320|0;f=x[e+4>>2];x[c+508>>2]=x[e>>2];x[c+512>>2]=f;d=d+946328|0;e=x[d+4>>2];x[c+516>>2]=x[d>>2];x[c+520>>2]=e;mk(c,127,1);lk(c,0,1)}b=b+1|0;c=z[a+480192>>1];continue};case 8:v[b+3|0]=19;v[b+5|0]=o|208;break a;case 9:v[b+3|0]=25;break a;case 11:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|64;break a;case 12:v[b+3|0]=14;break a;case 13:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|112;break a;case 15:v[b+3|0]=1;break a;case 16:case 17:v[b+3|0]=19;v[b+5|0]=l|c<<4;break a;case 18:v[b+3|0]=15;break a;case 19:v[b+3|0]=11;v[b+5|0]=l<<4;break a;case 20:v[b+5|0]=l;v[b+3|0]=11;break a;case 23:v[b+3|0]=6;v[b+5|0]=l<<4;break a;case 24:v[b+5|0]=l;v[b+3|0]=6;break a;case 27:v[b+3|0]=7;v[b+5|0]=l<<4;break a;case 28:break e;default:break a}}v[b+5|0]=l;v[b+3|0]=7;break a;case 0:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4;break a;case 1:if(!d){break a}v[b+5|0]=n;v[b+3|0]=24;break a;case 4:v[b+3|0]=11;v[b+5|0]=l<<4|15;break a;case 5:v[b+3|0]=11;v[b+5|0]=l|240;break a;case 6:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4|15;break a;case 7:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n|240;break a;case 8:if(!d){break a}v[b+3|0]=16;x[i>>2]=d;break a;case 9:if((e|0)>5){break a}a=x[h>>2];if(a>>>0<1e4){break a}v[b+3|0]=17;m=122925/(+(a>>>0)/1e4)+ +((d<<1)-256|0);s=b,t=gm(245850/(m+m)),v[s+5|0]=t;break a;case 10:v[b+3|0]=19;v[b+5|0]=o|224;break a;case 12:v[b+3|0]=28;v[b+5|0]=o|16;break a;case 13:v[b+3|0]=28;v[b+5|0]=o|32;break a;case 14:v[b+3|0]=29;v[b+5|0]=l<<3&240;break a;case 15:v[b+3|0]=29;v[b+5|0]=(l&254)>>>1;break a;case 16:v[b+3|0]=18;break a;case 17:v[b+3|0]=19;v[b+5|0]=o|176;break a;case 18:case 19:v[b+3|0]=20;v[b+5|0]=d?120:119;break a;case 20:v[b+3|0]=20;v[b+5|0]=d?125:123;break a;case 21:v[b+3|0]=20;v[b+5|0]=d?122:121;break a;case 22:v[b+3|0]=20;v[b+5|0]=d?126:123;break a;case 26:v[b+3|0]=10;v[b+5|0]=d+15>>>4;break a;case 27:v[b+5|0]=1;v[b+3|0]=10;break a;case 30:case 31:if(!d|(!g|!f)){break a}o=x[h>>2];if(o>>>0<1e4){break a}l=x[i>>2];if(!l){break a}i=xr(a,f,g);if(!i){break a}k=ui(a,i);n=z[k+34>>1];g:{if(!(n&2)){i=x[k>>2];break g}i=x[k+8>>2]-((e|0)<6?x[k+4>>2]:0)|0;if(!(n&4)){break g}i=i<<((e|0)>5)}if(!i|(e|0)<6&i>>>0<1024){break a}n=x[k+24>>2];if(!n){break a}h:{if(z[a+480192>>1]<g>>>0){break h}a=x[((g<<2)+a|0)+900380>>2];if(!a){break h}m=+(y[xb(a+108|0,f-1|0)|0]-f|0)}a=(c|0)==190;m=Di(m/12+(a?(e|0)<6?+v[k+37|0]/-1536:-0:-0))*+(n>>>0);if(a){v[b+3|0]=17;a=gm(m*.5*(+(D(d,l)>>>0)*2.5)/+(i>>>0));v[b+5|0]=a;x[h>>2]=D(a,1e4);break a}m=Uv(qL(+(i>>>0)/m/(+(D(d,l)>>>0)*2.5/(+(o>>>0)/1e4)))*12+61,1,120);i:{if(m<4294967296&m>=0){a=~~m>>>0;break i}a=0}c=Tc(y[b|0]);v[b|0]=a;m=(m-J(m))*64+128;j:{if(m<4294967296&m>=0){a=~~m>>>0;break j}a=0}v[b+5|0]=a;if((a|0)!=128){v[b+3|0]=35}if(c){break a}if(!y[b+2|0]){v[b+4|0]=9;v[b+2|0]=11;break a}v[b+5|0]=255;v[b+3|0]=4;break a;case 32:a=d>>>4|0;if(a-1>>>0>1){break a}v[b+3|0]=20;v[b+5|0]=a-99;break a;case 34:v[b+3|0]=21;v[b+5|0]=d<<2;break a;case 35:v[b+3|0]=21;s=b,t=bh(ID(d<<4)>>>6|0),v[s+5|0]=t;break a;case 36:case 38:v[b+3|0]=22;v[b+5|0]=k<<4;break a;case 37:case 39:v[b+5|0]=k;v[b+3|0]=22;break a;case 40:v[b+3|0]=22;v[b+5|0]=l<<4|15;break a;case 2:case 3:case 11:case 23:case 24:case 25:case 28:case 29:case 33:break a;case 41:break d}}v[b+3|0]=22;v[b+5|0]=l|240}fb=j+128|0}function Ro(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;h=z[a+480192>>1]>=c>>>0?x[((c<<2)+a|0)+900380>>2]:h;r=x[b+752>>2];a:{j=y[b+802|0];b:{if(!j){if(Ob(a+1074312|0,11)){break b}}c:{d:{if(!h){break d}if(!Tc(j)){break d}e:{g=h+236|0;j=j-1|0;if(z[_b(g,j)>>1]){break e}if(!Ob(a+1074312|0,43)){break e}if(Tj(y[h+31|0])){break e}x[b+656>>2]=h;return}if(y[xb(h+108|0,j)|0]>120){break b}j=z[_b(g,j)>>1];n=(j-1&65535)>>>0<3999?(D(j,104)+a|0)+484380|0:0;break c}if(!z[a+480192>>1]){n=(D(c,104)+a|0)+484380|0;break c}if(j>>>0>250){break b}if(!Ob(a+1074312|0,43)){break c}if(h){if(Tj(y[h+31|0])){break c}}v[b+803|0]=0;x[b+656>>2]=0;return}j=x[b+104>>2];m=(j|0)!=0&(j|0)!=(n|0);i=x[b+656>>2];p=!h|x[a+480180>>2]!=16777216?p:x[h+44>>2]!=0;o=d^1;g=(h|0)!=(i|0);if((o|g|m)==1){w[b+774>>1]=0}l=!m;if(!(l|(g|!(d&p)))){break b}f:{if(l|o){break f}q=a+1074312|0;if(!(!Ob(q,32)|!(y[a+480208|0]&8))){n=x[b+8>>2]|x[b+12>>2]?x[b+104>>2]:n}j=x[a+480180>>2];g:{h:{i:{j:{if(!g){if((h|0)!=0&(j&1048580)!=0|(j|0)==268435456){break h}if((j|0)!=1){break i}break j}if((j|0)==1){break j}if((j|0)==268435456){break h}break i}if(Ui(x[b+8>>2],x[b+12>>2])){break h}}if(!Ob(q,79)){break g}if(!Ui(x[b+8>>2],x[b+12>>2])){break g}}k=1}if(!Ob(q,119)|z[a+480192>>1]){break f}v[b+851|0]=y[b+851|0]|2}k:{if(!x[b+16>>2]|(g|!z[a+480192>>1]|l)){break k}if(!Ob(a+1074312|0,87)){break k}k=Tc(y[b+788|0])^1|k}l=(h|0)!=(i|0);l:{if(Ui(x[b+8>>2],x[b+12>>2])|!(x[a+480180>>2]&16777248)){break l}if(h){if(Tj(y[h+31|0])){break l}}l=1}m:{n:{if(!(m|l)|!d){break n}if(!Ob(a+1074312|0,61)){break n}i=x[b+656>>2];g=x[b+104>>2];j=0;if(i|g){break m}}x[b+656>>2]=h;g=n;i=h;j=l}o:{p:{q:{if(!e){break q}r:{if(y[a+480180|0]&3){if(g){if(je(x[g>>2],x[g+20>>2])){break r}}if(!Lj(i)){break q}}if(!g){break p}}if(w[g+34>>1]<0){break q}x[b+688>>2]=z[g+30>>1]}h=(g|0)!=0;if(!(k&m)|!g){break o}if(Ob(a+1074312|0,85)){w[b+772>>1]=v[g+37|0]}h=1;if(x[a+480180>>2]!=2){break o}if(!je(x[g>>2],x[g+20>>2])){break o}x[b+704>>2]=x[g+24>>2];break o}if(!(!i|!y[i+34|0])){h=x[b+688>>2];if(i){h=x[i+4>>2]<<2}x[b+688>>2]=h;h=0;break o}h=0;x[b+688>>2]=0}if(k){break b}v[b+803|0]=0;s:{if(!i){break s}if(s=(B=Ob(a+1074312|0,29),C=1,E=g,E?B:C),t=0,u=!y[i+34|0]&(j^-1),u?s:t){break s}v[b+798|0]=y[i+16|0]}k=64;x[b+752>>2]=64;if(g){k=z[g+32>>1];x[b+752>>2]=k}if(i){x[b+752>>2]=D(x[i+4>>2],k)>>>6}t:{if(!(x[a+480180>>2]&1048580?e:1)){break t}if(Ob(a+1074312|0,48)){break t}rT(a,b,i,g)}u:{v:{w:{if(!f){break w}x:{y:{z:{A:{B:{C:{D:{E:{f=a+1074312|0;if(Ob(f,19)){if(!x[b+76>>2]){e=1;break D}if(!(!c|o)){e=(y[a+480208|0]&8)>>>3|0;if(e){break D}break E}e=0;if(c){break E}break D}F:{c=x[a+480180>>2]&17301536;e=1;G:{if(!d|!c){break G}c=1;e=1;if(y[a+480208|0]&8){break G}e=1;if(!x[b+76>>2]){break G}if(!(y[b+89|0]&16)){break F}e=!x[b+696>>2]}if(j|(!i|!c)){break B}if(!e){break x}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(c&6144){break A}break C}if((j|!i)!=1){break x}break y}if(d){break D}if(!(y[b+89|0]&24)){e=0;break D}e=(y[a+480208|0]&4)>>>2|0}if(j|!x[b+696>>2]){break B}if(!e){break y}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(!i){break z}if(c&2048){break A}}if(!(y[i+60|0]&8)){Kj(b+724|0)}if(!(y[i+80|0]&8)){Kj(b+732|0)}if(y[i+100|0]&8){break z}Kj(b+740|0);break z}if(!e){break y}x[b+88>>2]=x[b+88>>2]|2097152;if(!i){break z}}en(b)}if(Ob(f,21)){break w}v[b+818|0]=0;x[b+756>>2]=0;break w}if(!i){break v}}if(v[i+60|0]&1){break w}if(Ob(f,32)){Kj(b+724|0);break w}en(b)}c=0;if(g){break u}if(!i){break a}c=1;if(Tj(y[i+31|0])){break u}break a}c=0;if(!g){break a}}H:{if(!(!d|(h^1|x[b+104>>2]!=(g|0)))){e=x[a+480180>>2];if(x[b+76>>2]?e&16777250:0){break b}I:{J:{if((e|0)!=4){break J}if(!Ob(a+1074312|0,40)|y[b+789|0]){break J}e=x[b+88>>2];break I}e=x[b+88>>2]&-6145}x[b+88>>2]=e&-640;break H}x[b+88>>2]=x[b+88>>2]&-6145;e=a+1074312|0;K:{L:{if(!Ob(e,18)){h=-640;if(j|(x[a+480180>>2]&16777248|x[b+104>>2]!=(g|0))){break L}break K}h=-640;if((j^-1)&x[b+104>>2]==(g|0)){break K}}h=-768}x[b+88>>2]=x[b+88>>2]&h;if(!i){break H}v[b+730|0]=y[i+60|0];v[b+738|0]=y[i+80|0];v[b+746|0]=y[i+100|0];M:{if((y[i+100|0]&17)!=17){break M}if(Ob(e,36)|y[b+837|0]){break M}v[b+837|0]=127}e=y[i+21|0];if(Cd(e)){s=b,t=Wh(e),v[s+837|0]=t}e=y[i+22|0];if(!Cd(e)){break H}s=b,t=Wh(e),v[s+838|0]=t}if(c){x[b+76>>2]=0;x[b+104>>2]=0;return}N:{if(x[b+76>>2]|!d){break N}c=a+1074312|0;if(!Ob(c,54)){if(!Ob(c,39)){break N}}x[b+8>>2]=0;x[b+12>>2]=0}O:{if(y[b+788|0]!=255){break O}if(!Ob(a+1074312|0,100)|!(y[a+480208|0]>>>2&m)){break O}c=x[b+104>>2];if(c){x[b+88>>2]=x[b+88>>2]|z[c+34>>1]&1023}x[b+752>>2]=r;x[b+688>>2]=z[g+30>>1];if(!(y[g+34|0]&32)){break b}Yq(b,z[g+28>>1],a);return}x[b+104>>2]=g;x[b+76>>2]=x[g>>2];x[b+80>>2]=x[g+4>>2];x[b+84>>2]=x[g+8>>2];c=a+1074312|0;if(!(!Ob(c,83)|x[b+80>>2])){x[b+84>>2]=x[g>>2]}x[b+88>>2]=x[b+88>>2]|z[g+34>>1]&1023;if(Ob(c,21)){v[b+818|0]=0;x[b+756>>2]=0}P:{Q:{if(p){x[b+704>>2]=x[g+24>>2];v[b+851|0]=y[b+851|0]|64;d=0;break Q}if(!(m|o)){d=x[a+480180>>2];if(d&5){break P}}x[b+704>>2]=x[g+24>>2];d=v[g+37|0]}w[b+772>>1]=d;d=x[a+480180>>2]}if(En(d)){d=v[g+36|0]}else{d=0}w[b+770>>1]=d;if(!(Ob(c,69)|x[a+480180>>2]==1)){x[b+708>>2]=0}x[b+852>>2]=0;h=x[b+88>>2];if(h&8){x[b+80>>2]=x[g+12>>2];x[b+84>>2]=x[g+16>>2];h=h>>>2&4|h|2;x[b+88>>2]=h}c=x[b+76>>2];R:{if(!(h&2)){break R}d=x[b+84>>2];if(d>>>0>=c>>>0){break R}x[b+76>>2]=d;c=d}if(!(x[a+480180>>2]&16777248)|A[b+4>>2]<c>>>0){break b}x[b>>2]=0;x[b+4>>2]=0}return}x[b+752>>2]=0;x[b+104>>2]=0}
function ppa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb-224|0;fb=d;xc(b);a:{if(!Gr(b,d+160|0)){break a}if(!WW(d+160|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(VW(d+160|0),hb))){break a}if(!c){e=1;break a}Bd(a,256);f=d+148|0;wi(f,2,d+160|0);e=d+56|0;Cc(e,f);Ab(a+1298308|0,e);tb(e);f=y[d+210|0]|y[d+211|0]<<8;x[a+480260>>2]=64;x[a+480264>>2]=32767;w[a+480188>>1]=4;w[a+480190>>1]=f;Lb(a+1074312|0,107,1);f=y[d+203|0];f=f?f:96;j=xC(f);x[a+480196>>2]=f>>>4;x[a+480204>>2]=j;v[d+56|0]=64;q=a,r=y[Rb(d+202|0,e)|0]<<2,x[q+480200>>2]=r;e=0;b:{c:{d:{e:{f:{g:{while(1){if((e|0)==4){h:{j=Nb(d+148|0);l=Nb(d+136|0);x[31725]=0;P(151,b|0,(y[d+192|0]|y[d+193|0]<<8)<<4)|0;e=x[31725];x[31725]=0;i:{if((e|0)==1){break i}x[31725]=0;U(215,b|0,j|0,y[d+208|0]|y[d+209|0]<<8)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}x[31725]=0;P(151,b|0,(y[d+194|0]|y[d+195|0]<<8)<<4)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}x[31725]=0;U(215,b|0,l|0,y[d+210|0]|y[d+211|0]<<8)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}x[31725]=0;P(151,b|0,((y[d+196|0]|y[d+197|0]<<8)<<4)+32|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}e=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;O(332,Xb(f,e)|0,y[d+212|0]|y[d+213|0]<<8);e=x[31725];x[31725]=0;if((e|0)==1){break i}e=Xb(x[a+484360>>2],y[a+484376|0]);q=d,r=wb(x[e>>2]),x[q+56>>2]=r;e=wb(x[e+4>>2]);j:{while(1){f=x[d+56>>2];if(!Ib(f,e)){e=0;if(!ZW(Xb(x[a+484360>>2],y[a+484376|0]))){break b}g=c&2;k=d+57|0;e=1;break j}x[31725]=0;g=R(199,b|0)|0;k=x[31725];x[31725]=0;k:{if((k|0)==1){break k}w[f>>1]=g;x[31725]=0;P(185,b|0,4)|0;f=x[31725];x[31725]=0;if((f|0)==1){break k}Md(d+56|0);continue}break}b=N()|0;break c}l:{m:{n:{o:{while(1){f=e&65535;if(f>>>0>(y[d+210|0]|y[d+211|0]<<8)>>>0){break l}h=_b(x[l>>2],f-1|0);h=y[h|0]|y[h+1|0]<<8;x[31725]=0;h=P(151,b|0,h<<4)|0;i=x[31725];x[31725]=0;p:{if((i|0)!=1){if(h){break p}e=0;break b}b=N()|0;break c}x[31725]=0;P(700,b|0,d+56|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break o}x[31725]=0;h=(D(f,104)+a|0)+484380|0;S(701,d+56|0,h|0,0);i=x[31725];x[31725]=0;if((i|0)==1){break o}i=d+28|0;Rk(i,2,k);x[31725]=0;O(220,d+40|0,i|0);i=x[31725];x[31725]=0;if((i|0)==1){break n}i=((f<<5)+a|0)+946304|0;f=d+40|0;zc(i,f);tb(f);q:{r:{if(!g|!(y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24))){break r}f=jX(d+56|0);x[31725]=0;f=P(151,b|0,f|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break m}if(!f){break r}f=d+40|0;iX(f,y[d+86|0],y[d+87|0],1);x[31725]=0;U(217,f|0,h|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break q}}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}v[d+27|0]=1;i=0;e=x[j>>2];s:{if(lc(e,x[j+4>>2])|(y[d+188|0]|y[d+189|0]<<8)==26){break s}f=y[e|0]|y[e+1|0]<<8;e=0;x[31725]=0;f=P(151,b|0,f<<4)|0;g=x[31725];x[31725]=0;if((g|0)==1){break h}if(!f){break b}x[31725]=0;e=R(191,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break h}if((e|0)!=(y[d+188|0]|y[d+189|0]<<8)){break s}v[d+27|0]=0;i=1}n=c&1;if(n){x[31725]=0;O(225,a+484344|0,y[d+208|0]|y[d+209|0]<<8);c=x[31725];x[31725]=0;if((c|0)==1){break h}}k=a+484344|0;f=0;while(1){t:{if(!n|(y[d+208|0]|y[d+209|0]<<8)>>>0<=f>>>0){break t}x[31725]=0;c=U(198,k|0,f&65535,64)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}if(!c){break t}c=_b(x[j>>2],f);c=y[c|0]|y[c+1|0]<<8;x[31725]=0;c=P(151,b|0,c<<4)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}e=0;if(!c){break b}if(i){x[31725]=0;c=R(191,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break g}if(c>>>0>2112){break b}}w[d+12>>1]=65535;x[d+28>>2]=63;c=Wb(x[k>>2],f);cf(d+40|0,x[c>>2],x[x[c+48>>2]+12>>2],0);u:while(1){c=e;while(1){if(c>>>0<=63){x[31725]=0;e=R(199,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break f}h=e<<24>>24;if(!h){e=64;if(c>>>0>62){continue u}e=Wb(x[k>>2],f);g=x[e>>2];h=x[x[e+48>>2]+12>>2];e=c+1|0;cf(d+56|0,g,h,e);c=x[d+60>>2];x[d+40>>2]=x[d+56>>2];x[d+44>>2]=c;continue u}e=ch(d+56|0);g=h&31;if(g>>>0<z[a+480188>>1]){e=Wc(x[d+40>>2],g)}m=h&255;if(m&32){x[31725]=0;O(200,d+25|0,b|0);g=x[31725];x[31725]=0;v:{w:{x:{if((g|0)!=1){o=Jc(d+25|0);g=y[d+25|0];if(g>>>0>239){break x}g=hX((D(g>>>4|0,12)+(g&15)|0)+37|0);break w}b=N()|0;break c}y:{switch(g-254|0){case 0:break w;case 1:break y;default:break v}}g=0}v[e|0]=g}v[e+1|0]=y[o|0]}if(m&64){x[31725]=0;g=R(199,b|0)|0;m=x[31725];x[31725]=0;if((m|0)==1){break e}v[d+25|0]=g;v[e+2|0]=1;v[d+24|0]=64;q=e,r=y[Rb(d+25|0,d+24|0)|0],v[q+4|0]=r}if((h|0)>=0){continue}x[31725]=0;O(200,d+25|0,b|0);g=x[31725];x[31725]=0;if((g|0)==1){break d}q=e,r=y[Jc(d+25|0)|0],v[q+5|0]=r;YW(e,y[d+25|0],c,255,d+12|0,d+28|0);continue}break}break}c=z[d+12>>1];if((c|0)!=65535){ye(Wb(x[k>>2],f),Gn(Ye(Ne(d+56|0,12,c&255),x[d+28>>2])))}f=f+1|0;continue}break}x[31725]=0;b=P(1,d+56|0,6088)|0;c=x[31725];x[31725]=0;z:{A:{B:{if((c|0)!=1){Ab(a+1298344|0,b);tb(b);x[31725]=0;b=P(1,d+40|0,5274)|0;c=x[31725];x[31725]=0;if((c|0)==1){break B}Ab(a+1298356|0,b);tb(b);q=a+1298404|0,r=x[Fc(d+28|0,4)>>2],x[q>>2]=r;x[31725]=0;O(703,d+12|0,4405);b=x[31725];x[31725]=0;if((b|0)==1){break A}x[31725]=0;S(211,d+28|0,d+12|0,d+27|0);b=x[31725];x[31725]=0;if((b|0)==1){break z}b=a+1298368|0;a=d+28|0;Ab(b,a);tb(a);Eb(d+12|0);e=1;break b}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;Eb(d+12|0);break c}b=N()|0;break c}}else{f=(e<<5)+a|0;Xe(f+480280|0);w[f+480284>>1]=e&1?64:192;e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}md(l);md(j);Q(b|0);p()}md(l);md(j)}fb=d+224|0;return e|0}function Poa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=fb-176|0;fb=d;xc(c);a:{if(!op(c,d+164|0)|(y[d+164|0]|y[d+165|0]<<8|(y[d+166|0]<<16|y[d+167|0]<<24))!=1297239878){break a}f=y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24);if((f|0)!=1179011393&(f|0)!=1128679745){break a}e=fb-32|0;fb=e;g=d+152|0;f=Nb(g);b:{c:{d:{e:{f:{while(1){h=x[c+8>>2];i=x[c>>2];x[31725]=0;h=U(152,i|0,h|0,8)|0;i=x[31725];x[31725]=0;if((i|0)==1){break d}if(!h){break e}x[31725]=0;O(829,e+4|0,c|0);h=x[31725];x[31725]=0;if((h|0)!=1){x[31725]=0;O(830,f|0,e+4|0);h=x[31725];x[31725]=0;if((h|0)==1){break f}Gd(e+4|0);continue}break}a=N()|0;break c}a=N()|0;Gd(e+4|0);break c}fb=e+32|0;break b}a=N()|0}ie(f);Q(a|0);p()}x[31725]=0;S(749,d+132|0,g|0,1129270605);c=x[31725];x[31725]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){x[31725]=0;c=P(750,d+132|0,d+114|0)|0;e=x[31725];x[31725]=0;n:{o:{if((e|0)!=1){if(!c){break g}if(!$b(z[d+116>>1]|z[d+118>>1]<<16)){break g}if((Bb(z[d+114>>1])-3&65535)>>>0<65534){break g}if((Bb(z[d+120>>1])-65&65535)>>>0<65472){break g}x[d+108>>2]=1162760014;c=1;if((y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24))==1128679745){x[31725]=0;c=P(629,d+132|0,d+108|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break o}if(!c){break g}c=x[d+108>>2]!=1936684916}x[31725]=0;S(749,d+88|0,d+152|0,1397968452);e=x[31725];x[31725]=0;p:{q:{if((e|0)!=1){x[31725]=0;k=P(751,d+88|0,d+80|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break p}if(k){break q}break h}c=N()|0;break j}e=(Bb(z[d+120>>1])-1|0)/8|0;g=e<<3;f=g&31;g=Xc(d+76|0,(e>>>0>=8?8:(g&63)>>>0>=32?1074268168>>>f|0:((1<<f)-1&1074268168)<<32-f|538447880>>>f)&120,(Bb(z[d+114>>1])|0)==2?2:1,c,0);c=x[d+108>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}yg(g,3);break r}yg(g,17);fd(g,16);break r}yg(g,16);fd(g,16);break r}yg(g,1)}c=x[d+80>>2];x[31725]=0;c=U(152,x[d+88>>2],x[d+96>>2],$b(c)|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}if(c){c=x[d+80>>2];x[31725]=0;P(185,d+88|0,$b(c)|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break l}}Vu(a,b);x[31725]=0;c=D(b,104)+a|0;h=c+484380|0;O(281,h|0,0);e=x[31725];x[31725]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}s=h,t=$b(z[d+116>>1]|z[d+118>>1]<<16),x[s>>2]=t;j=c+484404|0;c=y[d+124|0]|y[d+125|0]<<8|(y[d+126|0]<<16|y[d+127|0]<<24);f=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24);i=30-y[d+123|0]|0;e=0;while(1){c=f;if(i&255){f=c>>>1|0;i=i-1|0;e=c;continue}break}x[j>>2]=c+(e&1);x[31725]=0;U(217,g|0,h|0,d+88|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break D}x[31725]=0;S(749,d+56|0,d+152|0,1296126539);c=x[31725];x[31725]=0;if((c|0)==1){break C}x[31725]=0;c=R(174,x[d+56>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break B}if(!c){break u}x[31725]=0;S(749,d+16|0,d+152|0,1229869908);c=x[31725];x[31725]=0;if((c|0)==1){break A}x[31725]=0;c=P(752,d+16|0,d+36|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break z}ub(d+16|0);if(!c){break u}x[31725]=0;f=R(275,d+56|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break y}e=Nb(d+16|0);x[31725]=0;O(753,e|0,f|0);c=x[31725];x[31725]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}x[31725]=0;g=P(754,d+56|0,d+4|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break w}if(!g){break x}x[31725]=0;O(755,e|0,d+4|0);g=x[31725];x[31725]=0;if((g|0)==1){break w}x[31725]=0;g=y[d+10|0];P(185,d+56|0,!(g&1)+g|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=N()|0;break k}c=N()|0;break k}c=N()|0;break m}c=N()|0;break m}c=N()|0;ub(d+16|0);break m}c=N()|0;break m}c=Bb(y[d+44|0]|y[d+45|0]<<8);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65511|((c|0)==2)<<4|8}c=Bb(y[d+50|0]|y[d+51|0]<<8);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65529|((c|0)==2?4:2)|2}s=d,t=wb(x[e>>2]),x[s+4>>2]=t;c=D(b,104)+a|0;g=c+484388|0;i=c+484384|0;j=c+484396|0;l=c+484392|0;m=wb(x[e+4>>2]);n=y[d+46|0]|y[d+47|0]<<8;o=y[d+48|0]|y[d+49|0]<<8;q=y[d+52|0]|y[d+53|0]<<8;r=y[d+54|0]|y[d+55|0]<<8;while(1){c=x[d+4>>2];if(!Ib(c,m)){break v}f=Bb(y[c|0]|y[c+1|0]<<8);if((f|0)==(Bb(n)|0)){s=l,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Bb(y[c|0]|y[c+1|0]<<8)}if((Bb(o)|0)==(f|0)){s=j,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Bb(y[c|0]|y[c+1|0]<<8)}if((Bb(q)|0)==(f|0)){s=i,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Bb(y[c|0]|y[c+1|0]<<8)}if((f|0)==(Bb(r)|0)){s=g,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t}x[d+4>>2]=x[d+4>>2]+7;continue}}c=N()|0;_T(e);break m}al(h);_T(e)}x[31725]=0;S(749,d+16|0,d+152|0,1312902469);c=x[31725];x[31725]=0;if((c|0)==1){break n}x[31725]=0;c=R(174,x[d+16>>2])|0;e=x[31725];x[31725]=0;E:{if((e|0)==1){break E}F:{if(c){x[31725]=0;c=R(156,x[d+16>>2])|0;e=x[31725];x[31725]=0;if((e|0)==1){break E}x[31725]=0;S(319,d+16|0,((b<<5)+a|0)+946304|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break F}break E}x[31725]=0;c=P(36,d+4|0,22255)|0;e=x[31725];x[31725]=0;if((e|0)==1){break E}zc(((b<<5)+a|0)+946304|0,c);tb(c)}bC(h,x[a+480180>>2]);Sj(h,a);ub(d+16|0);ub(d+56|0);break h}c=N()|0;ub(d+16|0);break m}c=N()|0;break k}c=N()|0;break j}c=N()|0;break j}c=N()|0;break m}c=N()|0;break i}ub(d+56|0);break k}c=N()|0}ub(d+88|0)}ub(d+132|0)}ie(d+152|0);Q(c|0);p()}ub(d+88|0)}ub(d+132|0);ie(d+152|0)}fb=d+176|0;return k|0}function Wsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-1344|0;fb=d;xc(b);h=fb-16|0;fb=h;f=d+768|0;a_(h+8|0,f);j=x[h+12>>2];kc(h,x[b>>2],x[b+8>>2],x[h+8>>2],x[h+12>>2]);e=x[h+4>>2];if((e|0)==(j|0)){Vb(b,x[h+12>>2])}fb=h+16|0;e=(e|0)==(j|0);if(!e){$Z(f)}a:{if(!e){break a}if(!c_(d+768|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(b_(y[d+802|0]|y[d+803|0]<<8,y[d+804|0]|y[d+805|0]<<8),hb))){break a}if(!c){i=1;break a}k=sc(d+764|0);b:{while(1){if((i|0)!=32){n=(i<<5)+a|0;h=n+480280|0;Xe(h);j=(d+768|0)+(i<<4)|0;w[n+480284>>1]=((y[j+78|0]<<8&65280)>>>0)/255;e=d+496|0;Rk(e,1,j- -64|0);f=d+108|0;Cc(f,e);pm(n+480289|0,f);tb(f);c:{d:{switch(y[j+79|0]){case 0:o=g+1|0;break c;case 1:x[h>>2]=1024;o=i+1|0;break c;case 2:break d;default:break b}}x[h>>2]=1024;e=d+108|0;Pc(e,k,i);hp(e)}g=g+1|0;i=i+1|0;continue}break}Bd(a,33554432);w[a+480188>>1]=o&255;f=d+108|0;e=tc(f,6808);Ab(a+1298344|0,e);tb(e);e=tc(f,11140);Ab(a+1298356|0,e);tb(e);t=a+1298404|0,u=x[Fc(f,4)>>2],x[t>>2]=u;e:{if(y[d+847|0]){break e}i=1;g=1;while(1){if((i|0)==16){while(1){if((g|0)==16){break e}e=((g<<5)+a|0)+480280|0;x[e>>2]=x[e>>2]&-1025;g=g+1|0;continue}}e=i<<4;i=i+1|0;if(y[(d+e|0)+847|0]==1){continue}break}}f=d+496|0;We(f,1,d+768|0);e=d+108|0;Cc(e,f);Ab(a+1298308|0,e);tb(e);x[a+480208>>2]=x[a+480208>>2]&-17|(y[d+806|0]|y[d+807|0]<<8)<<4&16;x[a+480196>>2]=y[d+816|0];x[a+480204>>2]=D(y[d+817|0],1e4);x[a+480200>>2]=y[d+818|0]<<2;x[a+480228>>2]=y[d+819|0];e=y[d+804|0]|y[d+805|0]<<8;w[a+480190>>1]=0;w[a+480192>>1]=e;Dw(b,f);Vr(Xb(x[a+484360>>2],y[a+484376|0]),f,y[d+800|0]|y[d+801|0]<<8,65535,255);n=c&1;if(n){Vf(a+484344|0,y[d+802|0]|y[d+803|0]<<8)}q=a+484344|0;f:{while(1){g:{if((y[d+802|0]|y[d+803|0]<<8)>>>0<=s>>>0){n=c&2;f=1;c=0;h:while(1){if(z[a+480192>>1]<=(c&65535)>>>0){i=32;break b}c=c+1|0;l=BE(a,c&65535,0);i=!l;h=fb-16|0;fb=h;g=d+108|0;bc(h+8|0,g,384);j=x[h+12>>2];kc(h,x[b>>2],x[b+8>>2],x[h+8>>2],x[h+12>>2]);e=x[h+4>>2];if((e|0)==(j|0)){Vb(b,x[h+12>>2])}fb=h+16|0;e=(e|0)==(j|0);if(!e){Tb(g,0,384)}if(!e|i){continue}i=f&65535;h=fb-32|0;fb=h;e=h+8|0;m=d+108|0;We(e,1,m);g=h+20|0;Cc(g,e);zc(l+492|0,g);tb(g);i:{if(!(y[m+378|0]|y[m+379|0]<<8)){break i}g=l+236|0;j=0;while(1){x[h+20>>2]=120;x[h+8>>2]=116;if(A[Gb(h+20|0,h+8|0)>>2]<=j>>>0){break i}e=y[(j+m|0)+32|0];t=_b(g,j+12|0),u=e+i|0,w[t>>1]=u;j=j+1|0;continue}}e=y[m+376|0]|y[m+377|0]<<8;v[l+33|0]=1;x[l>>2]=e;BD(m,l+48|0,0);BD(m,l+68|0,1);BD(m,l+88|0,2);e=y[l+100|0];if(e&1){v[l+100|0]=e|16}if(!(x[l>>2]|v[l+60|0]&1)){x[l>>2]=32767}fb=h+32|0;i=0;while(1){e=y[d+486|0]|y[d+487|0]<<8;if(e>>>0<=i>>>0){f=e+f|0;continue h}u$(b,d+44|0);j:{k:{if((y[d+104|0]|y[d+105|0]<<8|(y[d+106|0]<<16|y[d+107|0]<<24))!=808538953){break k}e=f+i|0;l=e&65535;if(l>>>0>3999){break k}w[a+480190>>1]=e;q=fb-32|0;fb=q;m=D(l,104)+a|0;k=m+484380|0;ld(k,0);e=q+8|0;nk(e,1,d+44|0);g=q+20|0;Cc(g,e);ze(k+43|0,g);tb(g);h=y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24);x[k>>2]=h;j=y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24);x[k+4>>2]=j;g=y[d+68|0]|y[d+69|0]<<8|(y[d+70|0]<<16|y[d+71|0]<<24);x[k+8>>2]=g;x[k+24>>2]=y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24);w[k+30>>1]=y[d+76|0]<<2;w[k+28>>1]=y[d+77|0];e=y[d+92|0];if(e&1){w[k+34>>1]=z[k+34>>1]|2;e=y[d+92|0]}if(e&2){w[k+34>>1]=z[k+34>>1]|4;e=y[d+92|0]}if(e&4){x[k+8>>2]=g>>>1;x[k+4>>2]=j>>>1;x[k>>2]=h>>>1;w[k+34>>1]=z[k+34>>1]|1;e=y[d+92|0]}if(e&8){w[k+34>>1]=z[k+34>>1]|32}fb=q+32|0;g=fb-16|0;fb=g;Pw(g+8|0,m+484423|0);e=d+24|0;Gp(e,x[g+8>>2],x[g+12>>2]);fb=g+16|0;zc(((l<<5)+a|0)+946304|0,e);tb(e);e=y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24);if(!e){break k}g=d+4|0;fe(g,b,e);j=ic(d+24|0,g);ub(g);if(n){e=Xc(d+4|0,w[m+484414>>1]&1?16:8,1,0,0);x[31725]=0;U(217,e|0,k|0,j|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}}ub(j)}i=i+1|0;continue}break}break}a=N()|0;ub(j);break f}e=ih(b);l=ih(b);f=d+44|0;fe(f,b,e-4|0);r=ic(d+108|0,f);ub(f);l:{m:{if(!n){break m}x[31725]=0;f=U(198,q|0,s&65535,l|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}if(!f){break m}o=0;e=ch(d+24|0);while(1){if(l>>>0<=o>>>0){break m}x[31725]=0;j=R(199,r|0)|0;f=x[31725];x[31725]=0;n:{if((f|0)!=1){if(j){break n}o=o+1|0;continue}break g}g=e;m=j&31;if(m>>>0<z[a+480188>>1]){f=Wb(x[q>>2],s);g=jd(x[f>>2],x[x[f+48>>2]+12>>2],o,m)}if(j&32){x[31725]=0;O(200,d+44|0,r|0);f=x[31725];x[31725]=0;if((f|0)==1){break g}f=y[d+44|0];v[g|0]=f;t=g,u=y[Jc(d+44|0)|0],v[t+1|0]=u;o:{p:{if((f|0)==160){i=255;break p}if((f|0)==255){i=0;break p}i=0;f=(D(f>>>4|0,12)+(f&15)|0)+13|0;if(_Z(f)){break o}}f=i}v[g|0]=f}f=j&192;q:{if(!f){break q}if((f|0)==192){x[31725]=0;O(359,d+44|0,r|0);f=x[31725];x[31725]=0;if((f|0)!=1){f=d+44|0;i=Jc(f);h=af(f);j=fj(f);f=d+4|0;CD(f,y[d+44|0],y[i|0]);i=Jc(f);f=d+494|0;CD(f,y[h|0],y[j|0]);Hn(d+492|0,g,y[d+4|0],y[i|0],y[d+494|0],y[Jc(f)|0]);break q}break g}x[31725]=0;O(200,d+44|0,r|0);f=x[31725];x[31725]=0;r:{s:{if((f|0)!=1){f=d+4|0;CD(f,y[d+44|0],y[Jc(d+44|0)|0]);i=y[Jc(f)|0];f=y[d+4|0];if((f|0)!=13){break s}v[g+2|0]=1;f=g+4|0;break r}break g}v[g+3|0]=f;f=g+5|0}v[f|0]=i}Pc(d+44|0,k,m);if(!Hb(x[x[d+44>>2]>>2],x[d+48>>2])){continue}if(!v0(y[g+3|0],y[g+5|0])){continue}v[g+3|0]=0;continue}}ub(r);s=s+1|0;continue}}break}a=N()|0;ub(r)}Q(a|0);p()}i=i>>>0>31}fb=d+1344|0;return i|0}function Fqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=fb-1824|0;fb=e;xc(b);d=fb-16|0;fb=d;j=e+1224|0;gY(d+8|0,j);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);k=x[d+4>>2];if((k|0)==(f|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(f|0)==(k|0);if(!d){fY(j)}a:{if(!d){break a}if(!hY(e+1224|0)){break a}if(!SC(b,16,0)){break a}d=e+1240|0;x[e+1216>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=y[e+1228|0]|y[e+1229|0]<<8|(y[e+1230|0]<<16|y[e+1231|0]<<24);x[e+1200>>2]=y[e+1224|0]|y[e+1225|0]<<8|(y[e+1226|0]<<16|y[e+1227|0]<<24);x[e+1204>>2]=d;d=e+1232|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[e+1208>>2]=f;x[e+1212>>2]=d;Bd(a,1);Lb(Lb(dg(a+1074312|0,83),84,1),85,1);w[a+480188>>1]=4;x[e+1196>>2]=0;w[a+480190>>1]=15;cd(b,20);l=a+480188|0;g=1;j=1;b:{while(1){c:{if((g|0)==16){d=e+1064|0;if(!OC(b,d)){KC(d)}d=a+484376|0;jw(Xb(x[a+484360>>2],y[d|0]),e+1066|0,128);k=qY(b,Xb(x[a+484360>>2],y[d|0]),y[e+1064|0],i,l,0,1);if(!(y[e+1065|0]|k>>>0>1)){g=0;if(!y[e+1064|0]){break a}}d=(k<<10)+i|0;x[e+1060>>2]=d;x[e+24>>2]=65536;g=0;if(!Mb(x[b>>2],x[b+8>>2],d-x[Gb(e+1060|0,e+24|0)>>2]|0)){break a}if(c){break c}break b}d=e+24|0;MC(b,d);h=d;f=D(g,104)+a|0;k=f+484380|0;d=((g<<5)+a|0)+946304|0;UC(h,k,d,1);h=x[k>>2];d:{if(!y[xb(d,0)|0]){break d}e:{if(kd(d,16783,3)){if(kd(d,16787,3)){break e}}if(y[xb(d,5)|0]==58){break d}}j=0}d=Bb(y[e+52|0]|y[e+53|0]<<8);if(d>>>0>=2){n=d<<1;d=Bb(y[e+50|0]|y[e+51|0]<<8);x[f+484388>>2]=n+d;x[f+484384>>2]=d;al(k)}f:{if(Bb(y[e+46|0]|y[e+47|0]<<8)>>>0<=4999){if(Bb(y[e+50|0]|y[e+51|0]<<8)>>>0<1e4){break f}}x[e+1064>>2]=5;s=e,t=x[Ze(e+1196|0,e+1064|0)>>2],x[s+1196>>2]=t}i=i+h|0;g=g+1|0;continue}break}g=y[e+1065|0];if(!g){v[e+1065|0]=120;g=120}g:{if(!kd(e+1200|0,14933,6)){v[e+1065|0]=120;x[a+480204>>2]=125e4;break g}x[a+480204>>2]=125e4;if((g|0)==120){break g}s=a,t=_e(1773447.5/(+(240-g|0)*122)*1e4),x[s+480204>>2]=t;if(x[e+1196>>2]>=2){x[e+24>>2]=j&1?4:5;s=e,t=x[Ze(e+1196|0,e+24|0)>>2],x[s+1196>>2]=t;break g}x[e+24>>2]=j&1?1:2;s=e,t=x[Ze(e+1196|0,e+24|0)>>2],x[s+1196>>2]=t}x[a+480228>>2]=64;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480208>>2]=x[a+480208>>2]|2097152;f=e+1048|0;wi(f,3,e+1200|0);d=e+24|0;Cc(d,f);Ab(a+1298308|0,d);tb(d);Yh(a,0);f=j&1;r=x[b+8>>2];while(1){h:{if((p&65535)>>>0<k>>>0){d=Xb(x[a+484360>>2],y[a+484376|0]);d=Ib(LC(wb(x[d>>2]),wb(x[d+4>>2]),p),wb(x[d+4>>2]));eY(b,e+24|0);i:{if(d){q=QC(e+24|0,0)+q|0;if(q>>>0>512){break i}}o=0;d=x[e+1196>>2];i=0;j=0;j:while(1){if((j|0)==64){break h}g=0;while(1)if((g|0)==4){j=j+1|0;continue j}else{h=yb(Xd(e+24|0,j),g);n=y[xb(h,2)|0]&15;l=y[xb(h,3)|0];k:{if(!(!(i&255)|(y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24)))){i=i+1|0;if((i&255)>>>0<33){break k}d=6;x[e+1196>>2]=6;break k}i=0}l:{m:{n:{o:{switch(n-1|0){case 0:case 1:if((d|0)==1&l>>>0>=32){break m}h=(n|0)!=1;if(!(h|!l|l>>>0>2)){x[e+1048>>2]=2;d=x[Ze(e+1196|0,e+1048|0)>>2];break n}if(h|(l|0)!=55&(l|0)!=71){break l}if((d|0)<=2){break m}break l;case 10:d=6;break n;case 11:case 12:case 13:x[e+1048>>2]=2;d=x[Ze(e+1196|0,e+1048|0)>>2];x[e+1196>>2]=d;if((n|0)!=13){break l}o=((j|l)!=0)+o|0;i=1;break l;case 14:break o;default:break l}}x[e+1048>>2]=3;d=x[Ze(e+1196|0,e+1048|0)>>2]}x[e+1196>>2]=d;break l}x[e+1196>>2]=f;d=f}g=g+1|0;continue}}}g=0;break a}if(!(x[e+1196>>2]!=6|k+32>>>0>=m>>>0)){x[e+1196>>2]=5}cd(b,r);p=c&1;if(p){Vf(a+484344|0,k)}o=a+484344|0;m=0;while(1)if((k|0)==(m|0)){g=22255;d=x[e+1196>>2];if(d>>>0<7){g=x[(d<<2)+25260>>2]}d=e+24|0;f=tc(d,8304);Ab(a+1298344|0,f);tb(f);f=tc(d,10785);Ab(a+1298356|0,f);tb(f);ci(a+1298368|0,g);s=a+1298404|0,t=x[Fc(d,28)>>2],x[s>>2]=t;g=1;if(!(c&2)){break a}while(1){if((g|0)==16){break b}c=D(g,104)+a|0;d=c+484384|0;Vb(b,x[d>>2]);f=x[d>>2];x[d>>2]=0;d=c+484380|0;x[d>>2]=x[d>>2]-f;c=c+484388|0;x[c>>2]=x[c>>2]-f;c=e+24|0;Xc(c,8,1,1,0);fg(c,d,b);g=g+1|0;continue}}else{eY(b,e+24|0);p:{if(!p){break p}if(!Ng(o,m&65535,64)){break p}j=0;x[e+20>>2]=0;q:while(1){if((j|0)==64){break p}d=Wb(x[o>>2],m);cf(e+1048|0,x[d>>2],x[x[d+48>>2]+12>>2],j);g=0;while(1)if((g|0)==4){j=j+1|0;continue q}else{d=Wc(x[e+1048>>2],g);f=yb(Xd(e+24|0,j),g);f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[e+8>>2]=f;x[e+12>>2]=f;f=e+18|0;lp(f,e+8|0,d);l=(e+20|0)+g|0;i=y[e+18|0];f=Jc(f);h=y[f|0];r:{s:{if(!((i|0)!=14?h:0)){v[l|0]=0;if(i|h){break s}break r}h=y[l|0];if(!h){break s}n=h;q=h>>>4|0;h=h>>>0<16;v[d+4|0]=h?n:q;v[d+2|0]=h?4:3}t:{u:{v:{w:{x:{switch(i-12|0){case 1:i=x[e+1196>>2];if((i|0)!=6){v[e+18|0]=10;break v}v[f|0]=0;break w;case 0:v[f|0]=y[f|0]&127;break w;case 2:i=y[f|0];if(i>>>0<=1){h=14;if(x[e+1196>>2]>3){break u}}v[e+18|0]=10;v[l|0]=y[f|0];break w;case 3:break x;default:break w}}v[f|0]=y[f|0]&15}i=x[e+1196>>2]}if((i|0)<2){break t}i=y[f|0];h=y[e+18|0]}Bf(d,h,i&255);break r}i=y[f|0];v[d+5|0]=i;y:{z:{A:{switch(y[e+18|0]){case 0:if(y[f|0]>2){break z}break;case 2:break y;case 1:break z;default:break A}}v[d+3|0]=0;break r}v[d+3|0]=1;break r}f=i&15;if(f){v[d+5|0]=f;v[d+3|0]=2;break r}if(i>>>0<16){break r}v[d+3|0]=3;v[d+5|0]=(i&240)>>>4}g=g+1|0;continue}}}m=m+1|0;continue}}if((o-1&255)>>>0<2){x[e+1196>>2]=6}p=p+1|0;m=(o&255)+m|0;continue}}g=1}fb=e+1824|0;return g|0}function FL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0,E=0,F=0,G=0;j=fb-80|0;fb=j;x[j+76>>2]=b;E=j+55|0;s=j+56|0;a:{b:{c:{d:{e:while(1){k=b;if((p^2147483647)<(h|0)){break d}p=h+p|0;f:{g:{h:{h=k;i=y[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(y[i+1|0]!=37){b=i;break j}h=h+1|0;m=y[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;B=p^2147483647;if((h|0)>(B|0)){break d}if(a){Lf(a,k,h)}if(h){continue e}x[j+76>>2]=b;h=b+1|0;q=-1;i=v[b+1|0];if(!(!Oh(i)|y[b+2|0]!=36)){q=i-48|0;u=1;h=b+3|0}x[j+76>>2]=h;n=0;i=v[h|0];b=i-32|0;k:{if(b>>>0>31){o=h;break k}o=h;b=1<<b;if(!(b&75913)){break k}while(1){o=h+1|0;x[j+76>>2]=o;n=b|n;i=v[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=o;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){b=v[o+1|0];m:{if(!(!Oh(b)|y[o+2|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;i=o+3|0;u=1;b=x[((v[o+1|0]<<3)+d|0)-384>>2];break m}if(u){break h}i=o+1|0;if(!a){x[j+76>>2]=i;u=0;r=0;break l}b=x[c>>2];x[c>>2]=b+4;u=0;b=x[b>>2]}x[j+76>>2]=i;r=b;if((b|0)>=0){break l}r=0-r|0;n=n|8192;break l}r=EL(j+76|0);if((r|0)<0){break d}i=x[j+76>>2]}h=0;l=-1;n:{if(y[i|0]!=46){b=i;A=0;break n}if(y[i+1|0]==42){b=v[i+2|0];o:{if(!(!Oh(b)|y[i+3|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;b=i+4|0;l=x[((v[i+2|0]<<3)+d|0)-384>>2];break o}if(u){break h}b=i+2|0;l=0;if(!a){break o}i=x[c>>2];x[c>>2]=i+4;l=x[i>>2]}x[j+76>>2]=b;A=(l^-1)>>>31|0;break n}x[j+76>>2]=i+1;l=EL(j+76|0);b=x[j+76>>2];A=1}while(1){t=h;o=28;m=b;h=v[b|0];if(h-123>>>0<4294967238){break c}b=m+1|0;h=y[(h+D(t,58)|0)+92959|0];if(h-1>>>0<8){continue}break}x[j+76>>2]=b;p:{q:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){x[(q<<2)+e>>2]=h;i=(q<<3)+d|0;h=x[i+4>>2];x[j+64>>2]=x[i>>2];x[j+68>>2]=h;break q}if(!a){break f}DL(j- -64|0,h,c,g);break p}if((q|0)>=0){break c}}h=0;if(!a){continue e}}i=n&-65537;n=n&8192?i:n;q=0;z=5286;o=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=v[m|0];h=t?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(h-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((h|0)==83){break w}break g}i=x[j+64>>2];m=x[j+68>>2];z=5286;break z}h=0;I:{switch(t&255){case 0:x[x[j+64>>2]>>2]=p;continue e;case 1:x[x[j+64>>2]>>2]=p;continue e;case 2:k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e;case 3:w[x[j+64>>2]>>1]=p;continue e;case 4:v[x[j+64>>2]]=p;continue e;case 6:x[x[j+64>>2]>>2]=p;continue e;case 7:break I;default:continue e}}k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e}l=l>>>0<=8?8:l;n=n|8;h=120}k=s;F=h&32;i=x[j+64>>2];m=x[j+68>>2];if(i|m){while(1){k=k-1|0;v[k|0]=F|y[(i&15)+93488|0];G=!m&i>>>0>15|(m|0)!=0;t=m;m=m>>>4|0;i=(t&15)<<28|i>>>4;if(G){continue}break}}if(!(n&8)|!(x[j+64>>2]|x[j+68>>2])){break y}z=(h>>>4|0)+5286|0;q=2;break y}h=s;k=x[j+68>>2];m=k;i=x[j+64>>2];if(k|i){while(1){h=h-1|0;v[h|0]=i&7|48;t=!m&i>>>0>7|(m|0)!=0;k=m;m=k>>>3|0;i=(k&7)<<29|i>>>3;if(t){continue}break}}k=h;if(!(n&8)){break y}h=s-k|0;l=(h|0)<(l|0)?l:h+1|0;break y}i=x[j+64>>2];h=x[j+68>>2];m=h;if((h|0)<0){k=0-(m+((i|0)!=0)|0)|0;m=k;i=0-i|0;x[j+64>>2]=i;x[j+68>>2]=k;q=1;z=5286;break z}if(n&2048){q=1;z=5287;break z}q=n&1;z=q?5288:5286}k=qo(i,m,s)}if((l|0)<0?A:0){break d}n=A?n&-65537:n;h=x[j+64>>2];i=x[j+68>>2];if(!((h|i)!=0|l)){k=s;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=x[j+64>>2];k=h?h:17082;m=l>>>0>=2147483647?2147483647:l;h=Kz(k,0,m);h=h?h-k|0:m;o=h+k|0;if((l|0)>=0){n=i;l=h;break g}n=i;l=h;if(y[o|0]){break d}break g}if(l){i=x[j+64>>2];break u}h=0;Yf(a,32,r,0,n);break t}x[j+12>>2]=0;x[j+8>>2]=x[j+64>>2];i=j+8|0;x[j+64>>2]=i;l=-1}h=0;J:{while(1){k=x[i>>2];if(!k){break J}m=CL(j+4|0,k);k=(m|0)<0;if(!(k|m>>>0>l-h>>>0)){i=i+4|0;h=h+m|0;if(l>>>0>h>>>0){continue}break J}break}if(k){break b}}o=61;if((h|0)<0){break c}Yf(a,32,r,h,n);if(!h){h=0;break t}o=0;i=x[j+64>>2];while(1){k=x[i>>2];if(!k){break t}k=CL(j+4|0,k);o=k+o|0;if(o>>>0>h>>>0){break t}Lf(a,j+4|0,k);i=i+4|0;if(h>>>0>o>>>0){continue}break}}Yf(a,32,r,h,n^8192);h=(h|0)<(r|0)?r:h;continue e}if((l|0)<0?A:0){break d}o=61;h=ib[f|0](a,C[j+64>>3],r,l,n,h)|0;if((h|0)>=0){continue e}break c}v[j+55|0]=x[j+64>>2];l=1;k=E;n=i;break g}i=y[h+1|0];h=h+1|0;continue}}if(a){break a}if(!u){break f}h=1;while(1){a=x[(h<<2)+e>>2];if(a){DL((h<<3)+d|0,a,c,g);p=1;h=h+1|0;if((h|0)!=10){continue}break a}break}p=1;if(h>>>0>=10){break a}while(1){if(x[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}o=28;break c}m=o-k|0;i=(l|0)>(m|0)?l:m;if((i|0)>(q^2147483647)){break d}o=61;l=i+q|0;h=(l|0)<(r|0)?r:l;if((B|0)<(h|0)){break c}Yf(a,32,h,l,n);Lf(a,z,q);Yf(a,48,h,l,n^65536);Yf(a,48,i,m,0);Lf(a,k,m);Yf(a,32,h,l,n^8192);continue}break}p=0;break a}o=61}x[31600]=o}p=-1}fb=j+80|0;return p}function ysa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-192|0;fb=f;n=kk(b,13874);if(n){if(d){v[d|0]=1}k=a+480204|0;o=a+480216|0;q=a+480220|0;r=a+480224|0;l=a+1074368|0;u=a+480228|0;B=a+480232|0;s=a+480200|0;m=a+480268|0;C=a+1298320|0;E=a+480248|0;F=Qv(a+1074312|0);a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Mb(x[b>>2],x[b+8>>2],7)){break a}e=Pg(b);g=ih(b);if((e|0)==70791730){Gh(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Mb(x[b>>2],x[b+8>>2],g)){break a}d=f+152|0;fe(d,b,g);h=ic(f+172|0,d);ub(d);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=B;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=o;if((e|0)==1380991534){break s}d=q;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=u;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}x[31725]=0;S(453,h|0,g|0,f+152|0);d=x[31725];x[31725]=0;if((d|0)==1){break i}x[k>>2]=D(x[f+152>>2],1e4)+(A[k>>2]%1e4|0);break j}x[31725]=0;S(453,h|0,g|0,f+152|0);d=x[31725];x[31725]=0;if((d|0)!=1){d=x[k>>2];x[k>>2]=d-((d>>>0)%1e4|0)+A[f+152>>2]%1e4;break j}e=N()|0;break b}if(c){break j}x[31725]=0;w[f+152>>1]=0;S(454,h|0,g|0,f+152|0);d=x[31725];x[31725]=0;if((d|0)!=1){G=a,H=Kd(z[f+152>>1],z[a+480188>>1],127),w[G+480188>>1]=H;break j}e=N()|0;break b}x[31725]=0;S(455,h|0,g|0,l|0);d=x[31725];x[31725]=0;if((d|0)!=1){break j}break c}x[31725]=0;x[f+152>>2]=0;S(453,h|0,g|0,f+152|0);d=x[31725];x[31725]=0;if((d|0)!=1){x[a+1074304>>2]=x[f+152>>2];break j}e=N()|0;break b}x[31725]=0;x[f+152>>2]=0;S(453,h|0,g|0,f+152|0);d=x[31725];x[31725]=0;if((d|0)==1){break h}d=x[f+152>>2];if(!d){break j}x[a+1074308>>2]=d;break j}d=s}x[31725]=0;S(453,h|0,g|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}break j}if(x[a+480180>>2]==4){break j}x[31725]=0;S(454,h|0,g|0,f+152|0);d=x[31725];x[31725]=0;if((d|0)!=1){bf(Xb(x[a+484360>>2],y[a+484376|0]),z[f+152>>1]);break j}e=N()|0;break b}x[31725]=0;S(456,h|0,g|0,m|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}if(Bp(y[m|0])){break j}v[m|0]=5;break j}d=Fb(f+152|0);e=x[h>>2];x[31725]=0;e=R(156,e|0)|0;g=x[31725];x[31725]=0;x:{if((g|0)==1){break x}x[31725]=0;S(457,h|0,d|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break x}x[31725]=0;S(260,f+140|0,0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break x}e=f+140|0;Ab(C,e);tb(e);tb(d);break j}e=N()|0;tb(d);break b}if(g&1|g>>>0>126){break j}d=64;w[f+152>>1]=(g>>>1|0)- -64;w[f+140>>1]=127;e=z[Nc(f+152|0,f+140|0)>>1];i=e>>>0<=64?64:e;while(1){if((d|0)==(i|0)){break j}x[31725]=0;O(200,f+152|0,h|0);e=x[31725];x[31725]=0;if((e|0)==1){break g}e=y[f+152|0];y:{if((e|0)==255){break y}j=y[Jc(f+152|0)|0];g=(d<<5)+a|0;t=g+480284|0;w[t>>1]=128;w[g+480286>>1]=j;g=g+480280|0;j=(e&128)<<3;x[g>>2]=j;e=e&127;if(e>>>0<65){w[t>>1]=e<<2;break y}if((e|0)!=100){break y}x[g>>2]=j|256}d=d+1|0;continue}}if(g>>>0<3){break j}x[31725]=0;d=R(191,h|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break f}if(z[a+480190>>1]<=(d-1&65535)>>>0){break j}d=(D(d,104)+a|0)+484448|0;g=SZ(d);while(1){if((d|0)==(g|0)){break j}e=x[h>>2];x[31725]=0;i=U(152,e|0,x[f+180>>2],4)|0;e=x[31725];x[31725]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}x[31725]=0;e=R(153,h|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){break z}}e=N()|0;break b}x[d>>2]=e;d=d+4|0;continue}}if(g>>>0<3){break j}x[31725]=0;O(458,f+140|0,h|0);d=x[31725];x[31725]=0;A:{B:{C:{D:{if((d|0)!=1){x[31725]=0;S(459,f+152|0,x[f+140>>2],x[f+144>>2]);d=x[31725];x[31725]=0;if((d|0)==1){break D}x[31725]=0;d=P(105,f|0,f+152|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break C}tb(f+152|0);dc(f+140|0);e=x[h>>2];x[31725]=0;R(156,e|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break A}x[31725]=0;S(460,d|0,E|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break A}Ff(d);break j}e=N()|0;break b}e=N()|0;break B}e=N()|0;tb(f+152|0)}dc(f+140|0);break b}e=N()|0;Ff(d);break b}e=0;g=Qv(F);E:while(1){d=x[h>>2];x[31725]=0;d=U(152,d|0,x[f+180>>2],1)|0;i=x[31725];x[31725]=0;if((i|0)==1){break d}if(!(d&e>>>0<121)){break j}x[31725]=0;i=R(199,h|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>120){break F}x[31725]=0;U(268,g|0,e|0,1)|0;j=x[31725];x[31725]=0;if((j|0)!=1){break F}e=N()|0;break b}e=e+1|0;d=d+1|0;continue}}}x[31725]=0;S(461,h|0,g|0,r|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}}ub(h);continue}break}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0}ub(h);Q(e|0);p()}b=x[a+8>>2];Mp(k,D(x[b+20>>2],1e4),D(x[b+24>>2],1e4));if(y[a+480224|0]>=3){v[r|0]=0}if(y[l|0]>=6){v[l|0]=0}wc(s,256);wc(o,65536);wc(q,65536)}fb=f+192|0;return n|0}function jqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0;e=fb-272|0;fb=e;xc(b);a:{if(!U$(b,e+206|0)){break a}if(!VX(e+206|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(UX(e+206|0),hb))){break a}b:{if(!c){break b}Bd(a,16);f=e+44|0;wi(f,2,e+210|0);d=e- -64|0;Cc(d,f);Ab(a+1298308|0,d);tb(d);w[a+480190>>1]=y[e+236|0];w[a+480188>>1]=y[e+239|0];h=tc(d,8365);Ab(a+1298344|0,h);tb(h);h=tc(d,10129);Ab(a+1298356|0,h);tb(h);ig(f,4211);h=y[e+209|0];x[e+24>>2]=h>>>4;x[31725]=0;x[e+12>>2]=h&15;V(309,d|0,f|0,e+24|0,e+12|0);d=x[31725];x[31725]=0;c:{d:{if((d|0)!=1){d=e- -64|0;Ab(a+1298368|0,d);tb(d);Eb(e+44|0);u=a+1298404|0,B=x[Fc(d,4)>>2],x[u>>2]=B;d=1;while(1){k=d&65535;if(k>>>0>z[a+480190>>1]){d=0;while(1)if(z[a+480188>>1]<=d>>>0){f=e- -64|0;d=fb-16|0;fb=d;j=b;e:{if(!Mb(x[b>>2],x[b+8>>2],128)){b=0;while(1){if((b|0)!=128){fh(b+f|0);b=b+1|0;continue}break}break e}qZ(d+8|0,f);rd(d,j,x[d+8>>2],x[d+12>>2])}fb=d+16|0;Fw(Xb(x[a+484360>>2],y[a+484376|0]),f,y[e+233|0]+1|0,255,254);b=y[e+238|0];d=e+24|0;fe(d,j,D(y[e+230|0]|y[e+231|0]<<8,192));m=ic(e+44|0,d);ub(d);f:{o=c&1;if(!o){break f}x[31725]=0;O(225,a+484344|0,y[e+232|0]+1|0);d=x[31725];x[31725]=0;if((d|0)!=1){break f}break d}q=b?b:64;r=a+484344|0;b=0;while(1){g:{h:{i:{if(y[e+232|0]<l>>>0){if(!(b&t)){break h}u=e,B=wb(x[a+484344>>2]),x[u+12>>2]=B;i=wb(x[a+484348>>2]);break i}j:{if(o){x[31725]=0;d=U(198,r|0,l&65535,q|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}n=0;if(d){break j}}x[31725]=0;P(185,j|0,64)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break g}break d}while(1){d=n&65535;if(d>>>0>31){break g}x[31725]=0;f=R(191,j|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}k:{if((f-1&65535)>>>0>=(y[e+230|0]|y[e+231|0]<<8)>>>0|d>>>0>=z[a+480188>>1]){break k}x[31725]=0;P(151,m|0,D(f,192)-192|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}f=0;h=Wb(x[r>>2],l);d=jd(x[h>>2],x[x[h+48>>2]+12>>2],0,d);while(1){if((f|0)==(q|0)){break k}i=b;x[31725]=0;O(550,e+24|0,m|0);b=x[31725];x[31725]=0;l:{m:{n:{o:{p:{if((b|0)!=1){b=e+24|0;k=Jc(b);h=af(b);b=y[e+24|0];if(b>>>0>=4){v[d|0]=(b>>>2|0)+37;b=y[e+24|0]}v[d+1|0]=b<<4&48|y[k|0]>>>4;b=y[h|0];g=0;h=0;q:{r:{k=y[k|0]&15;switch(k-8|0){case 0:break o;case 2:break q;case 6:break r;default:break p}}k=14;s=(b&240)<<24>>24;if((s|0)<=-17|!(435>>>((s+16&240)>>>4)&1)){break n}break o}b=(b&240?-16:15)&b;k=10;break n}break d}g=k;h=b}k=g;b=h;if(!((g|b)&255)){break m}}Bf(d,k,b&255);b=1;s:{switch(y[d+3|0]-16|0){case 0:break l;case 1:break s;default:break m}}t=1}b=i}f=f+1|0;d=D(z[a+480188>>1],6)+d|0;continue}}n=n+1|0;continue}}while(1){t:{b=x[e+12>>2];if(Ib(b,i)){g=0;u:while(1){if(A[b+12>>2]<=g>>>0){break t}cf(e+24|0,x[b>>2],x[x[b+48>>2]+12>>2],g);u=e,B=wb(x[e+24>>2]),x[u+20>>2]=B;f=0;k=iw(x[e+24>>2],x[e+28>>2]);h=0;while(1){l=x[e+20>>2];if(Ib(l,k)){d=1;v:{switch(y[l+3|0]-16|0){case 1:h=1;default:d=f;break;case 0:break v}}vg(e+20|0);f=d;continue}else{g=g+1|0;if(!(f&h&1)){continue u}break h}}}}u=e,B=wb(x[a+484344>>2]),x[u+20>>2]=B;d=wb(x[a+484348>>2]);w:while(1){b=x[e+20>>2];if(!Ib(b,d)){break h}f=0;x:while(1){if(A[b+12>>2]<=f>>>0){bm(e+20|0);continue w}cf(e+12|0,x[b>>2],x[x[b+48>>2]+12>>2],f);u=e,B=wb(x[e+12>>2]),x[u+8>>2]=B;h=iw(x[e+12>>2],x[e+16>>2]);while(1){y:{g=x[e+8>>2];if(Ib(g,h)){g=y[g+3|0];if((g&254)!=16){break y}h=(g|0)==16;ye(b,Ye(Ne(e+24|0,h?17:16,h?125:6),f))}f=f+1|0;continue x}vg(e+8|0);continue}}}}bm(e+12|0);continue}}z:{b=y[e+234|0]|y[e+235|0]<<8;if(!b){break z}x[31725]=0;aa(318,a+1298332|0,j|0,b|0,39,1);b=x[31725];x[31725]=0;if((b|0)!=1){break z}break d}A:{if(!(c&2)){break A}d=1;while(1){b=d&65535;if(b>>>0>z[a+480190>>1]){break A}b=D(b,104)+a|0;c=Xc(e+24|0,w[b+484414>>1]&1?16:8,1,0,1);x[31725]=0;U(217,c|0,b+484380|0,j|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){d=d+1|0;continue}break}break d}x[a+480260>>2]=64;x[a+480264>>2]=32767;ub(m);break b}l=l+1|0;continue}}else{f=(d<<5)+a|0;Xe(f+480280|0);w[f+480284>>1]=(y[(e+d|0)+240|0]<<4|8)&248;d=d+1|0;continue}}else{i=e- -64|0;fF(b,i);j=fb-16|0;fb=j;g=(D(k,104)+a|0)+484380|0;ld(g,0);w[j+14>>1]=y[i+35|0]<<2;w[j+12>>1]=256;u=g,B=z[Nc(j+14|0,j+12|0)>>1],w[u+30>>1]=B;f=y[i+22|0]|y[i+23|0]<<8|(y[i+24|0]<<16|y[i+25|0]<<24);B:{if(f>>>0<3){break B}x[g>>2]=f;x[g+4>>2]=y[i+26|0]|y[i+27|0]<<8|(y[i+28|0]<<16|y[i+29|0]<<24);x[j+8>>2]=y[i+30|0]|y[i+31|0]<<8|(y[i+32|0]<<16|y[i+33|0]<<24);x[j+4>>2]=1;u=g,B=x[ad(j+8|0,j+4|0)>>2]-1|0,x[u+8>>2]=B;wc(g+8|0,f);h=x[g+8>>2];f=x[g+4>>2];C:{if(h>>>0<=f+4>>>0){x[g+4>>2]=0;x[g+8>>2]=0;h=0;f=0;break C}if(h>>>0<3){break C}w[g+34>>1]=z[g+34>>1]|2}v[g+37|0]=y[i+34|0];u=g,B=IE(0,v[i+34|0]<<4),x[u+24>>2]=B;if(!(v[i+36|0]&1)){break B}x[g+8>>2]=h>>>1;x[g+4>>2]=f>>>1;w[g+34>>1]=z[g+34>>1]|1;x[g>>2]=x[g>>2]>>>1}fb=j+16|0;h=e+24|0;Zk(h,2,i);f=e+44|0;Cc(f,h);zc(((k<<5)+a|0)+946304|0,f);d=d+1|0;tb(f);continue}}}d=N()|0;Eb(e+44|0);break c}d=N()|0;ub(m)}Q(d|0);p()}d=1}fb=e+272|0;return d|0}function tpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-352|0;fb=d;a:{b:{c:{if(!cd(b,60)){break c}if(!Up(b,d+332|0)){break c}e=15;if(vv(d+332|0,15)){break b}}if(!cd(b,124)){break a}if(!Up(b,d+332|0)){break a}e=31;if(!vv(d+332|0,31)){break a}}Bd(a,536870912);w[a+480190>>1]=e;xc(b);d:{while(1){if(z[a+480190>>1]>f>>>0){g=vp(b);x[(d+208|0)+(f<<2)>>2]=g;f=f+1|0;if(g>>>0<=131072){continue}break d}break}Vb(b,20);e=0;w[a+480192>>1]=0;w[a+480188>>1]=4;f=y[d+336|0]|y[d+337|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480196>>2]=6;o=a,q=_e(1776930/+(Bb(f)>>>0)*1e4),x[o+480204>>2]=q;x[a+480228>>2]=64;Yh(a,1);m=1;e:while(1){l=m&65535;if(l>>>0<=z[a+480190>>1]){MC(b,d+52|0);f=x[((l<<2)+d|0)+204>>2];h=fb-16|0;fb=h;i=(D(l,104)+a|0)+484380|0;ld(i,1);x[i>>2]=f;v[i+37|0]=y[d+76|0]<<4;v[h+15|0]=y[d+77|0];v[h+14|0]=64;o=i,q=y[Rb(h+15|0,h+14|0)|0]<<2,w[o+30>>1]=q;f:{if(!f){break f}g=Bb(y[d+80|0]|y[d+81|0]<<8);k=Bb(y[d+78|0]|y[d+79|0]<<8);x[i+4>>2]=k;g=(g<<1)+k|0;x[i+8>>2]=g;if(f>>>0<=k>>>0){k=f-1|0;x[i+4>>2]=k}if(f>>>0<g>>>0){x[i+8>>2]=f;g=f}if(!(!(g>>>0<4|g>>>0<k>>>0)&g-k>>>0>3)){x[i+4>>2]=0;x[i+8>>2]=0;break f}if(g>>>0<=k>>>0){break f}w[i+34>>1]=z[i+34>>1]|2}fb=h+16|0;f=0;while(1)if((f|0)==22){if(e>>>0>=128){break d}g=d+184|0;Zk(g,3,d+52|0);f=d+196|0;Cc(f,g);zc(((l<<5)+a|0)+946304|0,f);m=m+1|0;tb(f);continue e}else{g=(d+52|0)+f|0;if((y[g|0]-1&255)>>>0<=30){v[g|0]=32;e=e+1|0}f=f+1|0;continue}}break}m=1;g:{h:{i:{e=a+946336|0;f=Dc(d+52|0,14036);if(!dX(e,f)){x[31725]=0;g=P(36,d+196|0,14047)|0;i=x[31725];x[31725]=0;if((i|0)==1){break i}m=dX(e,g);tb(g)}tb(f);f=0;g=d+52|0;e=OC(b,g);if(!e){KC(g)}if(!e){break a}g=y[d+52|0];if(!fX(g)){break a}if(!c){break g}w[d+50>>1]=0;while(1)if((f|0)==(g|0)){f=a+484376|0;h=Xb(x[a+484360>>2],y[f|0]);e=y[d+53|0];bf(h,g>>>0>e>>>0?e:0);Fw(Xb(x[a+484360>>2],y[f|0]),d+54|0,y[d+52|0],65535,65535);if(z[a+480190>>1]==31){Vb(b,4)}x[d+44>>2]=0;x[d+40>>2]=0;x[d+36>>2]=0;v[d+35|0]=0;n=c&1;if(n){Vf(a+484344|0,z[d+50>>1])}l=a+484344|0;i=0;while(1){j:{k:{l:{if(z[d+50>>1]<=i>>>0){if(!(c&2)){break l}f=1;while(1){e=z[a+480190>>1];c=f&65535;if(e>>>0<c>>>0){break k}c=(D(c,104)+a|0)+484380|0;if(x[c>>2]){fg(Xc(d+184|0,8,1,0,0),c,b)}f=f+1|0;continue}}m:{if(n){k=0;if(Ng(l,i&65535,64)){break m}}Vb(b,1024);break j}n:while(1){if((k|0)==64){break j}f=Wb(x[l>>2],i);cf(d+184|0,x[f>>2],x[x[f+48>>2]+12>>2],k);f=0;while(1)if((f|0)==4){k=k+1|0;continue n}else{g=Wc(x[d+184>>2],f);e=d+12|0;tm(e,b);o:{p:{q:{r:{if(y[xb(e,0)|0]!=255){break r}v[(d+44|0)+f|0]=0;v[(d+36|0)+f|0]=0;e=xb(d+12|0,1);h=y[e|0];if((h|0)==252&m){v[e|0]=254;break p}switch(h-252|0){case 1:break o;case 2:break p;case 0:break q;default:break r}}e=x[d+12>>2];x[d+28>>2]=e;x[d+8>>2]=e;e=d+33|0;lp(e,d+8|0,g);h=Jc(e);e=y[g|0];s:{if(!e){break s}v[(d+36|0)+f|0]=0;v[(d+44|0)+f|0]=e;if(e>>>0>48){break s}v[d+27|0]=8;o=d,q=y[ef(d+35|0,d+27|0)|0],v[o+35|0]=q}j=y[d+33|0];e=y[h|0];t:{if(j|e){v[g+5|0]=e;u:{v:{w:{switch(j-1|0){case 0:v[g+3|0]=1;break o;case 1:if(e>>>0>=16){v[g+3|0]=3;v[g+5|0]=(e&240)>>>4;break o}if(!e){break v}v[g+5|0]=e;v[g+3|0]=2;break o;case 2:if(y[(d+36|0)+f|0]){break v}v[g+5|0]=0;v[g+3|0]=19;break o;case 3:if(y[(d+36|0)+f|0]){break v}v[g+5|0]=1;v[g+3|0]=19;break o;case 4:h=y[g+1|0];if(!h){break v}v[d+27|0]=63;v[d+26|0]=e+(z[(D(h,104)+a|0)+484410>>1]>>>2|0);e=y[Rb(d+27|0,d+26|0)|0];v[g+5|0]=e;v[g+3|0]=13;if(!y[(d+36|0)+f|0]){break o}h=g+3|0;v[g+4|0]=e;v[g+2|0]=1;break u;case 5:h=g+3|0;j=y[g+1|0];if(!j){break u}v[g+3|0]=13;j=z[(D(j,104)+a|0)+484410>>1]>>>2|0;e=e>>>0<=j>>>0?j-e|0:0;v[g+5|0]=e;if(!y[(d+36|0)+f|0]){break o}v[g+4|0]=e;v[g+2|0]=1;break u;case 6:h=e&15;v[(d+36|0)+f|0]=h;j=y[(d+44|0)+f|0];e=j-((e&240)>>>4|0)|0;v[(d+40|0)+f|0]=e;o=g,q=cX(h,e&255,j),v[o+5|0]=q;v[g+3|0]=3;break o;case 7:h=e&15;v[(d+36|0)+f|0]=h;j=(e&240)>>>4|0;e=y[(d+44|0)+f|0];j=j+e|0;v[(d+40|0)+f|0]=j;o=g,q=cX(h,e,j&255),v[o+5|0]=q;v[g+3|0]=2;break o;case 8:break w;default:break v}}v[d+27|0]=8;o=d,q=y[ef(d+35|0,d+27|0)|0],v[o+35|0]=q}h=g+3|0}v[h|0]=0;break t}if(y[g+3|0]){break o}}h=y[(d+36|0)+f|0];if(!h){break o}j=(d+40|0)+f|0;e=y[j|0];if(e){v[(d+44|0)+f|0]=e;v[g+5|0]=h;v[g|0]=e;v[j|0]=0}v[g+3|0]=4;break o}v[g+3|0]=14;v[d+35|0]=9;break o}v[g+3|0]=13}f=f+1|0;continue}}}e=z[a+480190>>1]}x:{y:{if((e&65535)==15){b=d+12|0;ig(b,4418);x[31725]=0;S(211,d+184|0,b|0,d+35|0);b=x[31725];x[31725]=0;if((b|0)!=1){break y}e=N()|0;Eb(d+12|0);break h}x[31725]=0;P(1,d+184|0,12390)|0;b=x[31725];x[31725]=0;if((b|0)==1){break x}}b=d+184|0;Ab(a+1298344|0,b);tb(b);if((e&65535)==15){Eb(d+12|0)}ci(a+1298356|0,z[a+480190>>1]==15?5282:15110);o=a+1298404|0,q=x[Fc(d+184|0,28)>>2],x[o>>2]=q;break g}e=N()|0;break h}i=i+1|0;continue}}else{w[d+184>>1]=y[(d+f|0)+54|0]+1;o=d,q=z[qe(d+50|0,d+184|0)>>1],w[o+50>>1]=q;f=f+1|0;continue}}e=N()|0;tb(f)}Q(e|0);p()}f=1;break a}f=0}fb=d+352|0;return f|0}function iM(a,b,c,d,e,f){var g=0,h=E(0),i=0,j=0,k=E(0),l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=E(0),A=E(0),C=0,F=0,G=0,H=E(0),I=E(0),J=E(0),K=E(0),L=E(0),M=E(0),N=E(0),O=E(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=D(s,2304)+b|0;u=0;q=(c|0)>0?c:0;n=fb-128|0;x=n+96|0;y=n- -64|0;C=n+32|0;while(1){if((q|0)!=(u|0)){o=G+(u<<2)|0;v=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=B[D(15-j|0,72)+o>>2];g=D(j,72)+o|0;h=B[g+1152>>2];l=E(k+h);m=B[g>>2];z=B[D(31-j|0,72)+o>>2];A=E(m+z);B[p>>2]=l+A;g=D(j,12);k=E(E(k-h)*B[g+87712>>2]);h=E(E(m-z)*B[g+87716>>2]);B[p+64>>2]=k+h;m=E(A-l);l=B[g+87720>>2];B[p+32>>2]=m*l;B[p+96>>2]=l*E(h-k);p=p+4|0;j=j+1|0;continue}break}while(1){if((v|0)!=4){l=B[i+8>>2];m=B[i+20>>2];h=E(l+m);z=B[i+4>>2];A=B[i+24>>2];H=E(z+A);k=E(h+H);I=B[i+12>>2];J=B[i+16>>2];K=E(I+J);L=B[i>>2];M=B[i+28>>2];N=E(L+M);O=E(K+N);B[i>>2]=k+O;B[i+16>>2]=E(O-k)*E(.7071067690849304);k=E(N-K);h=E(E(k+E(H-h))*E(.7071067690849304));B[i+24>>2]=E(k-h)*E(1.3065630197525024);B[i+8>>2]=E(k+h)*E(.5411961078643799);k=E(L-M);h=E(l-m);l=E(z-A);m=E(E(h+l)*E(.7071067690849304));z=E(k+m);A=E(E(I-J)+h);h=E(l+k);l=E(A-E(h*E(.1989123672246933)));h=E(E(l*E(.3826834261417389))+h);B[i+28>>2]=E(z-h)*E(2.562915563583374);B[i+4>>2]=E(z+h)*E(.509795606136322);k=E(k-m);h=E(l-E(h*E(.1989123672246933)));B[i+20>>2]=E(k+h)*E(.8999761939048767);B[i+12>>2]=E(k-h)*E(.601344883441925);i=i+32|0;v=v+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;B[o>>2]=B[p+n>>2];k=B[p+x>>2];i=i+1|0;j=i<<2;h=B[j+x>>2];B[o+72>>2]=E(B[p+y>>2]+k)+h;B[o+144>>2]=B[p+C>>2]+B[j+C>>2];B[o+216>>2]=h+E(k+B[j+y>>2]);o=o+288|0;continue}break}B[o>>2]=B[n+28>>2];k=B[n+124>>2];B[o+72>>2]=B[n+92>>2]+k;h=B[n+60>>2];B[o+216>>2]=k;B[o+144>>2]=h;u=u+1|0;continue}break}s=s+1|0;continue}break}C=yc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=fb-32|0;fb=i;o=C+(s<<8)|0;u=(s<<2)+b|0;B[o+4080>>2]=B[u+1152>>2];f=d-1|0;v=u+D(f,2304)|0;B[o+4084>>2]=B[v+1152>>2];B[o+4088>>2]=B[u>>2];B[o+4092>>2]=B[v>>2];B[o+4336>>2]=B[u+1156>>2];B[o+4340>>2]=B[v+1156>>2];B[o+4344>>2]=B[u+4>>2];B[o+4348>>2]=B[v+4>>2];x=(D(s,G)<<1)+e|0;y=x+(f<<1)|0;Rt(y,d,o+244|0);f=d<<6;Rt(f+y|0,d,o+500|0);Rt(x,d,o+240|0);Rt(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=87808;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=D(31-p|0,72);B[j>>2]=B[f+u>>2];B[j+4>>2]=B[f+v>>2];f=f|4;B[j+8>>2]=B[f+u>>2];B[j+12>>2]=B[f+v>>2];f=D(p,72);q=f+76|0;B[j+256>>2]=B[q+u>>2];B[j+260>>2]=B[q+v>>2];f=f+72|0;B[j-248>>2]=B[f+u>>2];B[j-244>>2]=B[f+v>>2];q=p<<2;t=g+o|0;k=B[n+4>>2];h=B[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=B[g+j>>2];m=B[g+t>>2];B[g+(i+16|0)>>2]=E(l*h)-E(k*m);B[i+g>>2]=E(l*k)+E(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=B[n+12>>2];h=B[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=B[n+20>>2];h=B[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=B[n+28>>2];h=B[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=B[n+36>>2];h=B[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=B[n+44>>2];h=B[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=B[n+52>>2];h=B[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=B[n+60>>2];h=B[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=B[j+q>>2];m=B[g+j>>2];B[t>>2]=B[t>>2]+E(E(l*k)+E(h*m));j=j+(i+16|0)|0;B[j>>2]=E(E(m*k)-E(h*l))+B[j>>2];f=f+1|0;continue}break}f=D(15-p|0,d)<<1;P=f+y|0,Q=Cj(B[i+20>>2]),w[P>>1]=Q;j=D(p+17|0,d)<<1;P=j+y|0,Q=Cj(B[i+4>>2]),w[P>>1]=Q;P=f+x|0,Q=Cj(B[i+16>>2]),w[P>>1]=Q;P=j+x|0,Q=Cj(B[i>>2]),w[P>>1]=Q;f=D(47-p|0,d)<<1;P=f+y|0,Q=Cj(B[i+28>>2]),w[P>>1]=Q;j=D(p+49|0,d)<<1;P=j+y|0,Q=Cj(B[i+12>>2]),w[P>>1]=Q;P=f+x|0,Q=Cj(B[i+24>>2]),w[P>>1]=Q;P=j+x|0,Q=Cj(B[i+8>>2]),w[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}fb=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}B[(s<<2)+a>>2]=B[C+(b+s<<2)>>2];s=s+2|0;continue}}yc(a,C+(b<<2)|0,3840)}}function zta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=fb-272|0;fb=f;xc(b);e=fb-16|0;fb=e;i=f+66|0;C_(e+8|0,i);g=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){B_(i)}a:{if(!e){break a}if(!E_(f+66|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(D_(f+66|0),hb))){break a}b:{if(!c){break b}Bd(a,16777216);gg(a);x[a+480208>>2]=x[a+480208>>2]|16777216;d=f+44|0;yr(d,32);g=x[f+56>>2];e=a+1074320|0;x[e>>2]=x[f+52>>2];x[e+4>>2]=g;e=x[f+48>>2];x[a+1074312>>2]=x[f+44>>2];x[a+1074316>>2]=e;Lb(a+1074312|0,114,1);r=a,s=Bb(y[f+266|0]|y[f+267|0]<<8),w[r+480188>>1]=s;Yh(a,1);e=tc(d,8541);Ab(a+1298368|0,e);tb(e);e=f+24|0;ig(e,3924);x[31725]=0;S(372,d|0,e|0,y[f+69|0]);d=x[31725];x[31725]=0;c:{if((d|0)!=1){d=f+44|0;Ab(a+1298344|0,d);tb(d);e=f+24|0;Eb(e);g=tc(d,10789);Ab(a+1298356|0,g);tb(g);r=a+1298404|0,s=x[Fc(d,26)>>2],x[r>>2]=s;We(e,3,f+70|0);Cc(d,e);Ab(a+1298308|0,d);tb(d);e=160;while(1){d:{d=e;if(!d){d=0;break d}e=d-1|0;if(y[(f+e|0)+102|0]==32){continue}}break}A_(a+1298332|0,f+102|0,d,4);d=Bb(y[f+262|0]|y[f+263|0]<<8);w[a+480190>>1]=d;n=1;while(1){e:{f:{g:{h:{i:{e=d&65535;d=n&65535;if(e>>>0<d>>>0){e=a+484376|0;bf(Xb(x[a+484360>>2],y[e|0]),Bb(y[f+270|0]|y[f+271|0]<<8));d=f+24|0;fe(d,b,512);m=ic(f+44|0,d);ub(d);d=y[e|0];e=x[a+484360>>2];g=y[f+268|0]|y[f+269|0]<<8;x[31725]=0;S(278,Xb(e,d)|0,m|0,Bb(g)|0);d=x[31725];x[31725]=0;if((d|0)!=1){break i}d=N()|0;break h}i=D(d,104)+a|0;m=i+484380|0;ld(m,1);np(m);T$(b,((d<<5)+a|0)+946304|0,y[f+69|0]==1?32:28);h=1;d=y[f+69|0];if(d>>>0>=3){Vb(b,14);d=JD(b);if((d|0)>=0){e=i+484414|0;w[e>>1]=z[e>>1]|32;r=i+484408|0,s=Bc((((d&65535)<<8)+2047>>>0)/4095|0,0),w[r>>1]=s}d=y[f+69|0]}if((d&255)>>>0>=2){h=Wk(b);r=i+484404|0,s=Wk(b),x[r>>2]=s}e=f+44|0;g=fb-16|0;fb=g;j:{if(!Mb(x[b>>2],x[b+8>>2],12)){x[g>>2]=0;d=e;k=3;while(1){if(k){l=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[d|0]=l;v[d+1|0]=l>>>8;v[d+2|0]=l>>>16;v[d+3|0]=l>>>24;k=k-1|0;d=d+4|0;continue}break}break j}Hr(g+8|0,e);rd(g,b,x[g+8>>2],x[g+12>>2])}fb=g+16|0;g=ec(e);d=zb(e);l=$b(x[f+44>>2]);x[m>>2]=l;j=i+484384|0;k=$b(y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24));x[j>>2]=k;o=i+484388|0;q=$b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+k|0;x[o>>2]=q;g=i+484414|0;if(k){e=z[g>>1];break f}e=z[g>>1];if($b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))>>>0>=3){break f}d=e&-3;break e}d=wb(x[Xb(x[a+484360>>2],y[a+484376|0])>>2]);g=wb(x[Xb(x[a+484360>>2],y[a+484376|0])+4>>2]);e=fb-16|0;fb=e;k:{if(!Ib(d,g)){break k}x[e+12>>2]=d;while(1){i=x[Md(e+12|0)>>2];if(!Ib(i,g)){break k}d=dl(z[d>>1],z[i>>1])?i:d;continue}}fb=e+16|0;d=z[d>>1];x[31725]=0;k=a+484344|0;o=d+1&65535;O(225,k|0,o|0);d=x[31725];x[31725]=0;if((d|0)!=1){d=y[f+69|0];x[f+20>>2]=x[a+480204>>2];x[f+16>>2]=x[a+480196>>2];l=d>>>0<4?4:5;q=c&1;e=0;while(1){if((e|0)==(o|0)){if(!(c&2)){break g}d=1;while(1){c=d&65535;if(c>>>0>z[a+480190>>1]){break g}c=D(c,104)+a|0;e=Xc(f+8|0,w[c+484414>>1]&1?16:8,1,1,0);x[31725]=0;U(217,e|0,c+484380|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){d=d+1|0;continue}break}d=N()|0;break h}l:{if(!q){break l}d=y[f+264|0]|y[f+265|0]<<8;g=x[b+8>>2];i=x[b>>2];h=z[a+480188>>1];x[31725]=0;d=U(152,i|0,g|0,D(h,D(Bb(d),l))|0)|0;g=x[31725];x[31725]=0;m:{n:{if((g|0)==1){break n}if(!d){break l}d=y[f+264|0]|y[f+265|0]<<8;x[31725]=0;d=U(198,k|0,e&65535,Bb(d)|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break n}if(!d){break l}d=z[a+480188>>1];v[f|0]=0;g=de(f+8|0,0,f);x[31725]=0;n=U(373,f+24|0,d|0,g|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break m}i=0;o:while(1){if(Bb(y[f+264|0]|y[f+265|0]<<8)>>>0<=i>>>0){md(n);break l}d=Wb(x[k>>2],e);cf(f+8|0,x[d>>2],x[x[d+48>>2]+12>>2],i);d=0;while(1){if(z[a+480188>>1]<=d>>>0){i=i+1|0;continue o}g=Wc(x[f+8>>2],d);v[f+4|0]=0;x[31725]=0;x[f>>2]=0;S(374,b|0,f|0,l|0);h=x[31725];x[31725]=0;p:{if((h|0)==1){break p}h=x[n>>2];j=y[f|0];if((j-24&255)>>>0<=59){j=j+13|0;v[g|0]=j;r=_b(h,d),s=j,v[r|0]=s}j=y[f+1|0];q:{if(!j){h=_b(h,d);break q}v[g+1|0]=j;h=_b(h,d);v[h+1|0]=j}j=y[h+1|0];h=y[h|0];x[31725]=0;ya(375,a|0,g|0,y[f+2|0],y[f+3|0],0-y[f+69|0]|0,h|0,j|0,f+20|0,f+16|0);h=x[31725];x[31725]=0;if((h|0)==1){break p}h=y[f+4|0];if(h){v[g+2|0]=1;v[g+4|0]=h+1>>>2}d=d+1|0;continue}break}break}d=N()|0;md(n);break h}d=N()|0;break h}d=N()|0;break h}e=e+1|0;continue}}d=N()|0}ub(m);break c}ub(m);break b}d=e|2}w[g>>1]=d;if((h|0)==2){w[g>>1]=d|1;x[m>>2]=l>>>1;x[j>>2]=k>>>1;x[o>>2]=q>>>1}r=i+484410|0,s=Wk(b),w[r>>1]=s;d=JD(b);if(d){hm(m,+(d|0)/96)}v[i+484417|0]=d<<4;n=n+1|0;d=z[a+480190>>1];continue}}d=N()|0;Eb(f+24|0)}Q(d|0);p()}d=1}fb=f+272|0;return d|0}function Roa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-112|0;fb=d;xc(c);a:{b:{c:{d:{if(!op(c,d+100|0)|(y[d+100|0]|y[d+101|0]<<8|(y[d+102|0]<<16|y[d+103|0]<<24))!=1297239878){break d}e=y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24);if(!((e|0)==1482052408|(e|0)==1448293937)&(y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24))!=1146437965){break d}e=fb-32|0;fb=e;j=Nb(d+88|0);e:{f:{g:{h:{i:{while(1){i=x[c+8>>2];g=x[c>>2];x[31725]=0;i=U(152,g|0,i|0,8)|0;g=x[31725];x[31725]=0;if((g|0)==1){break g}if(!i){break h}x[31725]=0;O(833,e+4|0,c|0);i=x[31725];x[31725]=0;if((i|0)!=1){x[31725]=0;O(834,j|0,e+4|0);i=x[31725];x[31725]=0;if((i|0)==1){break i}Gd(e+4|0);continue}break}a=N()|0;break f}a=N()|0;Gd(e+4|0);break f}fb=e+32|0;break e}a=N()|0}ie(j);Q(a|0);p()}x[31725]=0;i=R(170,d+68|0)|0;c=x[31725];x[31725]=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((c|0)!=1){j=Xc(d- -64|0,8,1,1,0);if((y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24))!=1146437965){break q}x[31725]=0;S(743,d+44|0,d+88|0,1296581714);c=x[31725];x[31725]=0;if((c|0)==1){break n}x[31725]=0;S(743,d+24|0,d+88|0,1296318804);c=x[31725];x[31725]=0;if((c|0)==1){break c}c=d+24|0;e=hd(i,c);ub(c);x[31725]=0;c=R(744,d+44|0)|0;h=x[31725];x[31725]=0;f=1;if((h|0)==1){break c}if(!c){break r}c=x[e>>2];x[31725]=0;c=R(174,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}if(!c){break r}x[31725]=0;k=R(283,d+44|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}x[31725]=0;e=R(275,d+44|0)|0;c=x[31725];x[31725]=0;t:{if((c|0)==1){break t}x[31725]=0;P(185,d+44|0,2)|0;c=x[31725];x[31725]=0;if((c|0)==1){break t}x[31725]=0;l=R(283,d+44|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break s}}break c}f=N()|0;break a}x[31725]=0;O(654,d+24|0,d+44|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}c=s_(d+24|0);h=Bb(z[d+24>>1]);if(!h){break r}l=(l>>>0)/(h>>>0)|0;g=d+24|0;h=ec(g);g=af(g);h=Bb(y[h|0]|y[h+1|0]<<8);if((h|0)!=(Bb(y[g|0]|y[g+1|0]<<8)+1|0)){break r}if((h|0)==2){Dp(j,2)}u:{if((e|0)!=16){if((e|0)!=8){break r}v:{switch(Bb(y[c|0]|y[c+1|0]<<8)|0){case 0:yg(j,1);break u;case 2:yg(j,17);break u;case 3:break v;default:break r}}yg(j,16);break u}if(Bb(y[c|0]|y[c+1|0]<<8)){break r}fd(j,16)}f=0}ub(d+44|0);h=0;if(!f){break p}f=0;break j}x[31725]=0;S(743,d+44|0,d+88|0,1447576658);c=x[31725];x[31725]=0;w:{x:{y:{if((c|0)!=1){x[31725]=0;S(743,d+24|0,d+88|0,1128808782);c=x[31725];x[31725]=0;if((c|0)==1){break y}x[31725]=0;S(743,d+4|0,d+88|0,1112491097);c=x[31725];x[31725]=0;if((c|0)==1){break x}c=d+4|0;g=hd(i,c);ub(c);c=x[g>>2];x[31725]=0;e=R(174,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break x}c=0;z:{if(!e){break z}x[31725]=0;e=R(174,x[d+44>>2])|0;c=x[31725];x[31725]=0;if((c|0)==1){break x}c=0;if(!e){break z}x[31725]=0;e=P(745,d+44|0,d+4|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break x}c=0;if(!e){break z}c=y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24);x[31725]=0;l=R(283,d+24|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break x}m=(c|0)!=1482052408;if(m){fd(j,16)}if((l|0)==6){Dp(j,3)}h=$b(x[d+4>>2]);e=x[d+8>>2];c=x[d+12>>2];k=$b(c);A:{B:{if(k>>>0<33){break B}n=$b(e);if(n>>>0<=k>>>0){break B}if(!((n>>>0)%(k>>>0)|0)){break A}}c=e}e=x[g>>2];x[31725]=0;g=x[d+20>>2];n=z[d+16>>1];k=R(156,e|0)|0;e=x[31725];x[31725]=0;o=1;if((e|0)==1){break x}e=m+((l|0)==6)|0;m=h>>>e|0;k=k>>>e|0;h=$b(g);l=Bb(n);c=$b(c)>>>e|0}ub(d+24|0);ub(d+44|0);if(o){break o}break j}f=N()|0;break b}f=N()|0;break w}f=N()|0;ub(d+24|0)}ub(d+44|0);break b}c=0}Vu(a,b);x[31725]=0;f=D(b,104)+a|0;e=f+484380|0;O(281,e|0,0);g=x[31725];x[31725]=0;if((g|0)==1){break m}x[e>>2]=k;c=c+m|0;x[f+484388>>2]=c;x[f+484384>>2]=m;if(!(c>>>0<=m+4>>>0|c>>>0>k>>>0)){c=(D(b,104)+a|0)+484414|0;w[c>>1]=z[c>>1]|2}c=D(b,104)+a|0;x[c+484404>>2]=l>>>0<2?22050:l;g=c+484410|0;c=h+128|0;f=c>>>8|0;w[g>>1]=(c&16776960)>>>0>65536?256:f&65535?f:256;bC(e,x[a+480180>>2]);x[31725]=0;S(743,d+44|0,d+88|0,1312902469);c=x[31725];x[31725]=0;if((c|0)==1){break l}x[31725]=0;c=R(174,x[d+44>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break k}C:{D:{if(c){x[31725]=0;c=R(156,x[d+44>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break k}x[31725]=0;S(333,d+44|0,((b<<5)+a|0)+946304|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break D}break k}x[31725]=0;c=P(36,d+24|0,22255)|0;f=x[31725];x[31725]=0;if((f|0)==1){break C}zc(((b<<5)+a|0)+946304|0,c);tb(c)}x[31725]=0;U(217,j|0,e|0,i|0)|0;b=x[31725];x[31725]=0;f=1;if((b|0)==1){break k}Sj(e,a);ub(d+44|0);break j}break k}f=N()|0;break b}f=N()|0;break b}f=N()|0;break b}f=N()|0;ub(d+44|0);break b}ub(i);ie(d+88|0)}fb=d+112|0;return f|0}f=N()|0;ub(d+44|0)}ub(i)}ie(d+88|0);Q(f|0);p()}function Coa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;i=fb-160|0;fb=i;xc(b);a:{if(!OD(b,i+112|0)){break a}if(!UV(i+112|0)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],Bc(TV(y[i+159|0]),hb))){break a}Bd(a,128);g=i+100|0;We(g,2,i+127|0);d=i+32|0;Cc(d,g);Ab(a+1298308|0,d);tb(d);e=tc(d,8453);Ab(a+1298344|0,e);tb(e);e=tc(d,6056);Ab(a+1298356|0,e);tb(e);g=tc(g,18163);x[31725]=0;S(758,d|0,g|0,x[(y[i+126|0]<<2)+25228>>2]);d=x[31725];x[31725]=0;c:{if((d|0)!=1){d=i+32|0;Ab(a+1298368|0,d);tb(d);tb(g);u=a+1298404|0,A=x[Fc(d,4)>>2],x[u>>2]=A;x[a+480208>>2]=12;gE(a+1298332|0,b,y[i+159|0]<<5,32,0);e=Zd(b);w[a+480190>>1]=e;g=1;while(1){k=g&65535;if(k>>>0>(e&65535)>>>0){jk(Xb(x[a+484360>>2],y[a+484376|0]),b,256,255,254);g=0;d=Zd(b);if(d>>>0>=127){break a}w[a+480188>>1]=d+1;d=Zd(b);while(1)if(z[a+480188>>1]<=g>>>0){o=a+484344|0;r=d+1|0;Vf(o,r);e=0;while(1){d:{f=e&65535;if(f>>>0>d>>>0){e:while(1){t=s&65535;g=z[a+480188>>1];if(t>>>0>=g>>>0){d=Zo(i);v[d+16|0]=0;w[d+14>>1]=0;w[d+12>>1]=g;x[31725]=0;O(760,d|0,g|0);g=x[31725];x[31725]=0;if((g|0)==1){a=N()|0;uf(d);Q(a|0);p()}x[31725]=0;O(759,o|0,d|0);e=x[31725];x[31725]=0;g=1;if((e|0)==1){break d}uf(d);if(!(c&2)){break a}while(1){c=g&65535;if(c>>>0>z[a+480190>>1]){break b}c=D(c,104)+a|0;fg(Xc(i+32|0,w[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);g=g+1|0;continue}}n=0;f=ch(i+32|0);f:while(1){g:{if((n|0)!=(r|0)){if(Mb(x[b>>2],x[b+8>>2],5)){break g}}s=s+1|0;continue e}e=0;d=Wb(x[o>>2],n);g=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,t);while(1){h:{i:{if(e>>>0>63){break i}j=y[i+126|0];h=fb-16|0;fb=h;q=1;d=Zd(b);if((d|0)==252){q=Zd(b);d=Zd(b)}v[f|0]=(d-1&255)>>>0<60?d+36|0:0;d=h+12|0;tm(d,b);l=Jc(d);k=af(d);d=fj(d);v[f+1|0]=y[h+12|0];m=h+10|0;RV(m,y[l|0]&15,y[k|0],j);k=Jc(m);m=h+8|0;RV(m,y[l|0]>>>4|0,y[d|0],j);j=Jc(m);d=y[h+10|0];m=(d|0)!=10;l=y[h+8|0];j:{if(!(m|(l|0)!=10)){k=y[k|0];d=y[j|0];v[f+3|0]=10;k=k|d<<8;v[f+5|0]=k>>>6;if(k>>>0<16384){break j}v[f+2|0]=15;v[f+4|0]=d>>>6;break j}k:{l:{m:{n:{o:{if(!m){l=y[k|0];m=l<<2;u=k,A=zi(m),v[u|0]=A;if(l>>>0<64){break o}d=y[h+8|0];if(yi(d)>>>0>=yi(10)>>>0){break n}v[f+5|0]=m;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=l>>>6;break j}if((l|0)==10){d=y[j|0];l=d<<2;u=j,A=zi(l),v[u|0]=A;if(d>>>0<64){break o}if(yi(y[h+10|0])>>>0>=yi(10)>>>0){break o}v[f+5|0]=l;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=d>>>6;break j}if((d|0)!=(l|0)){break o}v[h+8|0]=0;break m}d=y[h+8|0]}if((d|0)==13){break l}if(d){break k}d=y[h+10|0]}if((d|0)==13){break k}}tg(h+10|0,h+8|0);tg(k,j)}GE(h+8|0,j,h+10|0,k);Hn(h+6|0,f,y[h+10|0],y[k|0],y[h+8|0],y[j|0])}fb=h+16|0;h=e+q|0;e=h>>>0>64?64-e|0:q;if(!e){break i}while(1){if(!e){break h}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[g|0]=d;v[g+1|0]=d>>>8;v[g+2|0]=d>>>16;v[g+3|0]=d>>>24;d=y[f+4|0]|y[f+5|0]<<8;v[g+4|0]=d;v[g+5|0]=d>>>8;e=e-1|0;g=D(z[a+480188>>1],6)+g|0;continue}}n=n+1|0;continue f}e=h>>>0>=64?64:h;continue}}}}e=e+1|0;g=0;if(Ng(o,f,64)){continue}break a}break}e=N()|0;uf(d);break c}else{e=(g<<5)+a|0;Xe(e+480280|0);f=e+480284|0;p:{if(y[i+126|0]>=51){e=(Zd(b)<<4|8)&248;break p}e=g&1?192:64}w[f>>1]=e;g=g+1|0;continue}}else{q:{if(y[i+126|0]>=52){d=i+32|0;if(!y$(b,d)){jE(d)}break q}f=i+32|0;d=fb-32|0;fb=d;x[d+28>>2]=64;x[d+8>>2]=66;h=x[b>>2];j=x[b+8>>2];e=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(h,j,e)){e=lf(b)}h=d+8|0;gw(h,f);j=gc(d+16|0,x[d+8>>2],e);n=x[j>>2];kc(d,x[b>>2],x[b+8>>2],n,x[j+4>>2]);gw(h,f);Tb(x[d+8>>2]+e|0,0,66-e|0);Vb(b,x[d+28>>2]);fb=d+32|0;d=y[i+94|0]|y[i+95|0]<<8;v[i+96|0]=d;v[i+97|0]=d>>>8;v[i+94|0]=171;v[i+95|0]=32}h=fb-32|0;fb=h;f=(D(k,104)+a|0)+484380|0;ld(f,0);np(f);j=h+8|0;e=i+32|0;Rk(j,2,e+32|0);d=h+20|0;Cc(d,j);ze(f+43|0,d);tb(d);d=y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24);j=y[e+52|0]|y[e+53|0]<<8|(y[e+54|0]<<16|y[e+55|0]<<24);r:{if(d>>>0<=j>>>0){break r}x[f>>2]=d-j;x[f+12>>2]=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[h+20>>2]=y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24);u=f,A=x[Gb(h+20|0,f)>>2],x[u+16>>2]=A;w[f+30>>1]=y[e+60|0];x[f+24>>2]=y[e+62|0]|y[e+63|0]<<8;d=y[e+64|0]|y[e+65|0]<<8;if(d){hm(f,+(d<<16>>16)/393216)}d=y[e+61|0];if(d&8){w[f+34>>1]=z[f+34>>1]|8;d=y[e+61|0]}if(d&16){w[f+34>>1]=z[f+34>>1]|16;d=y[e+61|0]}if(!(d&4)){break r}w[f+34>>1]=z[f+34>>1]|1;x[f+12>>2]=x[f+12>>2]>>>1;x[f+16>>2]=x[f+16>>2]>>>1}fb=h+32|0;f=i+20|0;We(f,2,e);d=i+100|0;Cc(d,f);zc(((k<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);e=z[a+480190>>1];continue}}}e=N()|0;tb(g)}Q(e|0);p()}g=1}fb=i+160|0;return g|0}function Vd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=fb-96|0;fb=k;u=i&65535;o=(e^i)&-2147483648;r=e&65535;A=r;R=i>>>16&32767;S=e>>>16&32767;a:{b:{if(R-32767>>>0>4294934529&S-32767>>>0>=4294934530){break b}s=e&2147483647;q=s;j=d;if(!(!d&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){m=d;o=e|32768;break a}s=i&2147483647;p=s;e=h;if(!(!e&(p|0)==2147418112?!(f|g):p>>>0<2147418112)){m=h;o=i|32768;b=f;c=g;break a}if(!(b|j|(q^2147418112|c))){if(!(e|f|(g|p))){o=2147450880;b=0;c=0;break a}o=o|2147418112;b=0;c=0;break a}if(!(e|f|(p^2147418112|g))){e=b|j;d=c|q;b=0;c=0;if(!(d|e)){o=2147450880;break a}o=o|2147418112;break a}if(!(b|j|(c|q))){b=0;c=0;break a}if(!(e|f|(g|p))){b=0;c=0;break a}if((q|0)==65535|q>>>0<65535){j=!(d|r);i=j?b:d;s=j<<6;e=G(i)+32|0;i=G(j?c:r);i=s+((i|0)==32?e:i)|0;bg(k+80|0,b,c,d,r,i-15|0);t=16-i|0;d=x[k+88>>2];A=x[k+92>>2];c=x[k+84>>2];b=x[k+80>>2]}if(p>>>0>65535){break b}i=!(h|u);e=i?f:h;r=i<<6;j=G(e)+32|0;e=G(i?g:u);e=r+((e|0)==32?j:e)|0;bg(k- -64|0,f,g,h,u,e-15|0);t=(t-e|0)+16|0;h=x[k+72>>2];u=x[k+76>>2];f=x[k+64>>2];g=x[k+68>>2]}e=f;f=g<<15|f>>>17;i=e<<15;e=0;v=i&-32768;L=c;s=ova(v,e,c,0);e=hb;z=e;M=f;q=b;b=ova(f,0,b,0);i=b+s|0;f=hb+e|0;c=b>>>0>i>>>0?f+1|0:f;j=0;b=ova(q,l,v,l);p=j+b|0;f=i;e=f+hb|0;e=b>>>0>p>>>0?e+1|0:e;r=e;N=(f|0)==(e|0)&j>>>0>p>>>0|e>>>0<f>>>0;O=d;w=ova(v,l,d,0);P=hb;b=ova(L,l,M,l);y=b+w|0;j=hb+P|0;j=b>>>0>y>>>0?j+1|0:j;b=u<<15|h>>>17;B=h<<15|g>>>17;d=ova(B,0,q,l);C=d+y|0;f=hb+j|0;f=d>>>0>C>>>0?f+1|0:f;D=f;d=(c|0)==(z|0)&i>>>0<s>>>0|c>>>0<z>>>0;E=c+C|0;f=d+f|0;f=c>>>0>E>>>0?f+1|0:f;u=f;g=E;c=f;F=A|65536;A=ova(v,l,F,n);Q=hb;d=ova(O,m,M,l);H=d+A|0;e=hb+Q|0;e=d>>>0>H>>>0?e+1|0:e;i=e;I=b|-2147483648;b=ova(I,0,q,l);J=b+H|0;f=hb+e|0;f=b>>>0>J>>>0?f+1|0:f;b=ova(B,m,L,l);z=b+J|0;K=f;f=f+hb|0;s=b>>>0>z>>>0?f+1|0:f;b=0;q=b+g|0;e=c+z|0;v=b>>>0>q>>>0?e+1|0:e;f=v;b=q+N|0;c=b>>>0<q>>>0?f+1|0:f;t=((S+R|0)+t|0)-16383|0;d=ova(I,m,L,l);h=hb;e=ova(F,m,M,l);g=e+d|0;f=hb+h|0;f=e>>>0>g>>>0?f+1|0:f;n=(h|0)==(f|0)&d>>>0>g>>>0|f>>>0<h>>>0;h=f;e=ova(B,m,O,m);d=e+g|0;f=hb+f|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(f|0)==(h|0)&d>>>0<g>>>0|f>>>0<h>>>0;f=0;h=g;g=g+n|0;f=h>>>0>g>>>0?1:f;h=g;g=ova(I,m,F,m);h=h+g|0;f=hb+f|0;N=h;g=g>>>0>h>>>0?f+1|0:f;h=d;l=e;e=(j|0)==(P|0)&w>>>0>y>>>0|j>>>0<P>>>0;f=0;j=(j|0)==(D|0)&y>>>0>C>>>0|j>>>0>D>>>0;n=j;j=e+j|0;e=(n>>>0>j>>>0?1:f)+l|0;f=g;d=d+j|0;e=d>>>0<j>>>0?e+1|0:e;n=e;w=d;d=(e|0)==(l|0)&d>>>0<h>>>0|e>>>0<l>>>0;e=d;d=d+N|0;f=e>>>0>d>>>0?f+1|0:f;j=d;g=f;e=ova(B,m,F,m);l=hb;d=ova(I,m,O,m);h=d+e|0;f=hb+l|0;f=d>>>0>h>>>0?f+1|0:f;d=f;f=(l|0)==(f|0)&e>>>0>h>>>0|f>>>0<l>>>0;y=d+j|0;e=f+g|0;e=d>>>0>y>>>0?e+1|0:e;l=y;g=e;e=0;d=e+w|0;f=h+n|0;f=d>>>0<e>>>0?f+1|0:f;e=f;h=(n|0)==(f|0)&d>>>0<w>>>0|f>>>0<n>>>0;f=g;g=h+l|0;f=g>>>0<h>>>0?f+1|0:f;w=g;g=f;h=d;j=e;e=(s|0)==(K|0)&z>>>0<J>>>0|s>>>0<K>>>0;d=(i|0)==(Q|0)&A>>>0>H>>>0|i>>>0<Q>>>0;i=(i|0)==(K|0)&H>>>0>J>>>0|i>>>0>K>>>0;d=d+i|0;d=d+e|0;n=s;i=n+h|0;e=d+j|0;f=g;d=i;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(j|0)&h>>>0>d>>>0|e>>>0<j>>>0;g=h+w|0;f=h>>>0>g>>>0?f+1|0:f;j=g;g=f;h=d;f=0;i=e;n=(u|0)==(v|0)&q>>>0<E>>>0|u>>>0>v>>>0;l=n;n=n+((u|0)==(D|0)&C>>>0>E>>>0|u>>>0<D>>>0)|0;e=e+(l>>>0>n>>>0?1:f)|0;f=g;d=d+n|0;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(i|0)&d>>>0<h>>>0|e>>>0<i>>>0;g=h;h=h+j|0;f=g>>>0>h>>>0?f+1|0:f;i=f;c:{if(f&65536){t=t+1|0;break c}j=r>>>31|0;g=0;f=i<<1|h>>>31;h=h<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;f=r<<1|p>>>31;p=p<<1;r=f;f=c<<1|b>>>31;b=b<<1|j;c=f|g}if((t|0)>=32767){o=o|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){g=1-t|0;if(g>>>0<=127){f=t+127|0;bg(k+48|0,p,r,b,c,f);bg(k+32|0,d,e,h,i,f);gn(k+16|0,p,r,b,c,g);gn(k,d,e,h,i,g);p=x[k+32>>2]|x[k+16>>2]|(x[k+48>>2]|x[k+56>>2]|(x[k+52>>2]|x[k+60>>2]))!=0;r=x[k+36>>2]|x[k+20>>2];b=x[k+40>>2]|x[k+24>>2];c=x[k+44>>2]|x[k+28>>2];d=x[k>>2];e=x[k+4>>2];g=x[k+8>>2];f=x[k+12>>2];break d}b=0;c=0;break a}g=h;f=i&65535|t<<16}m=g|m;o=f|o;if(!(!b&(c|0)==-2147483648?!(p|r):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;e=o;c=j;d=!(j|b);m=d+m|0;o=d>>>0>m>>>0?e+1|0:e;break a}if(b|p|(c^-2147483648|r)){b=d;c=e;break a}f=e;b=d&1;c=b;b=b+d|0;f=c>>>0>b>>>0?f+1|0:f;c=f;d=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;f=o;m=d+m|0;o=m>>>0<d>>>0?f+1|0:f}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=m;x[a+12>>2]=o;fb=k+96|0}function WS(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-16|0;fb=h;a:{if(!Tc(d&255)){break a}m=a+1074376|0;j=(m+D(b,872)|0)+616|0;b:{g=z[a+480192>>1];if(!(!(x[a+480180>>2]&17825824)|!g|e)){break b}if(Lj(x[j+656>>2])){break b}c=D(b,872)+a|0;d=c+1075068|0;if(!x[d>>2]){break a}c=x[c+1075080>>2];if(c&1024){break a}e=D(b,872)+a|0;g=e+1075012|0;e=e+1075016|0;if(!(x[g>>2]|x[e>>2])){break a}c:{if(!(c&512)){break c}c=x[a+1298300>>2];if(!Dd(c)){break c}Oj(c,b,0);break a}c=dB(a,b);if((c|0)==65535){break a}i=D(c,872);c=a+1074992|0;a=i+c|0;Mq(a,j);v[a+831|0]=0;v[a+805|0]=0;w[a+786>>1]=b+1;x[a+88>>2]=x[a+88>>2]&-918529;ap(a+788|0);x[a+696>>2]=0;x[a+88>>2]=x[a+88>>2]|2101248;x[d>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=c+D(b,872)|0;x[a+92>>2]=0;x[a+96>>2]=0;x[g>>2]=0;x[e>>2]=0;break a}e=D(b,872)+a|0;l=x[e+1075096>>2];c=c>>>0<=g>>>0?c:0;g=x[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}k=d-1|0;c=z[_b(g+236|0,k)>>1];f=a+1074312|0;Jb(h+8|0,f,104);e:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){Jb(h,f,34);if(Hb(x[x[h>>2]>>2],x[h+4>>2])){break e}}d=y[xb(g+108|0,k)|0]}if((c-1&65535)>>>0<=3998){l=(D(c,104)+a|0)+484380|0;break d}Jb(h+8|0,f,43);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break d}if(!Tj(y[g+31|0])){break a}}if(y[e+1075081|0]&4){break a}o=b>>>0<=256?256:b;k=a+1074312|0;p=b+1|0;c=b;f:{while(1){if((c|0)==(o|0)){g:{e=0;c=0;if(!Lj(x[j+656>>2])){break f}c=0;if(!Tc(y[(D(b,872)+a|0)+1075789|0])){break f}d=wm(a,m,b,2,1)-1|0;c=0;if((d&255)>>>0>249){break f}e=x[vd(a+906300|0,d)>>2];if(e){break g}e=0;c=0;break f}}else{f=(b|0)==(c|0);h:{if(!f&z[a+480188>>1]>c>>>0){break h}e=D(c,872)+a|0;if(!f&z[e+1075778>>1]!=(p|0)){break h}n=e+1075648|0;f=x[n>>2];if(!f){break h}i:{j:{k:{l:{m:{n:{o:{switch(y[f+17|0]-1|0){case 0:if(!d){break h}i=(f|0)==(g|0)&y[e+1075789|0]==(d|0);if(!g){break n}if(i){break k}break h;case 1:if(!l|x[e+1075096>>2]!=(l|0)){break h}if((f|0)==(g|0)){break i}Jb(h+8|0,k,104);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break i}break h;case 3:break m;case 2:break o;default:break h}}if(g){break l}i=(f|0)==(g|0)}if(i){break i}break h}if(!g){break h}i=y[g+34|0];if(!i){break h}if((i|0)==y[f+34|0]){break j}break h}if((f|0)!=(g|0)){break h}}if(!y[g+34|0]){break i}}if(!y[e+1075789|0]|y[f+18|0]>2){break i}f=e+1075793|0;i=y[f|0];if(!i){break i}dn(a,c&65535,i|256,0);v[f|0]=0}f=e+1074992|0;p:{q:{switch(y[x[n>>2]+18|0]){case 0:Lo(a,f);x[e+1075680>>2]=0;if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!Dd(f)){break p}Oj(f,c&65535,1);break p;case 1:Lo(a,f);if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!Dd(f)){break p}Gk(f,c&65535);break p;case 2:break q;default:break p}}i=e+1075080|0;f=x[i>>2];x[i>>2]=f|4096;if(!(f&512)){break p}if(!Dd(x[a+1298300>>2])){break p}Jb(h+8|0,k,105);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break p}Gk(x[a+1298300>>2],c&65535)}if(x[e+1075680>>2]){break h}x[e+1075688>>2]=0;e=e+1075080|0;x[e>>2]=x[e>>2]|2101248}c=c+1|0;continue}break}d=y[(D(b,872)+a|0)+1075793|0];c=0;if(!d){break f}c=ib[x[x[e>>2]+104>>2]](e,d,b)|0}if(!(Ui(x[j+8>>2],x[j+12>>2])|c)){break a}r:{if(!e|c^1){break r}c=y[(D(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break r}dn(a,b,255,0);w[(D(b,872)+a|0)+1075792>>1]=0}c=dB(a,b);if((c|0)==65535){break a}f=D(c,872);e=f+a|0;d=e+1075080|0;g=e+1074992|0;s:{if(!(y[e+1075081|0]&2)){break s}e=x[a+1298300>>2];if(!Dd(e)){break s}Oj(e,c,1)}l=Mq(g,j);e=x[d>>2];g=e&-917505;x[d>>2]=g;i=a+1074992|0;f=i+f|0;v[f+831|0]=0;m=z[a+480188>>1];v[f+805|0]=0;w[f+786>>1]=b>>>0<m>>>0?b+1|0:0;t:{u:{switch(y[(i+D(b,872)|0)+798|0]){case 2:Lo(a,l);if(!(y[d+1|0]&2)){break t}e=x[a+1298300>>2];if(!Dd(e)){break t}Gk(e,b);Jb(h+8|0,k,105);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break t}TB(x[a+1298300>>2],b,c);break t;case 0:x[(D(c,872)+a|0)+1075688>>2]=0;x[d>>2]=g|4096;if(!(e&512)){break t}e=x[a+1298300>>2];if(!Dd(e)){break t}Oj(e,b,1);break t;case 3:x[d>>2]=g|4096;if(!(e&512)){break t}if(!Dd(x[a+1298300>>2])){break t}Jb(h+8|0,k,105);e=x[a+1298300>>2];if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){TB(e,b,c);break t}Gk(e,b);break t;case 1:break u;default:break t}}if(!(e&512)){break t}e=x[a+1298300>>2];if(!Dd(e)){break t}TB(e,b,c)}c=D(c,872)+a|0;if(!x[c+1075680>>2]){x[c+1075688>>2]=0;x[d>>2]=x[d>>2]|2101248}a=D(b,872)+a|0;x[a+1075068>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=a+1075084|0;x[a>>2]=0;x[a+4>>2]=0}fb=h+16|0}function bqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-128|0;fb=g;xc(b);a:{b:{c:{d:{e:{if(!NX(b,14147)){break e}k=Nb(g+116|0);j=Nb(g+104|0);x[31725]=0;x[g+96>>2]=0;x[g+100>>2]=0;O(248,a|0,32768);d=x[31725];x[31725]=0;if((d|0)==1){break b}x[31725]=0;d=P(1,g+84|0,8169)|0;i=x[31725];x[31725]=0;if((i|0)==1){break c}Ab(a+1298344|0,d);tb(d);x[31725]=0;d=P(1,g+72|0,6060)|0;i=x[31725];x[31725]=0;if((i|0)==1){break d}Ab(a+1298356|0,d);tb(d);n=a+1298404|0,o=x[Fc(g+44|0,28)>>2],x[n>>2]=o;i=a+480280|0;while(1){d=x[b+8>>2];f=x[b>>2];x[31725]=0;d=U(152,f|0,d|0,8)|0;f=x[31725];x[31725]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}x[31725]=0;d=P(653,b|0,g- -64|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break m}if(!d){break n}d=x[g+68>>2];x[31725]=0;S(187,g+24|0,b|0,$b(d)|0);d=x[31725];x[31725]=0;if((d|0)==1){break l}d=g+24|0;f=ic(g+44|0,d);ub(d);d=x[f>>2];x[31725]=0;d=R(174,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}if(d){break k}ub(f)}if(z[a+480188>>1]){break i}i=0;break g}a=N()|0;break a}a=N()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=$b(x[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(z[a+480188>>1]){break f}d=x[f>>2];x[31725]=0;d=R(156,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;x[31725]=0;O(654,g+24|0,f|0);e=x[31725];x[31725]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}i=1;break o}else{h=_b(g+24|0,d);e=z[a+480188>>1];v:{if(!Bb(y[h|0]|y[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+96|0;n=xb(h,e),o=1,v[n|0]=o;n=xb(h,z[a+480188>>1]+1|0),o=255,v[n|0]=o;Xe(i+(z[a+480188>>1]<<5)|0);h=z[a+480188>>1];e=h+1|0;w[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;w[l+4>>1]=h>>>0<2?192:64}Xe(i+((e&65535)<<5)|0);e=z[a+480188>>1];w[a+480188>>1]=e+1;w[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(z[a+480190>>1]){break f}x[31725]=0;O(655,f|0,a|0);d=x[31725];x[31725]=0;if((d|0)!=1){break f}break j}d=x[f>>2];x[31725]=0;d=R(156,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[31725]=0;d=R(275,f|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}n=a,o=Kd(d,1,255),x[n+480196>>2]=o;break f}d=x[f>>2];x[31725]=0;d=R(156,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[31725]=0;m=R(275,f|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break f}break j}d=y[a+484376|0];e=x[a+484360>>2];h=x[f>>2];x[31725]=0;h=R(156,h|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break j}x[31725]=0;aa(350,Xb(e,d)|0,f|0,h|0,255,254);d=x[31725];x[31725]=0;if((d|0)==1){break j}break f}d=k;if(Uf(x[d>>2],x[d+4>>2])>>>0>=256){break f}break q}if(Uf(x[j>>2],x[j+4>>2])>>>0>3998){break f}d=x[f>>2];x[31725]=0;e=R(156,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break j}d=j;if(!e){break f}}x[31725]=0;O(656,d|0,f|0);d=x[31725];x[31725]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}ub(f);break g}a=N()|0;ub(f);break a}x[a+480200>>2]=256;x[a+480204>>2]=125e4;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480228>>2]=48;x[a+480232>>2]=48;b=x[a+484360>>2];d=y[a+484376|0];x[31725]=0;O(332,Xb(b,d)|0,m&65535);b=x[31725];x[31725]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=x[k+4>>2];i=x[k>>2];d=0;x[31725]=0;O(225,a+484344|0,Uf(i,b)&65535);b=x[31725];x[31725]=0;if((b|0)==1){break b}while(1){e=x[k>>2];b=d&65535;if(Uf(e,x[k+4>>2])>>>0<=b>>>0){break w}x[31725]=0;i=x[g+100>>2];f=x[g+96>>2];x[g+16>>2]=f;x[g+20>>2]=i;x[g+8>>2]=f;x[g+12>>2]=i;V(657,eh(e,b)|0,b|0,a|0,g+8|0);b=x[31725];x[31725]=0;if((b|0)!=1){d=d+1|0;continue}break}a=N()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(z[a+480190>>1]<=d>>>0){break g}if(!f|Uf(x[j>>2],x[j+4>>2])>>>0<=b>>>0){break g}c=(D(d,104)+a|0)+484380|0;Ep(c);x:{if(x[c>>2]){e=x[eh(x[j>>2],b)>>2];x[31725]=0;e=R(156,e|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break h}wc(c,e);e=Xc(g+44|0,8,1,1,0);h=x[j>>2];x[31725]=0;U(217,e|0,c|0,eh(h,b)|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}Qc(j);Qc(k);break e}ub(f);continue}}fb=g+128|0;return i|0}a=N()|0;break a}a=N()|0;break a}a=N()|0}Qc(j);Qc(k);Q(a|0);p()}function j1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-80|0;fb=e;xc(b);a:{if(!Tr(b,11774)){break a}if(!vw(b,e+69|0)){break a}if(!NE(y[e+70|0])){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(ME(e+69|0),hb))){break a}if(!Vb(b,y[e+78|0]|y[e+79|0]<<8)){break a}b:{if(!c){break b}Bd(a,4096);x[a+480208>>2]=12;w[a+480188>>1]=(y[e+71|0]&31)+1;w[a+480190>>1]=y[e+72|0];Yh(a,1);d=e+20|0;i=tc(d,8476);Ab(a+1298344|0,i);tb(i);i=tc(d,7105);Ab(a+1298356|0,i);tb(i);i=fb-16|0;fb=i;f=tc(i+4|0,4247);_c(e,f);tb(f);fb=i+16|0;x[31725]=0;V(231,d|0,e|0,y[e+70|0],e+69|0);d=x[31725];x[31725]=0;c:{if((d|0)!=1){d=e+20|0;Ab(a+1298368|0,d);tb(d);Eb(e);l=a+1298404|0,m=x[Fc(d,4)>>2],x[l>>2]=m;d=y[e+72|0];i=e+56|0;x[i>>2]=0;x[i+4>>2]=0;Fc(i+8|0,0);if(d){$r(i,d);LF(i,d,0)}d=1;d:{while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){x[31725]=0;P(232,b|0,a+1298308|0)|0;f=x[31725];x[31725]=0;d=1;e:{if((f|0)==1){break e}while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){d=0;f:{while(1){if(z[a+480188>>1]<=d>>>0){d=0;x[31725]=0;f=a+484344|0;O(225,f|0,y[e+73|0]|y[e+74|0]<<8);g=x[31725];x[31725]=0;if((g|0)==1){break e}break f}f=(d<<5)+a|0;Xe(f+480280|0);x[31725]=0;O(233,b|0,f+480289|0);f=x[31725];x[31725]=0;if((f|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}g:{h:{i:{j:{while(1){if((y[e+73|0]|y[e+74|0]<<8)>>>0<=d>>>0){x[31725]=0;g=R(191,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break h}if(!g){break i}d=x[b+8>>2];f=x[b>>2];x[31725]=0;d=U(152,f|0,d|0,g|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break h}if(d){break j}break i}x[31725]=0;g=P(234,b|0,e+20|0)|0;h=x[31725];x[31725]=0;k:{if((h|0)==1){break k}x[31725]=0;h=U(198,f|0,d&65535,64)|0;j=x[31725];x[31725]=0;if((j|0)==1){break k}if((g&h)==1){g=x[f>>2];x[31725]=0;O(235,Wb(g,d)|0,e+20|0);g=x[31725];x[31725]=0;if((g|0)==1){break k}}d=d+1|0;continue}break}b=N()|0;break d}f=Nb(e+20|0);x[31725]=0;S(236,b|0,f|0,g|0);d=x[31725];x[31725]=0;l:{if((d|0)!=1){d=Fb(e);x[31725]=0;O(116,d|0,g|0);g=x[31725];x[31725]=0;m:{if((g|0)==1){break m}l=e,m=wb(x[f>>2]),x[l+40>>2]=m;h=wb(x[f+4>>2]);while(1){n:{g=x[e+40>>2];if(!Ib(g,h)){x[31725]=0;S(237,e+40|0,20,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break n}h=e+40|0;g=Ab(d,h);tb(h);h=Kb(g);j=y[g+11|0];k=x[g+4>>2];x[31725]=0;aa(238,a+1298332|0,h|0,Yc(k,j)|0,76,0);h=x[31725];x[31725]=0;if((h|0)==1){break m}tb(g);dc(f);break i}o:{g=v[g|0];if((g|0)<0){j=x[vb(e+52|0,Df(d))>>2];x[31725]=0;V(239,d|0,j|0,g&127,32);g=x[31725];x[31725]=0;if((g|0)!=1){break o}break m}x[31725]=0;O(117,d|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){break o}break m}me(e+40|0);continue}break}}b=N()|0;tb(d);break l}b=N()|0}dc(f);break d}d=y[a+484376|0];f=x[a+484360>>2];x[31725]=0;S(240,Xb(f,d)|0,b|0,y[e+75|0]|y[e+76|0]<<8);d=x[31725];x[31725]=0;if((d|0)==1){break h}g=c&1;d=0;while(1){p:{q:{if((y[e+73|0]|y[e+74|0]<<8)>>>0>d>>>0){f=x[b+8>>2];h=x[b>>2];x[31725]=0;f=U(152,h|0,f|0,4)|0;h=x[31725];x[31725]=0;if((h|0)==1){break p}if(f){break q}}if(!(c&2)){break g}d=1;while(1){c=d&65535;if(c>>>0>z[a+480190>>1]){break g}f=D(c,104)+a|0;g=z[f+484414>>1];Jb(e+20|0,x[i>>2],c-1|0);c=Xc(e,g&1?16:8,1,0,Hb(x[x[e+20>>2]>>2],x[e+24>>2])?6:0);x[31725]=0;U(217,c|0,f+484380|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}x[31725]=0;f=R(153,b|0)|0;h=x[31725];x[31725]=0;r:{s:{if((h|0)!=1){x[31725]=0;S(187,e|0,b|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break s}f=ic(e+20|0,e);ub(e);if(!g){break r}h=x[a+484344>>2];if(!He(h,x[a+484348>>2],d&65535)){break r}x[31725]=0;S(241,Wb(h,d)|0,0,f|0);h=x[31725];x[31725]=0;if((h|0)!=1){break r}b=N()|0;ub(f);break d}b=N()|0;break d}b=N()|0;break d}ub(f);d=d+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}uf(i);break b}x[31725]=0;P(242,b|0,((f<<5)+a|0)+946304|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}x[31725]=0;O(243,b|0,e+20|0);g=x[31725];x[31725]=0;t:{if((g|0)==1){break t}x[31725]=0;O(244,e+20|0,(D(f,104)+a|0)+484380|0);g=x[31725];x[31725]=0;if((g|0)==1){break t}g=y[e+36|0];Jb(e,x[i>>2],f-1|0);Jf(e,(g&3)!=0);d=d+1|0;continue}break}b=N()|0}uf(i);break c}b=N()|0;Eb(e)}Q(b|0);p()}d=1}fb=e+80|0;return d|0}function yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,q=0;d=fb-80|0;fb=d;g=-1;a:{b:{c:{d:{if(x[(x[x[b>>2]-12>>2]+b|0)+16>>2]){break d}$d(d- -64|0,b);e=x[d+72>>2];f=x[d+76>>2];k=d+56|0;gl(k);b=Ej(b,k,8);if((y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24))!=1414681667|(y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24))!=776101705){Ii(b,e,f,0);break d}w[d+54>>1]=0;pg(b,d+54|0);k=w[d+54>>1];if((k-4&65535)>>>0<65534){break d}e=d+46|0;gl(e);e=Ej(b,e,8);if((y[d+46|0]|y[d+47|0]<<8|(y[d+48|0]<<16|y[d+49|0]<<24))!=1933333571|(y[d+50|0]|y[d+51|0]<<8|(y[d+52|0]<<16|y[d+53|0]<<24))!=1111389030){break d}w[d+44>>1]=0;pg(e,d+44|0);f=w[d+44>>1];if((f-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{if(f>>>0<=3){b=Fb(d- -64|0);x[31725]=0;h=U(497,e|0,b|0,65535)|0;l=x[31725];x[31725]=0;if((l|0)==1){break b}if(!h){break i}x[31725]=0;S(498,d+32|0,c|0,b|0);h=x[31725];x[31725]=0;if((h|0)!=1){break j}break b}b=Fb(d- -64|0);x[31725]=0;h=P(500,e|0,b|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break c}if(!h){break h}x[31725]=0;S(498,d+32|0,c|0,b|0);h=x[31725];x[31725]=0;if((h|0)==1){break c}}h=d+32|0;Ab(a+40|0,h);tb(h);tb(b);w[d+30>>1]=0;pg(e,d+30|0);w[d+28>>1]=0;pg(e,d+28|0);w[a>>1]=z[d+28>>1];w[d+26>>1]=0;k:{if((f|0)<=3){x[d+64>>2]=0;Ok(e,d- -64|0);b=x[d+64>>2];if(b>>>0>65535){break d}b=lm(b);w[d+26>>1]=b;break k}pg(e,d+26|0);b=z[d+26>>1]}h=a+52|0;l=b&65535;n=(f|0)>3;b=0;l:{m:{while(1){if(l>>>0<=(b&65535)>>>0){break l}f=Fb(d- -64|0);x[31725]=0;w[d+8>>1]=0;O(940,e|0,d+8|0);i=x[31725];x[31725]=0;if((i|0)==1){break g}n:{if(!n){x[31725]=0;i=U(497,e|0,f|0,65535)|0;j=x[31725];x[31725]=0;if((j|0)==1){break g}if(i){break n}break e}x[31725]=0;i=P(500,e|0,f|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break g}if(!i){break e}}x[31725]=0;S(498,d+32|0,c|0,f|0);i=x[31725];x[31725]=0;if((i|0)!=1){x[31725]=0;i=P(937,h|0,d+8|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break m}j=i;i=d+32|0;Ab(j,i);tb(i);tb(f);b=b+1|0;continue}break}g=N()|0;break f}g=N()|0;tb(d+32|0);break f}b=d+32|0;gl(b);b=Ej(e,b,8);if((y[d+32|0]|y[d+33|0]<<8|(y[d+34|0]<<16|y[d+35|0]<<24))!=1933333571|(y[d+36|0]|y[d+37|0]<<8|(y[d+38|0]<<16|y[d+39|0]<<24))!=1161720678){break d}c=z[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;o:{if((k|0)<=2){if(cR(b,c)){break o}break d}if(!bR(b,c)){break d}}o=d,q=wb(x[a+4>>2]),x[o+64>>2]=q;c=wb(x[a+8>>2]);while(1){e=x[d+64>>2];if(Ib(e,c)){if(!an(B[e>>2])){break d}Je(d- -64|0);continue}break}c=a+16|0;p:{if((k|0)<=2){if(cR(b,c)){break p}break d}if(!bR(b,c)){break d}}o=d,q=wb(x[a+16>>2]),x[o+64>>2]=q;c=wb(x[a+20>>2]);while(1){e=x[d+64>>2];if(Ib(e,c)){if(!an(B[e>>2])){break d}Je(d- -64|0);continue}break}o=a,q=oc(x[a+16>>2],x[a+20>>2]),x[o+36>>2]=q;w[d+24>>1]=0;pg(b,d+24|0);c=z[d+24>>1];w[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}w[d+22>>1]=0;pg(b,d+22|0);c=w[d+22>>1];w[a+30>>1]=c;if((c|0)<0){break d}x[d+16>>2]=0;Dq(b,d+16|0);m=fR(B[d+16>>2]);B[a+32>>2]=m;if(!an(m)){break d}x[d+8>>2]=0;x[d+12>>2]=0;c=fb-32|0;fb=c;e=d+8|0;fl(c+16|0,e);Sm(c+24|0,b,x[c+16>>2],x[c+20>>2]);fl(c+8|0,e);fb=c+32|0;if(x[d+8>>2]!=1414681667|x[d+12>>2]!=776298313){break d}b=oc(x[a+4>>2],x[a+8>>2]);if(b>>>0>32767){break d}c=w[a+30>>1];e=z[a>>1];if(!(e?!(B[a+32>>2]<=E(0))&(c|0)>0:1)){break d}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break d}break;default:break q}}b=0;c=x[a+36>>2];if(c){b=c-1|0;x[a+36>>2]=b}o=d,q=vh(b),x[o+64>>2]=q;x[d+4>>2]=0;o=a,q=x[hk(d- -64|0,d+4|0,42288)>>2],x[o+36>>2]=q;Eq(a);g=1;if(z[a>>1]!=3){break d}c=w[a+30>>1];if((c-w[a+28>>1]|0)>(mR(oc(x[a+4>>2],x[a+8>>2]))|0)){break d}g=a+32|0;e=Nb(d- -64|0);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=z[a+28>>1];w[d+4>>1]=b;o=d,q=(oc(x[a+4>>2],x[a+8>>2])+b|0)-1|0,w[o+6>>1]=q;x[31725]=0;w[d+2>>1]=0;ha(935,a|0,e|0,g|0,d+4|0,d+2|0)|0;a=x[31725];x[31725]=0;g=1;if((a|0)==1){break r}uc(e);break d}c=w[a+28>>1];f=x[a+4>>2];x[31725]=0;O(941,e|0,yb(f,b-c|0)|0);c=x[31725];x[31725]=0;if((c|0)!=1){b=b+1|0;c=z[a+30>>1];continue}}break}g=N()|0;uc(e);break a}tb(b);break d}tb(b);break d}g=N()|0}tb(f);break a}tb(f)}fb=d+80|0;return g|0}g=N()|0;tb(b);break a}g=N()|0;tb(b)}Q(g|0);p()}function Ws(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-592|0;fb=e;x[e+572>>2]=6;x[e+576>>2]=364;x[e+564>>2]=11;x[e+568>>2]=161;x[e+556>>2]=23;x[e+560>>2]=31;x[e+548>>2]=59;x[e+552>>2]=55;x[e+584>>2]=0;x[e+588>>2]=0;x[e+580>>2]=-1;v[e+446|0]=c;v[e+445|0]=37;v[e+447|0]=0;f=e+448|0;fa(f|0,100,e+445|0,e+548|0,x[b>>2])|0;h=e+32|0;x[e+28>>2]=h;x[e+16>>2]=0;x[e+20>>2]=0;x[e+12>>2]=f;h=Hi(h,e+12|0,100,e+16|0,x[b>>2]);if((h|0)!=-1){l=b+484|0;i=b+460|0;j=b+172|0;k=b+4|0;f=e+32|0;h=f+(h<<2)|0;g=Fb(a);m=(c|0)!=120;a:while(1){b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=(h|0)){a=x[f>>2];x[31725]=0;a=U(1249,d|0,1,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}if(a){x[31725]=0;O(35,g|0,32);a=x[31725];x[31725]=0;if((a|0)==1){break c}while(1){f=f+4|0;if((h|0)==(f|0)){f=h;break b}a=x[f>>2];x[31725]=0;a=U(1249,d|0,1,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}if(a){continue}break}break b}x[e+8>>2]=f;x[31725]=0;x[e+4>>2]=0;a=ea(1359,e+8|0,h|0,k|0,j|0,d|0,e+4|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}p:{a=a-k|0;q:{if((a|0)<=167){x[31725]=0;O(35,g|0,37);c=x[31725];x[31725]=0;if((c|0)==1){break c}x[31725]=0;O(35,g|0,((a|0)<84?65:97)|0);a=x[31725];x[31725]=0;if((a|0)!=1){break q}break c}x[31725]=0;x[e+8>>2]=f;a=ea(1359,e+8|0,h|0,j|0,i|0,d|0,e+4|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}a=a-j|0;c=(a|0)/12|0;if((a|0)<=287){x[31725]=0;O(35,g|0,37);f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;O(35,g|0,((a|0)<144?66:98)|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}if(m){break q}a=x[Wd((D(c,12)+b|0)+172|0,0)>>2];x[31725]=0;a=U(1249,d|0,64,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}if(!a){break q}n=(Kb(g)+(Cb(x[g+4>>2],y[g+11|0])<<2)|0)-4|0,o=109,x[n>>2]=o;break q}if((Cb(x[b+464>>2],y[b+471|0])|0)==(0-Cb(x[b+476>>2],y[b+483|0])|0)){break p}x[31725]=0;x[e+8>>2]=f;a=ea(1359,e+8|0,h|0,i|0,l|0,d|0,e+4|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}if((a-i|0)>23){break p}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;O(35,g|0,112);a=x[31725];x[31725]=0;if((a|0)==1){break c}}f=x[e+8>>2];break b}x[e+8>>2]=f;a=x[f>>2];x[31725]=0;a=U(1249,d|0,64,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}if(a){x[31725]=0;a=ba(1360,e+28|0,h|0,e+4|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}r:{s:{switch(a-6|0){case 2:case 3:case 4:break r;case 0:break e;case 1:break f;case 5:break g;case 6:break h;default:break s}}t:{switch(a-55|0){case 0:break k;case 4:break l;case 6:break m;case 1:case 2:case 3:case 5:break r;default:break t}}if((a|0)==23){break i}if((a|0)==31){break j}if((a|0)==364){break n}if((a|0)==2061){break o}}a=x[e+28>>2];while(1){if((a|0)==(f|0)){f=a;continue a}c=x[f>>2];x[31725]=0;O(35,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}f=f+4|0;continue}}a=x[f>>2];x[31725]=0;a=P(1361,d|0,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}u:{if((a|0)==37){x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;O(35,g|0,37);break u}a=x[f>>2];x[31725]=0;O(35,g|0,a|0)}a=x[31725];x[31725]=0;if((a|0)==1){break c}f=f+4|0;break b}fb=e+592|0;return}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=89;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=106;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=121;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=83;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=77;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=100;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=72;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=109;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=73;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=117;break d}x[31725]=0;O(35,g|0,37);a=x[31725];x[31725]=0;c=119}if((a|0)==1){break c}x[31725]=0;O(35,g|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}f=x[e+28>>2];continue}a=N()|0;Qb(g);Q(a|0);p()}x[e+28>>2]=f;continue}}ko(12661);p()}function Eja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;d=fb-304|0;fb=d;e=-1;a:{b:{c:{if(!xk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){b=Qm(d+192|0,b);x[31725]=0;e=P(463,d+180|0,14001)|0;f=x[31725];x[31725]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){x[31725]=0;x[d+160>>2]=83886084;x[d+164>>2]=0;S(464,b|0,e|0,d+160|0);f=x[31725];x[31725]=0;if((f|0)==1){break A}Eb(e);v[d+179|0]=0;x[31725]=0;e=P(463,d+160|0,14728)|0;f=x[31725];x[31725]=0;if((f|0)==1){break z}x[31725]=0;S(465,b|0,d+179|0,e|0);f=x[31725];x[31725]=0;if((f|0)==1){break y}Eb(e);e=Fc(d+156|0,y[d+179|0]?0:c);x[31725]=0;c=P(463,d+144|0,15844)|0;f=x[31725];x[31725]=0;if((f|0)==1){break x}f=x[e>>2];x[31725]=0;V(929,b|0,a+40|0,c|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break w}Eb(c);w[d+142>>1]=65535;x[31725]=0;c=P(463,d+128|0,15528)|0;f=x[31725];x[31725]=0;if((f|0)==1){break v}x[31725]=0;U(493,b|0,d+142|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break u}Eb(c);w[d+126>>1]=0;x[31725]=0;c=P(463,d+112|0,15368)|0;f=x[31725];x[31725]=0;if((f|0)==1){break t}x[31725]=0;U(493,b|0,d+126|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break s}Eb(c);w[a>>1]=z[d+126>>1];x[31725]=0;c=P(463,d+100|0,15041)|0;f=x[31725];x[31725]=0;if((f|0)==1){break r}e=x[e>>2];x[31725]=0;V(930,b|0,a+52|0,c|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break q}Eb(c);x[31725]=0;c=P(463,d+88|0,14989)|0;e=x[31725];x[31725]=0;if((e|0)==1){break p}x[31725]=0;S(919,b|0,a+36|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break o}Eb(c);x[31725]=0;c=P(463,d+76|0,15530)|0;e=x[31725];x[31725]=0;if((e|0)==1){break n}x[31725]=0;h=a+4|0;S(931,b|0,h|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break m}Eb(c);x[31725]=0;c=P(463,d- -64|0,15370)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}x[31725]=0;f=a+28|0;S(932,b|0,f|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break k}Eb(c);x[31725]=0;c=P(463,d+52|0,15225)|0;e=x[31725];x[31725]=0;if((e|0)==1){break j}x[31725]=0;S(932,b|0,a+30|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break i}Eb(c);x[31725]=0;c=P(463,d+40|0,15013)|0;e=x[31725];x[31725]=0;if((e|0)==1){break h}x[31725]=0;S(933,b|0,a+32|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break g}Eb(c);w[d+38>>1]=0;x[31725]=0;c=P(463,d+24|0,14968)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}x[31725]=0;U(493,b|0,d+38|0,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break f}Eb(c);i=fR(B[a+32>>2]);B[a+32>>2]=i;e=-1;if(!an(i)){break d}k=d,l=wb(x[a+4>>2]),x[k+20>>2]=l;c=wb(x[a+8>>2]);while(1){g=x[d+20>>2];if(!Ib(g,c)){break e}if(!an(B[g>>2])){break d}Je(d+20|0);continue}}a=N()|0;break a}a=N()|0;Eb(e);break a}a=N()|0;break a}a=N()|0;Eb(e);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;Eb(c);break a}if(wl(y[b|0])){break d}c=z[f>>1];if((c-301&65535)>>>0<64935){break d}g=z[a>>1];if(g>>>0>3|(g|0)==2){break d}j=w[a+30>>1];if((j|0)<0){break d}k=d,l=vh(x[a+36>>2]),x[k+20>>2]=l;x[d+16>>2]=0;k=a,l=x[hk(d+20|0,d+16|0,42288)>>2],x[k+36>>2]=l;if(oc(x[a+4>>2],x[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=w[d+38>>1];if((f|0)<=0){break d}w[d+14>>1]=j;B[d+20>>2]=B[a+32>>2];x[31725]=0;w[d+16>>1]=c;w[d+18>>1]=(c+f|0)-1;a=ba(934,a|0,d+14|0,d+20|0,d+16|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(a){break B}break d}a=N()|0;break a;case 0:g=w[d+38>>1];if((g|0)<=0){break d}B[d+20>>2]=B[a+32>>2];x[31725]=0;w[d+16>>1]=c;w[d+18>>1]=(c+g|0)-1;a=ha(935,a|0,h|0,d+20|0,d+16|0,f|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(a){break B}break d}a=N()|0;break a;default:break C}}x[31725]=0;W(936,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}}e=1}Ch(b)}fb=d+304|0;return e|0}a=N()|0;break a}a=N()|0}Ch(b);Q(a|0);p()}function Cpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;e=fb-736|0;fb=e;xc(b);d=fb-16|0;fb=d;g=e+128|0;oX(d+8|0,g);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);k=x[d+4>>2];if((k|0)==(f|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(f|0)==(k|0);if(!d){nX(g)}a:{if(!d){break a}if(!qX(e+128|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(pX(y[e+162|0]|y[e+163|0]<<8),hb))){break a}if(!c){o=1;break a}Bd(a,262144);f=e+92|0;bj(f,2,e+128|0);d=e+12|0;Cc(d,f);Ab(a+1298308|0,d);tb(d);g=tc(d,8317);Ab(a+1298344|0,g);tb(g);d=tc(d,10125);Ab(a+1298356|0,d);tb(d);d=fb-16|0;fb=d;h=f;f=tc(d+4|0,4193);_c(h,f);tb(f);fb=d+16|0;v[e|0]=y[e+158|0];x[31725]=0;v[e+115|0]=y[e+157|0];O(693,e+116|0,e+115|0);d=x[31725];x[31725]=0;b:{c:{d:{if((d|0)!=1){x[31725]=0;V(252,e+12|0,e+92|0,e|0,e+116|0);d=x[31725];x[31725]=0;if((d|0)!=1){d=e+12|0;Ab(a+1298368|0,d);tb(d);tb(e+116|0);f=e+92|0;Eb(f);B=a+1298404|0,C=x[Fc(d,4)>>2],x[B>>2]=C;x[a+480208>>2]=12;w[a+480188>>1]=y[e+166|0]|y[e+167|0]<<8;w[e+12>>1]=y[e+162|0]|y[e+163|0]<<8;w[e+92>>1]=3999;B=a,C=z[Nc(d,f)>>1],w[B+480190>>1]=C;Q_(Xb(x[a+484360>>2],y[a+484376|0]),e+224|0,y[e+160|0]|y[e+161|0]<<8);d=0;while(1)if(z[a+480188>>1]<=d>>>0){d=e+12|0;fe(d,b,D(y[e+162|0]|y[e+163|0]<<8,80));g=c&2;k=ic(e+92|0,d);ub(d);m=e+60|0;d=0;e:{f:{while(1){if(z[a+480190>>1]<=d>>>0){o=1;if(c&1){break f}break b}x[31725]=0;O(694,k|0,e+12|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}bj(e,2,m);x[31725]=0;O(220,e+116|0,e|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}d=d+1|0;f=e+116|0;zc(((d<<5)+a|0)+946304|0,f);tb(f);x[31725]=0;h=f;f=(D(d,104)+a|0)+484380|0;S(695,h|0,e+12|0,f|0);j=x[31725];x[31725]=0;g:{if((j|0)==1){break g}if(!g|!x[f>>2]){continue}x[31725]=0;j=P(151,b|0,y[e+30|0]|y[e+31|0]<<8|(y[e+32|0]<<16|y[e+33|0]<<24))|0;i=x[31725];x[31725]=0;if((i|0)==1){break g}if(!j){continue}x[31725]=0;U(217,e+116|0,f|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){continue}}break}break e}x[31725]=0;n=a+484344|0;O(225,n|0,y[e+164|0]|y[e+165|0]<<8);c=x[31725];x[31725]=0;if((c|0)==1){break e}q=e+16|0;t=e+14|0;r=e+15|0;u=e+17|0;A=e+13|0;c=0;while(1){if((y[e+164|0]|y[e+165|0]<<8)>>>0<=c>>>0){break b}x[31725]=0;d=U(198,n|0,c&65535,64)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}h:{if(!d){break h}d=(c<<1)+e|0;d=y[d+480|0]|y[d+481|0]<<8;if(!d){break h}x[31725]=0;d=P(151,b|0,d<<4)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}if(!d){break h}m=0;d=Wb(x[n>>2],c);j=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,0);while(1){if(m>>>0>63){break h}d=x[b+8>>2];f=x[b>>2];x[31725]=0;d=U(152,f|0,d|0,1)|0;f=x[31725];x[31725]=0;i:{if((f|0)!=1){if(!d){break h}x[31725]=0;d=R(199,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}i=d<<24>>24;if(i){break i}m=m+1|0;j=D(z[a+480188>>1],6)+j|0;continue}break e}w[q>>1]=0;x[e+12>>2]=0;f=i&31;d=D(f,6)+j|0;h=ch(e+12|0);f=f>>>0<z[a+480188>>1];l=f?d:h;h=i&255;j:{if(!(h&32)){break j}x[31725]=0;O(200,e+116|0,b|0);g=x[31725];x[31725]=0;if((g|0)==1){break e}g=y[e+116|0];v[l|0]=g;B=f?d+1|0:A,C=y[Jc(e+116|0)|0],v[B|0]=C;k:{if(g){if((g|0)==254){break k}if(g>>>0<121){break j}}g=0}v[l|0]=g}l:{if(!(h&64)){break l}x[31725]=0;O(200,e+116|0,b|0);g=x[31725];x[31725]=0;if((g|0)==1){break e}g=f?d+5|0:u;s=Jc(e+116|0);v[g|0]=y[s|0];h=y[e+116|0];m:{if(h>>>0<=15){Bf(l,h,y[s|0]);break m}v[(f?d+3|0:r)|0]=h>>>0<=23?y[h+25367|0]:0}l=f?d+3|0:r;h=y[l|0];if((h|0)!=23){if((h|0)!=9){break l}v[l|0]=20;v[e|0]=y[g|0]>>>3;v[e+115|0]=1;B=g,C=y[ef(e,e+115|0)|0]-1&15|128,v[B|0]=C;break l}v[e|0]=64;B=g,C=y[Rb(g,e)|0]<<1,v[B|0]=C}if((i|0)>=0){continue}v[(f?d+2|0:t)|0]=1;x[31725]=0;g=R(199,b|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break e}v[(f?d+4|0:q)|0]=g;continue}}c=c+1|0;continue}}b=N()|0;ub(k);break c}else{f=(d<<5)+a|0;Xe(f+480280|0);w[f+480284>>1]=(y[(e+d|0)+192|0]<<4|4)&244;d=d+1|0;continue}}b=N()|0;tb(e+116|0);break d}b=N()|0}Eb(e+92|0)}Q(b|0);p()}ub(k)}fb=e+736|0;return o|0}function IL(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;i=fb-560|0;fb=i;g=c;c=(c-3|0)/24|0;t=(c|0)>0?c:0;k=g+D(t,-24)|0;n=x[(e<<2)+90176>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=t-j|0;while(1){C[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+x[(c<<2)+90192>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;h=(n|0)>0?n:0;m=(d|0)<=0;while(1){a:{if(m){f=0;break a}r=g+j|0;c=0;f=0;while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(r-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;c=(g|0)==(h|0);g=g+1|0;if(!c){continue}break}y=47-k|0;r=48-k|0;u=(k|0)<25;z=k-25|0;g=n;while(1){f=C[(g<<3)+i>>3];c=0;h=g;o=(g|0)<=0;if(!o){while(1){m=(i+480|0)+(c<<2)|0;l=f*5.960464477539063e-8;b:{if(F(l)<2147483648){j=~~l;break b}j=-2147483648}l=+(j|0);f=l*-16777216+f;c:{if(F(f)<2147483648){j=~~f;break c}j=-2147483648}x[m>>2]=j;h=h-1|0;f=C[(h<<3)+i>>3]+l;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=tk(f,q);f=f+J(f*.125)*-8;d:{if(F(f)<2147483648){m=~~f;break d}m=-2147483648}f=f-+(m|0);e:{f:{g:{h:{if(!u){h=(g<<2)+i|0;j=x[h+476>>2];c=j>>r;s=h;h=j-(c<<r)|0;x[s+476>>2]=h;m=c+m|0;j=h>>y;break h}if(q){break g}j=x[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break e}break f}j=2;if(f>=.5){break f}j=0;break e}c=0;h=0;if(!o){while(1){s=(i+480|0)+(c<<2)|0;o=x[s>>2];v=16777215;i:{j:{if(h){break j}v=16777216;if(o){break j}h=0;break i}x[s>>2]=v-o;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}k:{if(u){break k}c=8388607;l:{switch(z|0){case 1:c=4194303;break;case 0:break l;default:break k}}o=(g<<2)+i|0;x[o+476>>2]=x[o+476>>2]&c}m=m+1|0;if((j|0)!=2){break e}f=1-f;j=2;if(!h){break e}f=f-tk(1,q)}m:{n:{if(f==0){h=0;c=g;if((n|0)>=(c|0)){break m}while(1){c=c-1|0;h=x[(i+480|0)+(c<<2)>>2]|h;if((c|0)>(n|0)){continue}break}if(!h){break m}k=q;while(1){k=k-24|0;g=g-1|0;if(!x[(i+480|0)+(g<<2)>>2]){continue}break}break n}f=tk(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;l=f*5.960464477539063e-8;p:{if(F(l)<2147483648){c=~~l;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(F(f)<2147483648){a=~~f;break q}a=-2147483648}x[d>>2]=a;g=g+1|0;break o}if(F(f)<2147483648){c=~~f}else{c=-2147483648}k=q}x[(i+480|0)+(g<<2)>>2]=c}f=tk(1,k);if((g|0)>=0){d=g;while(1){a=d;C[(a<<3)+i>>3]=f*+x[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}h=g;while(1){f=0;c=0;a=g-h|0;d=(a|0)>(n|0)?n:a;if((d|0)>=0){while(1){f=C[(c<<3)+92960>>3]*C[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}}C[(i+160|0)+(a<<3)>>3]=f;a=(h|0)>0;h=h-1|0;if(a){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=C[d>>3];c=g;while(1){l=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;w=C[h>>3];f=w+f;C[e+(c<<3)>>3]=l+(w-f);C[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=C[d>>3];c=g;while(1){l=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=C[e>>3];f=p+f;C[d+(c<<3)>>3]=l+(p-f);C[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+C[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=C[i+160>>3];if(j){break s}C[b>>3]=f;f=C[i+168>>3];C[b+16>>3]=p;C[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;f=C[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+C[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}C[b+8>>3]=j?-f:f;break r}C[b>>3]=-f;f=C[i+168>>3];C[b+16>>3]=-p;C[b+8>>3]=-f}fb=i+560|0;return m&7}c=1;while(1){h=c;c=c+1|0;if(!x[(i+480|0)+(n-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;C[(i+320|0)+(j<<3)>>3]=x[(t+g<<2)+90192>>2];c=0;f=0;if((d|0)>0){while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}}function a8(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-48|0;fb=h;x[h+44>>2]=b;x[e>>2]=0;bd(h,x[d+28>>2]);x[31725]=0;i=R(1217,x[h>>2])|0;j=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Zb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Zb(h);Q(a|0);p()}gK(a,f+24|0,h+44|0,c,e,i);break b}fK(a,f+16|0,h+44|0,c,e,i);break b}g=a;i=b;a=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Kb(a);k=h,l=zk(g,i,c,d,e,f,b,b+(Cb(x[a+4>>2],y[a+11|0])<<2)|0),x[k+44>>2]=l;break b}a=qj(h+44|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}g=x[27955];x[h+24>>2]=x[27954];x[h+28>>2]=g;g=x[27953];x[h+16>>2]=x[27952];x[h+20>>2]=g;g=x[27951];x[h+8>>2]=x[27950];x[h+12>>2]=g;g=x[27949];x[h>>2]=x[27948];x[h+4>>2]=g;k=h,l=zk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}g=x[27963];x[h+24>>2]=x[27962];x[h+28>>2]=g;g=x[27961];x[h+16>>2]=x[27960];x[h+20>>2]=g;g=x[27959];x[h+8>>2]=x[27958];x[h+12>>2]=g;g=x[27957];x[h>>2]=x[27956];x[h+4>>2]=g;k=h,l=zk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=qj(h+44|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=qj(h+44|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=qj(h+44|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=qj(h+44|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=qj(h+44|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+44|0;b=fb-16|0;fb=b;x[b+12>>2]=c;while(1){H:{if(mi(a,b+12|0)){break H}if(!zj(i,1,Bl(x[a>>2]))){break H}oo(a);continue}break}if(mi(a,b+12|0)){x[e>>2]=x[e>>2]|2}fb=b+16|0;break b}b=h+44|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Cb(x[a+4>>2],y[a+11|0])|0)==(0-Cb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=it(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=yc(h,111856,44);k=g,l=zk(a,b,c,d,e,f,g,g+44|0),x[k+44>>2]=l;break b}x[h+16>>2]=x[27980];g=x[27979];x[h+8>>2]=x[27978];x[h+12>>2]=g;g=x[27977];x[h>>2]=x[27976];x[h+4>>2]=g;k=h,l=zk(a,b,c,d,e,f,h,h+20|0),x[k+44>>2]=l;break b}a=qj(h+44|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}g=x[27991];x[h+24>>2]=x[27990];x[h+28>>2]=g;g=x[27989];x[h+16>>2]=x[27988];x[h+20>>2]=g;g=x[27987];x[h+8>>2]=x[27986];x[h+12>>2]=g;g=x[27985];x[h>>2]=x[27984];x[h+4>>2]=g;k=h,l=zk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=qj(h+44|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Kb(a);k=h,l=zk(g,i,c,d,e,f,b,b+(Cb(x[a+4>>2],y[a+11|0])<<2)|0),x[k+44>>2]=l;break b}eK(f+20|0,h+44|0,c,e,i);break b}a=qj(h+44|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=fb-16|0;fb=a;x[a+12>>2]=c;b=6;c=h+44|0;L:{M:{if(mi(c,a+12|0)){break M}b=4;if((yk(i,Bl(x[c>>2]))|0)!=37){break M}b=2;if(!mi(oo(c),a+12|0)){break L}}x[e>>2]=x[e>>2]|b}fb=a+16|0}a=x[h+44>>2]}fb=h+48|0;return a|0}function D1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=fb-864|0;fb=f;xc(b);e=fb-16|0;fb=e;i=f+92|0;xF(e+8|0,i);d=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);g=x[e+4>>2];if((g|0)==(d|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(d|0)==(g|0);if(!e){wF(i)}a:{if(!e){break a}if(!zF(f+92|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],yF(y[f+607|0]))){break a}if(!c){j=1;break a}Bd(a,2);x[a+480204>>2]=15e5;x[a+480208>>2]=x[a+480208>>2]|16777216;e=y[f+606|0];x[a+480188>>2]=4194322;x[a+480196>>2]=e;e=a+484376|0;jk(Xb(x[a+484360>>2],y[e|0]),b,y[f+607|0],65535,65535);e=Xb(x[a+484360>>2],y[e|0]);o=f,q=wb(x[e>>2]),x[o+40>>2]=q;e=wb(x[e+4>>2]);while(1){d=x[f+40>>2];if(Ib(d,e)){if(z[d>>1]>127){break a}Md(f+40|0);continue}break}gg(a);j=1;while(1){i=j&65535;if(i>>>0>z[a+480190>>1]){b:{j=1;c:{d:{e:{if(!(c&1)){break e}m=x[b+8>>2];i=a+484344|0;Vf(i,128);c=0;f:{while(1){if((c|0)==128){break f}d=f+16|0;e=(c<<1)+f|0;vF(d,b,(y[e+608|0]|y[e+609|0]<<8)+m|0,4674);e=ic(f+40|0,d);ub(d);d=x[e>>2];x[31725]=0;d=R(174,d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break c}g:{if(!d){break g}x[31725]=0;d=U(198,i|0,c&65535,32)|0;g=x[31725];x[31725]=0;if((g|0)==1){break c}if(!d){break g}g=0;d=Wb(x[i>>2],c);cf(f+16|0,x[d>>2],x[x[d+48>>2]+12>>2],0);while(1){h:{d=x[e>>2];x[31725]=0;d=U(152,d|0,x[f+48>>2],1)|0;h=x[31725];x[31725]=0;i:{j:{k:{l:{m:{if((h|0)!=1){if(!d){break h}x[31725]=0;d=R(199,e|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}n:{switch(d-251|0){case 0:break j;case 1:break k;case 2:break l;case 3:break m;case 4:break n;default:break i}}x[31725]=0;d=R(199,e|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}if(!d){break h}g=d+g|0;if(g>>>0>=32){break h}d=Wb(x[i>>2],c);cf(f- -64|0,x[d>>2],x[x[d+48>>2]+12>>2],g);d=x[f+68>>2];x[f+16>>2]=x[f+64>>2];x[f+20>>2]=d;continue}break b}x[31725]=0;O(200,f- -64|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}h=z[a+480188>>1];d=y[xb(f- -64|0,0)|0];if(h>>>0<=d>>>0){break d}h=y[xb(f- -64|0,1)|0];if(h>>>0>63){break d}o=Wc(x[f+16>>2],d),q=h+1|0,v[o+1|0]=q;continue}x[31725]=0;O(200,f- -64|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}h=z[a+480188>>1];d=y[xb(f- -64|0,0)|0];if(h>>>0<=d>>>0){break d}h=y[xb(f- -64|0,1)|0];if(h>>>0>63){break d}d=Wc(x[f+16>>2],d);v[d+4|0]=63-h;v[d+2|0]=1;continue}x[31725]=0;d=R(199,e|0)|0;h=x[31725];x[31725]=0;if((h|0)!=1){h=Wc(x[f+16>>2],0);v[h+5|0]=d;v[h+3|0]=12;continue}break b}d=Wc(x[f+16>>2],0);v[d+5|0]=0;v[d+3|0]=14;continue}if(d>>>0>=z[a+480188>>1]){break d}x[31725]=0;h=R(199,e|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break b}if(h>>>0>=124){break d}o=Wc(x[f+16>>2],d),q=(D(h>>>4|0,12)+(h&15)|0)+13|0,v[o|0]=q;k=d|k;l=!(d&1)|l;continue}break}ub(e);c=c+1|0;continue}break}ub(e)}if(!(k&l&1)){break e}c=z[a+480188>>1];b=0;while(1){if((b|0)==(c|0)){break e}w[((b<<5)+a|0)+480284>>1]=b<<8&256;b=b+1|0;continue}}ci(a+1298344|0,14749);ci(a+1298356|0,14758);ci(a+1298368|0,14749);o=a+1298404|0,q=x[Fc(f+40|0,4)>>2],x[o>>2]=q;break a}ub(e);j=0;break a}}}else{e=f+81|0;d=fb-16|0;fb=d;o:{if(!Mb(x[b>>2],x[b+8>>2],11)){v[d|0]=0;Vh(e,11,d);break o}Hw(d+8|0,e);rd(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;x[f+48>>2]=0;x[f+40>>2]=0;x[f+44>>2]=0;g=xb(e,1);d=f+40|0;o=xb(d,0),q=y[g|0],v[o|0]=q;g=xb(e,6);o=xb(d,1),q=y[g|0],v[o|0]=q;g=xb(e,2);o=xb(d,2),q=y[g|0],v[o|0]=q;g=xb(e,7);o=xb(d,3),q=y[g|0],v[o|0]=q;g=xb(e,3);o=xb(d,4),q=y[g|0],v[o|0]=q;g=xb(e,8);o=xb(d,5),q=y[g|0],v[o|0]=q;g=xb(e,4);o=xb(d,6),q=y[g|0],v[o|0]=q;g=xb(e,9);o=xb(d,7),q=y[g|0],v[o|0]=q;g=xb(e,5);o=xb(d,8),q=y[g|0],v[o|0]=q;g=xb(e,10);o=xb(d,9),q=y[g|0],v[o|0]=q;e=xb(e,0);o=xb(d,10),q=y[e|0],v[o|0]=q;e=(D(i,104)+a|0)+484380|0;ld(e,2);x[f+8>>2]=x[f+48>>2];d=x[f+44>>2];x[f>>2]=x[f+40>>2];x[f+4>>2]=d;_k(e,1,f);d=f- -64|0;tF(d,((i<<3)+f|0)+86|0);e=f+16|0;Cc(e,d);zc(((i<<5)+a|0)+946304|0,e);j=j+1|0;tb(e);continue}break}a=N()|0;ub(e);Q(a|0);p()}fb=f+864|0;return j|0}function So(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;f=fb+-64|0;fb=f;r=OB(x[a+24>>2],y[a+32|0]);t=Rj(r);c=t;e=x[a>>2];d=Ud(e,x[a+4>>2]);a:{if(c>>>0>d>>>0){l=fb-32|0;fb=l;c=c-d|0;i=x[zb(a)>>2];e=x[a+4>>2];b:{if(c>>>0<=(i-e|0)/12>>>0){e=fb-16|0;fb=e;c=uv(e+4|0,a,c);d=x[c+4>>2];g=x[c+8>>2];while(1){if((d|0)==(g|0)){hc(c);fb=e+16|0}else{fU(d);d=d+12|0;x[c+4>>2]=d;continue}break}break b}d=zb(a);d=Em(l+12|0,Yp(a,Ud(x[a>>2],e)+c|0),Ud(x[a>>2],x[a+4>>2]),d);g=fb-16|0;fb=g;c=GW(g+4|0,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){fU(e);e=x[c>>2]+12|0;x[c>>2]=e;continue}break}he(c);fb=g+16|0;g=fb-16|0;fb=g;h=zb(a);c=vb(g+12|0,x[a+4>>2]);j=vb(g+8|0,x[a>>2]);k=vb(g+4|0,x[d+4>>2]);e=x[c>>2];j=x[j>>2];c=fb+-64|0;fb=c;k=x[k>>2];x[c+56>>2]=k;x[c+60>>2]=e;x[c+52>>2]=k;h=Se(c+24|0,h,c+52|0,c+56|0);x[c+16>>2]=x[h+8>>2];k=x[h+4>>2];x[c+8>>2]=x[h>>2];x[c+12>>2]=k;Re(c+36|0,c+8|0);while(1){if(pd(e,j)){AC(Xp(x[c+56>>2]),kl(e));e=uk(c+60|0);uk(c+56|0);e=x[e>>2];continue}break}Qe(c+36|0);k=x[c+56>>2];if(!y[c+48|0]){h=fb-16|0;fb=h;e=vb(h+12|0,x[x[c+44>>2]>>2]);n=x[vb(h+8|0,x[x[c+40>>2]>>2])>>2];j=fb-16|0;fb=j;e=x[e>>2];x[j+12>>2]=e;while(1){if(di(e,n)){uf(ux(e));e=x[jl(j+12|0)>>2];continue}break}fb=j+16|0;fb=h+16|0}fb=c- -64|0;x[d+4>>2]=k;Ub(a,d+4|0);Ub(a+4|0,d+8|0);Ub(zb(a),nc(d));x[d>>2]=x[d+4>>2];fb=g+16|0;c=x[d+4>>2];while(1){e=x[d+8>>2];if((e|0)!=(c|0)){e=e-12|0;x[d+8>>2]=e;uf(e);continue}break}c=x[d>>2];if(c){ys(d);Db(c)}}fb=l+32|0;break a}if(c>>>0<d>>>0){lU(a,e+D(c,12)|0)}}if(b){c=a+12|0;Sq(c,ce(c));A=zb(c),B=0,x[A>>2]=B;i=c;c=ec(c);x[i>>2]=c;x[c>>2]=0;x[a+28>>2]=0}h=Nb(f+52|0);c=x[a+24>>2];c=Zu(x[c+484344>>2],x[c+484348>>2]);x[31725]=0;j=U(627,f+40|0,c|0,28588)|0;c=x[31725];x[31725]=0;c:{if((c|0)!=1){g=a+12|0;while(1){if((m|0)==(t|0)){md(j);dc(h);fb=f- -64|0;return}c=x[a+24>>2];i=x[c+484344>>2];c=x[c+484348>>2];k=z[_b(x[r>>2],m)>>1];d=rU(i,c,k);x[f+36>>2]=d;c=Hd(x[a>>2],m);d:{e:{f:{if(b){x[31725]=0;v[f+20|0]=0;S(806,c|0,d|0,f+20|0);d=x[31725];x[31725]=0;if((d|0)!=1){break f}d=N()|0;break e}x[31725]=0;O(760,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){break f}d=N()|0;break e}if(!cj(r,m&65535)){break d}x[f+20>>2]=b?0:x[c+4>>2];s=x[Gb(f+20|0,f+36|0)>>2];n=Rf(g);c=z[_b(x[j>>2],k)>>1];if((c|0)!=65535){d=oU(g,z[kn(f+20|0,c,s)>>1],x[f+24>>2]);g:{if(Zg(d,Rf(g))){c=oU(g,z[kn(f+20|0,z[_b(x[j>>2],k)>>1],x[f+36>>2])>>1],x[f+24>>2]);break g}c=Rf(g)}x[f+32>>2]=d;while(1){h:{if(!Zg(d,c)){break d}e=Nb(f+20|0);d=Zn(td(d)+8|0);x[31725]=0;O(807,e|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){d=Fc(f+12|0,n);l=kn(f+4|0,m,x[td(x[f+32>>2])+4>>2]);d=x[d>>2];x[31725]=0;d=ba(808,g|0,d|0,l|0,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break h}x[f+16>>2]=d;n=x[ah(f+16|0)>>2];Ae(e);d=x[ah(f+32|0)>>2];continue}}break}d=N()|0;Ae(e);break e}q=Wb(x[x[a+24>>2]+484344>>2],k);c=z[x[x[q+48>>2]+12>>2]+480188>>1];x[31725]=0;v[f+20|0]=0;S(781,h|0,c|0,f+20|0);c=x[31725];x[31725]=0;if((c|0)!=1){o=x[f+36>>2];i:while(1){j:{if((o|0)==(s|0)){if(s){break d}A=_b(x[j>>2],k),B=m,w[A>>1]=B;break d}c=1;l=0;e=x[x[q+48>>2]+12>>2];o=o-1|0;d=jd(x[q>>2],e,o,0);while(1){if(c>>>0<16&z[e+480188>>1]>l>>>0){u=xb(x[h>>2],l);e=y[u|0];k:{l:{m:{switch(y[d+3|0]-19|0){case 1:i=y[d+5|0];if((i&240)==176){break l}break k;case 0:break m;default:break k}}i=y[d+5|0];if((i&240)!=96){break k}}v[u|0]=i&15;i=y[xb(x[h>>2],l)|0];e=i?i:e}i=c;c=e&255;c=D(i,c?c+1|0:1);d=d+6|0;l=l+1|0;e=x[x[q+48>>2]+12>>2];continue}else{n:{if(c>>>0<=1){continue i}e=Nb(f+20|0);x[31725]=0;O(807,e|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break n}c=Fc(f,n);d=kn(f+4|0,m,o);c=x[c>>2];x[31725]=0;n=ba(808,g|0,c|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break j}Ae(e);continue i}}break}}break}d=N()|0;Ae(e);break e}d=N()|0}md(j);break c}m=m+1|0;continue}}d=N()|0}dc(h);Q(d|0);p()}function Bqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-192|0;fb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!op(b,d+180|0)){break l}if(!bY(d+180|0)){break l}g=bi(d+160|0);h=Fb(d+148|0);aw(d+84|0);x[31725]=0;f=P(618,b|0,d+76|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break h}m:{if(!f){break m}m=d,n=$b($b(x[d+80>>2])-4|0),x[m+80>>2]=n;while(1){f=$b($b(x[d+80>>2])-8|0);x[d+80>>2]=f;n:{if(c){break n}if(($b(x[d+76>>2])|0)!=1347699796){break n}k=1;break m}x[31725]=0;S(187,d+56|0,b|0,$b(f)|0);f=x[31725];x[31725]=0;if((f|0)==1){break d}e=d+56|0;f=ic(d,e);ub(e);e=x[f>>2];x[31725]=0;j=R(174,e|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}o:{if(!j){break o}p:{e=$b(x[d+76>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}x[31725]=0;P(185,f|0,4)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;e=R(619,f|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}if(!e){break o}e=$b(x[d+80>>2]);if(e>>>0<7){break o}i=x[Fc(d+52|0,28)>>2];x[31725]=0;V(620,f|0,h|0,i|0,e-6|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}break o}x[31725]=0;l=P(621,f|0,d+84|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break o}break b}Xw(g,f);break o}x[31725]=0;k=U(622,a|0,f|0,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}}ub(f);if(j){x[31725]=0;f=P(618,b|0,d+76|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break i}if(f){continue}}break}if(Ad(x[h+4>>2],y[h+11|0])){x[31725]=0;b=P(1,d+56|0,14886)|0;c=x[31725];x[31725]=0;if((c|0)==1){break g}Ab(h,b);tb(b)}q:{if(!(k&l&1)){break q}b=y[d+126|0]|y[d+127|0]<<8;x[31725]=0;b=Bb(b)&256;U(268,a+1074312|0,5,!b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break f}c=Bb(y[d+122|0]|y[d+123|0]<<8);if(c){w[d>>1]=64;w[d+40>>1]=c;m=a,n=z[Nc(d,d+40|0)>>1],x[m+480228>>2]=n}c=!b;b=Bb(y[d+124|0]|y[d+125|0]<<8);if(!(c|!b)){x[a+480204>>2]=D(b,1e4)}if(y[d+84|0]){b=d+40|0;We(b,2,d+84|0);x[31725]=0;O(220,d|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}Ab(a+1298308|0,d);tb(d)}c=y[d+130|0]|y[d+131|0]<<8;if(!kr(c,1,12)){break q}f=y[d+128|0]|y[d+129|0]<<8;if(!kr(f,1,31)){break q}e=y[d+134|0]|y[d+135|0]<<8;if(!kr(e,0,23)){break q}j=y[d+136|0]|y[d+137|0]<<8;if(!kr(j,0,59)){break q}i=y[d+138|0]|y[d+139|0]<<8;if(!kr(i,0,59)){break q}x[a+1298408>>2]=0;b=rp(d);m=b,n=Bb(y[d+132|0]|y[d+133|0]<<8)+1900|0,x[m>>2]=n;m=b,n=Bb(c),x[m+4>>2]=n;m=b,n=Bb(f),x[m+8>>2]=n;m=b,n=Bb(e),x[m+12>>2]=n;m=b,n=Bb(j),x[m+16>>2]=n;m=b,n=Bb(i),x[m+24>>2]=n;x[b+28>>2]=0;x[31725]=0;O(449,a+1298412|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break q}a=N()|0;break a}if(k&1){b=x[g>>2];x[31725]=0;b=R(174,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break h}if(b){b=Fb(d);x[31725]=0;S(272,g|0,b|0,32);c=x[31725];x[31725]=0;if((c|0)==1){break c}if(!Ld(b,13798)){x[31725]=0;S(260,d+40|0,28,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}c=d+40|0;Ab(a+1298320|0,c);tb(c)}c=x[g+8>>2];f=x[g>>2];x[31725]=0;c=P(623,f|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}if(!c){x[31725]=0;c=R(204,g|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;aa(318,a+1298332|0,g|0,c|0,40,0);c=x[31725];x[31725]=0;if((c|0)==1){break c}}tb(b)}x[31725]=0;b=P(1,d+40|0,18151)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}x[31725]=0;S(491,d|0,b|0,h|0);c=x[31725];x[31725]=0;if((c|0)==1){break j}Ab(a+1298368|0,d);tb(d);tb(b)}x[a+480208>>2]=x[a+480208>>2]|2097152;x[31725]=0;a=U(268,a+1074312|0,84,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break h}x[31725]=0;a=U(268,a|0,83,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break h}x[31725]=0;P(269,a|0,85)|0;a=x[31725];x[31725]=0;if((a|0)==1){break h}}tb(h);ub(g)}fb=d+192|0;return k&1}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;ub(f)}tb(h);ub(g);Q(a|0);p()}function Gz(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=fb-48|0;fb=l;x[l+44>>2]=0;a:{if(d|g|h|i){j=g?l+44|0:0;b:{if(!j){break b}k=x[j>>2];if(!k){break b}Db(k);x[j>>2]=0}x[31725]=0;X(86);k=x[31725];x[31725]=0;c:{d:{if((k|0)==1){m=Va(125e3,47456,47512,48492,125188,125292,125240,125132,125120,125436,125404,125372,125360,125584,0)|0;e:{f:{n=gb;if((n|0)==($(125e3)|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=277;if((j|0)==1){break f}break c}if(($(47456)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=358;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(47512)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=359;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(48492)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=357;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125188)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=300;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125292)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=299;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125240)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=298;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125132)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=297;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125120)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=296;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125436)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=289;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125404)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=288;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125372)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=287;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}if(($(125360)|0)==(n|0)){k=Y(m|0)|0;x[31725]=0;O(1104,j|0,k|0);j=x[31725];x[31725]=0;k=286;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break e}o=$(125584)|0;k=257;m=Y(m|0)|0;if((n|0)!=(o|0)){break c}x[31725]=0;O(1104,j|0,m|0);j=x[31725];x[31725]=0;k=267;if((j|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break e}break d}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break d}}T(0)|0;Sb()}p()}Q(a|0);p()}Z();m=!g;if(d){j=ib[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){x[g+16>>2]=k;m=g;g=x[l+44>>2];q=m,r=Bg(g?g:22255),x[q+20>>2]=r}if(h){x[h>>2]=k}g=x[l+44>>2];if(i){q=i,r=Bg(g?g:22255),x[q>>2]=r;g=x[l+44>>2]}if(g){Db(g);x[l+44>>2]=0}if(!(j&1)){break a}}x[31725]=0;O(1102,l+32|0,a|0);g=x[31725];x[31725]=0;g:{h:{if((g|0)!=1){i:{if(f){g=x[f+24>>2];x[31725]=0;O(1103,g|0,l+32|0);g=x[31725];x[31725]=0;if((g|0)!=1){break i}break h}g=Kb(l+32|0);if(b){x[31725]=0;O(b|0,g|0,c|0);g=x[31725];x[31725]=0;if((g|0)==1){break h}break i}ju(g,l)}tb(l+32|0);break a}g=T(0)|0;break g}g=T(0)|0;tb(l+32|0)}Y(g|0)|0;x[l+28>>2]=f;x[l+24>>2]=e;x[l+20>>2]=d;x[l+16>>2]=c;x[l+12>>2]=b;x[l+8>>2]=a?a:22255;x[l+4>>2]=254;x[l>>2]=9174;GP(18460,l);iu(125936);Z()}fb=l+48|0}function Vsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;j=fb-720|0;fb=j;a:{b:{if(d>>>0<=511){a=fb-16|0;fb=a;e=j+46|0;bc(a+8|0,e,554);d=x[a+12>>2];kc(a,x[b>>2],x[b+8>>2],x[a+8>>2],x[a+12>>2]);f=x[a+4>>2];if((f|0)==(d|0)){Vb(b,x[a+12>>2])}fb=a+16|0;a=(d|0)==(f|0);if(!a){Tb(e,0,554)}if(!a){break b}d=fb-32|0;fb=d;c:{a=j+46|0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1229999433){break c}e=d+8|0;as(e,a+32|0);b=d+20|0;Cc(b,e);zc(c+492|0,b);tb(b);nk(e,1,a+4|0);Cc(b,e);zc(c+524|0,b);tb(b);b=y[a+24|0]|y[a+25|0]<<8;x[c+4>>2]=64;x[c+8>>2]=128;x[c>>2]=b<<6;v[c+16|0]=y[a+26|0];v[c+17|0]=y[a+27|0];f=c+108|0;k=c+236|0;b=0;while(1)if((b|0)==120){b=y[c+60|0]&-2|v[a+17|0]&1;v[c+60|0]=b;b=b&-3|y[a+17|0]&2;v[c+60|0]=b;v[c+60|0]=b&251|y[a+17|0]&4;k=c+61|0;v[k|0]=y[a+18|0];g=c+62|0;v[g|0]=y[a+19|0];h=c+63|0;v[h|0]=y[a+20|0];i=c- -64|0;v[i|0]=y[a+21|0];f=c+48|0;hh(f,25);e=x[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=yb(e,b);m=b<<1;n=y[(a+m|0)+504|0];w[l>>1]=n;if((n|0)!=255){break d}hh(f,b);e=x[f>>2]}b=ef(k,g);a=Sd(e,x[c+52>>2]);if(a>>>0<=y[b|0]){v[c+60|0]=y[c+60|0]&253}if(a>>>0>y[ef(h,i)|0]){break c}v[c+60|0]=y[c+60|0]&251;break c}v[l+2|0]=y[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{g=a+(b<<1)|0;e=y[g- -64|0];g=y[g+65|0];o=_b(k,b),q=g,w[o>>1]=q;o=xb(f,b),q=(e>>>0<120?e:b)+1|0,v[o|0]=q;b=b+1|0;continue}}fb=d+32|0;break b}k=x[b+8>>2];d=fb-32|0;fb=d;x[d+28>>2]=674;x[d+8>>2]=674;e=x[b>>2];g=x[b+8>>2];f=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,g,f)){f=lf(b)}g=d+8|0;e=j+46|0;ZZ(g,e);h=gc(d+16|0,x[d+8>>2],f);i=x[h>>2];kc(d,x[b>>2],x[b+8>>2],i,x[h+4>>2]);ZZ(g,e);Tb(x[d+8>>2]+f|0,0,674-f|0);Vb(b,x[d+28>>2]);fb=d+32|0;g=x[a+480180>>2];a=0;d=fb-32|0;fb=d;if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))==1229999433){f=d+8|0;as(f,e+32|0);a=d+20|0;Cc(a,f);zc(c+492|0,a);tb(a);nk(f,1,e+4|0);Cc(a,f);zc(c+524|0,a);tb(a);x[c>>2]=(y[e+20|0]|y[e+21|0]<<8)<<5;x[c+4>>2]=y[e+24|0]>>>1;wc(c+4|0,64);h=y[e+25|0]&127;x[c+8>>2]=h>>>0>64?128:h<<2;v[c+15|0]=y[c+15|0]&254|((y[e+25|0]^-1)&128)>>>7;v[d+20|0]=y[e+26|0];v[d+8|0]=100;o=c,q=y[Rb(a,f)|0],v[o+20|0]=q;v[d+20|0]=y[e+27|0];v[d+8|0]=64;o=c,q=y[Rb(a,f)|0],v[o+19|0]=q;v[c+16|0]=y[e+17|0];v[c+17|0]=y[e+18|0];v[c+18|0]=y[e+19|0];v[c+26|0]=y[e+22|0];v[c+27|0]=y[e+23|0];a=y[e+58|0];mk(c,a&127,a>>>7|0);a=y[e+59|0];lk(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=y[e+28|0]|y[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=y[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){v[c+30|0]=a}a=y[e+62|0]|y[e+63|0]<<8;if(a>>>0<129){break f}break e}a=v[e+61|0];if((a|0)<0){break g}v[c+30|0]=a+1}a=y[e+62|0];a=a<<24>>24>=0?a+1|0:0;f=v[e+63|0];if((f|0)<0){break f}a=((f&255)<<7)+a|0}w[c+28>>1]=a}a=v[e+60|0];v[c+31|0]=a;if((a|0)<0){v[c+31|0]=0;v[c+34|0]=a^128}a=0;f=g&16777216?240:25;Tw(e+304|0,c+48|0,0,f);Tw(e+386|0,c+68|0,32,f);Tw(e+468|0,c+88|0,32,f);v[c+100|0]=y[c+100|0]&239|y[e+468|0]>>>3&16;g=c+108|0;h=c+236|0;while(1){if((a|0)!=120){i=e+(a<<1)|0;f=y[i- -64|0];i=y[i+65|0];o=_b(h,a),q=i,w[o>>1]=q;o=xb(g,a),q=(f>>>0<120?f:a)+1|0,v[o|0]=q;a=a+1|0;continue}break}a=554}fb=d+32|0;d=0;k:{if(!a){break k}d=y[e+550|0]|y[e+551|0]<<8|(y[e+552|0]<<16|y[e+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){a=c+236|0;f=0;while(1){if((f|0)!=120){d=y[(e+f|0)+554|0];g=_b(a,f);w[g>>1]=z[g>>1]|d<<8;f=f+1|0;continue}break}a=674}d=a}cd(b,d+k|0);if(!kk(b,14031)){break b}d=j+4|0;fe(d,b,Pg(b));a=ic(j+24|0,d);ub(d);b=x[a>>2];x[31725]=0;R(156,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;b=P(414,a|0,13813)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}if(b){x[31725]=0;b=R(199,a|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}v[c+34|0]=b>>>0<=250?b:0}ub(a)}fb=j+720|0;return}b=N()|0;ub(a);Q(b|0);p()}function Zua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-3056|0;fb=e;xc(b);g=fb-16|0;fb=g;i=e+1102|0;E0(g+8|0,i);f=x[g+12>>2];j=b;kc(g,x[b>>2],x[b+8>>2],x[g+8>>2],x[g+12>>2]);b=x[g+4>>2];if((b|0)==(f|0)){Vb(j,x[g+12>>2])}fb=g+16|0;b=(b|0)==(f|0);if(!b){D0(i)}a:{if(!b){break a}if(!G0(e+1102|0)){break a}b:{if(!c){break b}if(!Mb(x[j>>2],x[j+8>>2],Bc(1024,0))){break a}C0(j,e+576|0);C0(j,e- -64|0);while(1){if((h|0)!=128){b=h<<2;g=x[b+(e+576|0)>>2];if(g>>>0>16777215){break a}b=x[b+(e- -64|0)>>2];if(b-4097>>>0<4294963202){break a}h=h+1|0;if(Dm(x[j>>2],(b+g|0)+2978|0)){continue}break a}break}Bd(a,2);gg(a);b=e+40|0;d=tc(b,13879);Ab(a+1298344|0,d);tb(d);d=tc(b,14745);Ab(a+1298356|0,d);tb(d);d=tc(b,15546);Ab(a+1298368|0,d);tb(d);o=a+1298404|0,q=x[Fc(b,4)>>2],x[o>>2]=q;b=y[e+1102|0];x[a+480204>>2]=143e4;x[a+480196>>2]=b;bf(Xb(x[a+484360>>2],y[a+484376|0]),y[e+1103|0]);x[a+480188>>2]=4194317;Lb(a+1074312|0,95,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=0;h=0;while(1){if((h|0)==4){c:{while(1){d:{if((d|0)==32){h=0;break d}b=d+1|0;h=D(b,104)+a|0;f=h+484380|0;ld(f,2);i=e+20|0;B0(i,(D(d,13)+e|0)+1104|0);g=e+40|0;Cc(g,i);zc(((b<<5)+a|0)+946304|0,g);tb(g);d=(e+1102|0)+(d<<4)|0;g=y[d+422|0]|y[d+423|0]<<8|(y[d+424|0]<<16|y[d+425|0]<<24);x[f>>2]=g;f=g;g=y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24);if(f>>>0>=g>>>0){d=y[d+426|0]|y[d+427|0]<<8|(y[d+428|0]<<16|y[d+429|0]<<24);w[h+484414>>1]=2;x[h+484388>>2]=g;x[h+484384>>2]=d}x[h+484404>>2]=8287;d=b;continue}break}while(1){if((h|0)!=32){d=h+33|0;g=(D(d,104)+a|0)+484380|0;ld(g,2);f=e+20|0;B0(f,(D(h,13)+e|0)+2032|0);b=e+40|0;Cc(b,f);zc(((d<<5)+a|0)+946304|0,b);tb(b);x[e+48>>2]=0;x[e+40>>2]=0;x[e+44>>2]=0;d=(D(h,11)+e|0)+2448|0;f=xb(d,1);o=xb(b,0),q=y[f|0],v[o|0]=q;f=xb(d,6);o=xb(b,1),q=y[f|0],v[o|0]=q;f=xb(d,2);o=xb(b,2),q=y[f|0],v[o|0]=q;f=xb(d,7);o=xb(b,3),q=y[f|0],v[o|0]=q;f=xb(d,3);o=xb(b,4),q=y[f|0],v[o|0]=q;f=xb(d,8);o=xb(b,5),q=y[f|0],v[o|0]=q;f=xb(d,4);o=xb(b,6),q=y[f|0],v[o|0]=q;f=xb(d,9);o=xb(b,7),q=y[f|0],v[o|0]=q;f=xb(d,5);o=xb(b,8),q=y[f|0],v[o|0]=q;f=xb(d,10);o=xb(b,9),q=y[f|0],v[o|0]=q;d=xb(d,0);o=xb(b,10),q=y[d|0],v[o|0]=q;x[e+16>>2]=x[e+48>>2];b=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=b;_k(g,1,e+8|0);h=h+1|0;continue}break}Vr(Xb(x[a+484360>>2],y[a+484376|0]),e+2800|0,256,255,65535);l=a+484344|0;Vf(l,128);m=c&1;g=0;while(1){e:{f:{if((g|0)!=128){b=g<<2;cd(j,x[b+(e+576|0)>>2]+2978|0);d=e+20|0;fe(d,j,x[b+(e- -64|0)>>2]);b=ic(e+40|0,d);ub(d);if(!m){break e}x[31725]=0;d=U(198,l|0,g&65535,64)|0;h=x[31725];x[31725]=0;if((h|0)==1){break c}if(!d){break e}h=0;f=Wb(x[l>>2],g);while(1){if(h>>>0>63){break e}d=x[b>>2];x[31725]=0;d=U(152,d|0,x[e+48>>2],1)|0;i=x[31725];x[31725]=0;g:{if((i|0)!=1){if(!d){break e}x[31725]=0;d=R(199,b|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break c}if(d>>>0>12){break g}i=jd(x[f>>2],x[x[f+48>>2]+12>>2],h,d);x[31725]=0;O(200,e+20|0,b|0);k=x[31725];x[31725]=0;if((k|0)==1){break c}k=y[e+20|0];d=d>>>0>3;v[i|0]=((k&15)+(d?13:37)|0)+D(k>>>4&7,12);k=Jc(e+20|0);v[i+1|0]=((y[k|0]>>>4|0)+(d?33:1)|0)+(y[e+20|0]>>>3&16);A0(i,y[k|0],d);continue}break c}i=d-32|0;if((i&255)>>>0<=12){i=jd(x[f>>2],x[x[f+48>>2]+12>>2],h,i&65535);x[31725]=0;k=R(199,b|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break c}A0(i,k,d>>>0>35);continue}if((d|0)!=64){if((d|0)!=96){break f}if(!h){break e}o=jd(x[f>>2],x[x[f+48>>2]+12>>2],h-1|0,0),q=14,v[o+3|0]=q;break e}x[31725]=0;d=R(199,b|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break c}h=d+h|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}fg(Xc(e+40|0,8,1,0,1),(D(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}ub(b);d=0;break a}ub(b);g=g+1|0;continue}}}else{w[((h<<5)+a|0)+480284>>1]=h&1?192:64;h=h+1|0;continue}break}a=N()|0;ub(b);Q(a|0);p()}d=1}fb=e+3056|0;return d|0}function jua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;d=fb-320|0;fb=d;xc(b);a:{if(!op(b,d+308|0)){break a}if(!w$(d+308|0)){break a}if((y[d+308|0]|y[d+309|0]<<8|(y[d+310|0]<<16|y[d+311|0]<<24))==1179472708){Vb(b,4)}if(!Ci(b,d+300|0)|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1196314451){break a}if(!c){l=1;break a}K0(b,d+108|0,y[d+304|0]|y[d+305|0]<<8|(y[d+306|0]<<16|y[d+307|0]<<24));if((y[d+144|0]|y[d+145|0]<<8)>>>0>128|(y[d+150|0]|y[d+151|0]<<8)>>>0>16|((y[d+148|0]|y[d+149|0]<<8)>>>0>256|(y[d+142|0]|y[d+143|0]<<8)>>>0>128)){break a}Bd(a,8192);e=d+24|0;f=tc(e,6574);Ab(a+1298344|0,f);tb(f);f=tc(e,10141);Ab(a+1298356|0,f);tb(f);r=a+1298404|0,s=x[Fc(e,4)>>2],x[r>>2]=s;f=d+88|0;bj(f,2,d+108|0);Cc(e,f);Ab(a+1298308|0,e);tb(e);w[d+24>>1]=y[d+150|0]|y[d+151|0]<<8;w[d+88>>1]=1;g=z[qe(e,f)>>1];w[a+480188>>1]=g;x[a+480196>>2]=y[d+154|0];x[a+480204>>2]=D(y[d+155|0],1e4);v[d+24|0]=y[d+152|0];v[d+88|0]=64;e=y[Rb(e,f)|0];x[a+480200>>2]=e<<2;if(!e){x[a+480200>>2]=256}e=y[d+153|0];b:{if((e|0)==128){x[d+24>>2]=256/(g>>>0);x[d+88>>2]=128;e=x[Gb(d+24|0,d+88|0)>>2];break b}e=e&127}x[a+480228>>2]=e;e=0;while(1){if((e|0)==16){g=Xb(x[a+484360>>2],y[a+484376|0]);l=d+172|0;f=fb-16|0;fb=f;x[f+12>>2]=y[d+144|0]|y[d+145|0]<<8;e=f+12|0;wc(e,128);wc(e,65535);i=z[f+12>>1];xg(g,i);e=0;while(1){if((e|0)==(i|0)){fb=f+16|0}else{h=y[e+l|0];r=Wr(x[g>>2],x[g+4>>2],e),s=(h|0)==255?-1:(h|0)==254?-2:h,w[r>>1]=s;e=e+1|0;continue}break}e=y[d+142|0]|y[d+143|0]<<8;if(e>>>0<(y[d+144|0]|y[d+145|0]<<8)>>>0){bf(Xb(x[a+484360>>2],y[a+484376|0]),e)}n=c&2;i=a+484344|0;l=1;o=c&1;q=d+60|0;while(1){if(!Ci(b,d+300|0)){break a}e=d+24|0;fe(e,b,y[d+304|0]|y[d+305|0]<<8|(y[d+306|0]<<16|y[d+307|0]<<24));c=ic(d+88|0,e);ub(e);c:{d:{if(!(!o|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414807888)){x[31725]=0;j=m&65535;e=U(198,i|0,j|0,64)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}if(!e){break c}x[31725]=0;P(185,c|0,2)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}f=0;e:{while(1){e=x[c>>2];x[31725]=0;e=U(152,e|0,x[d+96>>2],1)|0;g=x[31725];x[31725]=0;f:{if((g|0)!=1){if(!(e&f>>>0<64)){break e}x[31725]=0;e=R(199,c|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}h=e<<24>>24;if(h){break f}f=f+1|0;continue}break d}e=d+24|0;g=h&15;if(g>>>0<z[a+480188>>1]){e=Wb(x[i>>2],j);e=jd(x[e>>2],x[x[e+48>>2]+12>>2],f,g)}g:{if((h|0)>=0){break g}x[31725]=0;g=R(199,c|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break d}if(!g){break g}v[e|0]=g>>>0<109?g+12|0:g}g=h&255;if(g&64){x[31725]=0;h=R(199,c|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break d}v[e+1|0]=h}if(g&32){v[e+2|0]=1;x[31725]=0;h=R(199,c|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break d}v[d+12|0]=h;v[d|0]=64;r=e,s=y[Rb(d+12|0,d)|0],v[r+4|0]=s}if(!(g&16)){continue}x[31725]=0;O(200,d+12|0,c|0);g=x[31725];x[31725]=0;if((g|0)!=1){Bf(e,y[d+12|0],y[Jc(d+12|0)|0]);continue}break}break d}m=m+1|0;break c}if((y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414745673){break c}e=z[a+480190>>1];if(!vi(e)){break c}e=e+1|0;w[a+480190>>1]=e;x[31725]=0;O(326,c|0,d+24|0);f=x[31725];x[31725]=0;h:{if((f|0)==1){break h}x[31725]=0;h=(D(e&65535,104)+a|0)+484380|0;O(327,d+24|0,h|0);e=x[31725];x[31725]=0;if((e|0)==1){break h}bj(d,2,q);x[31725]=0;O(220,d+12|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break h}e=d+12|0;zc(((z[a+480190>>1]<<5)+a|0)+946304|0,e);tb(e);if(!n){break c}e=y[d+37|0]|y[d+38|0]<<8;f=2;j=d+12|0;g=Xc(j,8,1,0,1);i:{if(!(e&64)){f=0;if(!(e&2)){break i}}yg(g,f)}if(e&4){fd(g,16)}x[31725]=0;U(217,j|0,h|0,c|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break c}}}a=N()|0;ub(c);Q(a|0);p()}ub(c);continue}}f=(e<<5)+a|0;Xe(f+480280|0);g=y[(d+e|0)+156|0];if(g>>>0<=128){w[f+480284>>1]=g<<1}e=e+1|0;continue}}fb=d+320|0;return l|0}function Mz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-256|0;fb=f;g=x[b+4>>2];a:{if(!g){h=x[b>>2];break a}h=x[b>>2];i=y[Il(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Ul(f+96|0,h,g,g-1|0);g=x[f+100>>2];h=x[f+96>>2];x[b>>2]=h;x[b+4>>2]=g}j=f+96|0;ge(j);i=x[f+96>>2];ge(f+236|0);i=Hl(i,x[f+240>>2],b);ge(j);b:{c:{d:{e:{if((i|0)==x[f+100>>2]){i=qc(f+248|0,22255);a=x[i+4>>2];x[f+8>>2]=x[i>>2];x[f+12>>2]=a;if(Ic(h,g,f+8|0)){e=ac(8);x[31725]=0;c=gi(f+236|0,c,d);a=x[31725];x[31725]=0;f:{g:{h:{if((a|0)!=1){x[31725]=0;S(1017,f+96|0,18246,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}pc(e,f+96|0);a=0;x[31725]=0;S(99,e|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}g=N()|0;tb(f+96|0);break g}g=N()|0;break f}g=N()|0;a=1}tb(c);if(!a){break c}}jc(e);break c}if(!e){break e}h=ac(8);e=x[b>>2];a=x[b+4>>2];x[31725]=0;e=gi(f+212|0,e,a);a=x[31725];x[31725]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[31725]=0;S(1017,f+224|0,18282,e|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}x[31725]=0;O(1019,f+236|0,f+224|0);b=x[31725];x[31725]=0;a=1;if((b|0)==1){break p}x[31725]=0;c=gi(f+200|0,c,d);a=x[31725];x[31725]=0;if((a|0)==1){break o}x[31725]=0;S(1021,f+96|0,f+236|0,c|0);b=x[31725];x[31725]=0;a=1;if((b|0)==1){break n}pc(h,f+96|0);x[31725]=0;S(99,h|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}g=N()|0;tb(f+96|0);a=0;break m}g=N()|0;break i}g=N()|0;a=1;break j}g=N()|0;break k}g=N()|0;a=1;break l}g=N()|0}tb(c)}tb(f+236|0)}tb(f+224|0)}tb(e);if(!a){break c}}jc(h);break c}e=qc(f+192|0,22255);b=x[e+4>>2];x[f+88>>2]=x[e>>2];x[f+92>>2]=b;if(Ic(h,g,f+88|0)){e=ac(8);x[31725]=0;c=gi(f+236|0,c,d);a=x[31725];x[31725]=0;r:{s:{t:{if((a|0)!=1){x[31725]=0;S(1017,f+96|0,18246,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break t}pc(e,f+96|0);a=0;x[31725]=0;S(99,e|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}g=N()|0;tb(f+96|0);break s}g=N()|0;break r}g=N()|0;a=1}tb(c);if(!a){break c}}jc(e);break c}e=qc(f+184|0,12421);b=x[e+4>>2];x[f+80>>2]=x[e>>2];x[f+84>>2]=b;if(Ic(h,g,f+80|0)){e=qc(f+176|0,5601);b=x[e+4>>2];x[f+32>>2]=x[e>>2];x[f+36>>2]=b;if(Ic(c,d,f+32|0)){x[a+52>>2]=0;break e}e=qc(f+168|0,11285);b=x[e+4>>2];x[f+24>>2]=x[e>>2];x[f+28>>2]=b;if(Ic(c,d,f+24|0)){x[a+52>>2]=1;break e}e=qc(f+160|0,9206);b=x[e+4>>2];x[f+16>>2]=x[e>>2];x[f+20>>2]=b;if(Ic(c,d,f+16|0)){x[a+52>>2]=2;break e}e=ac(8);x[31725]=0;c=gi(f+236|0,c,d);a=x[31725];x[31725]=0;u:{v:{w:{if((a|0)!=1){x[31725]=0;S(1017,f+96|0,14606,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break w}pc(e,f+96|0);a=0;x[31725]=0;S(99,e|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}g=N()|0;tb(f+96|0);break v}g=N()|0;break u}g=N()|0;a=1}tb(c);if(!a){break c}}jc(e);break c}e=qc(f+152|0,11522);b=x[e+4>>2];x[f+72>>2]=x[e>>2];x[f+76>>2]=b;if(!Ic(h,g,f+72|0)){break e}e=qc(f+144|0,15627);b=x[e+4>>2];x[f+64>>2]=x[e>>2];x[f+68>>2]=b;b=0;x:{if(Ic(c,d,f- -64|0)){break x}e=qc(f+136|0,15632);b=x[e+4>>2];x[f+56>>2]=x[e>>2];x[f+60>>2]=b;b=1;if(Ic(c,d,f+56|0)){break x}e=qc(f+128|0,12695);b=x[e+4>>2];x[f+48>>2]=x[e>>2];x[f+52>>2]=b;b=2;if(Ic(c,d,f+48|0)){break x}e=qc(f+120|0,9270);b=x[e+4>>2];x[f+40>>2]=x[e>>2];x[f+44>>2]=b;b=3;if(Ic(c,d,f+40|0)){break x}c=ac(8);x[31725]=0;b=P(36,f+96|0,11558)|0;a=x[31725];x[31725]=0;if((a|0)==1){break d}pc(c,b);x[31725]=0;S(99,c|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}g=N()|0;tb(b);break c}x[a+56>>2]=b;d=x[a+24>>2];if(!x[d+24668>>2]){break e}c=d+24664|0;a=x[c+4>>2];x[f+112>>2]=x[c>>2];x[f+116>>2]=a;c=d+24656|0;a=x[c+4>>2];x[f+104>>2]=x[c>>2];x[f+108>>2]=a;a=x[d+24652>>2];x[f+96>>2]=x[d+24648>>2];x[f+100>>2]=a;k=f,l=eN(b),x[k+116>>2]=l;if(!yz(f+96|0,d+24648|0)){break e}KA(d,f+96|0)}fb=f+256|0;return}g=N()|0;jc(c)}Q(g|0)}p()}function gta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;f=fb-32|0;fb=f;a:{b:{if(!c){break b}g=_h(a,b);a=wb(x[d>>2]);x[f+28>>2]=a;d=wb(x[d+4>>2]);while(1){if(!Ib(a,d)){break b}xc(a);c:{if((Wk(a)|0)==(c|0)){Vb(a,20);d=Wk(a);k=qg(f+16|0);c=fm(f+12|0,0,b?32:64);x[31725]=0;O(404,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}o=(b|0)==2?4096:(b|0)==1?2048:16384;c=24;d=d+24|0;q=1;l=1;d:{while(1){h=o;while(1){e=x[a+8>>2];i=x[a>>2];x[31725]=0;e=U(152,i|0,e|0,1)|0;i=x[31725];x[31725]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((i|0)!=1){if(!e){break d}e=x[g+4>>2];i=x[g>>2];m=x[a+8>>2];x[31725]=0;x[f+12>>2]=m;m=P(405,k|0,f+12|0)|0;r=x[31725];x[31725]=0;if((r|0)==1){break a}u=m,A=Sd(i,e),x[u>>2]=A;x[31725]=0;e=R(199,a|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}q:{switch(e-128|0){case 5:case 6:case 9:case 10:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:case 7:case 8:break e;default:break q}}r:{switch(e|0){case 0:break g;case 5:break l;case 4:break m;case 3:break n;case 2:break o;case 1:break p;default:break r}}s:{switch(e-160|0){case 5:case 6:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:break e;default:break s}}switch(e-192|0){case 2:break i;case 1:break j;case 0:break k;default:break e}}break a}if(y[g+12|0]&4){break e}x[31725]=0;e=R(275,a|0)|0;i=x[31725];x[31725]=0;t:{if((i|0)==1){break t}x[31725]=0;x[f+12>>2]=e;e=P(405,k|0,f+12|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break t}v[g+15|0]=x[e>>2];u=g,A=Sd(x[g>>2],x[g+4>>2])-1|0,v[u+16|0]=A;v[g+12|0]=y[g+12|0]|4;break e}break a}x[31725]=0;e=R(275,a|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}w[f+12>>1]=e;w[f+10>>1]=1;e=z[qe(f+12|0,f+10|0)>>1];h=D(e,D(s<<16>>16,l))+h|0;u:{if(e>>>0<2){break u}u=f,A=lm((e+z[xf(x[g+4>>2])>>1]|0)-1|0),w[u+12>>1]=A;e=Sv(b,h);x[31725]=0;v[f+10|0]=e;S(406,g|0,f+12|0,f+10|0);e=x[31725];x[31725]=0;if((e|0)!=1){break u}break a}u=f,A=lm(z[xf(x[g+4>>2])>>1]+1|0),w[u+12>>1]=A;e=Sv(b,h);x[31725]=0;v[f+10|0]=e;S(406,g|0,f+12|0,f+10|0);e=x[31725];x[31725]=0;if((e|0)!=1){break e}break a}x[31725]=0;j=R(199,a|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}t=x[a+8>>2];break e}x[31725]=0;e=R(275,a|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}e=c+e|0;x[f+12>>2]=e;if(!(!(j&255)|e>>>0<t>>>0)){j=j-1|0;if(!(j&255)){break f}x[31725]=0;P(151,a|0,e|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break e}break a}if(!(j&255)){break f}x[31725]=0;e=P(407,k|0,f+12|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}v[g+13|0]=x[e>>2];u=g,A=Sd(x[g>>2],x[g+4>>2])-1|0,v[u+14|0]=A;v[g+12|0]=y[g+12|0]|2;break e}q=0;n=1;break e}x[31725]=0;h=R(275,a|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}e=Sv(b,h);u=xf(x[g+4>>2]),A=e,v[u+2|0]=A;break e}x[31725]=0;s=R(408,a|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break e}break a}x[31725]=0;e=R(199,a|0)|0;l=x[31725];x[31725]=0;if((l|0)!=1){v[f+12|0]=e;v[f+10|0]=1;l=y[ef(f+12|0,f+10|0)|0];break e}break a}x[31725]=0;P(185,a|0,1)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}break e}n=1;if(c>>>0<d>>>0){break e}break d}j=0}if(!n|c>>>0>=d>>>0){continue}break}x[31725]=0;c=P(151,a|0,d|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}if(!c){break d}c=x[a+8>>2];h=x[a>>2];x[31725]=0;c=U(152,h|0,c|0,2)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}if(!c){break d}c=x[g+4>>2];h=y[g+12|0];if(!(h&4)&q){e=x[g>>2];v[g+12|0]=h|4;h=Sd(e,c)-1|0;v[g+15|0]=h;v[g+16|0]=h}u=f,A=lm(z[xf(c)>>1]+1|0),w[u+12>>1]=A;c=Sv(b,o);x[31725]=0;v[f+10|0]=c;S(406,g|0,f+12|0,f+10|0);c=x[31725];x[31725]=0;if((c|0)!=1){n=1;v[g+17|0]=y[g+16|0]+1;c=d;continue}break}break a}v[g+12|0]=y[g+12|0]|1;k_(k);break b}a=x[Sf(f+28|0)>>2];continue}break}break a}fb=f+32|0;return}a=N()|0;k_(k);Q(a|0);p()}function moa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-176|0;fb=e;a:{b:{if(Mb(x[c>>2],x[c+8>>2],8)){Vb(c,4);while(1){if(Ov(x[c>>2],x[c+8>>2])){break b}m=fb-288|0;fb=m;f=LU(m+6|0);h=fb-368|0;fb=h;k=yc(f,LU(h+80|0),282);f=0;g=fb-32|0;fb=g;x[g+28>>2]=0;j=gc(g+8|0,g+28|0,4);i=x[j>>2];kc(g+20|0,x[c>>2],x[c+8>>2],i,x[j+4>>2]);j=x[g+24>>2]==4&x[g+28>>2]==1399285583;if(j){Vb(c,4)}fb=g+32|0;c:{d:{e:{f:{g:{if(j){MU(c,4);j=q0(h+60|0,c);x[31725]=0;g=P(792,j|0,k|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break g}h:{if(!g){break h}g=x[j+8>>2];i=x[j>>2];l=y[k+26|0];x[31725]=0;g=U(793,i|0,g|0,l|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break g}if(!g){break h}g=0;i:{while(1){if(y[k+26|0]<=f>>>0){i=x[j+8>>2];l=x[j>>2];f=0;x[31725]=0;n=i;i=g&65535;g=U(793,l|0,n|0,i|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break e}if(!g){break h}x[31725]=0;O(794,j|0,i|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}MU(j,NU(k));f=sc(h+56|0);g=h+80|0;QB(g);x[31725]=0;O(795,j|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){w[h+102>>1]=0;w[h+104>>1]=0;f=KU(f,h+80|0,h+107|0);g=y[k+26|0];x[31725]=0;O(794,j|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){break i}}f=N()|0;break d}x[31725]=0;i=R(796,j|0)|0;l=x[31725];x[31725]=0;if((l|0)!=1){v[(f+k|0)+27|0]=i;f=f+1|0;g=g+i|0;continue}break}f=N()|0;break d}n=f;f=k+27|0;g=KU(n,f,f+y[k+26|0]|0);x[31725]=0;S(797,h+36|0,j|0,i|0);f=x[31725];x[31725]=0;if((f|0)==1){break f}f=0;x[31725]=0;O(576,h+16|0,h+36|0);i=x[31725];x[31725]=0;if((i|0)==1){f=N()|0;ub(h+36|0);break d}n=h+16|0;gG(h+8|0,n);i=wb(x[h+8>>2]);o=Yk(x[h+8>>2],x[h+12>>2]);l=fb-16|0;fb=l;x[l+12>>2]=i;while(1){if(Ib(i,o)){IU(g,y[i|0]);i=x[me(l+12|0)>>2];continue}else{fb=l+16|0}break}Kc(n);ub(h+36|0);if(x[g>>2]!=(y[k+22|0]|y[k+23|0]<<8|(y[k+24|0]<<16|y[k+25|0]<<24))){break h}f=NU(k);x[31725]=0;O(794,c|0,f|0);g=x[31725];x[31725]=0;f=1;if((g|0)==1){break e}}ub(j)}fb=h+368|0;break c}f=N()|0;break d}f=N()|0;break d}f=N()|0}ub(j);Q(f|0);p()}fb=m+288|0;if(f){continue}break}}xc(c);fg(b,a,c);a=1;break a}v[d|0]=1;xc(c);f=Pg(c);d=e+136|0;fe(d,c,lf(c));g=ic(e+156|0,d);ub(d);c=z[a+34>>1]&-66|y[b|0]>15;b=y[b+1|0]!=1;c=c|b<<6;w[a+34>>1]=c;x[a>>2]=f>>>(c&1)>>>b;x[e+132>>2]=0;x[e+128>>2]=0;x[31725]=0;O(576,d|0,g|0);b=x[31725];x[31725]=0;j:{k:{l:{m:{if((b|0)!=1){c=$e(e+136|0);d=x[e+136>>2];h=ZC(c,vh(d),e+132|0,e+128|0);x[31725]=0;b=x[e+132>>2];P(185,g|0,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){if(!h){break j}Fh(a);k=b+c|0;d=d-b|0;b=x[e+128>>2];c=0;while(1){n:{if(b){if(!d|(b|0)!=1){break k}b=x[a>>2];if(c>>>0<b>>>0){break n}break k}b=x[a>>2];if(c>>>0>=b>>>0){break k}}if(!je(b,x[a+20>>2])){break k}x[e+124>>2]=0;x[e+120>>2]=0;j=FY(h,k,vh(d),e+124|0,e+116|0,e+120|0);x[31725]=0;P(185,g|0,j|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break m}Bi(e+120|0,vh(x[a>>2]-c|0));b=x[e+120>>2];o:{if((b|0)<=0){break o}f=x[e+124>>2];m=z[a+34>>1];if((_d(m)|0)!=(f|0)){break o}i=D(c,f);l=x[a+20>>2];if(m&1){x[e+112>>2]=b;x[e+100>>2]=b;x[e- -64>>2]=b;x[e+48>>2]=b;x[e+96>>2]=f;x[e+92>>2]=x[e+116>>2];x[e+108>>2]=f;x[e+104>>2]=l+(i<<1);x[31725]=0;f=x[e+96>>2];x[e+40>>2]=x[e+92>>2];x[e+44>>2]=f;f=x[e+108>>2];x[e+56>>2]=x[e+104>>2];x[e+60>>2]=f;O(577,e+56|0,e+40|0);f=x[31725];x[31725]=0;if((f|0)!=1){break o}break m}x[e+88>>2]=b;x[e+76>>2]=b;x[e+32>>2]=b;x[e+16>>2]=b;x[e+72>>2]=f;x[e+68>>2]=x[e+116>>2];x[e+84>>2]=f;x[e+80>>2]=i+l;x[31725]=0;f=x[e+72>>2];x[e+8>>2]=x[e+68>>2];x[e+12>>2]=f;f=x[e+84>>2];x[e+24>>2]=x[e+80>>2];x[e+28>>2]=f;O(578,e+24|0,e+8|0);f=x[31725];x[31725]=0;if((f|0)==1){break m}}d=d-j|0;k=j+k|0;c=b+c|0;b=EY(h);continue}}break m}c=N()|0;break l}c=N()|0;Kc(e+136|0)}ub(g);Q(c|0);p()}DY(h)}Kc(e+136|0);ub(g);a=(h|0)!=0}fb=e+176|0;return a|0}function g8(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;x[h+12>>2]=b;x[e>>2]=0;bd(h,x[d+28>>2]);x[31725]=0;i=R(28,x[h>>2])|0;j=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Zb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Zb(h);Q(a|0);p()}jK(a,f+24|0,h+12|0,c,e,i);break b}iK(a,f+16|0,h+12|0,c,e,i);break b}g=a;i=b;a=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Kb(a);k=h,l=Ak(g,i,c,d,e,f,b,Cb(x[a+4>>2],y[a+11|0])+b|0),x[k+12>>2]=l;break b}a=rj(h+12|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}x[h>>2]=623865125;x[h+4>>2]=2032480100;k=h,l=Ak(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}x[h>>2]=623728933;x[h+4>>2]=1680158061;k=h,l=Ak(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=rj(h+12|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=rj(h+12|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=rj(h+12|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=rj(h+12|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=rj(h+12|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+12|0;b=fb-16|0;fb=b;x[b+12>>2]=c;while(1){H:{if(uh(a,b+12|0)){break H}c=Cl(x[a>>2]);if(!Kf(x[i+8>>2],1,c)){break H}Lm(a);continue}break}if(uh(a,b+12|0)){x[e>>2]=x[e>>2]|2}fb=b+16|0;break b}b=h+12|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Cb(x[a+4>>2],y[a+11|0])|0)==(0-Cb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=mt(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=y[111768]|y[111769]<<8|(y[111770]<<16|y[111771]<<24);v[h+7|0]=g;v[h+8|0]=g>>>8;v[h+9|0]=g>>>16;v[h+10|0]=g>>>24;g=y[111765]|y[111766]<<8|(y[111767]<<16|y[111768]<<24);x[h>>2]=y[111761]|y[111762]<<8|(y[111763]<<16|y[111764]<<24);x[h+4>>2]=g;k=h,l=Ak(a,b,c,d,e,f,h,h+11|0),x[k+12>>2]=l;break b}v[h+4|0]=y[111776];x[h>>2]=y[111772]|y[111773]<<8|(y[111774]<<16|y[111775]<<24);k=h,l=Ak(a,b,c,d,e,f,h,h+5|0),x[k+12>>2]=l;break b}a=rj(h+12|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}x[h>>2]=624576549;x[h+4>>2]=1394948685;k=h,l=Ak(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=rj(h+12|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Kb(a);k=h,l=Ak(g,i,c,d,e,f,b,Cb(x[a+4>>2],y[a+11|0])+b|0),x[k+12>>2]=l;break b}hK(f+20|0,h+12|0,c,e,i);break b}a=rj(h+12|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=fb-16|0;fb=a;x[a+12>>2]=c;b=6;c=h+12|0;L:{M:{if(uh(c,a+12|0)){break M}b=4;if((tl(i,Cl(x[c>>2]))|0)!=37){break M}b=2;if(!uh(Lm(c),a+12|0)){break L}}x[e>>2]=x[e>>2]|b}fb=a+16|0}a=x[h+12>>2]}fb=h+16|0;return a|0}function wk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;i=1;o(+b);c=j(1)|0;e=j(0)|0;a:{b:{g=c;p=c&2147483647;c:{if(!(p|e)){break c}o(+a);c=j(1)|0;f=j(0)|0;if(!f&(c|0)==1072693248){break c}q=c&2147483647;t=f;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(f|0)!=0|p>>>0>2146435072)&(!e|(p|0)!=2146435072))){return a+b}d:{e:{f:{g:{h:{r=0;i:{if((c|0)>0|(c|0)>=0){break i}r=2;if(p>>>0>1128267775){break i}r=0;if(p>>>0<1072693248){break i}f=p>>>20|0;if(p>>>0<1094713344){break h}m=1075-f|0;f=e>>>m|0;r=0;if((e|0)!=f<<m){break i}r=2-(f&1)|0}m=r;if(e){break f}if((p|0)!=2146435072){break g}if(!(q-1072693248|t)){break c}if(q>>>0<1072693248){break e}return(g|0)>0|(g|0)>=0?b:0}if(e){break f}f=1043-f|0;e=p>>>f|0;if((p|0)!=e<<f){break g}m=2-(e&1)|0}if((p|0)==1072693248){if((g|0)>0|(g|0)>=0){return a}return 1/a}if((g|0)==1073741824){return a*a}if((g|0)!=1071644672|(c|0)<0){break f}return M(a)}d=F(a);if(t){break d}j:{if((c|0)<0){if((c|0)==-2147483648|(c|0)==-1074790400|(c|0)==-1048576){break j}break d}if(!c|(c|0)==2146435072){break j}if((c|0)!=1072693248){break d}}i=(g|0)<0?1/d:d;if((c|0)>0|(c|0)>=0){break c}if(!(q-1072693248|m)){a=i-i;return a/a}return(m|0)==1?-i:i}return(g|0)>0|(g|0)>=0?0:-b}k:{if((c|0)>0|(c|0)>=0){break k}l:{switch(m|0){case 0:a=a-a;return a/a;case 1:break l;default:break k}}i=-1}m:{if(p>>>0>=1105199105){if(p>>>0>=1139802113){if(q>>>0<=1072693247){return(g|0)<0?Infinity:0}return(g|0)>0?Infinity:0}if(q>>>0<=1072693246){return(g|0)<0?i*1e300*1e300:i*1e-300*1e-300}if(q>>>0>=1072693249){return(g|0)>0?i*1e300*1e300:i*1e-300*1e-300}a=d+-1;d=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;h=d;d=a*1.4426950216293335;o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-d);break m}a=d*9007199254740992;e=q>>>0<1048576;d=e?a:d;o(+a);c=j(1)|0;j(0)|0;m=e?c:q;f=m&1048575;c=f|1072693248;m=(m>>20)+(e?-1076:-1023)|0;e=0;n:{if(f>>>0<235663){break n}if(f>>>0<767610){e=1;break n}c=f|1071644672;m=m+1|0}f=((e<<18)+(c>>>1|0)|0)+537395200|0;e=e<<3;w=C[e+3536>>3];o(+d);j(1)|0;t=0;l(0,j(0)|t);l(1,c|0);k=+n();s=C[e+3520>>3];h=k-s;u=1/(s+k);d=h*u;o(+d);c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();x=a;l(0,t|0);l(1,f|0);v=a*a;y=h;h=+n();k=u*(y-a*h-a*(k-(h-s)));h=k*(d+a);a=d*d;s=h+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();h=x*a;d=k*a+d*(s-(a+-3-v));o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=w+(a*-7.028461650952758e-9+(d-(a-h))*.9617966939259756);h=d;k=C[e+3552>>3];d=a*.9617967009544373;s=+(m|0);o(+(k+(h+d)+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-s-k-d)}l(0,0);l(1,g|0);k=+n();d=(b-k)*a+d*b;b=a*k;a=d+b;o(+a);c=j(1)|0;g=j(0)|0;o:{if((c|0)>=1083179008){if(g|c-1083179008){break b}if(!(d+8008566259537294e-32>a-b)){break o}break b}if((c&2147482624)>>>0<1083231232){break o}if(g|c+1064252416){break a}if(!(d<=a-b)){break o}break a}e=0;f=c&2147483647;if(f>>>0>=1071644673){g=c+(1048576>>>(f>>>20|0)-1022|0)|0;f=g>>>20&2047;e=(g&1048575|1048576)>>>1043-f|0;e=(c|0)<0?0-e|0:e;l(0,0);l(1,g&-1048576>>f-1023);b=b-+n();o(+(d+b));c=j(1)|0;j(0)|0}l(0,0);l(1,c|0);a=+n();k=a*.6931471824645996;d=(d-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=k+d;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);h=a*b/(b+-2);b=a;a=d-(a-k);a=b-(h-(b*a+a))+1;o(+a);c=j(1)|0;g=j(0)|0;c=(e<<20)+c|0;p:{if((c|0)<=1048575){a=tk(a,e);break p}l(0,g|0);l(1,c|0);a=+n()}i=i*a}return i}return i*1e300*1e300}return i*1e-300*1e-300}function oy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-32|0;fb=e;j=a+32|0;Pc(e+8|0,j,11);a:{b:{c:{if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])|x[a+8>>2]){b=x[a+76>>2]+x[a+20>>2]|0;f=x[a+16>>2];c=f+x[a+72>>2]|0;Ii(x[a+36>>2],c,c>>>0<f>>>0?b+1|0:b,0);b=x[a+36>>2];if(xk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){Qh(a,2,256);break a}b=x[a+104>>2];c=a+52|0;f=x[c>>2];d=pj(f,x[c+4>>2]);d:{if(b>>>0>d>>>0){n=fb-32|0;fb=n;f=b-d|0;d=x[zb(c)>>2];g=x[c+4>>2];e:{if(f>>>0<=(d-g|0)/24>>>0){d=fb-16|0;fb=d;b=CJ(d+4|0,c,f);c=x[b+4>>2];f=x[b+8>>2];while(1){if((c|0)==(f|0)){hc(b);fb=d+16|0}else{BJ(c);c=c+24|0;x[b+4>>2]=c;continue}break}break e}b=zb(c);d=LJ(n+12|0,OJ(c,pj(x[c>>2],g)+f|0),pj(x[c>>2],x[c+4>>2]),b);g=fb-16|0;fb=g;b=g+4|0;x[b>>2]=x[d+8>>2];h=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=h+D(f,24);f=x[b>>2];while(1){if(x[b+4>>2]!=(f|0)){BJ(f);f=x[b>>2]+24|0;x[b>>2]=f;continue}break}he(b);fb=g+16|0;k=fb-16|0;fb=k;b=vb(k+12|0,x[c+4>>2]);g=vb(k+8|0,x[c>>2]);h=x[vb(k+4|0,x[d+4>>2])>>2];m=fb-16|0;fb=m;p=m+8|0;f=fb-32|0;fb=f;Id(f+24|0,x[b>>2],x[g>>2]);q=f+16|0;b=x[f+24>>2];r=x[f+28>>2];g=fb-16|0;fb=g;x[g+8>>2]=h;x[g+12>>2]=b;while(1){if(pd(b,r)){b=ql(b);h=ql(x[g+8>>2]);l=z[b+18>>1]|z[b+20>>1]<<16;o=z[b+14>>1]|z[b+16>>1]<<16;w[h+14>>1]=o;w[h+16>>1]=o>>>16;w[h+18>>1]=l;w[h+20>>1]=l>>>16;l=x[b+12>>2];x[h+8>>2]=x[b+8>>2];x[h+12>>2]=l;l=x[b+4>>2];x[h>>2]=x[b>>2];x[h+4>>2]=l;b=$s(g+12|0);$s(g+8|0);b=x[b>>2];continue}break}Ac(q,b,g+8|0);fb=g+16|0;b=x[f+16>>2];x[f+12>>2]=x[f+20>>2];Ac(p,b,f+12|0);fb=f+32|0;fb=m+16|0;x[d+4>>2]=x[m+12>>2];Ub(c,d+4|0);Ub(c+4|0,d+8|0);Ub(zb(c),nc(d));x[d>>2]=x[d+4>>2];fb=k+16|0;JJ(d)}fb=n+32|0;break d}if(b>>>0<d>>>0){FJ(c,f+D(b,24)|0)}}f=a+40|0;xo(f,x[a+104>>2]<<2);while(1){if(A[a+104>>2]>i>>>0){b=x[a+36>>2];if(xk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){Qh(a,2,1024);break a}c=z[a+24>>1];w[e>>1]=c;if((c|0)==65535){yy(b,e);c=z[e>>1]}b=Sc(x[a+40>>2],x[a+44>>2]);d=c&65535;f:{if(!d){c=0;break f}if(d>>>0>(b^-1)>>>0){break f}_j(f,b+d|0);Ej(x[a+36>>2],xb(x[a+40>>2],b),d)}d=wf(x[a+52>>2],i);x[d>>2]=b;w[d+20>>1]=c;Pc(e+8|0,j,6);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){vl(x[a+36>>2],e+8|0);b=x[e+8>>2];c=x[e+12>>2];if(!sy(b,c)){break c}d=wf(x[a+52>>2],i);x[d+8>>2]=b;x[d+12>>2]=c}b=x[a+8>>2];g:{if(b){c=wf(x[a+52>>2],i);x[c+16>>2]=b;break g}Pc(e+8|0,j,7);if(!Hb(x[x[e+8>>2]>>2],x[e+12>>2])){c=wf(x[a+52>>2],i);break g}vl(x[a+36>>2],e+8|0);b=x[e+8>>2];if(!sy(b,x[e+12>>2])){break b}c=wf(x[a+52>>2],i);x[c+16>>2]=b}h:{if(x[c+16>>2]==-1){break h}Pc(e+8|0,j,6);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break h}i:{if(!i){c=0;d=wf(x[a+52>>2],0);b=0;break i}d=x[a+52>>2];b=wf(d,i-1|0);g=x[b+16>>2];c=x[b+8>>2]+g|0;b=x[b+12>>2];d=wf(d,i);b=c>>>0<g>>>0?b+1|0:b}x[d+8>>2]=c;x[d+12>>2]=b}Pc(e+8|0,j,8);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){w[e+30>>1]=0;yy(x[a+36>>2],e+30|0);Pc(e+8|0,j,9);Um(x[a+36>>2],z[e+30>>1]<<Hb(x[x[e+8>>2]>>2],x[e+12>>2]))}i=i+1|0;continue}break}$d(e+8|0,x[a+36>>2]);b=x[e+20>>2];x[a+80>>2]=x[e+16>>2];x[a+84>>2]=b}d=e+8|0;Pc(d,j,4);Jf(d,1);f=x[a+80>>2];g=x[a+84>>2];b=x[a+96>>2];h=x[a+16>>2];i=b+h|0;k=x[a+100>>2];c=k+x[a+20>>2]|0;c=i>>>0<h>>>0?c+1|0:c;h=i;i=(b|0)==x[a+72>>2]&(k|0)==x[a+76>>2];b=i?f:h;x[a+88>>2]=b;c=i?g:c;x[a+92>>2]=c;Ii(x[a+36>>2],b,c,0);Pc(d,j,6);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}Pc(e,j,7);if(!(Hb(x[x[e>>2]>>2],x[e+4>>2])|x[a+8>>2])){break a}c=x[a+88>>2];d=x[a+16>>2];b=c-d|0;f=x[a+92>>2]-(x[a+20>>2]+(c>>>0<d>>>0)|0)|0;j=x[a+52>>2];g=x[a+104>>2];a=0;while(1){if((a|0)==(g|0)){break a}c=wf(j,a);d=c;h=x[c+8>>2];i=h+b|0;c=x[c+12>>2]+f|0;x[d+8>>2]=i;x[d+12>>2]=i>>>0<h>>>0?c+1|0:c;a=a+1|0;continue}}Qh(a,2,2048);break a}Qh(a,2,2048)}fb=e+32|0}function eS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-16|0;fb=i;a:{b:{c:{if(!Tc(c)|!d|x[b+480180>>2]!=16777216|z[b+480192>>1]<d>>>0){break c}d=x[((d<<2)+b|0)+900380>>2];if(!d){break c}d=x[d+44>>2];if(!d){break c}w[i+14>>1]=c-61;b=fb+-64|0;fb=b;d:{e:{e=w[d+28>>1];g=i+14|0;c=w[g>>1];if((e|0)<=(c|0)){if((c|0)<=(oc(x[d+4>>2],x[d+8>>2])+e|0)-1<<16>>16){break e}}Fb(a);break d}f:{e=z[d+30>>1];if(!e){c=d+52|0;d=iA(c,g);if(!Zg(d,Rf(c))){break f}Cm(a,td(d)+4|0);break d}c=hA(c,e<<16>>16);w[b+62>>1]=c;e=Fb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=d+52|0;f=iA(a,b+62|0);t:{if(Zg(f,Rf(a))){x[31725]=0;O(131,e|0,td(f)+4|0);a=x[31725];x[31725]=0;if((a|0)==1){break t}a=w[d+30>>1];c=w[g>>1];x[31725]=0;m=b,n=gA(c,a)+5|0,x[m+36>>2]=n;O(128,b+48|0,b+36|0);a=x[31725];x[31725]=0;u:{if((a|0)!=1){x[31725]=0;P(76,e|0,b+48|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break u}tb(b+48|0);break d}a=N()|0;break g}a=N()|0;tb(b+48|0);break g}if(w[d+30>>1]>26){break q}x[31725]=0;c=U(543,b+36|0,1,c+65<<24>>24)|0;a=x[31725];x[31725]=0;if((a|0)==1){break s}x[31725]=0;S(603,b+48|0,0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break r}a=b+48|0;f=Ab(e,a);tb(a);tb(c);x[31725]=0;P(129,f|0,14629)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break p}}a=N()|0;break g}a=N()|0;break g}a=N()|0;tb(c);break g}x[31725]=0;f=c;a=c<<16>>16;c=(a|0)/16|0;x[b+32>>2]=f-(c<<4)<<16>>16;O(884,b+36|0,b+32|0);f=x[31725];x[31725]=0;if((f|0)==1){break o}x[31725]=0;x[b+16>>2]=(c<<16>>16)%16;O(884,b+20|0,b+16|0);c=x[31725];x[31725]=0;if((c|0)==1){break n}x[31725]=0;S(2,b+48|0,b+36|0,b+20|0);c=x[31725];x[31725]=0;if((c|0)==1){break m}c=b+48|0;h=Ab(e,c);tb(c);tb(b+20|0);tb(b+36|0);if((a|0)<256){break p}x[31725]=0;O(885,b+4|0,h|0);a=x[31725];x[31725]=0;if((a|0)==1){break k}j=b+36|0;f=b+4|0;c=zd(f);k=Df(f);l=zd(f);a=fb-16|0;fb=a;x[a+8>>2]=l;x[a+12>>2]=c;while(1){if(Ib(c,k)){m=x[a+8>>2],n=Rq(v[c|0]),v[m|0]=n;c=me(a+12|0);me(a+8|0);c=x[c>>2];continue}break}fb=a+16|0;_c(j,f);x[31725]=0;S(603,b+48|0,0,j|0);a=x[31725];x[31725]=0;if((a|0)==1){break j}a=b+48|0;Ab(h,a);tb(a);tb(b+36|0);tb(b+4|0)}a=w[d+30>>1];c=w[g>>1];x[31725]=0;m=b,n=gA(c,a)+5|0,x[m+20>>2]=n;O(128,b+48|0,b+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break i}x[31725]=0;P(76,e|0,b+48|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break h}tb(b+48|0);break d}a=N()|0;break g}a=N()|0;break l}a=N()|0;tb(b+20|0)}tb(b+36|0);break g}a=N()|0;break g}a=N()|0;tb(b+36|0);tb(b+4|0);break g}a=N()|0;break g}a=N()|0;tb(b+48|0)}break a}f=fb-16|0;fb=f;e=f+4|0;d=fb-32|0;fb=d;c=rf(d+20|0,1,0);v:{w:{x:{while(1){h=Kb(c);ws(d+12|0,h,Cb(x[c+4>>2],y[c+11|0])+h|0,w[g>>1]);if(!x[d+16>>2]){break x}h=ri(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,h|0);h=x[31725];x[31725]=0;if((h|0)!=1){continue}break}break w}g=x[d+12>>2];h=Kb(c);x[31725]=0;O(46,c|0,g-h|0);g=x[31725];x[31725]=0;y:{if((g|0)!=1){x[31725]=0;O(47,e|0,c|0);g=x[31725];x[31725]=0;if((g|0)!=1){break y}break w}break w}tb(c);fb=d+32|0;break v}a=N()|0;tb(c);Q(a|0);p()}Sh(a,e);tb(e);fb=f+16|0}fb=b- -64|0;break b}d=x[b>>2];b=fb-32|0;fb=b;z:{if(Ol(c)){x[b+16>>2]=x[7628];d=x[7627];x[b+8>>2]=x[7626];x[b+12>>2]=d;d=x[7625];x[b>>2]=x[7624];x[b+4>>2]=d;tc(a,(b+(c<<2)|0)-1004|0);break z}if(Tc(c)){e=Fb(b);x[31725]=0;c=c-1|0;g=(c|0)/12|0;c=P(886,e|0,d+(D(g,-12)+c<<16>>16<<2)|0)|0;d=x[31725];x[31725]=0;A:{if((d|0)==1){break A}x[31725]=0;c=P(887,c|0,g+48&255)|0;d=x[31725];x[31725]=0;if((d|0)==1){break A}x[31725]=0;P(3,a|0,c|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break A}tb(c);break z}a=N()|0;break a}if(!c){tc(a,16775);break z}tc(a,14600)}fb=b+32|0}fb=i+16|0;return}tb(e);Q(a|0);p()}function QS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=a+1074376|0;h=D(b,872);f=(g+h|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+h|0)+1075080|0;x[a>>2]=x[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(y[a+480209|0]&16)){break a}if(Uj(x[f+656>>2])){a=D(b,872)+a|0;w[a+1075764>>1]=d-8;a=a+1075843|0;v[a|0]=y[a|0]|64;break a}if(x[a+480180>>2]!=64){b=D(b,872)+a|0;c=d<<28>>24;w[b+1075764>>1]=c;f=z[(d<<1)+31712>>1];x[b+1075696>>2]=f;d=b+1075692|0;if(!x[d>>2]){break a}l=d,m=yh(a,y[b+1075789|0],c,f),x[l>>2]=m;break a}a=D(b,872)+a|0;b=x[a+1075096>>2];if(!b){break a}x[a+1075696>>2]=x[b+24>>2]+D(d,80);break a;case 2:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075814|0]=c&3;break a}Jb(e+8|0,a+1074312|0,21);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){v[(D(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075817|0]=c&3;break a}Jb(e+8|0,a+1074312|0,21);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){v[(D(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Jb(e+8|0,a+1074312|0,21);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){a=D(b,872)+a|0;v[a+1075813|0]=0;v[a+1075820|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(x[a+1074392>>2]|!(y[a+480209|0]&16)){break a}a=a+1074400|0;x[a>>2]=x[a>>2]+d;break a;case 6:if(!(y[a+480209|0]&16)){break a}if(d>>>0<=2){c=z[a+480188>>1];h=c>>>0<=256?256:c;i=a+906300|0;j=b+1|0;k=d-1|0;while(1){if((c|0)==(h|0)){break a}f=D(c,872)+a|0;c:{if(z[f+1075778>>1]!=(j|0)){break c}d:{e:{switch(k|0){case 0:Lo(a,f+1074992|0);if(!(y[f+1075081|0]&2)){break d}d=x[a+1298300>>2];if(!Dd(d)){break d}Gk(d,c&65535);break d;case 1:g=f+1075080|0;d=x[g>>2];x[g>>2]=d|4096;if(!(d&512)){break d}d=x[a+1298300>>2];if(!Dd(d)){break d}Gk(d,c&65535);break d;default:break e}}x[f+1075688>>2]=0;g=f+1075080|0;d=x[g>>2];x[g>>2]=d|4096;if(!(d&512)){break d}d=x[a+1298300>>2];if(!Dd(d)){break d}Oj(d,c&65535,1)}d=x[f+1075648>>2];if(!d){break c}g=y[d+34|0];if(!g){break c}g=x[vd(i,g-1|0)>>2];if(!g){break c}ib[x[x[g>>2]+96>>2]](g,d,y[f+1075789|0]|256,0,b)}c=c+1|0;continue}}uV(f,d,x[a+480180>>2]);break a;case 7:if(!(y[a+480209|0]&16)){break a}fn(a,f,d,4);break a;case 8:b=f;c=x[a+480208>>2];f:{if(!(c&4096)){break f}g:{switch(d|0){case 0:x[b+88>>2]=x[b+88>>2]&-257;break f;case 1:x[b+692>>2]=128;x[b+88>>2]=x[b+88>>2]|256;break f;case 8:x[b+88>>2]=x[b+88>>2]&-25165825|16777216;break f;case 9:x[b+88>>2]=x[b+88>>2]&-25165825|8388608;break f;case 10:x[a+480208>>2]=c&-16385;break f;case 11:x[a+480208>>2]=c|16384;break f;case 12:x[a+480208>>2]=c&-8193;break f;case 13:x[a+480208>>2]=c|8192;break f;case 14:x[b+88>>2]=x[b+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(x[b>>2]|x[b+4>>2]){break h}a=x[b+76>>2];if(!a){break h}if(!(l=Tc(y[b+788|0]),m=1,n=y[b+88|0]&2,n?l:m)){break h}x[b>>2]=-1;x[b+4>>2]=a-1}x[b+88>>2]=x[b+88>>2]|128}break a;case 9:if(!(y[a+480209|0]&16)){break a}c=D(b,872)+a|0;v[c+1075828|0]=d;Jb(e+8|0,a+1074312|0,35);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}if(!Tc(y[c+1075780|0])){break a}b=x[(D(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}x[f+4>>2]=a;break a;case 10:if(!(y[a+480209|0]&16)){break a}uB(a,g,b,d);break a;case 11:i:{if(d){break i}d=1;c=x[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}Jb(e+8|0,a+1074312|0,30);cB(a,b,d,Hb(x[x[e+8>>2]>>2],x[e+12>>2])|x[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(x[a+480180>>2]==2){break a}v[(D(b,872)+a|0)+1075836|0]=d}fb=e+16|0}function Eta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;f=fb-320|0;fb=f;xc(b);d=fb-16|0;fb=d;L_(d+8|0,f+102|0);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;a:{b:{c:{if((g|0)!=(h|0)){break c}if(!N_(f+102|0)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(M_(y[f+318|0],y[f+319|0]),hb))){break c}if(!c){e=1;break c}Bd(a,2);gg(a);x[a+480188>>2]=524296;t=a,u=_e(455e3),x[t+480204>>2]=u;Lb(a+1074312|0,110,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=f+72|0;We(d,2,f+133|0);e=f+88|0;Cc(e,d);Ab(a+1298308|0,e);tb(e);e=0;d:{e:{while(1){if((e|0)==8){f:{d=Xb(x[a+484360>>2],y[a+484376|0]);o=y[f+318|0];m=o+1|0;jk(d,b,m,65535,65535);d=Nb(f+88|0);x[31725]=0;S(236,b|0,d|0,m|0);e=x[31725];x[31725]=0;if((e|0)==1){break f}t=f,u=wb(x[d>>2]),x[t+72>>2]=u;e=wb(x[d+4>>2]);while(1){g=x[f+72>>2];q=Ib(g,e);if(q){if((y[g|0]-1&255)>>>0>7){break d}me(f+72|0);continue}break}t=a,u=y[xb(x[d>>2],0)|0],x[t+480196>>2]=u;e=y[f+317|0];h=y[f+319|0];g=Nb(f+72|0);x[31725]=0;n=h+1|0;S(236,b|0,g|0,n|0);h=x[31725];x[31725]=0;g:{if((h|0)==1){break g}x[31725]=0;h=a+484344|0;O(225,h|0,n|0);j=x[31725];x[31725]=0;if((j|0)==1){break g}r=e+1|0;if(!(c&1)){break e}c=0;while(1){if((c|0)==(n|0)){break e}e=y[xb(x[g>>2],c)|0];x[31725]=0;e=U(198,h|0,e|0,r|0)|0;j=x[31725];x[31725]=0;h:{if((j|0)!=1){if(!e){break e}j=0;l=Wb(x[h>>2],y[xb(x[g>>2],c)|0]);i:while(1){s=j&65535;if(s>>>0>7){break h}j=j+1|0;e=0;while(1){if(A[l+12>>2]<=e>>>0){continue i}x[31725]=0;i=R(199,b|0)|0;k=x[31725];x[31725]=0;j:{k:{if((k|0)!=1){i=i<<24>>24;if((i|0)>=0){break k}e=(i&127)+e|0;break j}break b}k=jd(x[l>>2],x[x[l+48>>2]+12>>2],e,s);if((i|0)==1){v[k|0]=254;break j}if((i-1&255)>>>0>96){break j}v[k+1|0]=j;v[k|0]=i+12}e=e+1|0;continue}}}break b}c=c+1|0;continue}}break b}}else{h=f+88|0;d=(f+102|0)+D(e,19)|0;ND(h,d+63|0);g=f+72|0;Cc(g,h);pm(((e<<5)+a|0)+480289|0,g);tb(g);e=e+1|0;j=D(e,104)+a|0;i=j+484380|0;ld(i,2);v[f+83|0]=0;g=y[d+78|0]|y[d+79|0]<<8|(y[d+80|0]<<16|y[d+81|0]<<24);v[f+79|0]=g;v[f+80|0]=g>>>8;v[f+81|0]=g>>>16;v[f+82|0]=g>>>24;g=y[d+75|0]|y[d+76|0]<<8|(y[d+77|0]<<16|y[d+78|0]<<24);d=y[d+71|0]|y[d+72|0]<<8|(y[d+73|0]<<16|y[d+74|0]<<24);x[f+16>>2]=x[f+80>>2];x[f+72>>2]=d;x[f+76>>2]=g;d=x[f+76>>2];x[f+8>>2]=x[f+72>>2];x[f+12>>2]=d;_k(i,1,f+8|0);x[j+484404>>2]=8215;d=f+60|0;Cc(d,h);zc(((e<<5)+a|0)+946304|0,d);tb(d);continue}break}e=N()|0;break a}j=o+1|0;e=0;while(1){l:{if((e|0)==(j|0)){x[31725]=0;b=P(1,f+60|0,8616)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break l}break b}b=Xb(x[a+484360>>2],y[a+484376|0]);i=e&65535;m:{if(!cj(b,i)){x[31725]=0;c=P(369,h|0,r|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}if((c|0)==65535){break m}b=Xb(x[a+484360>>2],y[a+484376|0]);t=_b(x[b>>2],e),u=c,w[t>>1]=u}b=MD(wb(x[Wb(x[h>>2],z[_b(x[b>>2],e)>>1])+4>>2]),1);c=y[b+5|0];l=y[xb(x[d>>2],(e+1>>>0)%(m>>>0)|0)|0];if((c|0)==(l|0)){break m}n:{if(y[b+3|0]!=16){break n}c=y[a+484376|0];k=x[a+484360>>2];x[31725]=0;c=P(370,Xb(k,c)|0,i|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}if((c|0)==65535){break n}b=MD(wb(x[Wb(x[h>>2],c)+4>>2]),1)}v[b+5|0]=l;v[b+3|0]=16}e=e+1|0;continue}break}Ab(a+1298344|0,b);tb(b);x[31725]=0;b=P(1,f+48|0,6049)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}Ab(a+1298356|0,b);tb(b);b=f+24|0;wi(b,2,f+113|0);x[31725]=0;S(371,f+36|0,4,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}b=f+36|0;Ab(a+1298368|0,b);tb(b);t=a+1298404|0,u=x[Fc(b,4)>>2],x[t>>2]=u;dc(g)}dc(d);e=q^1}fb=f+320|0;return e|0}e=N()|0;dc(g)}dc(d);Q(e|0);p()}function Gta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=fb-960|0;fb=e;xc(b);d=fb-16|0;fb=d;h=e+862|0;U_(d+8|0,h);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(f|0)==(g|0);if(!d){T_(h)}a:{if(!d){break a}if(!W_(e+862|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(V_(y[e+909|0]|y[e+910|0]<<8),hb))){break a}if(!c){l=1;break a}Bd(a,512);x[a+480228>>2]=32;w[a+480188>>1]=16;x[a+480196>>2]=y[e+937|0];x[a+480208>>2]=16;x[a+480200>>2]=256;x[a+480204>>2]=8e5;Lb(a+1074312|0,7,1);d=e+88|0;f=tc(d,8224);Ab(a+1298344|0,f);tb(f);f=tc(d,8912);Ab(a+1298356|0,f);tb(f);s=a+1298404|0,t=x[Fc(d,4)>>2],x[s>>2]=t;f=e+12|0;R_(f,e+866|0);Cc(d,f);Ab(a+1298308|0,d);tb(d);d=0;while(1){if((d|0)==16){b:{d=y[e+958|0]|y[e+959|0]<<8;if(d){gE(a+1298332|0,b,d,132,0)}d=fb-16|0;fb=d;h=e+88|0;bc(d+8|0,h,771);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Vb(b,x[d+12>>2])}fb=d+16|0;l=(f|0)==(g|0);if(!l){Tb(h,0,771)}if(!l){break a}d=a+484376|0;Q_(Xb(x[a+484360>>2],y[d|0]),e+88|0,y[e+345|0]);bf(Xb(x[a+484360>>2],y[d|0]),y[e+346|0]);cd(b,y[e+909|0]|y[e+910|0]<<8);m=a+484344|0;o=c&1;h=0;while(1){c:{if((h|0)==256){if(!(c&2)){break a}u0(b,e+60|0);d=0;while(1){if((d|0)==64){break a}if(!(y[e+60+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}if(!OD(b,e+12|0)){break a}d=d+1|0;w[a+480190>>1]=d;We(e,1,e+12|0);h=e+68|0;Cc(h,e);zc(((z[a+480190>>1]<<5)+a|0)+946304|0,h);tb(h);c=(D(d,104)+a|0)+484380|0;ld(c,0);i=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[c>>2]=i;f=y[e+50|0]|y[e+51|0]<<8|(y[e+52|0]<<16|y[e+53|0]<<24);x[c+4>>2]=f;g=y[e+54|0]|y[e+55|0]<<8|(y[e+56|0]<<16|y[e+57|0]<<24);x[c+24>>2]=16726;x[c+8>>2]=g;w[c+30>>1]=y[e+49|0]<<4;if(v[e+58|0]&1){g=g>>>1|0;x[c+8>>2]=g;f=f>>>1|0;x[c+4>>2]=f;x[c>>2]=i>>>1}if(!(!(y[e+59|0]&8)|f>>>0>=g>>>0)){w[c+34>>1]=z[c+34>>1]|2}Xc(h,v[e+58|0]&1?16:8,1,0,0);fg(h,c,b);continue}}d:{d=(h<<1)+e|0;g=y[d+347|0]|y[d+348|0]<<8;if(g){f=e+68|0;fe(f,b,g);i=ic(e+12|0,f);ub(f);n=((y[d+347|0]|y[d+348|0]<<8)-2|0)/64|0;e:{if(!o){break e}x[31725]=0;d=U(198,m|0,h&65535,n|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}if(!d){break e}x[31725]=0;d=R(199,i|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}x[31725]=0;P(185,i|0,1)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}q=d?d>>>0>=n-2>>>0?-1:d+1|0:-1;f=0;f:while(1){if((f|0)!=(n|0)){d=Wb(x[m>>2],h);cf(e+68|0,x[d>>2],x[x[d+48>>2]+12>>2],f);s=e,t=wb(x[e+68>>2]),x[s>>2]=t;r=iw(x[e+68>>2],x[e+72>>2]);while(1){d=x[e>>2];if(!Ib(d,r)){f=f+1|0;continue f}x[31725]=0;O(359,e+60|0,i|0);g=x[31725];x[31725]=0;if((g|0)==1){break c}j=e+60|0;g=af(j);j=fj(j);k=y[e+60|0];if((k-1&255)>>>0<=71){v[d|0]=k+36;s=d,t=y[Jc(e+60|0)|0]+1|0,v[s+1|0]=t}if((y[g|0]-1&255)>>>0<=15){v[d+2|0]=1;v[d+4|0]=((y[g|0]<<6)+-64>>>0)/15}k=y[j|0];g=k&15;v[d+5|0]=g;g:{h:{switch((y[j|0]>>>4|0)-1|0){case 0:case 1:v[d+5|0]=k|240;break g;case 2:v[d+5|0]=g<<2;break g;case 3:v[d+5|0]=(6/(g+1>>>0)|0)+1;break g;case 5:case 6:v[d+5|0]=g<<3;break g;case 9:v[d+2|0]=1;v[d+4|0]=(g<<2)+4;break g;case 10:v[d+5|0]=g|128;break g;case 11:break h;default:break g}}v[d+5|0]=(6/(g+1>>>0)|0)+1|13}v[d+3|0]=y[(y[j|0]>>>4|0)+24736|0];vg(e);continue}}break}ye(Wb(x[m>>2],h),Zh(Ye(Ne(e+68|0,14,0),q)))}ub(i)}h=h+1|0;continue}}break}}}else{f=(d<<5)+a|0;h=f+480280|0;Xe(h);g=h;h=(e+862|0)+d|0;x[g>>2]=!y[h+50|0]<<10;w[f+480284>>1]=(y[h+76|0]<<4|8)&248;d=d+1|0;continue}break}a=N()|0;ub(i);Q(a|0);p()}fb=e+960|0;return l|0}function A1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=fb-560|0;fb=e;xc(b);d=fb-16|0;fb=d;f=e+63|0;oF(d+8|0,f);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(g|0)==(j|0);if(!d){nF(f)}a:{if(!d){break a}if(!qF(e+63|0)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],Bc(pF(y[e+173|0],y[e+174|0]),hb))){break a}Bd(a,64);x[a+480204>>2]=78e4;x[a+480260>>2]=112;x[a+480264>>2]=13696;x[a+480196>>2]=4;w[a+480188>>1]=8;Lb(a+1074312|0,7,1);d=e+36|0;g=tc(d,14642);Ab(a+1298344|0,g);tb(g);g=tc(d,14675);Ab(a+1298356|0,g);tb(g);ci(a+1298368|0,(y[e+63|0]|y[e+64|0]<<8)==26217?14642:14670);o=a+1298404|0,p=x[Fc(d,4)>>2],x[o>>2]=p;f=y[e+173|0];w[a+480190>>1]=f;g=1;while(1){j=g&65535;if(j>>>0<=f>>>0){f=fb-16|0;fb=f;d=e+36|0;bc(f+8|0,d,25);l=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(l|0)){Vb(b,x[f+12>>2])}fb=f+16|0;if((i|0)!=(l|0)){v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;v[d+24|0]=0;v[d+16|0]=0;v[d+17|0]=0;v[d+18|0]=0;v[d+19|0]=0;v[d+20|0]=0;v[d+21|0]=0;v[d+22|0]=0;v[d+23|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;v[d+11|0]=0;v[d+12|0]=0;v[d+13|0]=0;v[d+14|0]=0;v[d+15|0]=0}if((y[e+49|0]|y[e+50|0]<<8|(y[e+51|0]<<16|y[e+52|0]<<24))>>>0>67108863){break a}f=(D(j,104)+a|0)+484380|0;ld(f,0);x[f+24>>2]=8363;l=e+36|0;d=l;i=y[d+13|0]|y[d+14|0]<<8|(y[d+15|0]<<16|y[d+16|0]<<24);x[f>>2]=i;k=y[d+17|0]|y[d+18|0]<<8|(y[d+19|0]<<16|y[d+20|0]<<24);x[f+4>>2]=k;d=y[d+21|0]|y[d+22|0]<<8|(y[d+23|0]<<16|y[d+24|0]<<24);x[f+8>>2]=d;c:{if(!(k|d>>>0<=i>>>0)){x[f+8>>2]=0;break c}if(d){w[f+34>>1]=2;al(f)}}f=e+12|0;nk(f,2,l);d=e+24|0;Cc(d,f);zc(((j<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);f=z[a+480190>>1];continue}break}g=e+24|0;h=e+65|0;wg(g,3,h,36);d=e+36|0;Cc(d,g);Ab(a+1298308|0,d);tb(d);g=0;mF(a+1298332|0,h,108,36,0);d=a+484376|0;Fw(Xb(x[a+484360>>2],y[d|0]),e+176|0,128,255,254);d=Xb(x[a+484360>>2],y[d|0]);h=y[e+175|0];if(z[_b(x[d>>2],h)>>1]<y[e+174|0]){bf(d,h)}while(1)if((g|0)==8){j=a+484344|0;Vf(j,y[e+174|0]);n=c&1;f=0;while(1)if(y[e+174|0]<=f>>>0){h=1;if(!(c&2)){break a}c=Xc(e+36|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>z[a+480190>>1]){break b}fg(c,(D(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{d:{e:{if(n){if(Ng(j,f&65535,64)){break e}}Vb(b,1536);break d}x[e+24>>2]=-1;x[e+28>>2]=-1;l=0;f:while(1){if((l|0)==64){d=x[j>>2];g=(e+63|0)+f|0;h=y[g+369|0];if(h>>>0<63){ye(Wb(d,f),Zh(Ye(Ne(e+36|0,14,0),h)));d=x[j>>2]}ye(Wb(d,f),Zh(Ne(e+36|0,16,y[g+241|0])));break d}g=0;d=Wb(x[j>>2],f);h=jd(x[d>>2],x[x[d+48>>2]+12>>2],l,0);while(1){if((g|0)==8){l=l+1|0;continue f}d=e+36|0;Xr(d,b);i=Jc(d);k=af(d);i=y[i|0];d=y[e+36|0];if(d>>>0<=253){v[h|0]=(d>>>2|0)+37;v[h+1|0]=(d<<4&48|i>>>4)+1;v[(e+24|0)+g|0]=255;d=y[e+36|0]}if((d&255)!=255){v[h+2|0]=1;v[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=y[k|0];if((d|0)!=255){v[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;g:{h:{if(!(d&15)&(d|0)!=48){break h}k=y[i|0];if((k|0)==255){break g}m=k<<24>>24;d=m&15;v[h+5|0]=d;i:{if((m|0)<0){break i}k=k>>>4|0;v[h+3|0]=y[k+24536|0];j:{switch(k-3|0){case 0:v[h+5|0]=d|32;break h;case 1:v[h+5|0]=d|m<<4;break g;case 2:break h;case 3:break j;default:break g}}k:{switch(d|0){case 0:v[h+5|0]=79;break g;case 1:break k;default:break i}}v[h+5|0]=244;break g}v[h+3|0]=0;break g}v[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;Xe(d+480280|0);w[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}fb=e+560|0;return h|0}function $A(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0;f=fb-16|0;fb=f;m=D(b,872)+a|0;n=m+1075800|0;i=y[n|0];k=a+1074312|0;Jb(f+8|0,k,23);h=c&15;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){if(!(x[a+1074392>>2]|!y[(D(b,872)+a|0)+1075780|0])){v[n|0]=h;break i}e=y[n|0];if(e){g=e-1|0;v[n|0]=g;e=0;if(g&255){break c}}v[n|0]=h;e=1;break c}Jb(f+8|0,k,52);g=c&256;if(!(!g|!Hb(x[x[f+8>>2]>>2],x[f+12>>2]))){g=x[a+480208>>2]&4096;if(!g){break e}e=D(b,872)+a|0;if(y[e+1075781|0]){i=_Z(y[e+1075780|0])?1:i}if(y[(D(b,872)+a|0)+1075784|0]?y[e+1075782|0]==1:0){break b}e=0;if(h>>>0>i>>>0){break c}if(!g){break d}if(Tc(y[(D(b,872)+a|0)+1075780|0])){break c}break d}j=x[a+480180>>2];if(j&16777250){e=!(i?(i>>>0)%((h>>>0<=1?1:h)>>>0)|0:1);i=i+1|0;break c}if((j|0)==16){break g}if((j|0)!=1){break f}e=A[a+1074392>>2]%A[a+1074416>>2]|0;if(!e){if(Tc(y[(D(b,872)+a|0)+1075780|0])){break a}}if(h){break h}}e=0;break c}e=!((e>>>0)%(h>>>0)|0);break c}e=x[a+1074392>>2]==(h|0)&(h|0)!=0;break c}j:{if(!g){break j}e=D(b,872)+a|0;if(y[e+1075782|0]!=1){break j}h=(y[e+1075785|0]>15)+h|0}k:{if(x[a+480208>>2]&4096?g:1){h=h>>>0<=1?1:h;e=0;e=!x[a+1074416>>2]|g?e:!(A[a+1074392>>2]%(h>>>0)|0);i=i+1|0;break k}e=0;i=j&1048580?0:i}if(!(!(y[(D(b,872)+a|0)+1075780|0]|!g?x[a+1074392>>2]:1)|(i&255)>>>0<h>>>0)){e=1}Jb(f+8|0,k,52);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])|c){break c}e=!x[a+1074392>>2];break c}if(h>>>0>i>>>0){break c}}i=0;e=1}h=m+1074992|0;q=(D(b,872)+a|0)+1075068|0;l:{if(x[q>>2]){break l}Jb(f+8|0,k,38);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break l}if(!Lj(x[h+656>>2])){break a}}Jb(f+8|0,k,106);if(C=0,E=Hb(x[x[f+8>>2]>>2],x[f+12>>2]),F=x[(D(b,872)+a|0)+1075688>>2],F?C:E){break a}if(e){j=D(b,872)+a|0;r=j+1075680|0;g=x[r>>2];x[f+4>>2]=g;e=c>>>4&15;m:{if(!e){e=x[j+1075080>>2];break m}Jb(f+8|0,k,52);n:{if(C=Hb(x[x[f+8>>2]>>2],x[f+12>>2]),E=0,F=y[(D(b,872)+a|0)+1075782|0]==1,F?C:E){break n}if(!(16191>>>e&1)){x[f+4>>2]=(D(g,v[e+32128|0])|0)/16;break n}x[f+4>>2]=g+(v[e+32144|0]<<2)}Fe(f+4|0,0,256);g=(D(b,872)+a|0)+1075080|0;e=x[g>>2]|2097152;x[g>>2]=e}l=D(b,872)+a|0;s=l+1075692|0;t=x[s>>2];g=y[l+1075794|0];j=0;if(e&512){Jb(f+8|0,k,108);j=Hb(x[x[f+8>>2]>>2],x[f+12>>2])}if(!((j^-1)&x[a+480180>>2]==2|(!x[q>>2]|(g-1&255)>>>0>119))){WS(a,b,0,g,1)}o:{if(!(x[a+480180>>2]&1048580)){m=0;break o}m=(c|0)<256;if((c|0)>255){break o}e=y[(D(b,872)+a|0)+1075781|0];if(!e){break o}m=1;Ro(a,h,e,0,0,1)}l=l+1075080|0;Jb(f+8|0,k,85);p:{if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break p}e=D(b,872)+a|0;o=y[e+1075781|0];if(!o){break p}e=e+1075764|0;p=z[e>>1];Ro(a,h,o,0,0,1);w[e>>1]=p}o=D(b,872)+a|0;p=o+1075652|0;u=x[p>>2];B=x[l>>2];x[p>>2]=0;Jb(f+8|0,k,23);e=1;q:{if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break q}e=0;if(x[a+480180>>2]!=2){break q}e=(j^1)&x[q>>2]!=0}Su(a,h,g,e,m,0,b);if(!y[o+1075781|0]){x[p>>2]=u}if(!(!(B&4096)|x[a+480180>>2]!=4)){x[l>>2]=x[l>>2]|4096}j=o+1075780|0;x[r>>2]=x[f+4>>2];if(z[a+480192>>1]){v[j|0]=g;US(a,b)}g=x[a+480180>>2];if(!(!(g&16777248)|(y[j|0]|!t))){x[s>>2]=t}if(e){x[h>>2]=0;x[h+4>>2]=0}e=g&16777250;r:{if(d-11>>>0<4294967286){break r}g=x[(D(b,872)+a|0)+1075096>>2];if(!g){break r}s:{if((d|0)==1){b=x[(D(b,872)+a|0)+1075656>>2];break s}j=(D(b,872)+a|0)+1075656|0;b=x[yb(g+68|0,d-2|0)>>2];x[j>>2]=b}Qo(a,h,b)}i=e?i:0}a=f+8|0;Jb(a,k,52);b=x[x[f+8>>2]>>2];d=x[f+12>>2];Jb(a,k,23);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}i=(Hb(b,d)&c>>>8)+i|0}v[n|0]=i}fb=f+16|0}function Us(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-160|0;fb=e;x[e+148>>2]=-1;x[e+140>>2]=6;x[e+144>>2]=364;x[e+132>>2]=11;x[e+136>>2]=161;x[e+124>>2]=23;x[e+128>>2]=31;x[e+116>>2]=59;x[e+120>>2]=55;x[e+152>>2]=0;x[e+156>>2]=0;v[e+14|0]=c;v[e+13|0]=37;v[e+15|0]=0;l=b+484|0;i=b+460|0;j=b+172|0;k=b+4|0;f=e+16|0;h=f+(fa(f|0,100,e+13|0,e+116|0,x[b>>2])|0)|0;x[e+8>>2]=f;g=Fb(a);m=(c|0)!=120;a:while(1){b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=(h|0)){if(Kf(x[d+8>>2],1,v[f|0])){x[31725]=0;O(117,g|0,32);a=x[31725];x[31725]=0;if((a|0)==1){break c}a=x[d+8>>2];while(1){f=f+1|0;if((h|0)==(f|0)){f=h;break b}if(Kf(a,1,v[f|0])){continue}break}break b}x[e+4>>2]=f;x[31725]=0;x[e>>2]=0;a=ea(1362,e+4|0,h|0,k|0,j|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}p:{a=a-k|0;q:{if((a|0)<=167){x[31725]=0;O(117,g|0,37);c=x[31725];x[31725]=0;if((c|0)==1){break c}x[31725]=0;O(117,g|0,((a|0)<84?65:97)|0);a=x[31725];x[31725]=0;if((a|0)!=1){break q}break c}x[31725]=0;x[e+4>>2]=f;a=ea(1362,e+4|0,h|0,j|0,i|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}a=a-j|0;c=(a|0)/12|0;if((a|0)<=287){x[31725]=0;O(117,g|0,37);f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;O(117,g|0,((a|0)<144?66:98)|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}if(m){break q}if(!Kf(x[d+8>>2],64,v[cc((D(c,12)+b|0)+172|0,0)|0])){break q}n=xz(g),o=109,v[n|0]=o;break q}if((Cb(x[b+464>>2],y[b+471|0])|0)==(0-Cb(x[b+476>>2],y[b+483|0])|0)){break p}x[31725]=0;x[e+4>>2]=f;a=ea(1362,e+4|0,h|0,i|0,l|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}if((a-i|0)>23){break p}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;O(117,g|0,112);a=x[31725];x[31725]=0;if((a|0)==1){break c}}f=x[e+4>>2];break b}x[e+4>>2]=f;a=v[f|0];if(Kf(x[d+8>>2],64,a)){x[31725]=0;a=ba(1363,e+8|0,h|0,e|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}r:{s:{switch(a-6|0){case 2:case 3:case 4:break r;case 0:break e;case 1:break f;case 5:break g;case 6:break h;default:break s}}t:{switch(a-55|0){case 0:break k;case 4:break l;case 6:break m;case 1:case 2:case 3:case 5:break r;default:break t}}if((a|0)==23){break i}if((a|0)==31){break j}if((a|0)==364){break n}if((a|0)==2061){break o}}a=x[e+8>>2];while(1){if((a|0)==(f|0)){f=a;continue a}c=v[f|0];x[31725]=0;O(117,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}f=f+1|0;continue}}u:{if((a|0)==37){x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;O(117,g|0,37);break u}x[31725]=0;O(117,g|0,a|0)}a=x[31725];x[31725]=0;if((a|0)==1){break c}f=f+1|0;break b}fb=e+160|0;return}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=89;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=106;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=121;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=83;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=77;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=100;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=72;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=109;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=73;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=117;break d}x[31725]=0;O(117,g|0,37);a=x[31725];x[31725]=0;c=119}if((a|0)==1){break c}x[31725]=0;O(117,g|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}f=x[e+8>>2];continue}a=N()|0;tb(g);Q(a|0);p()}x[e+8>>2]=f;continue}}function doa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=fb-48|0;fb=g;xc(b);n=Zd(b);a:{if((n-5&255)>>>0<253){break a}if(!Mb(x[b>>2],x[b+8>>2],4355)){break a}h=1;while(1){if((h&65535)>>>0<=256){d=g+32|0;fE(b,d);if(!IV(d,n)){break a}d=0;e=fb-32|0;fb=e;m=y[g+43|0];l=y[g+41|0]|y[g+42|0]<<8;v[e+14|0]=0;v[e+18|0]=m;w[e+16>>1]=l;w[e+12>>1]=0;while(1){if((d|0)!=3){m=y[xb(e+16|0,d)|0];p=xb(e+12|0,d),q=m,v[p|0]=q;d=d+1|0;continue}break}m=eg(e+12|0);l=y[g+40|0];i=y[g+38|0]|y[g+39|0]<<8;d=0;v[e+10|0]=0;v[e+26|0]=l;w[e+24>>1]=i;w[e+8>>1]=0;while(1){if((d|0)!=3){l=y[xb(e+24|0,d)|0];p=xb(e+8|0,d),q=l,v[p|0]=q;d=d+1|0;continue}break}d=eg(e+8|0);fb=e+32|0;f=d>>>0<m>>>0?h:f;h=h+1|0;continue}break}if(!(f&65535)){break a}b:{if(!c){break b}Bd(a,1);w[a+480190>>1]=f;x[a+480228>>2]=(n|0)==3?192:48;x[a+480208>>2]=x[a+480208>>2]&-25165825|16777216;cd(b,1);m=f+1|0;l=m&65535;h=1;while(1)if((h|0)==(l|0)){cd(b,4097);jk(Xb(x[a+484360>>2],y[a+484376|0]),b,256,255,65535);h=Zd(b);if(h>>>0>31){break a}w[a+480188>>1]=h+1;h=Zd(b);d=z[a+480188>>1];f=h+1|0;if(!Mb(x[b>>2],x[b+8>>2],D(D(d,f),384)+d|0)){break a}while(1)if(z[a+480188>>1]<=j>>>0){d=a+484344|0;Vf(d,f);l=c&1;j=0;while(1){c:{if((f|0)!=(j|0)){d:{if(l){if(Ng(d,j&65535,64)){break d}}Vb(b,D(z[a+480188>>1],384));break c}i=ch(g+32|0);h=Wb(x[d>>2],j);p=g,q=wb(x[h>>2]),x[p+16>>2]=q;k=wb(x[h+4>>2]);while(1){h=x[g+16>>2];if(!Ib(h,k)){break c}e=g+20|0;__(e,b);e=y[xb(e,0)|0];if((e-1&255)>>>0<=76){v[h|0]=e+36}e=g+20|0;p=h,q=y[xb(e,1)|0],v[p+1|0]=q;e:{if(!HV(h,y[xb(e,2)|0],y[xb(e,5)|0],n)){break e}e=g+20|0;if(!HV(i,y[xb(e,3)|0],y[xb(e,4)|0],n)){break e}e=y[g+35|0];if(e){Hn(g+14|0,h,y[h+3|0],y[h+5|0],e,y[g+37|0])}vg(g+16|0);continue}break}j=0;break a}f:{if(!(c&2)){break f}c=m&65535;h=1;while(1){if((c|0)==(h|0)){break f}f=D(h,104)+a|0;fg(Xc(g+32|0,w[f+484414>>1]&1?16:8,1,0,0),f+484380|0,b);h=h+1|0;continue}}ci(a+1298344|0,14170);ci(a+1298356|0,11136);tf(a+1298368|0);p=a+1298404|0,q=x[Fc(g+32|0,4)>>2],x[p>>2]=q;break b}j=j+1|0;continue}}else{h=(j<<5)+a|0;Xe(h+480280|0);p=h+480284|0,q=D(Zd(b),17),w[p>>1]=q;j=j+1|0;continue}}else{fE(b,g+32|0);d=0;f=fb-16|0;fb=f;e=(D(h,104)+a|0)+484380|0;ld(e,1);i=y[g+43|0];k=y[g+41|0]|y[g+42|0]<<8;v[f+6|0]=0;v[f+10|0]=i;w[f+8>>1]=k;w[f+4>>1]=0;while(1){if((d|0)!=3){i=y[xb(f+8|0,d)|0];p=xb(f+4|0,d),q=i,v[p|0]=q;d=d+1|0;continue}break}i=eg(f+4|0);k=y[g+40|0];o=y[g+38|0]|y[g+39|0]<<8;d=0;v[f+2|0]=0;v[f+10|0]=k;w[f+8>>1]=o;w[f>>1]=0;while(1){if((d|0)!=3){k=y[xb(f+8|0,d)|0];p=xb(f,d),q=k,v[p|0]=q;d=d+1|0;continue}break}p=e,q=i-eg(f)|0,x[p>>2]=q;i=y[g+34|0];k=y[g+32|0]|y[g+33|0]<<8;d=0;v[f+6|0]=0;v[f+10|0]=i;w[f+8>>1]=k;w[f+4>>1]=0;while(1){if((d|0)!=3){i=y[xb(f+8|0,d)|0];p=xb(f+4|0,d),q=i,v[p|0]=q;d=d+1|0;continue}break}p=e,q=eg(f+4|0)+1|0,x[p+4>>2]=q;i=y[g+37|0];k=y[g+35|0]|y[g+36|0]<<8;d=0;v[f+6|0]=0;v[f+10|0]=i;w[f+8>>1]=k;w[f+4>>1]=0;while(1){if((d|0)!=3){i=y[xb(f+8|0,d)|0];p=xb(f+4|0,d),q=i,v[p|0]=q;d=d+1|0;continue}break}p=e,q=eg(f+4|0)+1|0,x[p+8>>2]=q;d=y[g+45|0];i=d>>>2|0;i=z[e+34>>1]&-7|i&2|i&4;w[e+34>>1]=i;if(d&4){w[e+34>>1]=i|1;x[e>>2]=x[e>>2]>>>1}w[e+30>>1]=y[g+44|0];if((n|0)!=2){x[e+24>>2]=y[g+46|0]|y[g+47|0]<<8}GV(e);fb=f+16|0;f=Dc(g+20|0,22255);zc(((h<<5)+a|0)+946304|0,f);tb(f);h=h+1|0;continue}}j=1}fb=g+48|0;return j|0}function Ela(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-96|0;fb=e;g=a+140|0;ck(e+76|0,g,1296125513);x[31725]=0;f=R(174,x[e+76>>2])|0;h=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Fb(e+28|0);x[31725]=0;h=R(156,x[e+76>>2])|0;i=x[31725];x[31725]=0;if((i|0)==1){break p}x[31725]=0;S(817,e+76|0,f|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break p}h=z[a+174>>1];x[31725]=0;S(818,e- -64|0,h|0,f|0);h=x[31725];x[31725]=0;if((h|0)==1){break o}x[31725]=0;S(819,e+4|0,c|0,e- -64|0);c=x[31725];x[31725]=0;if((c|0)==1){break n}c=e+4|0;zc(d,c);tb(c);tb(e- -64|0);tb(f)}if(y[a+176|0]){x[31725]=0;O(820,e+28|0,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}c=e+28|0;ze(b+43|0,c);tb(c)}x[31725]=0;S(812,e+28|0,g|0,1413894985);c=x[31725];x[31725]=0;if((c|0)==1){break l}x[31725]=0;f=R(821,e+28|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}g=e+28|0;ub(g);c=a+40|0;xc(c);x[31725]=0;g=P(822,c|0,g|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break j}if(g){q:{if((y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24))>>>0<2){break q}x[31725]=0;g=P(823,c|0,e+4|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break i}if(!g){break q}LR(e+4|0,b+12|0,b+16|0,x[b>>2],b+34|0,8,16,f)}x[31725]=0;c=P(823,c|0,e+4|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break i}if(c){LR(e+4|0,b+4|0,b+8|0,x[b>>2],b+34|0,2,4,f)}c=y[e+40|0]|y[e+41|0]<<8|(y[e+42|0]<<16|y[e+43|0]<<24);v[b+42|0]=c&128?0:c+1|0;al(b)}r:{if(y[b+42|0]){break r}c=x[a+60>>2];x[31725]=0;c=P(680,c|0,7)|0;f=x[31725];x[31725]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;xc(c);x[31725]=0;c=P(824,c|0,e+4|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}if(!c){break r}c=v[e+4|0];v[b+42|0]=(c|0)>=0?c+1|0:0}c=x[a+120>>2];x[31725]=0;c=R(174,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break j}if(!c){break f}x[31725]=0;h=a+120|0;c=R(153,h|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}x[e+64>>2]=c;wc(e- -64|0,9);f=b+68|0;g=x[e+64>>2];c=0;while(1){if((c|0)==(g|0)){break g}x[31725]=0;O(825,h|0,e+4|0);i=x[31725];x[31725]=0;if((i|0)==1){break h}i=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);j=yb(f,c),k=i,x[j>>2]=k;c=c+1|0;continue}}a=N()|0;break a}a=N()|0;break m}a=N()|0;break m}a=N()|0;tb(e- -64|0)}tb(f);break a}a=N()|0;break a}a=N()|0;ub(e+28|0);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}Yz(f+(g<<2)|0,SZ(f),41140)}c=a+80|0;xc(c);x[31725]=0;f=P(826,c|0,e+4|0)|0;g=x[31725];x[31725]=0;s:{if((g|0)==1){break s}if(!f){break b}if(y[e+4|0]&32){w[b+34>>1]=z[b+34>>1]|32}w[e+64>>1]=z[e+8>>1];w[e+2>>1]=256;j=b,k=z[Nc(e- -64|0,e+2|0)>>1],w[j+28>>1]=k;w[e+64>>1]=z[e+10>>1];w[e+2>>1]=256;j=b,k=z[Nc(e- -64|0,e+2|0)>>1],w[j+30>>1]=k;w[e+64>>1]=z[e+12>>1];w[e+2>>1]=64;j=b,k=z[Nc(e- -64|0,e+2|0)>>1],w[j+32>>1]=k;v[b+38|0]=y[e+16|0];v[b+39|0]=y[e+17|0];v[b+40|0]=y[e+18|0];v[b+41|0]=y[e+19|0];f=x[a+88>>2];a=x[a+80>>2];x[31725]=0;a=U(152,a|0,f|0,32)|0;f=x[31725];x[31725]=0;if((f|0)==1){break s}if(!a){break b}x[31725]=0;O(827,c|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break s}x[31725]=0;a=R(204,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break s}x[31725]=0;S(828,c|0,b+43|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break b}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}ub(e+76|0);fb=e+96|0;return}ub(e+76|0);Q(a|0);p()}function rpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-176|0;fb=e;xc(b);a:{if(!OD(b,e+128|0)){break a}if(!aX(e+128|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc($W(y[e+159|0],y[e+161|0]),hb))){break a}b:{if(!c){break b}Bd(a,256);g=e+16|0;wi(g,2,e+128|0);d=e+48|0;Cc(d,g);Ab(a+1298308|0,d);tb(d);f=tc(d,15331);Ab(a+1298344|0,f);tb(f);d=tc(d,10120);Ab(a+1298356|0,d);tb(d);ig(g,4271);x[31725]=0;O(251,e+116|0,e+159|0);d=x[31725];x[31725]=0;c:{d:{if((d|0)!=1){x[31725]=0;V(702,e+48|0,e+16|0,e+158|0,e+116|0);d=x[31725];x[31725]=0;if((d|0)!=1){d=e+48|0;Ab(a+1298368|0,d);tb(d);tb(e+116|0);Eb(e+16|0);o=a+1298404|0,q=x[Fc(d,4)>>2],x[o>>2]=q;d=Lb(a+1074312|0,107,1);x[a+480260>>2]=64;x[a+480264>>2]=32767;x[a+480188>>2]=2031620;Lb(d,107,1);f=y[e+160|0];d=y[e+159|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|D(g,-10)+f}g=(f&255?f:96)&255;f=xC(g);x[a+480196>>2]=g>>>4;x[a+480204>>2]=f;if(d>>>0>=11){v[e+48|0]=64;o=a,q=y[Rb(e+162|0,e+48|0)|0]<<2,x[o+480200>>2]=q}f=0;while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){Fr(b,e+16|0);d=y[e+28|0];if(d?(d|0)!=46:0){break c}i=fb-32|0;fb=i;d=(D(f,104)+a|0)+484380|0;ld(d,0);j=i+8|0;k=e+16|0;g=k;Rk(j,2,g);h=i+20|0;Cc(h,j);ze(d+43|0,h);tb(h);x[d+24>>2]=y[g+24|0]|y[g+25|0]<<8;v[i+20|0]=y[g+22|0];v[i+8|0]=64;o=d,q=y[Rb(h,j)|0]<<2,w[o+30>>1]=q;h=y[g+16|0]|y[g+17|0]<<8;x[d>>2]=h;j=y[g+18|0]|y[g+19|0]<<8;x[d+4>>2]=j;g=y[g+20|0]|y[g+21|0]<<8;x[d+8>>2]=g;e:{if(h>>>0<=1){x[d>>2]=0;break e}if((g|0)==65535|h>>>0<=j>>>0|g>>>0<=j>>>0){break e}w[d+34>>1]=2;o=d,q=x[Gb(d+8|0,d)>>2],x[o+8>>2]=q}fb=i+32|0;g=e+4|0;Rk(g,2,k);d=e+116|0;Cc(d,g);zc(((f<<5)+a|0)+946304|0,d);tb(d);w[((f<<1)+e|0)+46>>1]=y[e+30|0]|y[e+31|0]<<8;f=f+1|0;continue}break}d=a+484376|0;jk(Xb(x[a+484360>>2],y[d|0]),b,y[e+159|0]?128:64,65535,65535);f=0;if(!ZW(Xb(x[a+484360>>2],y[d|0]))){break a}m=c&1;if(m){Vf(a+484344|0,y[e+161|0])}h=a+484344|0;while(1)if(y[e+161|0]<=l>>>0){f=1;if(!(c&2)){break a}c=Xc(e+16|0,8,1,0,0);while(1){if((f|0)==32){break b}d=D(f,104)+a|0;g=d+484380|0;f:{if(!x[g>>2]|!z[d+484410>>1]){break f}d=z[((f<<1)+e|0)+46>>1];if(d>>>0<4){break f}if(!cd(b,d<<4)){break f}fg(c,g,b)}f=f+1|0;continue}}else{g:{h:{if(m){if(Ng(h,l&65535,64)){break h}}f=0;while(1){if((f|0)==256){break g}if((Zd(b)+2&255)>>>0<=252){Vb(b,3)}f=f+1|0;continue}}o=e,q=wb(x[Wb(x[h>>2],l)>>2]),x[o+116>>2]=q;w[e+2>>1]=65535;x[e+4>>2]=63;i=0;i:while(1){f=0;if((i|0)==64){d=z[e+2>>1];if((d|0)==65535){break g}ye(Wb(x[h>>2],l),Gn(Ye(Ne(e+16|0,12,d&255),x[e+4>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;j=0;k=0;n=0;m:{n:{o:{p:{g=Zd(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}v[x[e+116>>2]]=254;break j}d=e+16|0;Xr(d,b);j=y[xb(d,0)|0];k=y[xb(d,1)|0];n=y[xb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(D(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=x[e+116>>2];v[d|0]=g;break k}i=i+1|0;continue i}d=x[e+116>>2]}v[d+1|0]=(j&248)>>>3;g=k>>>1&120|j&7;if(g>>>0<=64){v[d+4|0]=g;v[d+2|0]=1}v[d+5|0]=n;YW(d,k&15,i,y[e+159|0],e+2|0,e+4|0)}f=f+1|0;JC(e+116|0);continue}}}l=l+1|0;continue}}else{d=(f<<5)+a|0;Xe(d+480280|0);w[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=N()|0;tb(e+116|0);break d}f=N()|0}Eb(e+16|0);Q(f|0);p()}f=0;break a}f=1}fb=e+176|0;return f|0}function gua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-128|0;fb=f;xc(b);a:{if(!Gr(b,f- -64|0)){break a}if(!q$(f- -64|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],p$(f- -64|0))){break a}if(!c){j=1;break a}Bd(a,1);x[a+480208>>2]=x[a+480208>>2]|16777216;w[a+480188>>1]=y[f+109|0];w[a+480190>>1]=y[f+110|0];n=a,o=Bc((((y[f+113|0]<<8|48)&65328)>>>0)/100|0,0),x[n+480200>>2]=o;e=f+52|0;wi(e,3,f+69|0);d=f+16|0;Cc(d,e);Ab(a+1298308|0,d);tb(d);wi(e,3,f+89|0);Mr(d,4,e);Ab(a+1298320|0,d);tb(d);d=0;while(1)if(z[a+480188>>1]<=d>>>0){d=a+484376|0;jk(Xb(x[a+484360>>2],y[d|0]),b,y[f+111|0],65535,65535);w[f+50>>1]=0;d=Xb(x[a+484360>>2],y[d|0]);n=f,o=wb(x[d>>2]),x[n+16>>2]=o;d=wb(x[d+4>>2]);while(1){e=x[f+16>>2];if(Ib(e,d)){w[f+52>>1]=z[e>>1];n=f,o=z[qe(f+52|0,f+50|0)>>1],w[n+50>>1]=o;Md(f+16|0);continue}else{d=z[f+50>>1]+1|0;w[f+50>>1]=d;j=Mb(x[b>>2],x[b+8>>2],D(D(z[a+480188>>1],d&65535),264)+(z[a+480190>>1]<<5)|0);if(!j){break a}d=0;while(1){e=z[a+480188>>1];if(e>>>0<=d>>>0){Vb(b,D(e,z[f+50>>1]-1|0)<<3);d=1;while(1){i=d&65535;if(i>>>0>z[a+480190>>1]){k=a+484344|0;Vf(k,z[f+50>>1]);l=c&1;g=0;while(1){b:{c:{if(z[f+50>>1]<=g>>>0){if(!(c&2)){break c}d=1;while(1){c=d&65535;if(c>>>0>A[a+480228>>2]){break c}c=D(c,104)+a|0;fg(Xc(f+16|0,w[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);d=d+1|0;continue}}d:{if(l){if(Ng(k,g&65535,64)){break d}}Vb(b,z[a+480188>>1]<<8);break b}d=Wb(x[k>>2],g);n=f,o=wb(x[d>>2]),x[n+16>>2]=o;m=wb(x[d+4>>2]);while(1){d=x[f+16>>2];if(!Ib(d,m)){break b}e=f+52|0;tm(e,b);e:{if(!y[xb(e,1)|0]){break e}if(y[xb(f+52|0,1)|0]>168){break e}n=d,o=(y[xb(f+52|0,1)|0]>>>1|0)+36|0,v[n|0]=o}h=f+52|0;n=d,o=y[xb(h,0)|0],v[n+1|0]=o;e=y[xb(h,3)|0];v[d+5|0]=e;f:{if(y[xb(h,2)|0]==8){g:{switch(e>>>4|0){case 0:v[d+3|0]=19;v[d+5|0]=e|128;break f;case 1:v[d+3|0]=11;v[d+5|0]=e<<4;break f;case 2:v[d+3|0]=19;v[d+5|0]=e|160;break f;case 3:case 4:break g;default:break f}}v[d+3|0]=19;v[d+5|0]=e-32;break f}if(y[xb(f+52|0,2)|0]==19){v[d+3|0]=9;i=e<<1&254;h=i+128|0;h:{if(e>>>0<=64){break h}h=384-i|0;if(e<<24>>24>=0){break h}h=128-i|0;if(e>>>0<=191){break h}h=i-128|0}n=d,o=zi(h),v[n+5|0]=o;break f}if((y[xb(f+52|0,2)|0]&240)==32){v[d+2|0]=1;v[d+3|0]=10;n=d,o=(y[xb(f+52|0,2)|0]<<2&60)+4|0,v[n+4|0]=o;break f}i:{if(y[xb(f+52|0,2)|0]<16){break i}if(y[xb(f+52|0,2)|0]==17){break i}if(y[xb(f+52|0,2)|0]!=18){break f}}e=d;d=f+52|0;Bf(e,y[xb(d,2)|0]&15,y[xb(d,3)|0])}vg(f+16|0);continue}}b=f+16|0;c=tc(b,9510);Ab(a+1298344|0,c);tb(c);c=tc(b,10141);Ab(a+1298356|0,c);tb(c);n=a+1298404|0,o=x[Fc(b,4)>>2],x[n>>2]=o;break a}g=g+1|0;continue}}else{e=f+16|0;Fr(b,e);h=fb-16|0;fb=h;v[h+15|0]=64;g=(D(i,104)+a|0)+484380|0;n=g,o=y[Rb(e+26|0,h+15|0)|0]<<2,w[n+30>>1]=o;v[g+37|0]=y[e+25|0]<<4;x[g>>2]=y[e+23|0]|y[e+24|0]<<8;x[g+4>>2]=y[e+27|0]|y[e+28|0]<<8;x[g+8>>2]=(y[e+29|0]|y[e+30|0]<<8)+(y[e+27|0]|y[e+28|0]<<8);w[g+34>>1]=z[g+34>>1]&65532|((y[e+29|0]|y[e+30|0]<<8)>>>0>2)<<1|y[e+22|0]==16;fb=h+16|0;g=f+4|0;Zk(g,3,e);e=f+52|0;Cc(e,g);zc(((i<<5)+a|0)+946304|0,e);d=d+1|0;tb(e);continue}}}else{e=f+4|0;o$(e,b);g=f+52|0;tF(g,e);e=f+16|0;Cc(e,g);pm(((d<<5)+a|0)+480289|0,e);d=d+1|0;tb(e);continue}}}}}else{e=(d<<5)+a|0;Xe(e+480280|0);n=e+480284|0,o=D(Zd(b)&15,17),w[n>>1]=o;d=d+1|0;continue}}fb=f+128|0;return j|0}function gla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0;l=fb-32|0;fb=l;s=x[a+4>>2];k=Ve(x[a+8>>2],b);t=x[k>>2];a:{if(t+1>>>0<2){break a}i=(D(b,872)+s|0)+616|0;if(!(Ui(x[i+8>>2],x[i+12>>2])|y[k+4|0])){break a}h=D(b,872)+s|0;if(!x[h+720>>2]){break a}g=x[h+704>>2]&2;u=x[(g?h+700|0:h+692|0)>>2];n=x[h+700>>2];f=x[h+696>>2];w=Ob(x[a>>2]+1074312|0,31);e=vf(x[h+624>>2],x[h+628>>2],c);o=y[h+704|0]&128;k=o?0-e|0:e;m=hb;m=o?0-(m+((e|0)!=0)|0)|0:m;e=0;o=g?e:0;e=f;r=g?e:0;n=n-e|0;B=n<<1;C=h+1316|0;p=h+1467|0;A=h+1362|0;F=(y[A|0]&17)!=1;b:{c:{while(1){if((q|0)!=(t|0)){d:{if(d>>>0>q>>>0){e=(y[A|0]&17)==1;break d}x[x[a+4>>2]+16>>2]=q-d;v[p|0]=y[p|0]&254|(d|0)==(q|0);e=x[a>>2];j=x[a+4>>2];f=Wb(x[e+484344>>2],z[j+70>>1]);f=jd(x[f>>2],x[x[f+48>>2]+12>>2],x[j+48>>2],b);g=y[f+3|0];e:{f:{switch(y[f+2|0]-11|0){case 0:j=l+8|0;vB(j,e,g,y[f+4|0],0);j=af(j);Ou(x[a>>2],x[a+4>>2],b,z[l+8>>1]);e=1;if(!y[j|0]){break e}break d;case 1:qB(e,j,b,y[f+4|0]<<2&252,Ob(e+1074312|0,12));break e;case 2:break f;default:break e}}pB(e,j,b,y[f+4|0]<<2&252,Ob(e+1074312|0,12))}e=1;g:{h:{i:{j:{k:{switch(g-2|0){default:if(g-38>>>0<4){break h}if((g|0)==19){break j}if((g|0)!=28){break g}e=y[f+5|0];f=e&240;if((f|0)==32){break i}if((f|0)!=16){break g}oB(x[a>>2],i,e&15);break g;case 2:Ou(x[a>>2],x[a+4>>2],b,y[f+5|0]);break g;case 4:Ou(x[a>>2],x[a+4>>2],b,0);break g;case 0:f=y[f+5|0];g=x[a>>2];if(!f&(v[g+480180|0]&1)){break d}qB(g,x[a+4>>2],b,f,0);break g;case 1:break k;case 3:break d}}f=y[f+5|0];g=x[a>>2];if(!f&(v[g+480180|0]&1)){break d}pB(g,x[a+4>>2],b,f,0);break g}f=y[f+5|0];e=f&15;if(!(e|x[x[a>>2]+480180>>2]&1048580)){break g}f=f&240;if((f|0)!=32){if((f|0)!=16){break g}nB(x[a>>2],i,e);break g}mB(x[a>>2],i,e);break g}lB(x[a>>2],i,e&15);break g}pT(x[a>>2],i,y[f+5|0],(g|0)==38|(g|0)==40,(g&254)==40)}e=1}x[l+28>>2]=x[C>>2];if(w){Nu(x[a>>2],i)}if(!F){oT(x[a>>2],i,l+28|0);e=1}if(!w){Nu(x[a>>2],i)}x[l+24>>2]=0;nT(i,l+24|0);l:{if(y[h+705|0]&2){break l}m:{if(!e){if(!y[Ve(x[a+8>>2],b)+4|0]){break m}}if(y[p|0]&96){vV(i,E(1),0,x[a>>2]);k=y[p|0];v[p|0]=(k&64?-65:-33)&k}wB(l+8|0,x[a>>2],i,x[l+28>>2],0);k=x[l+12>>2];x[h+624>>2]=x[l+8>>2];x[h+628>>2]=k;H=Ve(x[a+8>>2],b),I=0,v[H+4|0]=I;e=vf(x[h+624>>2],x[h+628>>2],c);f=y[h+704|0]&128;k=f?0-e|0:e;g=hb;m=f?0-(g+((e|0)!=0)|0)|0:g}Pb(i,k,m);f=x[i>>2];e=x[i+4>>2];if((f>>>0<G>>>0&(e|0)<=(u|0)|(e|0)<(u|0))&((e|0)>=(r|0)&f>>>0>=o>>>0|(e|0)>(r|0)|((m|0)>0|(m|0)>=0))){break l}j=x[h+704>>2];if(!(j&2)){break c}if(j&4){g=x[h+696>>2];if(f>>>0<o>>>0&(e|0)<=(r|0)|(e|0)<(r|0)){H=i,I=jh(0,g<<1,f,e),x[H>>2]=I;e=hb;x[i+4>>2]=e;x[h+704>>2]=j^128;f=k;k=0-f|0;m=0-(((f|0)!=0)+m|0)|0}e=(e-g>>>0)%(B-Ob(x[a>>2]+1074312|0,33)>>>0)|0;n:{if(e>>>0<n>>>0){f=e+x[h+696>>2]|0;break n}f=x[h+700>>2]+(n-e|0)|0}x[i+4>>2]=f;f=x[h+704>>2];if((f&128)>>>7^e>>>0<n>>>0){break l}x[h+704>>2]=f^128;e=k;k=0-e|0;m=0-(((e|0)!=0)+m|0)|0;break l}j=x[h+700>>2];if(j+n>>>0<=e>>>0){e=j+((e-j>>>0)%(n>>>0)|0)|0}while(1){g=e;e=e-n|0;if(g>>>0>=j>>>0){continue}break}x[i>>2]=f;x[i+4>>2]=g}q=q+1|0;continue}break}x[x[a+4>>2]+16>>2]=0;break b}x[x[a+4>>2]+16>>2]=0;xV(i);x[(D(b,872)+s|0)+1324>>2]=0}H=Ve(x[a+8>>2],b),I=0,x[H>>2]=I}fb=l+32|0}function gH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-32|0;fb=f;d=x[b+28>>2];x[f+24>>2]=x[b+24>>2];x[f+28>>2]=d;d=x[b+20>>2];x[f+16>>2]=x[b+16>>2];x[f+20>>2]=d;d=x[b+12>>2];x[f+8>>2]=x[b+8>>2];x[f+12>>2]=d;d=x[b+4>>2];x[f>>2]=x[b>>2];x[f+4>>2]=d;d=fb-144|0;fb=d;j=Fb(d+132|0);k=Fb(d+120|0);x[31725]=0;b=P(1,d+108|0,c|0)|0;c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=Ab(k,b);tb(b);if(!x[f>>2]){break b}x[31725]=0;O(75,d+96|0,f|0);b=x[31725];x[31725]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){x[31725]=0;e=P(76,j|0,d+96|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break q}tb(d+96|0);x[31725]=0;b=P(1,d+84|0,16809)|0;g=x[31725];x[31725]=0;if((g|0)==1){break p}x[31725]=0;O(77,d+72|0,f+4|0);g=x[31725];x[31725]=0;if((g|0)==1){break o}x[31725]=0;S(2,d+96|0,b|0,d+72|0);g=x[31725];x[31725]=0;if((g|0)==1){break n}x[31725]=0;e=P(76,e|0,d+96|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break m}tb(d+96|0);g=d+72|0;tb(g);tb(b);x[31725]=0;b=P(1,g|0,16809)|0;g=x[31725];x[31725]=0;if((g|0)==1){break j}x[31725]=0;O(77,d+60|0,f+8|0);g=x[31725];x[31725]=0;if((g|0)==1){break i}x[31725]=0;S(2,d+96|0,b|0,d+60|0);g=x[31725];x[31725]=0;if((g|0)==1){break h}x[31725]=0;i=P(76,e|0,d+96|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}tb(d+96|0);tb(d+60|0);tb(b);b=x[f+24>>2];g=x[f+28>>2];if(x[f+12>>2]|(x[f+16>>2]|!(b|g))){break d}break b}a=N()|0;break c}a=N()|0;tb(d+96|0);break c}a=N()|0;break c}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+96|0)}tb(d+72|0)}tb(b);break c}a=N()|0;break c}a=N()|0;break e}a=N()|0;break f}a=N()|0;tb(d+96|0)}tb(d+60|0)}tb(b);break c}x[31725]=0;e=P(1,d+96|0,13717)|0;h=x[31725];x[31725]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{if((h|0)!=1){x[31725]=0;i=P(76,i|0,e|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break J}tb(e);x[31725]=0;O(78,d+36|0,f+12|0);e=x[31725];x[31725]=0;if((e|0)==1){break I}x[31725]=0;e=P(1,d+24|0,14629)|0;h=x[31725];x[31725]=0;if((h|0)==1){break H}x[31725]=0;S(2,d+48|0,d+36|0,e|0);h=x[31725];x[31725]=0;if((h|0)==1){break G}x[31725]=0;O(78,d+12|0,f+16|0);h=x[31725];x[31725]=0;if((h|0)==1){break F}x[31725]=0;S(2,d+60|0,d+48|0,d+12|0);h=x[31725];x[31725]=0;if((h|0)==1){break E}x[31725]=0;i=P(76,i|0,d+60|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break D}tb(d+60|0);tb(d+12|0);tb(d+48|0);tb(e);tb(d+36|0);if(b|g){break y}x[31725]=0;S(79,a|0,i|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break x}break a}a=N()|0;break c}a=N()|0;tb(e);break c}a=N()|0;break c}a=N()|0;break z}a=N()|0;break A}a=N()|0;break B}a=N()|0;break C}a=N()|0;tb(d+60|0)}tb(d+12|0)}tb(d+48|0)}tb(e)}tb(d+36|0);break c}x[31725]=0;b=P(1,d+48|0,14629)|0;e=x[31725];x[31725]=0;if((e|0)==1){break w}x[31725]=0;O(80,d+36|0,f+24|0);e=x[31725];x[31725]=0;if((e|0)==1){break v}x[31725]=0;S(2,d+60|0,b|0,d+36|0);e=x[31725];x[31725]=0;if((e|0)==1){break u}x[31725]=0;e=P(76,i|0,d+60|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break t}tb(d+60|0);tb(d+36|0);tb(b);x[31725]=0;P(76,e|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break b}}a=N()|0;break c}a=N()|0;break c}a=N()|0;break r}a=N()|0;break s}a=N()|0;tb(d+60|0)}tb(d+36|0)}tb(b);break c}a=N()|0}tb(k);tb(j);Q(a|0);p()}_c(a,j)}tb(c);tb(j);fb=d+144|0;fb=f+32|0}function dQ(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=E(0),p=0,q=E(0),r=E(0),s=E(0),t=0,u=E(0);j=fb-16|0;fb=j;b=a+4208|0;i=Jk(E(B[yb(b,12)>>2]*E(3)));x[a+4264>>2]=i;d=E(x[x[a+16>>2]+24620>>2]>>>((i^-1)>>>1&1)>>>0);B[a+4268>>2]=d;t=a,u=E(E(B[yb(b,9)>>2]*E(100))*E(.0061803399585187435)),B[t+4272>>2]=u;t=j,u=De(E(10),E(E(cQ(a)+E(E(B[yb(b,5)>>2]*E(11e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[j+8>>2]=1065353216;t=a,u=E(B[Zm(j+12|0,j+8|0)>>2]*E(.7609999775886536)),B[t+4280>>2]=u;c=De(E(10),E(E(E(E(B[yb(b,1)>>2]*E(1e4))+E(-1e4))/E(100))/E(10)));if(c!=E(1)){d=Cq(E(E(bQ(a)*E(6.2831854820251465))/d));f=E(c+c);e=E(c*c);c=BB(E(E(E(E(d*f)+E(-2))+E(M(E(E(E(E(d*E(E(d*e)*E(4)))+E(c*E(8)))-E(e*E(4)))-E(E(d*c)*E(8))))))/E(f+E(-2))),E(0),E(1))}else{c=E(0)}B[a+4276>>2]=c;i=fb-16|0;fb=i;c=B[a+4268>>2];b=a+4208|0;d=E(B[yb(b,6)>>2]*E(.30000001192092896));t=i,u=E(B[yb(b,8)>>2]*E(.10000000149011612)),B[t+12>>2]=u;x[i+8>>2]=1000593162;f=B[Wz(i+12|0,i+8|0)>>2];e=E(c*E(E(d+f)+E(.007000000216066837)));a:{if(E(F(e))<E(2147483648)){b=~~e;break a}b=-2147483648}x[a+4352>>2]=b;b=1;while(1){if((b|0)==12){t=i,u=E(E(E(E(B[yb(a+4208|0,10)>>2]*E(100))/E(100))+E(.10000000149011612))*E(.9090999960899353)),B[t+12>>2]=u;x[i+8>>2]=1065353216;d=B[Zm(i+12|0,i+8|0)>>2];f=E(c*E(E(d*E(75))/E(1e3)));d=E(c*E(E(d*E(67))/E(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=E(c*E(.0035299998708069324));b:{if(E(F(d))<E(2147483648)){b=~~d;break b}b=-2147483648}x[h>>2]=b;h=a+4344|0;d=E(c*E(.0032500000670552254));c:{if(E(F(d))<E(2147483648)){b=~~d;break c}b=-2147483648}x[h>>2]=b;h=a+4340|0;c=E(c*E(.009999999776482582));d:{if(E(F(c))<E(2147483648)){b=~~c;break d}b=-2147483648}x[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=De(E(.9300000071525574),E(n|0));g=E(f*e);e:{if(E(F(g))<E(2147483648)){k=~~g;break e}k=-2147483648}x[p>>2]=k;k=h+4292|0;e=E(d*e);f:{if(E(F(e))<E(2147483648)){h=~~e;break f}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){fQ((D(b,24)+a|0)+4504|0,x[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}fb=i+16|0}else{k=((D(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=E(c*E(E(f*B[(b<<2)+45408>>2])+d));g:{if(E(F(e))<E(2147483648)){h=~~e;break g}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=fb-16|0;fb=b;d=Rh(a,5);e=Rh(a,11);c=E(d*Rh(a,4));d=E(E(c*E(.03999999910593033))+E(E(d*E(.02250000089406967))+E(0)));f=E(e*Rh(a,10));e=E(E(f*E(.03999999910593033))+E(E(e*E(.02250000089406967))+E(0)));if(v[a+4264|0]&1){g=Rh(a,3);l=Rh(a,9);g=E(c*g);c=E(g*Rh(a,2));d=E(E(c*E(.1444000005722046))+E(E(g*E(.12250000238418579))+d));g=E(f*l);f=E(g*Rh(a,8));e=E(E(f*E(.1444000005722046))+E(E(g*E(.12250000238418579))+e))}Rh(a,12);g=B[a+4496>>2];l=Rh(a,1);m=Rh(a,7);q=Rh(a,0);r=Rh(a,6);t=b,u=De(E(10),E(E(cQ(a)+E(E(B[yb(a+4208|0,7)>>2]*E(12e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[b+8>>2]=1065353216;o=B[Zm(b+12|0,b+8|0)>>2];s=c;c=E(g*g);g=E(l*E(s*c));l=E(q*g);c=E(m*E(f*c));f=E(r*c);m=E(E(E(l+f)*E(-.5))+E(1));B[a+4284>>2]=o*E(M(E(m/E(E(l*E(.1444000005722046))+E(E(c*E(.1444000005722046))+d)))));B[a+4288>>2]=o*E(M(E(m/E(E(f*E(.1444000005722046))+E(E(g*E(.1444000005722046))+e)))));fb=b+16|0;v[a+5046|0]=0;fb=j+16|0}function CS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,z=0;if(b){i=a+327720|0;c=fb-352|0;fb=c;HU(c+340|0,8);x[31725]=0;la(798,c+328|0,9);j=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((j|0)!=1){x[31725]=0;j=P(799,c+312|0,14)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}x[31725]=0;O(800,c+340|0,j|0);e=x[31725];x[31725]=0;if((e|0)==1){break k}x[31725]=0;O(800,c+328|0,j|0);e=x[31725];x[31725]=0;if((e|0)==1){break k}FU(c+240|0,4900);FU(c+168|0,32e3);yU(c+96|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);x[31725]=0;e=P(801,c+72|0,c+340|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break j}bv(c+84|0,c+240|0,e);Ae(e);x[31725]=0;e=P(801,c+48|0,c+328|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break i}bv(c+60|0,c+168|0,e);Ae(e);x[31725]=0;e=P(801,c+24|0,c+84|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break h}bv(c+36|0,c+96|0,e);Ae(e);x[31725]=0;e=P(801,c|0,c+60|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break g}g=c+12|0;bv(g,c+96|0,e);Ae(e);e=c+84|0;Uq(e);l=c+36|0;Uq(l);m=c+60|0;Uq(m);Uq(g);q=c+328|0;Uq(q);Tq(x[c+84>>2],x[c+88>>2],To(i,0));Tq(x[c+36>>2],x[c+40>>2],To(i,1));Tq(x[c+60>>2],x[c+64>>2],To(i,2));Tq(x[c+12>>2],x[c+16>>2],To(i,3));Tq(x[c+328>>2],x[c+332>>2],To(i,4));Ae(g);Ae(l);Ae(m);Ae(e);rn(j);Ae(q);Ae(c+340|0);fb=c+352|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;Ae(c+36|0)}Ae(c+60|0)}Ae(c+84|0)}rn(j)}Ae(c+328|0)}Ae(c+340|0);Q(a|0);p()}AA(a+131112|0,9.6377,.97);AA(a+196648|0,8.5,.5);AA(a+262184|0,7,.425)}c=a+368680|0;if(!(u=0,v=OR(c,a),z=b,z?u:v)){e=a+24|0;s=C[a+8>>3];g=y[a+16|0];i=fb+-64|0;fb=i;m:while(1){if((n|0)!=8193){t=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){d=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;h=J(C[i+(b<<3)>>3]*32768*d+.5);h=h<-32768?-32768:h>32768?32768:h;n:{if(F(h)<2147483648){j=~~h;break n}j=-2147483648}w[m>>1]=j;b=b+1|0;continue}}else{h=s;f=1;d=+(b|0)-t;r=d+-3.5;if(!(F(r)<1e-8)){o:{p:{switch(g|0){case 0:f=kf(d*.8975979010256552)*-.5+.5;break o;case 1:f=kf(d*.8975979010256552)*-.46+.54;break o;case 2:f=kf(d*1.7951958020513104)*.08+(kf(d*.8975979010256552)*-.5+.42);break o;case 3:f=kf(d*1.7951958020513104)*.05677+(kf(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=kf(d*1.7951958020513104)*.07922+(kf(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=kf(d*1.7951958020513104);k=kf(d*.8975979010256552);f=kf(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=kf(d*1.7951958020513104);k=kf(d*.8975979010256552);f=kf(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=kf(d*1.7951958020513104);k=kf(d*.8975979010256552);f=kf(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=r*3.141592653589793;h=Xi(d*h)/d}h=f*h;C[i+(b<<3)>>3]=h;o=o+h;b=b+1|0;continue}}break}fb=i- -64|0;b=x[a+20>>2];x[c+16>>2]=x[a+16>>2];x[c+20>>2]=b;b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b}}function Pz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-240|0;fb=e;v[e+239|0]=c;f=x[b+4>>2];a:{if(!f){g=x[b>>2];break a}g=x[b>>2];h=y[Il(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Ul(e+80|0,g,f,f-1|0);f=x[e+84>>2];g=x[e+80>>2];x[b>>2]=g;x[b+4>>2]=f}h=e+80|0;ge(h);i=x[e+80>>2];ge(e+216|0);i=Hl(i,x[e+220>>2],b);ge(h);b:{c:{d:{e:{f:{g:{h:{if((i|0)==x[e+84>>2]){a=qc(e+228|0,22255);c=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=c;if(Ic(g,f,e)){f=ac(8);x[31725]=0;O(1010,e+216|0,e+239|0);a=x[31725];x[31725]=0;if((a|0)==1){break g}x[31725]=0;S(1017,e+80|0,18246,e+216|0);a=x[31725];x[31725]=0;if((a|0)==1){break f}pc(f,e+80|0);g=0;x[31725]=0;S(99,f|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(e+80|0);break e}if(!d){break h}f=ac(8);a=x[b>>2];b=x[b+4>>2];x[31725]=0;a=gi(e+192|0,a,b);b=x[31725];x[31725]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[31725]=0;S(1017,e+204|0,18282,a|0);b=x[31725];x[31725]=0;if((b|0)==1){break p}x[31725]=0;O(1019,e+216|0,e+204|0);b=x[31725];x[31725]=0;c=1;if((b|0)==1){break o}x[31725]=0;O(1010,e+180|0,e+239|0);b=x[31725];x[31725]=0;if((b|0)==1){break n}x[31725]=0;S(1021,e+80|0,e+216|0,e+180|0);b=x[31725];x[31725]=0;if((b|0)==1){break m}pc(f,e+80|0);x[31725]=0;S(99,f|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;tb(e+80|0);c=0;break l}b=N()|0;break d}b=N()|0;c=1;break i}b=N()|0;break j}b=N()|0;break k}b=N()|0}tb(e+180|0)}tb(e+216|0)}tb(e+204|0)}tb(a);if(c){break d}break c}b=qc(e+172|0,22255);d=x[b+4>>2];x[e+72>>2]=x[b>>2];x[e+76>>2]=d;if(Ic(g,f,e+72|0)){f=ac(8);x[31725]=0;O(1010,e+216|0,e+239|0);a=x[31725];x[31725]=0;q:{r:{if((a|0)!=1){x[31725]=0;S(1017,e+80|0,18246,e+216|0);a=x[31725];x[31725]=0;if((a|0)==1){break r}pc(f,e+80|0);g=0;x[31725]=0;S(99,f|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(e+80|0);break q}b=N()|0;break d}b=N()|0;g=1}tb(e+216|0);if(g){break d}break c}b=qc(e+164|0,7462);d=x[b+4>>2];x[e+64>>2]=x[b>>2];x[e+68>>2]=d;s:{if(!Ic(g,f,e- -64|0)){b=qc(e+156|0,7444);d=x[b+4>>2];x[e+56>>2]=x[b>>2];x[e+60>>2]=d;if(!Ic(g,f,e+56|0)){break s}}v[a+60|0]=c;break h}b=qc(e+148|0,6989);d=x[b+4>>2];x[e+48>>2]=x[b>>2];x[e+52>>2]=d;t:{if(!Ic(g,f,e+48|0)){b=qc(e+140|0,6970);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(!Ic(g,f,e+40|0)){break t}}v[a+61|0]=c;break h}b=qc(e+132|0,7073);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Ic(g,f,e+32|0)){v[a+62|0]=c;break h}b=qc(e+124|0,6064);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Ic(g,f,e+24|0)){v[a+63|0]=c;break h}b=qc(e+116|0,7511);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(Ic(g,f,e+16|0)){v[a+64|0]=c;break h}b=qc(e+108|0,13509);d=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=d;if(!Ic(g,f,e+8|0)){break h}b=x[a+24>>2];d=b+24664|0;g=x[d+4>>2];x[e+96>>2]=x[d>>2];x[e+100>>2]=g;d=b+24656|0;g=x[d+4>>2];x[e+88>>2]=x[d>>2];x[e+92>>2]=g;d=x[b+24652>>2];x[e+80>>2]=x[b+24648>>2];x[e+84>>2]=d;if(c){a=eN(x[a+56>>2])}else{a=0}x[e+100>>2]=a;if(!yz(e+80|0,b+24648|0)){break h}KA(b,e+80|0)}fb=e+240|0;return}b=N()|0;break d}b=N()|0;g=1}tb(e+216|0);if(!g){break c}}jc(f)}Q(b|0)}p()}function vH(){var a=0,b=0,c=0,d=0;if(y[500384]){return x[125095]}b=xd(502024,1);x[b>>2]=111976;c=DJ(b+8|0);x[31725]=0;d=P(36,b+152|0,14276)|0;a=x[31725];x[31725]=0;a:{b:{c:{if((a|0)!=1){Nf(c);yJ(501696,1);x[31725]=0;W(1258,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xJ(501704,1);x[31725]=0;W(1259,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}wJ(501712,1);x[31725]=0;W(1260,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}vJ(501728,1);x[31725]=0;W(1261,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501736,1);x[125434]=113924;x[31725]=0;W(1262,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;X(1263);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;W(1264,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501760,1);x[125440]=114072;x[31725]=0;W(1265,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501768,1);x[125442]=114304;x[31725]=0;W(1266,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501776,1);x[125444]=114188;x[31725]=0;W(1267,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501784,1);x[125446]=114420;x[31725]=0;W(1268,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}uJ(501792,1);x[31725]=0;W(1269,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}tJ(501816,1);x[31725]=0;W(1270,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501848,1);x[125462]=115140;x[31725]=0;W(1271,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501856,1);x[125464]=115384;x[31725]=0;W(1272,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501864,1);x[125466]=115596;x[31725]=0;W(1273,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501872,1);x[125468]=115828;x[31725]=0;W(1274,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}sJ(501880,1);x[31725]=0;W(1275,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}rJ(501888,1);x[31725]=0;W(1276,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}qJ(501896,1);x[31725]=0;W(1277,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}pJ(501904,1);x[31725]=0;W(1278,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501912,1);x[125478]=118520;x[31725]=0;W(1279,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501920,1);x[125480]=118684;x[31725]=0;W(1280,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501928,1);x[125482]=118848;x[31725]=0;W(1281,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}xd(501936,1);x[125484]=119012;x[31725]=0;W(1282,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}oJ(501944,1);x[31725]=0;W(1283,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}nJ(501960,1);x[31725]=0;W(1284,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;X(1285);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;W(1286,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;X(1287);a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;W(1288,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}mJ(502008,1);x[31725]=0;W(1289,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}lJ(502016,1);x[31725]=0;W(1290,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}break a}b=N()|0;break b}b=N()|0;tb(d)}dy(c);Q(b|0);p()}x[125094]=502024;v[500384]=1;x[125095]=500376;return 500376}function Oz(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-160|0;fb=e;C[e+152>>3]=c;f=x[b+4>>2];a:{if(!f){g=x[b>>2];break a}g=x[b>>2];h=y[Il(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Ul(e+128|0,g,f,f-1|0);f=x[e+132>>2];g=x[e+128>>2];x[b>>2]=g;x[b+4>>2]=f}i=e+128|0;ge(i);h=x[e+128>>2];ge(e+116|0);h=Hl(h,x[e+120>>2],b);ge(i);b:{c:{d:{e:{if((h|0)==x[e+132>>2]){h=qc(e+144|0,22255);a=x[h+4>>2];x[e+8>>2]=x[h>>2];x[e+12>>2]=a;if(Ic(g,f,e+8|0)){b=ac(8);x[31725]=0;O(1014,e+116|0,e+152|0);a=x[31725];x[31725]=0;f:{g:{h:{if((a|0)!=1){x[31725]=0;S(1017,e+128|0,18246,e+116|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}pc(b,e+128|0);g=0;x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(e+128|0);break g}f=N()|0;break f}f=N()|0;g=1}tb(e+116|0);if(!g){break c}}jc(b);break c}if(!d){break e}g=ac(8);d=x[b>>2];a=x[b+4>>2];x[31725]=0;d=gi(e+92|0,d,a);a=x[31725];x[31725]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[31725]=0;S(1017,e+104|0,18282,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}x[31725]=0;O(1019,e+116|0,e+104|0);b=x[31725];x[31725]=0;a=1;if((b|0)==1){break p}x[31725]=0;O(1014,e+80|0,e+152|0);a=x[31725];x[31725]=0;if((a|0)==1){break o}x[31725]=0;S(1021,e+128|0,e+116|0,e+80|0);b=x[31725];x[31725]=0;a=1;if((b|0)==1){break n}pc(g,e+128|0);x[31725]=0;S(99,g|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(e+128|0);a=0;break m}f=N()|0;break i}f=N()|0;a=1;break j}f=N()|0;break k}f=N()|0;a=1;break l}f=N()|0}tb(e+80|0)}tb(e+116|0)}tb(e+104|0)}tb(d);if(!a){break c}}jc(g);break c}d=qc(e+72|0,22255);b=x[d+4>>2];x[e+40>>2]=x[d>>2];x[e+44>>2]=b;if(Ic(g,f,e+40|0)){b=ac(8);x[31725]=0;O(1014,e+116|0,e+152|0);a=x[31725];x[31725]=0;r:{s:{t:{if((a|0)!=1){x[31725]=0;S(1017,e+128|0,18246,e+116|0);a=x[31725];x[31725]=0;if((a|0)==1){break t}pc(b,e+128|0);g=0;x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(e+128|0);break s}f=N()|0;break r}f=N()|0;g=1}tb(e+116|0);if(!g){break c}}jc(b);break c}d=qc(e- -64|0,7759);b=x[d+4>>2];x[e+32>>2]=x[d>>2];x[e+36>>2]=b;if(Ic(g,f,e+32|0)){if(!Ed(y[a+28|0])){break e}if(c<=0|c>4){d=ac(8);x[31725]=0;b=P(36,e+128|0,7854)|0;a=x[31725];x[31725]=0;if((a|0)==1){break d}pc(d,b);x[31725]=0;S(99,d|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}a=x[a+24>>2];j=a,k=_e(65536/c),x[j+480244>>2]=k;Iq(a);break e}d=qc(e+56|0,7811);b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;if(Ic(g,f,e+24|0)){if(!Ed(y[a+28|0])){break e}if(c<=0|c>4){d=ac(8);x[31725]=0;b=P(36,e+128|0,7875)|0;a=x[31725];x[31725]=0;if((a|0)!=1){pc(d,b);x[31725]=0;S(99,d|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}f=N()|0;jc(d);break c}a=x[a+24>>2];j=a,k=_e(c*65536),x[j+480240>>2]=k;Iq(a);break e}d=qc(e+48|0,7829);b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;if(!Ic(g,f,e+16|0)){break e}j=x[a+24>>2],k=_i(c*65536),x[j+480236>>2]=k}fb=e+160|0;return}f=N()|0;jc(d)}Q(f|0)}p()}function oM(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-48|0;fb=g;a:{b:{if(St(c)){h=x[b+484344>>2];if(He(h,x[b+484348>>2],c&65535)){break b}}c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ki(c,a,b);tb(b);tb(a);break a}c=Wb(h,c);if(!(x[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ki(c,a,b);tb(b);tb(a);break a}if(!(z[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ki(c,a,b);tb(b);tb(a);break a}if(f>>>0>=6){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ki(c,a,b);tb(b);tb(a);break a}c=jd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=y[c|0];if(!Tc(d)){if(!Ol(d)){break k}}e=g+24|0;eS(e,b,d,y[c+1|0]);x[31725]=0;O(1065,g+36|0,e|0);b=x[31725];x[31725]=0;d=1;if((b|0)!=1){break j}c=N()|0;break g}d=0;x[31725]=0;P(36,g+36|0,16775)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}}b=9968;c=y[c|0];if(!Tc(c)){b=Ol(c)?10278:16775}x[31725]=0;b=P(36,g+12|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break h}c=a;a=g+36|0;Ki(c,a,b);tb(b);tb(a);if(!d){break a}tb(g+24|0);break a}c=N()|0;break d}c=N()|0;tb(g+36|0);if(!d){break d}}tb(g+24|0);break d;case 1:b=c+1|0;l:{if(y[c+1|0]){Gv(g+36|0,b);break l}Dc(g+36|0,16780)}b=y[b|0];x[31725]=0;b=P(36,g+24|0,(b?10801:16780)|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}c=a;a=g+36|0;Ki(c,a,b);tb(b);tb(a);break a;case 2:m:{if(Vg(y[c|0])){Dc(g+36|0,18429);break m}d=y[c+2|0];if(d){rf(g+36|0,1,ER(x[x[b+8>>2]+88>>2],d));break m}Dc(g+36|0,18429)}b=18429;if(!Vg(y[c|0])){b=y[c+2|0]?5505:18429}x[31725]=0;b=P(36,g+24|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){c=a;a=g+36|0;Ki(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 4:n:{if(Vg(y[c|0])){i=g,j=Mj(y[c+2|0],y[c+4|0])&255,x[i+12>>2]=j;_C(g+36|0,g+12|0);break n}if(y[c+2|0]){Gv(g+36|0,c+4|0);break n}Dc(g+36|0,16780)}b=5489;if(!Vg(y[c|0])){b=y[c+2|0]?5489:16780}x[31725]=0;b=P(36,g+24|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){c=a;a=g+36|0;Ki(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 3:o:{if(Vg(y[c|0])){i=g,j=(Mj(y[c+3|0],y[c+5|0])&3840)!=0,v[i+12|0]=j;b=fb-32|0;fb=b;x[b+12>>2]=-1;x[b+16>>2]=0;x[b+4>>2]=0;Fb(b+20|0);x[31725]=0;x[b+4>>2]=x[b+4>>2]&-1332|1058;x[b+8>>2]=1;S(1167,g+36|0,g+12|0,b+4|0);d=x[31725];x[31725]=0;p:{if((d|0)!=1){Hh(b+4|0);fb=b+32|0;break p}a=N()|0;Hh(b+4|0);Q(a|0);p()}break o}d=y[c+3|0];if(d){rf(g+36|0,1,DR(x[x[b+8>>2]+84>>2],d));break o}Dc(g+36|0,16781)}b=12375;if(!Vg(y[c|0])){b=y[c+3|0]?12375:16781}x[31725]=0;b=P(36,g+24|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){c=a;a=g+36|0;Ki(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 5:break f;default:break c}}q:{if(Vg(y[c|0])){i=g,j=Mj(y[c+3|0],y[c+5|0])&255,x[i+12>>2]=j;_C(g+36|0,g+12|0);break q}if(y[c+3|0]){Gv(g+36|0,c+5|0);break q}Dc(g+36|0,16780)}b=11162;if(!Vg(y[c|0])){b=y[c+3|0]?11162:16780}x[31725]=0;b=P(36,g+24|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){c=a;a=g+36|0;Ki(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d}c=N()|0;tb(g+36|0)}Q(c|0);p()}c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ki(c,a,b);tb(b);tb(a)}fb=g+48|0}function qsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-368|0;fb=e;g=fb-32|0;fb=g;d=g+12|0;rD(d,b);Tn(g+4|0,d);x[31725]=0;S(477,e+216|0,x[g+4>>2],x[g+8>>2]);b=x[31725];x[31725]=0;a:{if((b|0)!=1){Kc(g+12|0);fb=g+32|0;break a}a=N()|0;Kc(g+12|0);Q(a|0);p()}x[31725]=0;S(459,e+104|0,x[e+216>>2],x[e+220>>2]);b=x[31725];x[31725]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){x[31725]=0;g=P(105,e+228|0,e+104|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break z}tb(e+104|0);dc(e+216|0);if(c>>>0<2189){break g}b=Qm(e+104|0,g);x[31725]=0;c=P(463,e+216|0,10124)|0;d=x[31725];x[31725]=0;if((d|0)==1){break x}x[31725]=0;x[e+88>>2]=19989250;x[e+92>>2]=0;S(464,b|0,c|0,e+88|0);d=x[31725];x[31725]=0;if((d|0)==1){break w}Eb(c);v[e+103|0]=0;x[31725]=0;c=P(463,e+88|0,11047)|0;d=x[31725];x[31725]=0;if((d|0)==1){break v}x[31725]=0;S(465,b|0,e+103|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break u}Eb(c);d=Fc(e+84|0,y[e+103|0]?0:x[a+1298404>>2]);f=x[a+4>>2];x[31725]=0;c=P(463,e+72|0,15844)|0;h=x[31725];x[31725]=0;if((h|0)==1){break i}h=x[d>>2];x[31725]=0;V(466,b|0,f|0,c|0,h|0);f=x[31725];x[31725]=0;if((f|0)==1){break t}Eb(c);x[31725]=0;c=P(463,e+60|0,15528)|0;f=x[31725];x[31725]=0;if((f|0)==1){break s}d=x[d>>2];x[31725]=0;V(467,b|0,a|0,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break r}Eb(c);x[31725]=0;c=P(463,e+48|0,15368)|0;d=x[31725];x[31725]=0;if((d|0)==1){break q}x[31725]=0;d=a+484360|0;S(468,b|0,d|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break p}Eb(c);x[31725]=0;c=P(463,e+36|0,25014)|0;f=x[31725];x[31725]=0;if((f|0)==1){break o}x[31725]=0;S(469,b|0,a+484344|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break n}Eb(c);f=x[a+1298404>>2];x[31725]=0;c=P(463,e+24|0,25020)|0;h=x[31725];x[31725]=0;if((h|0)==1){break m}x[31725]=0;V(470,b|0,d|0,c|0,f|0);d=x[31725];x[31725]=0;if((d|0)==1){break l}Eb(c);if(wl(y[b|0])){x[31725]=0;c=P(1,e+12|0,16318)|0;d=x[31725];x[31725]=0;if((d|0)==1){break k}a=x[a+1298472>>2];x[31725]=0;S(387,a|0,1,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break j}tb(c)}Ch(b);break f}a=N()|0;break y}a=N()|0;tb(e+104|0)}dc(e+216|0);break b}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;tb(c);break h}a=N()|0}Ch(b);break c}b=Fb(e+104|0);d=x[a+1298404>>2];f=x[a+4>>2];x[31725]=0;d=ba(471,f|0,g|0,b|0,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}A:{if((d|0)!=1){x[31725]=0;c=P(1,e+216|0,16624)|0;d=x[31725];x[31725]=0;B:{if((d|0)!=1){a=x[a+1298472>>2];x[31725]=0;S(387,a|0,1,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break B}tb(c);break A}a=N()|0;break d}a=N()|0;tb(c);break d}d=x[a+1298404>>2];x[31725]=0;V(472,g|0,a|0,d|0,c>>>0<2188|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}}tb(b)}Ff(g);fb=e+368|0;return}a=N()|0}tb(b)}Ff(g)}Q(a|0);p()}function dsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-192|0;fb=f;$d(f+80|0,b);i=x[f+88>>2];l=x[f+92>>2];e=fb-32|0;fb=e;x[e+28>>2]=0;Ok(b,e+28|0);a:{b:{c:{if(x[e+28>>2]!=(Ln(14123)|0)){break c}x[e+24>>2]=0;h=fb-32|0;fb=h;x[h+28>>2]=0;Ux(h+8|0,h+28|0);Sm(h+20|0,b,x[h+8>>2],x[h+12>>2]);Rm(e+24|0,x[h+28>>2]);fb=h+32|0;h=-1;g=x[e+24>>2];if(g-3>>>0<4294967294){break c}d:{e:{f:{if(g>>>0<=1){g=Fb(e+12|0);x[31725]=0;j=U(497,b|0,g|0,256)|0;k=x[31725];x[31725]=0;if((k|0)==1){break b}if(!j){break e}x[31725]=0;S(498,e|0,d|0,g|0);j=x[31725];x[31725]=0;if((j|0)!=1){break f}break b}g=Fb(e+12|0);x[31725]=0;j=P(500,b|0,g|0)|0;k=x[31725];x[31725]=0;if((k|0)==1){break b}if(!j){break d}x[31725]=0;S(498,e|0,d|0,g|0);j=x[31725];x[31725]=0;if((j|0)==1){break b}}Ab(c,e);tb(e);tb(g);pg(b,e);g=0;x[e+12>>2]=0;Ok(b,e+12|0);j=x[e+12>>2];if(j>>>0>50){break c}g:{while(1){if((g|0)==(j|0)){break g}g=g+1|0;if(aR(a,b,d)){continue}break}break c}x[e+12>>2]=0;Ok(b,e+12|0);h=x[e+12>>2]==(Ln(14161)|0)?1:-1;break c}tb(g);break c}tb(g)}fb=e+32|0;break a}a=N()|0;tb(g);Q(a|0);p()}h:{if(h){break h}kg(x[x[b>>2]-12>>2]+b|0,0);b=Qm(f+80|0,Ii(b,i,l,0));x[31725]=0;h=P(463,f+68|0,14272)|0;i=x[31725];x[31725]=0;i:{if((i|0)!=1){x[31725]=0;x[f+48>>2]=3;x[f+52>>2]=0;S(464,b|0,h|0,f+48|0);i=x[31725];x[31725]=0;if((i|0)!=1){Eb(h);v[f+67|0]=0;x[31725]=0;h=P(463,f+48|0,14728)|0;i=x[31725];x[31725]=0;if((i|0)!=1){x[31725]=0;S(465,b|0,f+67|0,h|0);i=x[31725];x[31725]=0;if((i|0)!=1){Eb(h);h=Fc(f+44|0,y[f+67|0]?0:d);x[31725]=0;d=R(478,b|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){x[31725]=0;i=R(479,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){x[f+40>>2]=d;j:{k:{l:{m:{while(1){if(!Ib(d,i)){a=wl(y[b|0]);Ch(b);h=a?-1:1;break h}x[31725]=0;d=P(463,f+24|0,15844)|0;e=x[31725];x[31725]=0;if((e|0)==1){break l}e=x[b+44>>2];g=x[b+40>>2];x[31725]=0;e=ba(480,g|0,e|0,x[f+40>>2],d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break k}Eb(d);n:{o:{if(e){d=x[h>>2];x[31725]=0;V(481,b|0,f+40|0,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){break o}break j}x[31725]=0;d=P(463,f+12|0,15528)|0;e=x[31725];x[31725]=0;p:{q:{if((e|0)!=1){e=x[b+44>>2];g=x[b+40>>2];x[31725]=0;e=ba(480,g|0,e|0,x[f+40>>2],d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break q}Eb(d);if(!e){break p}x[31725]=0;S(482,b|0,f+40|0,f+38|0);d=x[31725];x[31725]=0;if((d|0)==1){break j}break o}a=N()|0;break i}a=N()|0;Eb(d);break i}x[31725]=0;d=P(463,f|0,15368)|0;e=x[31725];x[31725]=0;if((e|0)==1){break n}e=x[b+44>>2];g=x[b+40>>2];x[31725]=0;e=ba(480,g|0,e|0,x[f+40>>2],d|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break m}Eb(d);if(!e){break o}d=x[h>>2];x[31725]=0;V(483,b|0,f+40|0,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break j}}fA(f+40|0);d=x[f+40>>2];continue}break}a=N()|0;break i}a=N()|0;Eb(d);break i}a=N()|0;break i}a=N()|0;Eb(d);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;Eb(h);break i}a=N()|0;break i}a=N()|0;Eb(h);break i}a=N()|0}Ch(b);Q(a|0);p()}fb=f+192|0;return h|0}function Sg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-112|0;fb=j;k=i&2147483647;a:{b:{l=e&2147483647;m=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:m)){o=k-2147418112|0;if(!h&(o|0)==-2147418112?f|g:(o|0)==-2147418112&(h|0)!=0|o>>>0>2147549184){break b}}if(!(!d&(l|0)==2147418112?m:l>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(l^2147418112|c))){n=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:n;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|l))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}n=(k|0)==(l|0);r=n&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:n&d>>>0<h>>>0|k>>>0>l>>>0;m=r;l=m?f:b;o=m?g:c;n=m?i:e;s=n;m=m?h:d;q=n&65535;d=r?d:h;e=r?e:i;t=e;n=e>>>16&32767;p=s>>>16&32767;if(!p){e=!(m|q);i=e;k=e?l:m;e=e<<6;i=G(i?o:q);e=e+((i|0)==32?G(k)+32|0:i)|0;bg(j+96|0,l,o,m,q,e-15|0);m=x[j+104>>2];q=x[j+108>>2];o=x[j+100>>2];p=16-e|0;l=x[j+96>>2]}f=r?b:f;g=r?c:g;h=d;i=t&65535;if(!n){b=!(h|i);e=b;k=b?f:h;b=b<<6;e=G(e?g:i);b=b+((e|0)==32?G(k)+32|0:e)|0;bg(j+80|0,f,g,h,i,b-15|0);n=16-b|0;h=x[j+88>>2];i=x[j+92>>2];g=x[j+84>>2];f=x[j+80>>2]}c=i<<3|h>>>29;b=h<<3|g>>>29;c=c|524288;h=m<<3|o>>>29;i=q<<3|m>>>29;r=s^t;e=g<<3|f>>>29;d=f<<3;c:{if((n|0)==(p|0)){break c}f=p-n|0;if(f>>>0>127){b=0;c=0;e=0;d=1;break c}bg(j- -64|0,d,e,b,c,128-f|0);gn(j+48|0,d,e,b,c,f);b=x[j+56>>2];c=x[j+60>>2];e=x[j+52>>2];d=x[j+48>>2]|(x[j+64>>2]|x[j+72>>2]|(x[j+68>>2]|x[j+76>>2]))!=0}m=d;k=e;n=h;q=i|524288;e=o<<3|l>>>29;o=l<<3;l=e;d:{if((r|0)<0){f=0;g=0;h=0;i=0;if(!(m^o|b^n|(k^l|c^q))){break a}d=o-m|0;e=l-((m>>>0>o>>>0)+k|0)|0;f=n-b|0;g=(k|0)==(l|0)&m>>>0>o>>>0|k>>>0>l>>>0;h=f-g|0;b=(q-((b>>>0>n>>>0)+c|0)|0)-(f>>>0<g>>>0)|0;i=b;if(b>>>0>524287){break d}b=!(h|i);f=b;g=b?d:h;b=b<<6;f=G(f?e:i);b=b+((f|0)==32?G(g)+32|0:f)|0;b=b-12|0;bg(j+32|0,d,e,h,i,b);p=p-b|0;h=x[j+40>>2];i=x[j+44>>2];d=x[j+32>>2];e=x[j+36>>2];break d}e=k+l|0;d=m+o|0;e=d>>>0<o>>>0?e+1|0:e;f=(k|0)==(e|0)&d>>>0<m>>>0|e>>>0<k>>>0;k=c+q|0;b=b+n|0;k=b>>>0<n>>>0?k+1|0:k;h=b+f|0;i=h>>>0<b>>>0?k+1|0:k;if(!(i&1048576)){break d}d=m&1|((e&1)<<31|d>>>1);e=h<<31|e>>>1;p=p+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}c=0;l=s&-2147483648;if((p|0)>=32767){h=c;i=l|2147418112;f=0;g=0;break a}n=0;e:{if((p|0)>0){n=p;break e}bg(j+16|0,d,e,h,i,p+127|0);gn(j,d,e,h,i,1-p|0);d=x[j>>2]|(x[j+16>>2]|x[j+24>>2]|(x[j+20>>2]|x[j+28>>2]))!=0;e=x[j+4>>2];h=x[j+8>>2];i=x[j+12>>2]}o=d&7;d=(e&7)<<29|d>>>3;f=(o>>>0>4)+d|0;b=h<<29|e>>>3;g=d>>>0>f>>>0?b+1|0:b;d=(b|0)==(g|0)&d>>>0>f>>>0|b>>>0>g>>>0;b=c|((i&7)<<29|h>>>3);h=d+b|0;i=l|(i>>>3&65535|n<<16);i=b>>>0>h>>>0?i+1|0:i;f:{if((o|0)==4){b=0;k=g+b|0;d=f;c=f&1;f=f+c|0;g=d>>>0>f>>>0?k+1|0:k;b=(b|0)==(g|0)&c>>>0>f>>>0|b>>>0>g>>>0;h=b+h|0;i=b>>>0>h>>>0?i+1|0:i;break f}if(!o){break a}}}x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;fb=j+112|0}function yua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-720|0;fb=d;xc(b);f=fb-16|0;fb=f;h=d+110|0;$$(f+8|0,h);g=x[f+12>>2];j=b;kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){Vb(j,x[f+12>>2])}fb=f+16|0;b=(b|0)==(g|0);if(!b){_$(h)}a:{if(!b){break a}if(!a0(d+110|0)){break a}b:{if(!c){break b}Bd(a,67108864);gg(a);b=y[d+135|0];w[a+480190>>1]=31;w[a+480188>>1]=b;x[a+480228>>2]=256/(b>>>0);b=tc(d,8179);Ab(a+1298344|0,b);tb(b);b=tc(d,10804);Ab(a+1298356|0,b);tb(b);b=d+84|0;ig(b,4174);f=y[d+134|0];x[d+64>>2]=f>>>4;x[31725]=0;x[d+104>>2]=f&15;V(309,d|0,b|0,d- -64|0,d+104|0);b=x[31725];x[31725]=0;c:{d:{if((b|0)!=1){Ab(a+1298368|0,d);tb(d);Eb(d+84|0);n=a+1298404|0,o=x[Fc(d,28)>>2],x[n>>2]=o;jw(Xb(x[a+484360>>2],y[a+484376|0]),d+158|0,y[d+157|0]+1|0);while(1){e:{if((e|0)==31){wE(j,a+1298308|0,32);e=1;break e}b=e+1|0;g=D(b,104)+a|0;h=g+484380|0;ld(h,1);f=(d+110|0)+(e<<2)|0;n=h,o=$b(y[f+176|0]|y[f+177|0]<<8|(y[f+178|0]<<16|y[f+179|0]<<24)),x[n>>2]=o;k=$b(y[f+300|0]|y[f+301|0]<<8|(y[f+302|0]<<16|y[f+303|0]<<24));x[g+484384>>2]=k;f=$b(y[f+424|0]|y[f+425|0]<<8|(y[f+426|0]<<16|y[f+427|0]<<24));x[g+484388>>2]=f+k;if(f){f=g+484414|0;w[f>>1]=z[f>>1]|2}al(h);e=(d+110|0)+e|0;v[d|0]=y[e+548|0];v[d+84|0]=64;n=g+484410|0,o=y[Rb(d,d+84|0)|0]<<2,w[n>>1]=o;v[g+484417|0]=y[e+579|0]<<4;e=b;continue}break}while(1){if((e|0)!=32){Y$(j,((e<<5)+a|0)+946304|0,30);e=e+1|0;continue}break}k=c&1;if(k){Vf(a+484344|0,y[d+156|0]+1|0)}h=a+484344|0;f=0;while(1){if(y[d+156|0]<f>>>0){e=1;if(!(c&2)){break a}b=Xc(d,8,1,1,0);while(1){if((e|0)==32){break b}fg(b,(D(e,104)+a|0)+484380|0,j);e=e+1|0;continue}}g=bi(d+84|0);f:{g:{if(y[d+136|0]){x[31725]=0;b=R(275,j|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break f}x[31725]=0;S(187,d- -64|0,j|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break f}break g}b=z[a+480188>>1];x[31725]=0;S(187,d- -64|0,j|0,b<<8);b=x[31725];x[31725]=0;if((b|0)==1){break d}}b=d- -64|0;e=ic(d,b);hd(g,e);ub(e);ub(b);h:{if(!k){break h}x[31725]=0;b=U(198,h|0,f&65535,64)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}if(!b){break h}b=0;if(y[d+136|0]){x[31725]=0;O(310,g|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break d}i:while(1){if((b|0)==64){break h}e=Wb(x[h>>2],f);cf(d- -64|0,x[e>>2],x[x[e+48>>2]+12>>2],b);n=d,o=wb(x[d+64>>2]),x[n+104>>2]=o;l=b+d|0;e=128;i=iw(x[d+64>>2],x[d+68>>2]);while(1){m=x[d+104>>2];if(!Ib(m,i)){b=b+1|0;continue i}j:{if(!(y[l|0]&e)){break j}x[31725]=0;O(311,g|0,m|0);m=x[31725];x[31725]=0;if((m|0)!=1){break j}break d}e=e>>>1|0;vg(d+104|0);continue}}}k:while(1){e=0;l=b&65535;if(l>>>0>=z[a+480188>>1]){break h}while(1){if((e|0)==64){b=b+1|0;continue k}i=Wb(x[h>>2],f);i=jd(x[i>>2],x[x[i+48>>2]+12>>2],e,l);x[31725]=0;O(311,g|0,i|0);i=x[31725];x[31725]=0;if((i|0)!=1){e=e+1|0;continue}break}break}break d}ub(g);f=f+1|0;continue}break}break d}e=N()|0;Eb(d+84|0);break c}e=N()|0;ub(g)}Q(e|0);p()}e=1}fb=d+720|0;return e|0}function Db(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=x[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=x[d>>2];d=d-b|0;if(d>>>0<A[31605]){break a}a=a+b|0;c:{d:{if(x[31606]!=(d|0)){if(b>>>0<=255){e=b>>>3|0;b=x[d+12>>2];c=x[d+8>>2];if((b|0)==(c|0)){i=126404,j=x[31601]&rva(-2,e),x[i>>2]=j;break b}x[c+12>>2]=b;x[b+8>>2]=c;break b}g=x[d+24>>2];b=x[d+12>>2];if((d|0)!=(b|0)){c=x[d+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break c}e=d+20|0;c=x[e>>2];if(!c){c=x[d+16>>2];if(!c){break d}e=d+16|0}while(1){h=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[h>>2]=0;break c}b=x[f+4>>2];if((b&3)!=3){break b}x[31603]=a;x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[f>>2]=a;return}b=0}if(!g){break b}c=x[d+28>>2];e=(c<<2)+126708|0;e:{if(x[e>>2]==(d|0)){x[e>>2]=b;if(b){break e}i=126408,j=x[31602]&rva(-2,c),x[i>>2]=j;break b}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}x[b+24>>2]=g;c=x[d+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[d+20>>2];if(!c){break b}x[b+20>>2]=c;x[c+24>>2]=b}if(d>>>0>=f>>>0){break a}b=x[f+4>>2];if(!(b&1)){break a}f:{g:{h:{i:{if(!(b&2)){if(x[31607]==(f|0)){x[31607]=d;a=x[31604]+a|0;x[31604]=a;x[d+4>>2]=a|1;if(x[31606]!=(d|0)){break a}x[31603]=0;x[31606]=0;return}if(x[31606]==(f|0)){x[31606]=d;a=x[31603]+a|0;x[31603]=a;x[d+4>>2]=a|1;x[a+d>>2]=a;return}a=(b&-8)+a|0;if(b>>>0<=255){e=b>>>3|0;b=x[f+12>>2];c=x[f+8>>2];if((b|0)==(c|0)){i=126404,j=x[31601]&rva(-2,e),x[i>>2]=j;break g}x[c+12>>2]=b;x[b+8>>2]=c;break g}g=x[f+24>>2];b=x[f+12>>2];if((f|0)!=(b|0)){c=x[f+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break h}e=f+20|0;c=x[e>>2];if(!c){c=x[f+16>>2];if(!c){break i}e=f+16|0}while(1){h=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[h>>2]=0;break h}x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a;break f}b=0}if(!g){break g}c=x[f+28>>2];e=(c<<2)+126708|0;j:{if(x[e>>2]==(f|0)){x[e>>2]=b;if(b){break j}i=126408,j=x[31602]&rva(-2,c),x[i>>2]=j;break g}x[g+(x[g+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}x[b+24>>2]=g;c=x[f+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[f+20>>2];if(!c){break g}x[b+20>>2]=c;x[c+24>>2]=b}x[d+4>>2]=a|1;x[a+d>>2]=a;if(x[31606]!=(d|0)){break f}x[31603]=a;return}if(a>>>0<=255){b=(a&-8)+126444|0;c=x[31601];a=1<<(a>>>3);k:{if(!(c&a)){x[31601]=a|c;a=b;break k}a=x[b+8>>2]}x[b+8>>2]=d;x[a+12>>2]=d;x[d+12>>2]=b;x[d+8>>2]=a;return}c=31;if(a>>>0<=16777215){b=G(a>>>8|0);c=((a>>>38-b&1)-(b<<1)|0)+62|0}x[d+28>>2]=c;x[d+16>>2]=0;x[d+20>>2]=0;b=(c<<2)+126708|0;l:{m:{e=x[31602];h=1<<c;n:{if(!(e&h)){x[31602]=e|h;x[b>>2]=d;x[d+24>>2]=b;break n}c=a<<((c|0)!=31?25-(c>>>1|0)|0:0);b=x[b>>2];while(1){e=b;if((x[b+4>>2]&-8)==(a|0)){break m}b=c>>>29|0;c=c<<1;h=e+(b&4)|0;b=x[h+16>>2];if(b){continue}break}x[h+16>>2]=d;x[d+24>>2]=e}x[d+12>>2]=d;x[d+8>>2]=d;break l}a=x[e+8>>2];x[a+12>>2]=d;x[e+8>>2]=d;x[d+24>>2]=0;x[d+12>>2]=e;x[d+8>>2]=a}a=x[31609]-1|0;x[31609]=a?a:-1}}function sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-112|0;fb=e;g=x[b+4>>2];h=y[b+11|0];a:{if(Ad(g,h)){break a}f=y[xz(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+100|0;tx(f,b,0,Yc(g,h)-1|0);Ab(b,f);tb(f)}g=e+100|0;ge(g);f=x[e+100>>2];ge(e+88|0);f=fN(f,x[e+92>>2],b);ge(g);b:{c:{d:{e:{if((f|0)==x[e+104>>2]){if(Ld(b,22255)){a=ac(8);x[31725]=0;S(1008,e+100|0,18246,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}pc(a,e+100|0);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(e+100|0);break c}if(!d){break e}a=ac(8);x[31725]=0;S(1008,e+76|0,18282,b|0);b=x[31725];x[31725]=0;f:{g:{h:{i:{j:{if((b|0)!=1){x[31725]=0;O(1019,e+88|0,e+76|0);b=x[31725];x[31725]=0;if((b|0)==1){break j}x[31725]=0;S(545,e+100|0,e+88|0,c|0);b=x[31725];x[31725]=0;d=1;if((b|0)==1){break i}pc(a,e+100|0);x[31725]=0;S(99,a|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;tb(e+100|0);d=0;break h}b=N()|0;break f}b=N()|0;d=1;break g}b=N()|0}tb(e+88|0)}tb(e+76|0);if(!d){break c}}jc(a);break c}k:{switch(x[f+4>>2]){case 0:ee(e+68|0,b);b=fb-176|0;fb=b;f=b+12|0;Wf(f,c);x[31725]=0;O(126,b+24|0,f|0);c=x[31725];x[31725]=0;l:{m:{n:{o:{p:{if((c|0)!=1){x[31725]=0;c=P(105,b+36|0,b+24|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break p}tb(b+24|0);tb(b+12|0);f=x[x[c>>2]-12>>2];x[31725]=0;g=ca(106)|0;h=x[31725];x[31725]=0;if((h|0)==1){break n}x[31725]=0;S(107,b+8|0,c+f|0,g|0);f=x[31725];x[31725]=0;if((f|0)==1){break n}Zb(b+8|0);x[31725]=0;f=P(127,c|0,b+24|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break n}c=xk(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];Ff(f);fb=b+176|0;b=(c^-1)&(g|0)!=0;break l}a=N()|0;break o}a=N()|0;tb(b+24|0)}tb(b+12|0);break m}a=N()|0;Ff(c)}Q(a|0);p()}c=x[e+72>>2];x[e>>2]=x[e+68>>2];x[e+4>>2]=c;Pz(a,e,b,d);break e;case 1:ee(e+60|0,b);b=fb-176|0;fb=b;f=b+12|0;Wf(f,c);x[31725]=0;O(126,b+24|0,f|0);c=x[31725];x[31725]=0;q:{r:{s:{t:{u:{if((c|0)!=1){x[31725]=0;c=P(105,b+36|0,b+24|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break u}tb(b+24|0);tb(b+12|0);f=x[x[c>>2]-12>>2];x[31725]=0;g=ca(106)|0;h=x[31725];x[31725]=0;if((h|0)==1){break s}x[31725]=0;S(107,b+8|0,c+f|0,g|0);f=x[31725];x[31725]=0;if((f|0)==1){break s}Zb(b+8|0);x[31725]=0;x[b+24>>2]=0;x[b+28>>2]=0;f=P(1135,c|0,b+24|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break s}c=xk(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];h=x[b+28>>2];Ff(f);fb=b+176|0;b=c?0:g;c=c?0:h;break q}a=N()|0;break t}a=N()|0;tb(b+24|0)}tb(b+12|0);break r}a=N()|0;Ff(c)}Q(a|0);p()}f=x[e+64>>2];x[e+8>>2]=x[e+60>>2];x[e+12>>2]=f;Nz(a,e+8|0,b,c,d);break e;case 2:ee(e+52|0,b);i=p_(c);b=x[e+56>>2];x[e+16>>2]=x[e+52>>2];x[e+20>>2]=b;Oz(a,e+16|0,i,d);break e;case 3:break k;default:break e}}ee(e+44|0,b);ee(e+32|0,c);b=x[e+48>>2];x[e+24>>2]=x[e+44>>2];x[e+28>>2]=b;Mz(a,e+24|0,x[e+32>>2],x[e+36>>2],d)}fb=e+112|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function bS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=E(0),u=0;if(b){LA(a);c=a+24596|0;x[c>>2]=0;x[c+4>>2]=0;x[a+24588>>2]=0;x[a+24592>>2]=0;gS(a)}aS(a+24648|0);o=x[a+24620>>2];f=fb-144|0;fb=f;d=!b;e=a+397456|0;c=x[e+4>>2];if(c>>>0>=29){x[e+4>>2]=0;c=0}g=D(c,44)+45984|0;if(!((g|0)==x[e+8>>2]&d)){x[e+8>>2]=g;m=E(o>>>0);c=f+12|0;d=x[g+24>>2];x[c>>2]=d;j=x[g+16>>2];x[c+4>>2]=j;x[c+8>>2]=x[g+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){h=j;j=k+600|0;x[c+4>>2]=h-j;x[c>>2]=d-j}i=E(B[g+36>>2]*E(79.30999755859375));a:{if(E(F(i))<E(2147483648)){d=~~i;break a}d=-2147483648}x[c+16>>2]=d- -8192;i=E(E(E(B[g+32>>2]*E(.0036000001709908247))+E(.15000000596046448))*E(32767));b:{if(E(F(i))<E(2147483648)){d=~~i;break b}d=-2147483648}x[c+20>>2]=(d|0)>=32512?32512:d;j=0;i=B[g+8>>2];l=B[g+20>>2];l=E((l>E(.10000000149011612)?E(.10000000149011612):l)*m);c:{if(E(F(l))<E(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)<=96?96:d;h=k-7500|0;n=k>>>0>=h>>>0?h:0;l=E(B[g+28>>2]*m);d:{if(E(F(l))<E(2147483648)){h=~~l;break d}h=-2147483648}d=n+(h+((d|0)<96?d-96|0:0)|0)|0;h=(d|0)<=128?128:d;p=h>>>0>=3800?3800:h;x[c+24>>2]=p;n=(d|0)<128?d-128|0:0;i=E(i*m);e:{if(E(F(i))<E(2147483648)){q=~~i;break e}q=-2147483648}d=h-3800|0;h=(q+n|0)+(d>>>0<=h>>>0?d:0)|0;x[c+32>>2]=h;n=k>>>0>=7500?7500:k;while(1){if((j|0)==8){i=E(h|0);l=E(De(E(.0010000000474974513),(h|0)<4721?E(1):E(E(4720)/i))*E(32768));f:{if(E(F(l))<E(2147483648)){d=~~l;break f}d=-2147483648}x[c+12>>2]=d;i=E(B[g+12>>2]*i);s=c,t=De(E(.0010000000474974513),i<=E(4720)?E(1):E(E(4720)/i)),B[s+28>>2]=t}else{d=D(j,12);k=d+c|0;w[k+42>>1]=z[d+47274>>1];w[k+36>>1]=z[d+47268>>1];w[k+40>>1]=z[d+47272>>1];w[k+38>>1]=z[d+47270>>1];x[k+44>>2]=n+((D(x[d+47264>>2],p)+50|0)/100|0);j=j+1|0;continue}break}x[e+20>>2]=x[f+44>>2];r=+m;c=TP(UP(x[f+20>>2]),r);w[e+86>>1]=c;w[e+84>>1]=c;c=z[f+28>>1]<<1;w[e+94>>1]=c;w[e+92>>1]=c;c=0;while(1){if((c|0)==8){x[e+49892>>2]=x[f+36>>2];c=x[f+16>>2];if((c|0)>-9e3){c=SP(c)}else{c=0}x[e+80>>2]=c;d=e+49948|0;c=x[f+12>>2];if((c|0)>=-8999){c=SP(c)}else{c=0}x[d>>2]=c;c=x[f+32>>2];d=e+49932|0;x[d>>2]=268464128;x[d+4>>2]=1879052288;c=c>>>0>=32512?32512:c;w[e+49906>>1]=c;w[e+49904>>1]=c;w[e+49902>>1]=c;w[e+49900>>1]=c;x[f+8>>2]=x[f+24>>2];Fe(f+8|0,0,32752);c=z[f+8>>1];w[e+49914>>1]=c;w[e+49910>>1]=0;w[e+49912>>1]=0;w[e+49908>>1]=c;m=B[f+40>>2];s=f,u=TP(+E(m*m),r),x[s+4>>2]=u;Fe(f+4|0,256,32512);c=z[f+4>>1];w[e+49922>>1]=c;w[e+49918>>1]=0;w[e+49920>>1]=0;w[e+49916>>1]=c}else{d=(c<<4)+e|0;g=(f+12|0)+D(c,12)|0;j=x[g+44>>2];x[d+100>>2]=j;x[d+104>>2]=j;w[d+108>>1]=z[g+36>>1];w[d+110>>1]=z[g+42>>1];w[d+112>>1]=z[g+40>>1];w[d+114>>1]=z[g+38>>1];c=c+1|0;continue}break}}if(b){x[e+16>>2]=0;XP(e,a+397448|0,a+397452|0)}b=D(o,5);if(b>>>0>A[e+20>>2]){x[e+20>>2]=b}fb=f+144|0;b=x[a+1298300>>2];if(Dd(b)){SU(b,x[a+24620>>2])}}function Zoa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;h=fb-4128|0;fb=h;g=Bb(y[a+14|0]|y[a+15|0]<<8);if(!(!g|g>>>0>20|z[b+480190>>1]<=y[a+23|0])){ld(d,32);w[d+34>>1]=1;f=h+12|0;g=a+20|0;x[f>>2]=g;x[f+4>>2]=(g+80|0)-g>>2;yW(h+4120|0,x[h+12>>2],x[h+16>>2],Bb(y[a+14|0]|y[a+15|0]<<8));g=x[h+4120>>2];i=y[yb(g,0)+3|0];x[h+12>>2]=1;i=x[ad(ui(b,i+1|0)+24|0,f)>>2];j=f;f=x[h+4124>>2];yW(j,g,f,c?f:1);B=h,C=wb(x[h+12>>2]),x[B+4108>>2]=C;q=1/+(i>>>0);f=fb-16|0;fb=f;i=x[vb(f+12|0,x[h+12>>2]+(x[h+16>>2]<<2)|0)>>2];fb=f+16|0;f=x[d>>2];j=x[h+4120>>2];k=z[b+480190>>1];while(1){g=x[h+4108>>2];if(Ib(g,i)){l=y[g+3|0];a:{if(l>>>0>=k>>>0){break a}g=v[g+1|0];if((g|0)<0){break a}l=ui(b,l+1|0);n=x[l>>2];f=_e(q*(Di(+(g-v[yb(j,0)+1|0]|0)/-12)*+(n>>>0)*+A[l+24>>2]))+f|0;x[d>>2]=f}Je(h+4108|0);continue}else{b:{r=Fh(d);if(!r){break b}i=(e<<12>>>0)/1e4|0;f=x[h+4124>>2];e=fb-16|0;fb=e;j=h+4108|0;x[j>>2]=0;x[j+4>>2]=0;sc(j+8|0);Rd(e+8|0,x[vb(e+4|0,j)>>2]);c:{if(!f){break c}x[31725]=0;O(756,j|0,f|0);g=x[31725];x[31725]=0;if((g|0)!=1){x[31725]=0;kW(j,f);f=x[31725];x[31725]=0;if((f|0)!=1){break c}}a=N()|0;jW(e+8|0);Q(a|0);p()}f=e+8|0;Qd(f);jW(f);fb=e+16|0;t=x[j>>2];l=x[h+4120>>2];u=x[h+4124>>2];f=0;while(1){if((f|0)==(u|0)){g=b+24648|0}else{g=yb(l,f);e=xW(t,f);k=y[g+3|0];d:{if(k>>>0>=z[b+480190>>1]){break d}o=v[g+1|0];if((o|0)<0){break d}n=0;g=y[g+2|0];if((g+14&255)>>>0<=5){n=v[g+25166|0]}k=ui(b,k+1|0);g=x[k+24>>2];s=q*(Di(+(n<<24>>24)/96+ +(o-v[yb(l,0)+1|0]|0)/12)*+(g>>>0));if(s<=0){break d}g=wW(s);x[e+8>>2]=g;n=hb;x[e+12>>2]=n;x[e+16>>2]=x[k+20>>2];o=x[k>>2];x[e+76>>2]=o;x[e+88>>2]=z[k+34>>1]&1023;e:{if(c){x[e+664>>2]=m;m=_e(+(o>>>0)/rC(g,n))+m|0;g=i;break e}g=(i>>>0)/(Bb(y[a+14|0]|y[a+15|0]<<8)>>>0)|0}x[e+20>>2]=g;x[e+24>>2]=g}f=f+1|0;continue}break}b=0;while(1){f:{a=x[d>>2];if(a>>>0>b>>>0){Tb(h+12|0,0,4096);x[h+8>>2]=512;x[h+4>>2]=a-b;c=x[Gb(h+8|0,h+4|0)>>2];B=h,C=wb(x[j>>2]),x[B+8>>2]=C;i=wb(x[j+4>>2]);while(1){a=x[h+8>>2];if(!Ib(a,i)){break f}g:{h:{if(!x[a+16>>2]){break h}e=x[a+664>>2];if(e>>>0>=c>>>0){x[a+664>>2]=e-c;break h}f=x[a+88>>2];x[h+4>>2]=c-e;B=h,C=_e((+A[a+76>>2]-rC(x[a>>2],x[a+4>>2]))/rC(x[a+8>>2],x[a+12>>2])),x[B>>2]=C;m=x[Gb(h+4|0,h)>>2];x[31725]=0;V(x[((f&1|(f&64?18:16))<<2)+25760>>2],a|0,g|0,(h+12|0)+(e<<3)|0,m|0);e=x[31725];x[31725]=0;if((e|0)==1){break g}x[a+664>>2]=0;if(A[a+76>>2]>A[a+4>>2]){break h}x[a+16>>2]=0}x[h+8>>2]=x[h+8>>2]+872;continue}break}a=N()|0;vW(j);Q(a|0);p()}vW(j);break b}e=x[d+20>>2]+(b<<1)|0;f=h+12|0;a=fb-16|0;fb=a;x[a+12>>2]=c;wc(a+12|0,512);m=x[a+12>>2];while(1){if(m){i=qd(x[f>>2]+2048|0,12);i=(i|0)>=32767?32767:i;w[e>>1]=(i|0)<=-32768?-32768:i;f=f+8|0;e=e+2|0;m=m-1|0;continue}break}fb=a+16|0;b=b+c|0;continue}}f=(r|0)!=0}break}}fb=h+4128|0;return f|0}function Cv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=x[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=x[a>>2];b=c+b|0;c:{d:{e:{a=a-c|0;if((a|0)!=x[31606]){if(c>>>0<=255){d=x[a+8>>2];e=x[a+12>>2];if((d|0)!=(e|0)){break e}i=126404,j=x[31601]&rva(-2,c>>>3|0),x[i>>2]=j;break b}g=x[a+24>>2];c=x[a+12>>2];if((c|0)!=(a|0)){d=x[a+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break c}e=a+20|0;d=x[e>>2];if(!d){d=x[a+16>>2];if(!d){break d}e=a+16|0}while(1){h=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[h>>2]=0;break c}c=x[f+4>>2];if((c&3)!=3){break b}x[31603]=b;x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[f>>2]=b;return}x[d+12>>2]=e;x[e+8>>2]=d;break b}c=0}if(!g){break b}d=x[a+28>>2];e=(d<<2)+126708|0;f:{if(x[e>>2]==(a|0)){x[e>>2]=c;if(c){break f}i=126408,j=x[31602]&rva(-2,d),x[i>>2]=j;break b}x[g+(x[g+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}x[c+24>>2]=g;d=x[a+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[a+20>>2];if(!d){break b}x[c+20>>2]=d;x[d+24>>2]=c}g:{h:{i:{j:{c=x[f+4>>2];if(!(c&2)){if(x[31607]==(f|0)){x[31607]=a;b=x[31604]+b|0;x[31604]=b;x[a+4>>2]=b|1;if(x[31606]!=(a|0)){break a}x[31603]=0;x[31606]=0;return}if(x[31606]==(f|0)){x[31606]=a;b=x[31603]+b|0;x[31603]=b;x[a+4>>2]=b|1;x[a+b>>2]=b;return}b=(c&-8)+b|0;if(c>>>0<=255){e=c>>>3|0;c=x[f+12>>2];d=x[f+8>>2];if((c|0)==(d|0)){i=126404,j=x[31601]&rva(-2,e),x[i>>2]=j;break h}x[d+12>>2]=c;x[c+8>>2]=d;break h}g=x[f+24>>2];c=x[f+12>>2];if((f|0)!=(c|0)){d=x[f+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break i}e=f+20|0;d=x[e>>2];if(!d){d=x[f+16>>2];if(!d){break j}e=f+16|0}while(1){h=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[h>>2]=0;break i}x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[a+b>>2]=b;break g}c=0}if(!g){break h}d=x[f+28>>2];e=(d<<2)+126708|0;k:{if(x[e>>2]==(f|0)){x[e>>2]=c;if(c){break k}i=126408,j=x[31602]&rva(-2,d),x[i>>2]=j;break h}x[g+(x[g+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}x[c+24>>2]=g;d=x[f+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[f+20>>2];if(!d){break h}x[c+20>>2]=d;x[d+24>>2]=c}x[a+4>>2]=b|1;x[a+b>>2]=b;if(x[31606]!=(a|0)){break g}x[31603]=b;return}if(b>>>0<=255){c=(b&-8)+126444|0;d=x[31601];b=1<<(b>>>3);l:{if(!(d&b)){x[31601]=b|d;b=c;break l}b=x[c+8>>2]}x[c+8>>2]=a;x[b+12>>2]=a;x[a+12>>2]=c;x[a+8>>2]=b;return}d=31;if(b>>>0<=16777215){c=G(b>>>8|0);d=((b>>>38-c&1)-(c<<1)|0)+62|0}x[a+28>>2]=d;x[a+16>>2]=0;x[a+20>>2]=0;c=(d<<2)+126708|0;m:{e=x[31602];h=1<<d;n:{if(!(e&h)){x[31602]=e|h;x[c>>2]=a;x[a+24>>2]=c;break n}d=b<<((d|0)!=31?25-(d>>>1|0)|0:0);c=x[c>>2];while(1){e=c;if((x[c+4>>2]&-8)==(b|0)){break m}c=d>>>29|0;d=d<<1;h=e+(c&4)|0;c=x[h+16>>2];if(c){continue}break}x[h+16>>2]=a;x[a+24>>2]=e}x[a+12>>2]=a;x[a+8>>2]=a;return}b=x[e+8>>2];x[b+12>>2]=a;x[e+8>>2]=a;x[a+24>>2]=0;x[a+12>>2]=e;x[a+8>>2]=b}}function Q1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;e=fb-32|0;fb=e;a:{if((d|0)<=0){break a}x[e+8>>2]=d;x[e+20>>2]=b;x[e+16>>2]=214748364;u=e,w=D(x[Gb(e+20|0,e+16|0)>>2],20),x[u+24>>2]=w;xo(c,x[Gb(e+8|0,e+24|0)>>2]);x[e+12>>2]=b;x[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=Jh(a,b,i);h=Jh(a,b,i+4|0);f=Jh(a,b,i+5|0);u=e,w=Jh(a,b,i+6|0)<<8|Jh(a,b,i+7|0),x[u+28>>2]=w;n=f|h<<8;t=i+8|0;f:{g:{switch(g|0){case 0:i=0;if(d>>>0<n>>>0){i=ac(8);x[31725]=0;a=R(190,i|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break f}break d}while(1){if((i|0)!=(n|0)){u=e,w=Jh(a,b,i+t|0),v[u+24|0]=w;vo(c,e+24|0);i=i+1|0;continue}break};s=n;break b;case 1:break g;default:break e}}Bi(e+28|0,d);s=x[e+28>>2];o=Jh(a,b,i+10|0);v[e+24|0]=o;vo(c,e+24|0);j=i+11|0;n=n+3&65532;i=s-1|0;h=0;l=0;q=0;m=0;while(1){if((i|0)<=0){break c}f=Og(j,h,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=h;break i}g=h+1|0;m=8;break l}g=h+1|0;m:{if(!f){if(!Og(j,g,1,e+8|0)){break i}k=2;n:{o:{f=h+2|0;if(!Og(j,f,1,e+8|0)){break o}k=3;f=h+3|0;if(!Og(j,f,1,e+8|0)){break o}k=Og(j,f,3,e+8|0);g=h+6|0;break n}g=f+1|0}f=4;p:{q:{r:{h=((m<<3)+k|0)-17|0;s:{if((h|0)<0){a=ac(8);x[31725]=0;b=R(190,a|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break r}break s}if(h>>>0<56){break p}a=ac(8);x[31725]=0;b=R(190,a|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break q}}b=N()|0;jc(a);Q(b|0);p()}da(b|0,24440,164);p()}da(b|0,24440,164);p()}m=y[h+24480|0];if((m|0)!=8){break k}break m}f=4;if((m|0)!=8){break k}}m=8;f=1;if((q|0)>19){break k}}f=0;break j}q=q+8|0}while(1){if(!((f|0)<0|(i|0)<=0)){k=(g|0)/8|0;h=k+j|0;r=Jh(x[e+8>>2],x[e+12>>2],h);o=o-qd((Jh(x[e+8>>2],x[e+12>>2],h+1|0)<<8|r<<16|Jh(x[e+8>>2],x[e+12>>2],h+2|0))<<(g-(k<<3)|0)+8,32-m|0)|0;v[e+24|0]=o;vo(c,e+24|0);f=f-1|0;i=i-1|0;g=g+m|0;continue}break}l=(l|0)==31?31:l+1|0;h=g;break h}t:{u:{v:{f=g+1|0;if(!Og(j,f,1,e+8|0)){h=2;break v}f=g+2|0;if(!Og(j,f,1,e+8|0)){h=4;break v}f=g+3|0;if(!Og(j,f,1,e+8|0)){h=6;break v}f=g+5|0;if(!Og(j,g+4|0,1,e+8|0)){g=g+8|0;f=Og(j,f,3,e+8|0)+8|0;break t}g=g+10|0;h=16;f=Og(j,f,5,e+8|0);break u}g=f+2|0;f=Og(j,f+1|0,1,e+8|0)}f=f+h|0}w:{if(Og(j,g,1,e+8|0)){k=-256;h=12;break w}g=g+1|0;h=Og(j,g,1,e+8|0);k=h?-4352:0;h=h?14:8}r=g+1|0;g=Og(j,r,h,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)<=1?1:l)-1|0}k=(g^-1)+k|0;g=Sc(x[c>>2],x[c+4>>2])+k|0;if(g>>>0<k>>>0){h=h+r|0;while(1){if((f|0)<=0|(i|0)<=0){break h}o=y[xb(x[c>>2],g)|0];v[e+24|0]=o;vo(c,e+24|0);i=i-1|0;g=g+1|0;f=f-1|0;continue}}i=ac(8);x[31725]=0;a=R(190,i|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}da(a|0,24440,164);p()}q=q-(q>>3)|0;continue}}da(a|0,24440,164);p()}i=lc(x[c>>2],x[c+4>>2])^1;break a}a=N()|0;jc(i);Q(a|0);p()}x[e+28>>2]=i}d=d-s|0;i=n+t|0;continue}}fb=e+32|0;return i|0}function xoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-32|0;fb=j;a:{b:{if(fv(a)>>>0<b>>>0){if((b|0)<0){break b}m=Zo(j+20|0);x[31725]=0;O(763,m|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}tn(j+12|0,x[a>>2]);fr(j+4|0,x[a>>2],x[a+4>>2]);l=fb-48|0;fb=l;e=x[m+4>>2];c=gc(l+40|0,x[j+12>>2],x[j+16>>2]);f=gc(l+32|0,x[j+4>>2],x[j+8>>2]);b=fb-16|0;fb=b;c=gc(b+8|0,x[c>>2],x[c+4>>2]);f=gc(b,x[f>>2],x[f+4>>2]);c=uX(x[c>>2],x[c+4>>2],x[f>>2],x[f+4>>2]);fb=b+16|0;c=c+e|0;x[m+4>>2]=c;c:{d:{if(!e){b=c-1|0;break d}b=c-1|0;if((b^e-1)>>>0<32){break c}}x[x[m>>2]+((c>>>0>=33?b>>>5|0:0)<<2)>>2]=0}c=gc(l+24|0,x[j+12>>2],x[j+16>>2]);g=gc(l+16|0,x[j+4>>2],x[j+8>>2]);b=l+8|0;Fp(b,x[m>>2],e);e=x[c>>2];n=fb-48|0;fb=n;c=x[c+4>>2];e:{if((c|0)==x[b+4>>2]){f=gc(n+40|0,e,c);c=gc(n+32|0,x[g>>2],x[g+4>>2]);b=gc(n+24|0,x[b>>2],x[b+4>>2]);e=fb-16|0;fb=e;g=x[f>>2];d=x[f+4>>2];c=sn(x[c>>2],x[c+4>>2],g,d);x[e+12>>2]=c;f:{if((c|0)<=0){c=x[b>>2];break f}if(d){i=32-d|0;x[e+8>>2]=i;h=c;c=x[ud(e+8|0,e+12|0)>>2];x[e+12>>2]=h-c;h=x[b>>2];d=-1<<d&-1>>>i-c;x[h>>2]=x[h>>2]&(d^-1)|d&x[g>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;x[b>>2]=h+(c>>>3&536870908);g=x[f>>2]+4|0;x[f>>2]=g;c=x[e+12>>2]}h=g;g=(c|0)/32|0;iD(h,g,x[b>>2]);d=c-(g<<5)|0;x[e+12>>2]=d;g=g<<2;c=g+x[b>>2]|0;x[b>>2]=c;if((d|0)<=0){break f}c=f;f=g+x[f>>2]|0;x[c>>2]=f;c=x[b>>2];g=-1>>>32-d|0;x[c>>2]=x[c>>2]&(g^-1)|g&x[f>>2];x[b+4>>2]=x[e+12>>2]}gc(l,c,x[b+4>>2]);fb=e+16|0;break e}c=gc(n+16|0,e,c);e=gc(n+8|0,x[g>>2],x[g+4>>2]);g=gc(n,x[b>>2],x[b+4>>2]);f=fb-16|0;fb=f;h=x[e>>2];d=x[e+4>>2];b=x[c>>2];e=x[c+4>>2];d=sn(h,d,b,e);x[f+12>>2]=d;g:{if((d|0)<=0){e=x[g+4>>2];c=x[g>>2];break g}h:{if(!e){e=x[g+4>>2];break h}k=32-e|0;x[f+8>>2]=k;i=f+8|0;h=x[ud(i,f+12|0)>>2];x[f+12>>2]=d-h;d=x[g+4>>2];q=x[b>>2];x[f+8>>2]=h;o=32-d|0;x[f+4>>2]=o;b=x[g>>2];r=x[b>>2];i=x[Gb(i,f+4|0)>>2];k=q&(-1<<e&-1>>>k-h);x[b>>2]=(-1<<d&-1>>>o-i^-1)&r|(e>>>0<d>>>0?k<<d-e:k>>>e-d|0);d=d+i|0;e=d&31;x[g+4>>2]=e;d=b+(d>>>3&536870908)|0;x[g>>2]=d;b=h-i|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|k>>>i+x[c+4>>2];x[g+4>>2]=b;e=b}b=x[c>>2]+4|0;x[c>>2]=b;d=x[f+12>>2]}h=32-e|0;i=-1<<e;k=i^-1;while(1){if((d|0)>=32){d=x[g>>2];b=x[b>>2];x[d>>2]=k&x[d>>2]|b<<e;x[g>>2]=d+4;x[d+4>>2]=i&x[d+4>>2]|b>>>h;d=x[f+12>>2]-32|0;x[f+12>>2]=d;b=x[c>>2]+4|0;x[c>>2]=b;continue}break}c=x[g>>2];if((d|0)<=0){break g}k=x[b>>2];x[f+8>>2]=h;o=x[c>>2];b=x[ud(f+12|0,f+8|0)>>2];i=o&(i&-1>>>h-b^-1);h=k&-1>>>32-d;x[c>>2]=i|h<<e;d=b+e|0;e=d&31;x[g+4>>2]=e;c=(d>>>3&536870908)+c|0;x[g>>2]=c;d=x[f+12>>2]-b|0;x[f+12>>2]=d;if((d|0)<=0){break g}x[c>>2]=x[c>>2]&(-1>>>32-d^-1)|h>>>b;e=x[f+12>>2];x[g+4>>2]=e}gc(l,c,e);fb=f+16|0}fb=n+48|0;fb=l+48|0;iC(a,m);uf(m)}fb=j+32|0;return}dd();p()}a=N()|0;uf(m);Q(a|0);p()}function MZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-128|0;fb=g;i=qg(g+116|0);a:{b:{c:{if(d){x[31725]=0;S(484,a|0,i|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){break c}break b}x[31725]=0;S(485,a|0,i|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}}k=Nb(g+104|0);c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{h=c&65535;if(h>>>0<=z[b+480192>>1]){x[31725]=0;w[g+102>>1]=0;O(486,a|0,g+102|0);d=x[31725];x[31725]=0;t:{u:{v:{w:{if((d|0)!=1){j=fb-16|0;fb=j;m=z[g+102>>1];d=ce(i);e=ec(i);f=fb-16|0;fb=f;while(1){if(d){l=fp(z[d+16>>1],m);e=l?e:d;d=x[(l?d+4|0:d)>>2];continue}break}d=x[vb(f+12|0,e)>>2];fb=f+16|0;x:{if(Ib(d,rg(i))){if(!fp(z[g+102>>1],z[td(d)>>1])){break x}}d=rg(i)}d=vb(j+12|0,d);fb=j+16|0;j=((h<<2)+b|0)+900380|0;if(!x[j>>2]){break d}d=x[d>>2];if(!Zg(d,Rf(i))){break u}x[31725]=0;d=P(3,g+88|0,td(d)+4|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break t}x[31725]=0;e=P(1,g+76|0,16791)|0;f=x[31725];x[31725]=0;if((f|0)==1){break v}f=or(d,e);tb(e);if(f){break p}e=x[b+4>>2];x[31725]=0;e=P(487,e|0,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break r}x[x[j>>2]+44>>2]=e;if(!x[x[j>>2]+44>>2]){break w}break e}c=N()|0;break f}x[31725]=0;e=P(1,g- -64|0,13543)|0;f=x[31725];x[31725]=0;y:{z:{A:{if((f|0)!=1){B:{if(!or(d,e)){x[31725]=0;f=P(1,g+52|0,13703)|0;h=x[31725];x[31725]=0;if((h|0)==1){break A}h=or(d,f);tb(f);tb(e);if(h){break B}break s}tb(e)}x[31725]=0;e=R(488,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break z}x[g+36>>2]=e;e=x[b+4>>2];f=x[re(g+48|0,g+36|0)>>2];x[31725]=0;e=P(489,e|0,f|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break y}og(g+36|0);if(e){break e}break s}c=N()|0;break g}c=N()|0;tb(e);break g}c=N()|0;break g}c=N()|0;og(g+36|0);break g}c=N()|0;break g}d=x[j>>2];if(!d){break d}x[d+44>>2]=0;break d}c=N()|0;break f}Td(k);JZ(i);fb=g+128|0;return}e=wb(x[k>>2]);h=wb(x[k+4>>2]);f=fb-16|0;fb=f;x[f+12>>2]=e;while(1){C:{D:{if(Ib(e,h)){if(!or(e,d)){break D}e=x[f+12>>2]}fb=f+16|0;break C}e=x[jl(f+12|0)>>2];continue}break}if(Ib(e,wb(x[k+4>>2]))){break p}x[31725]=0;O(490,k|0,d|0);e=x[31725];x[31725]=0;if((e|0)!=1){break q}}c=N()|0;break g}x[31725]=0;e=P(1,g+12|0,17508)|0;f=x[31725];x[31725]=0;if((f|0)==1){break o}x[31725]=0;S(491,g+24|0,e|0,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break n}x[31725]=0;f=P(1,g|0,16367)|0;h=x[31725];x[31725]=0;if((h|0)==1){break m}x[31725]=0;S(2,g+36|0,g+24|0,f|0);h=x[31725];x[31725]=0;if((h|0)==1){break l}h=x[b+1298472>>2];x[31725]=0;S(387,h|0,2,g+36|0);h=x[31725];x[31725]=0;if((h|0)==1){break k}tb(g+36|0);tb(f);tb(g+24|0);tb(e)}x[x[j>>2]+44>>2]=0;break e}c=N()|0;break g}c=N()|0;break h}c=N()|0;break i}c=N()|0;break j}c=N()|0;tb(g+36|0)}tb(f)}tb(g+24|0)}tb(e)}tb(d)}Td(k);break a}tb(d)}c=c+1|0;continue}}c=N()|0}JZ(i);Q(c|0);p()}function X1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=fb-144|0;fb=d;xc(b);Tp(a);a:{if(!_w(b,d+108|0)){break a}if(!eG(d+108|0)){break a}j=x[b+8>>2];b:{if(!cd(b,y[d+124|0]|y[d+125|0]<<8|(y[d+126|0]<<16|y[d+127|0]<<24))){break b}while(1){c:{if((y[d+120|0]|y[d+121|0]<<8|(y[d+122|0]<<16|y[d+123|0]<<24))>>>0>h>>>0){if(Mb(x[b>>2],x[b+8>>2],5)){break c}}f=i&1;break b}d:{if((y[d+112|0]|y[d+113|0]<<8)>>>0>=64){if((Si(b)|0)<=0){break d}}f=0;g=1;while(1){l=Zd(b);if(l){m=f>>>0>4;e=m&g;if(!((g^1)&1|m)){e=(Rq(l<<24>>24)&255)==y[f+13165|0]}g=e;f=f+1|0;continue}break}Vb(b,4);i=(f|0)==5?g&1?1:i:i}h=h+1|0;continue}}cd(b,j);if(!f){break a}if(!Mb(x[b>>2],x[b+8>>2],dG(d+108|0))){break a}if(!c){k=1;break a}e=fb-16|0;fb=e;c=d+108|0;cd(b,y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24));i=d+96|0;f=Nb(i);g=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);x[31725]=0;O(178,f|0,g|0);g=x[31725];x[31725]=0;e:{f:{g:{if((g|0)!=1){g=0;h:{i:{while(1){if((y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24))>>>0<=g>>>0){break h}h=x[b+8>>2];j=x[b>>2];x[31725]=0;h=U(152,j|0,h|0,5)|0;j=x[31725];x[31725]=0;if((j|0)==1){break g}if(!h){break h}h=y[c+4|0]|y[c+5|0]<<8;x[31725]=0;S(179,e+4|0,b|0,h|0);h=x[31725];x[31725]=0;if((h|0)!=1){x[31725]=0;O(180,f|0,e+4|0);h=x[31725];x[31725]=0;if((h|0)==1){break i}g=g+1|0;tb(e+4|0);continue}break}a=N()|0;break f}a=N()|0;tb(e+4|0);break f}fb=e+16|0;break e}a=N()|0;break f}a=N()|0}Td(f);Q(a|0);p()}x[31725]=0;V(172,d+84|0,b|0,c|0,i|0);c=x[31725];x[31725]=0;j:{if((c|0)!=1){x[31725]=0;P(151,b|0,y[d+132|0]|y[d+133|0]<<8|(y[d+134|0]<<16|y[d+135|0]<<24))|0;c=x[31725];x[31725]=0;k:{if((c|0)!=1){g=d+36|0;l:{m:{n:{o:{while(1){p:{q:{if((y[d+128|0]|y[d+129|0]<<8|(y[d+130|0]<<16|y[d+131|0]<<24))>>>0>k>>>0){c=x[b+8>>2];e=x[b>>2];x[31725]=0;c=U(152,e|0,c|0,8)|0;e=x[31725];x[31725]=0;if((e|0)==1){break q}if(c){break p}}k=lc(x[a>>2],x[a+4>>2])^1;uc(d+84|0);Td(d+96|0);break a}b=N()|0;break k}x[31725]=0;aa(173,d+60|0,b|0,d+108|0,d+84|0,d+96|0);c=x[31725];x[31725]=0;if((c|0)!=1){e=Vp(d+60|0);x[31725]=0;c=R(174,x[d+60>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break o}if(c){x[31725]=0;c=R(175,d+24|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break n}e=x[e>>2];r:{if((e|0)<0){break r}f=x[d+96>>2];if(Ud(f,x[d+100>>2])>>>0<=e>>>0){break r}x[31725]=0;O(176,d+12|0,Hd(f,e)|0);e=x[31725];x[31725]=0;if((e|0)==1){break m}e=d+12|0;Ab(c,e);tb(e)}Xw(g,d+60|0);x[31725]=0;O(177,a|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break m}Op(c)}k=k+1|0;ub(d+60|0);continue}break}b=N()|0;break k}b=N()|0;break l}b=N()|0;break l}b=N()|0;Op(c)}ub(d+60|0);break k}b=N()|0}uc(d+84|0);break j}b=N()|0}Td(d+96|0);Q(b|0);p()}fb=d+144|0;return k|0}function MG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-144|0;fb=d;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)<=5){mx(d+108|0,b);x[31725]=0;b=P(1,d+96|0,18382)|0;e=x[31725];x[31725]=0;if((e|0)==1){break E}x[31725]=0;S(2,d+120|0,d+108|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break D}x[31725]=0;c=P(3,d+72|0,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break C}x[31725]=0;e=P(1,d+60|0,20187)|0;f=x[31725];x[31725]=0;if((f|0)==1){break B}x[31725]=0;S(4,d+84|0,c|0,e|0);f=x[31725];x[31725]=0;if((f|0)==1){break A}x[31725]=0;S(2,d+132|0,d+120|0,d+84|0);f=x[31725];x[31725]=0;if((f|0)==1){break z}tb(d+84|0);tb(e);tb(c);c=d+120|0;tb(c);tb(b);tb(d+108|0);b=x[a>>2];x[31725]=0;O(5,c|0,(b?b:22255)|0);b=x[31725];x[31725]=0;if((b|0)==1){break t}b=x[a+4>>2];x[31725]=0;O(5,d+108|0,(b?b:22255)|0);b=x[31725];x[31725]=0;if((b|0)==1){break s}a=x[a+8>>2];x[31725]=0;x[d+48>>2]=a;O(6,d+84|0,d+48|0);a=x[31725];x[31725]=0;if((a|0)==1){break r}x[31725]=0;P(7,499560,18261)|0;a=x[31725];x[31725]=0;if((a|0)==1){break q}x[31725]=0;O(8,d+48|0,d+120|0);a=x[31725];x[31725]=0;if((a|0)==1){break p}x[31725]=0;P(9,499560,d+48|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break o}x[31725]=0;P(7,499560,17468)|0;a=x[31725];x[31725]=0;if((a|0)==1){break o}x[31725]=0;O(8,d+36|0,d+84|0);a=x[31725];x[31725]=0;if((a|0)==1){break n}x[31725]=0;P(9,499560,d+36|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break m}x[31725]=0;P(7,499560,17466)|0;a=x[31725];x[31725]=0;if((a|0)==1){break m}x[31725]=0;P(7,499560,18382)|0;a=x[31725];x[31725]=0;if((a|0)==1){break m}x[31725]=0;O(8,d+24|0,d+132|0);a=x[31725];x[31725]=0;if((a|0)==1){break l}x[31725]=0;P(9,499560,d+24|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break k}x[31725]=0;P(7,499560,13569)|0;a=x[31725];x[31725]=0;if((a|0)==1){break k}x[31725]=0;O(8,d+12|0,d+108|0);a=x[31725];x[31725]=0;if((a|0)==1){break j}x[31725]=0;P(9,499560,d+12|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break i}x[31725]=0;P(7,499560,13567)|0;a=x[31725];x[31725]=0;if((a|0)==1){break i}x[31725]=0;R(10,499560)|0;a=x[31725];x[31725]=0;if((a|0)==1){break i}tb(d+12|0);tb(d+24|0);tb(d+36|0);tb(d+48|0);tb(d+84|0);tb(d+108|0);tb(d+120|0);tb(d+132|0)}fb=d+144|0;return}a=N()|0;break u}a=N()|0;break v}a=N()|0;break w}a=N()|0;break x}a=N()|0;break y}a=N()|0;tb(d+84|0)}tb(e)}tb(c)}tb(d+120|0)}tb(b)}tb(d+108|0);break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break e}a=N()|0;break f}a=N()|0;break f}a=N()|0;break g}a=N()|0;break g}a=N()|0;break h}a=N()|0;break h}a=N()|0;tb(d+12|0)}tb(d+24|0)}tb(d+36|0)}tb(d+48|0)}tb(d+84|0)}tb(d+108|0)}tb(d+120|0)}tb(d+132|0)}Q(a|0);p()}function aQ(a){var b=E(0),c=E(0),d=0,e=E(0),f=E(0),g=0,h=0,i=E(0),k=0,m=E(0),p=E(0),s=E(0),t=0,u=0,v=E(0),w=E(0);d=a+4208|0;AB(yb(d,0),B[a+4272>>2]);b=E(E(B[yb(d,0)>>2]*E(15920))+E(80));s=De(E(10),E(E(E(B[yb(d,2)>>2]+E(-.5))*E(30))/E(40)));c=E(E(b/E(A[x[a+16>>2]+24620>>2]))*E(6.2831854820251465));b=rQ(c);v=Cq(c);w=b;f=E(E(c*E(E(E(B[yb(d,1)>>2]*E(35))+E(1))*E(.02888113260269165)))/b);m=(l(2,(q(f),j(2))&-2147483648|1056964608),r());c=E(F(f));k=(q(f),j(2))&2147483647;a:{if(k>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(q(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=E(-1);if((h|0)<0){break b}if(d>>>0<1118925336){break g}b=E(c*E(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=E(905800061445916e-20);b=E(c+E(-.6931381225585938));break f}d=-1;e=E(-905800061445916e-20);b=E(c+E(.6931381225585938));break f}b=E(E(c*E(1.4426950216293335))+(l(2,(q(c),j(2))&-2147483648|1056964608),r()));h:{if(E(F(b))<E(2147483648)){d=~~b;break h}d=-2147483648}b=E(d|0);e=E(b*E(905800061445916e-20));b=E(c+E(b*E(-.6931381225585938)))}c=E(b-e);e=E(E(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=E(c*E(.5));i=E(c*b);p=E(E(i*E(E(i*E(.0015807170420885086))+E(-.03333321213722229)))+E(1));b=E(E(3)-E(p*b));p=E(i*E(E(p-b)/E(E(6)-E(c*b))));b=E(c-E(E(c*p)-i));if(!d){break b}e=E(E(E(c*E(p-e))-e)-i);i:{switch(d+1|0){case 0:b=E(E(E(c-e)*E(.5))+E(-.5));break b;case 2:b=E(E(e-E(c+E(.5)))*E(-2));if(c<E(-.25)){break b}b=E(c-e);b=E(E(b+b)+E(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),r());if(d>>>0>=57){c=E(E(c-e)+E(1));b=E(((d|0)==128?E(E(c+c)*E(17014118346046923e22)):E(c*b))+E(-1));break b}i=(l(2,1065353216-h|0),r());c=E((d>>>0<=22?E(E(E(1)-i)+E(c-e)):E(E(c-E(e+i))+E(1)))*b)}b=c}if(k>>>0<=1065353215){if(k>>>0<964689920){break a}f=E(m*E(E(b+b)-E(E(b*b)/E(b+E(1)))));break a}f=E(m*E(b+E(b/E(b+E(1)))));break a}m=E(E(m+m)*E(1661534994731145e20));b=E(c+E(-162.88958740234375));d=_y(b)&2047;j:{k:{if(_y(E(88))>>>0>d>>>0){break k}c=E(0);if(((q(b),j(2))|0)==-8388608){break j}c=E(b+b);if(_y(E(Infinity))>>>0<=d>>>0){break j}if(b>E(88.72283172607422)){c=cG(0);break j}if(!(b<E(-103.97207641601562))){break k}c=MF(0);break j}g=C[165]*+b;t=C[164];u=g+t;g=g-(u-t);g=(C[166]*g+C[167])*(g*g)+(C[168]*g+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;k=x[d>>2];d=x[d+4>>2]+h|0;l(0,k|0);l(1,(k>>>0<k>>>0?d+1|0:d)|0);c=E(g*+n())}f=E(E(m*c)*E(1661534994731145e20))}c=E(w*f);f=E(c/s);b=E(f+E(1));B[a+4236>>2]=E(E(1)-f)/b;f=E(E(v*E(-2))/b);B[a+4232>>2]=f;c=E(c*s);B[a+4228>>2]=E(E(1)-c)/b;B[a+4224>>2]=f;B[a+4220>>2]=E(c+E(1))/b}function Nz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=fb-144|0;fb=f;x[f+136>>2]=c;x[f+140>>2]=d;g=x[b+4>>2];a:{if(!g){h=x[b>>2];break a}h=x[b>>2];i=y[Il(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Ul(f+112|0,h,g,g-1|0);g=x[f+116>>2];h=x[f+112>>2];x[b>>2]=h;x[b+4>>2]=g}j=f+112|0;ge(j);i=x[f+112>>2];ge(f+100|0);i=Hl(i,x[f+104>>2],b);ge(j);b:{c:{d:{e:{f:{g:{h:{if((i|0)==x[f+116>>2]){c=qc(f+128|0,22255);a=x[c+4>>2];x[f+8>>2]=x[c>>2];x[f+12>>2]=a;if(Ic(h,g,f+8|0)){g=ac(8);x[31725]=0;O(1012,f+100|0,f+136|0);a=x[31725];x[31725]=0;if((a|0)==1){break g}x[31725]=0;S(1017,f+112|0,18246,f+100|0);a=x[31725];x[31725]=0;if((a|0)==1){break f}pc(g,f+112|0);h=0;x[31725]=0;S(99,g|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(f+112|0);break e}if(!e){break h}g=ac(8);c=x[b>>2];a=x[b+4>>2];x[31725]=0;c=gi(f+76|0,c,a);a=x[31725];x[31725]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){x[31725]=0;S(1017,f+88|0,18282,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break p}x[31725]=0;O(1019,f+100|0,f+88|0);b=x[31725];x[31725]=0;a=1;if((b|0)==1){break o}x[31725]=0;O(1012,f- -64|0,f+136|0);a=x[31725];x[31725]=0;if((a|0)==1){break n}x[31725]=0;S(1021,f+112|0,f+100|0,f- -64|0);b=x[31725];x[31725]=0;a=1;if((b|0)==1){break m}pc(g,f+112|0);x[31725]=0;S(99,g|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(f+112|0);a=0;break l}b=N()|0;break d}b=N()|0;a=1;break i}b=N()|0;break j}b=N()|0;a=1;break k}b=N()|0}tb(f- -64|0)}tb(f+100|0)}tb(f+88|0)}tb(c);if(a){break d}break c}e=qc(f+56|0,22255);b=x[e+4>>2];x[f+32>>2]=x[e>>2];x[f+36>>2]=b;if(Ic(h,g,f+32|0)){g=ac(8);x[31725]=0;O(1012,f+100|0,f+136|0);a=x[31725];x[31725]=0;q:{r:{if((a|0)!=1){x[31725]=0;S(1017,f+112|0,18246,f+100|0);a=x[31725];x[31725]=0;if((a|0)==1){break r}pc(g,f+112|0);h=0;x[31725]=0;S(99,g|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(f+112|0);break q}b=N()|0;break d}b=N()|0;h=1}tb(f+100|0);if(h){break d}break c}e=qc(f+48|0,10974);b=x[e+4>>2];x[f+24>>2]=x[e>>2];x[f+28>>2]=b;if(Ic(h,g,f+24|0)){Jz(a,Gc(c,d));break h}e=qc(f+40|0,8627);b=x[e+4>>2];x[f+16>>2]=x[e>>2];x[f+20>>2]=b;if(!Ic(h,g,f+16|0)){break h}b=x[a+32>>2];a=Tu(c,d);a=a>>>0>=4?1:a;c=fb-16|0;fb=c;s:{if((Ck(y[b+140|0])|0)==(a|0)){b=b+120|0;$t(y[b+20|0]);d=fb-16|0;fb=d;x[d+12>>2]=c+15;e=fb-16|0;fb=e;a=x[19879];x[e+8>>2]=x[19878];x[e+12>>2]=a;a=x[19877];x[e>>2]=x[19876];x[e+4>>2]=a;ib[x[vq(e,Ck(y[b+20|0]))>>2]](d+12|0,b);fb=e+16|0;fb=d+16|0;break s}cN(b,a,dN(b))}fb=c+16|0}fb=f+144|0;return}b=N()|0;break d}b=N()|0;h=1}tb(f+100|0);if(!h){break c}}jc(g)}Q(b|0)}p()}function u9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-336|0;fb=d;e=fb-16|0;fb=e;x[a+4>>2]=0;v[a|0]=0;f=a+40|0;xo(f,32);v[e+15|0]=0;vo(f,e+15|0);fb=e+16|0;e=x[a+36>>2];a:{if(x[(x[x[e>>2]-12>>2]+e|0)+16>>2]){Qh(a,2,16777216);break a}$d(d+72|0,e);e=x[d+84>>2];x[a+16>>2]=x[d+80>>2];x[a+20>>2]=e;x[d+72>>2]=3;f=x[a+36>>2];e=0;while(1){if(A[d+72>>2]>e>>>0){Li(f,d+e|0);e=e+1|0;continue}break}if(kd(d,24336,3)){Qh(a,2,512);break a}v[d+335|0]=0;Li(x[a+36>>2],d+335|0);Tb(d+72|0,0,256);e=y[d+335|0];if(e){Ej(x[a+36>>2],d+72|0,e)}f=b;b=yl(d,d+72|0,e);e=Fy(f,b);Eb(b);if(!e){Qh(a,2,4096)}if(wl(y[a|0])){break a}Li(x[a+36>>2],d+71|0);b=y[d+71|0];e=b&3;w[a+24>>1]=(e|0)==3?4:e;if(yj(b,6)){Pc(d,a+32|0,9);Jf(d,1)}x[d+64>>2]=0;BK(x[a+36>>2],d- -64|0);e=x[d+64>>2];v[d+63|0]=0;if(e>>>0>=2){Li(x[a+36>>2],d+71|0);f=-1;if(!y[d+71|0]){Li(x[a+36>>2],d+63|0);f=-2}Um(x[a+36>>2],e+f|0)}x[d+48>>2]=0;x[d+52>>2]=0;b:{if(!yj(b,4)){break b}vl(x[a+36>>2],d+48|0);e=x[d+52>>2];f=x[d+48>>2];x[a+64>>2]=f;x[a+68>>2]=e;g=x[c+4>>2];if((g|0)==(e|0)&A[c>>2]>=f>>>0|e>>>0<g>>>0){break b}Qh(a,1,4)}if(yj(b,5)){Li(x[a+36>>2],d+71|0);Um(x[a+36>>2],y[d+71|0])}c=y[d+63|0];c:{if(!yj(c,0)){break c}Li(x[a+36>>2],d+71|0);e=y[d+71|0];e=e&1?-1:e>>>1|0;w[a+24>>1]=e;if(e){break c}Qh(a,1,2)}x[a+8>>2]=0;f=1;if(yj(c,1)){BK(x[a+36>>2],a+8|0)}g=yj(b,2);e=a+32|0;Pc(d,e,6);Jf(d,g);g=yj(b,3);Pc(d,e,7);Jf(d,g);g=z[a+24>>1];Pc(d,e,5);Jf(d,(g|0)!=0);b=yj(b,7);Pc(d,e,8);Jf(d,b);Pc(d,e,5);d:{if(Hb(x[x[d>>2]>>2],x[d+4>>2])){break d}Pc(d+40|0,e,6);if(Hb(x[x[d+40>>2]>>2],x[d+44>>2])){break d}Pc(d+32|0,e,7);if(Hb(x[x[d+32>>2]>>2],x[d+36>>2])){break d}Pc(d+24|0,e,8);f=Hb(x[x[d+24>>2]>>2],x[d+28>>2])}b=d+16|0;Pc(b,e,11);Jf(b,f);Pc(d,e,11);if(yj(c,2)){w[d+40>>1]=0;yy(x[a+36>>2],d+40|0);b=x[a+36>>2];f=z[d+40>>1];Pc(d,e,9);Um(b,f<<Hb(x[x[d>>2]>>2],x[d+4>>2]))}if(yj(c,3)){Um(x[a+36>>2],5)}vl(x[a+36>>2],d+48|0);c=x[d+52>>2];f=c;b=x[d+48>>2];if(!c&b>>>0>=16001|c){Qh(a,2,8192);break a}x[a+104>>2]=b;if(!b){Qh(a,1,1)}Pc(d,e,11);e:{if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break e}vl(x[a+36>>2],d+48|0);c=x[d+52>>2];f=c;b=x[d+48>>2];if(sy(b,c)){break e}Qh(a,2,2048);break a}$d(d,x[a+36>>2]);g=x[d+8>>2];h=x[a+16>>2];c=g-h|0;g=x[d+12>>2]-(x[a+20>>2]+(g>>>0<h>>>0)|0)|0;if((g|0)<0){Qh(a,2,16384);break a}x[a+96>>2]=c;x[a+100>>2]=g;Pc(d,e,11);c=x[a+100>>2];g=b;h=x[a+96>>2];b=Hb(x[x[d>>2]>>2],x[d+4>>2]);x[a+72>>2]=b?g:h;x[a+76>>2]=b?f:c;Pc(d,e,11);if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){b=x[a+100>>2]+x[a+20>>2]|0;f=x[a+16>>2];c=f+x[a+96>>2]|0;x[a+80>>2]=c;x[a+84>>2]=c>>>0<f>>>0?b+1|0:b}Pc(d,e,10);Jf(d,1)}fb=d+336|0}function Sja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb-32|0;fb=c;a:{b:{if(!Ib(x[b>>2],x[b+4>>2])){break b}l=a+16|0;m=x[b+12>>2];k=z[x[x[b+48>>2]+12>>2]+480188>>1];d=k;e=fb-16|0;fb=e;g=c+20|0;x[g>>2]=0;x[g+4>>2]=0;sc(g+8|0);Rd(e+8|0,x[vb(e+4|0,g)>>2]);c:{d:{if(d){x[31725]=0;O(462,g|0,d|0);f=x[31725];x[31725]=0;if((f|0)==1){break d}h=fb-16|0;fb=h;f=Kr(h+4|0,g,d);d=x[f+4>>2];i=x[f+8>>2];while(1){if((d|0)==(i|0)){hc(f);fb=h+16|0}else{v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;ch(d);d=d+6|0;x[f+4>>2]=d;continue}break}}d=e+8|0;Qd(d);jm(d);fb=e+16|0;break c}a=N()|0;jm(e+8|0);Q(a|0);p()}while(1){e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(!(x[x[x[a>>2]-12>>2]+l>>2]|j>>>0>=m>>>0)){x[31725]=0;v[c+19|0]=0;P(922,a|0,c+19|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}d=v[c+19|0];if(!d){j=j+1|0;continue}v[c+18|0]=0;t:{if((d|0)>=0){break t}x[31725]=0;P(922,a|0,c+18|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break t}break a}v[c+17|0]=0;w[c+12>>1]=0;x[c+8>>2]=0;u:{d=d&127;f=(d?d-1|0:0)&65535;i=f>>>0>=k>>>0;v:{w:{if(!i){h=jd(x[b>>2],x[x[b+48>>2]+12>>2],j,f);d=y[c+18|0];if(d&1){break w}e=Wc(x[g>>2],f);break v}h=c+8|0;d=y[c+18|0];if(!(d&1)){break u}}x[31725]=0;P(922,a|0,c+17|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break u}e=Wc(x[g>>2],f);v[e|0]=y[c+17|0]}v[h|0]=y[e|0];d=y[c+18|0];if(!(d&2)){break r}break s}if(d&2){break s}break q}Sk(g);break b}x[31725]=0;P(922,a|0,c+17|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break q}e=Wc(x[g>>2],f);v[e+1|0]=y[c+17|0]}v[h+1|0]=y[e+1|0];if(d&4){break p}break o}if(!(d&4)){break n}}x[31725]=0;P(922,a|0,c+17|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break n}e=Wc(x[g>>2],f);v[e+2|0]=y[c+17|0]}v[h+2|0]=y[e+2|0];if(!(d&8)){break l}break m}if(!(d&8)){break k}}x[31725]=0;P(922,a|0,c+17|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break k}e=Wc(x[g>>2],f);v[e+4|0]=y[c+17|0]}v[h+4|0]=y[e+4|0];if(d&16){break j}break i}if(!(d&16)){break h}}x[31725]=0;P(922,a|0,c+17|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break h}e=Wc(x[g>>2],f);v[e+3|0]=y[c+17|0]}v[h+3|0]=y[e+3|0];if(!(d&32)){break f}break g}if(!(d&32)){break e}}x[31725]=0;P(922,a|0,c+17|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break e}e=Wc(x[g>>2],f);v[e+5|0]=y[c+17|0]}v[h+5|0]=y[e+5|0]}if(!(d&64)){continue}x[31725]=0;P(922,a|0,c+7|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;P(923,a|0,y[c+7|0])|0;d=x[31725];x[31725]=0;if((d|0)!=1){continue}}break}break a}fb=c+32|0;return}a=N()|0;Sk(g);Q(a|0);p()}function mla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=fb-16|0;fb=f;e=fb-16|0;fb=e;d=CB(f+8|0);a:{b:{c:{d:{switch(b-850|0){default:e:{f:{if((b|0)!=437){if((b|0)==737){break f}if((b|0)==775){break e}if((b|0)==1252){break c}g:{h:{if((b|0)!=20127){if((b|0)==28591){break h}if((b|0)==28605){break g}if((b|0)!=65001){break b}b=nf(e+8|0,0);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,1);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,2);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,3);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,4);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,5);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,6);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 0:b=nf(e+8|0,7);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 2:b=nf(e+8|0,8);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 5:b=nf(e+8|0,9);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 7:b=nf(e+8|0,10);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 10:b=nf(e+8|0,11);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 11:b=nf(e+8|0,12);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 12:b=nf(e+8|0,13);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 13:b=nf(e+8|0,14);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 14:b=nf(e+8|0,15);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 15:b=nf(e+8|0,16);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 16:b=nf(e+8|0,17);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 19:b=nf(e+8|0,18);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 1:case 3:case 4:case 6:case 8:case 9:case 17:case 18:case 20:case 21:case 22:case 23:break b;case 24:break d}}b=nf(e+8|0,19);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=nf(e+8|0,20);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}if(y[d+4|0]){v[d+4|0]=0}}fb=e+16|0;i:{if(Ed(y[f+12|0])){if(!Ed(y[f+12|0])){a=ac(4);x[a>>2]=0;a=Nj(a);x[a>>2]=121436;da(a|0,121472,844);p()}b=fb-32|0;fb=b;j:{k:{l:{m:{d=x[f+8>>2];if(!d){Wf(b+20|0,c);c=0;a=Fb(a);d=y[b+31|0];e=x[b+24>>2];x[31725]=0;O(95,a|0,zh(e,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){while(1){if(zh(x[b+24>>2],y[b+31|0])>>>0<=c>>>0){break m}d=y[cc(b+20|0,c)|0];x[31725]=0;O(97,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break k}c=c+1|0;continue}}break k}e=b+8|0;Wf(e,c);x[31725]=0;S(11,b+20|0,d|0,e|0);c=x[31725];x[31725]=0;n:{o:{if((c|0)!=1){x[31725]=0;O(12,a|0,b+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break o}Qb(b+20|0);tb(b+8|0);break l}c=N()|0;break n}c=N()|0;Qb(b+20|0)}tb(b+8|0);break j}tb(b+20|0)}fb=b+32|0;break i}c=N()|0;tb(a);tb(b+20|0)}Q(c|0);p()}I0(a,22,c)}fb=f+16|0}function pI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;h=fb-48|0;fb=h;o(+a);d=j(1)|0;i=j(0)|0;a:{b:{e=d;k=e&2147483647;c:{if(k>>>0<=1074752122){if((d&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(F(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;i=k>>>20|0;e:{if((i-(e>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;if((i-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;C[b>>3]=a}C[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;C[b>>3]=a;C[b+8>>3]=a;d=0;break a}l(0,i|0);l(1,e&1048575|1096810496);a=+n();d=0;i=1;while(1){m=(h+16|0)+(d<<3)|0;if(F(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);C[m>>3]=c;a=(a-c)*16777216;d=1;m=i;i=0;if(m){continue}break}C[h+32>>3]=a;d=2;while(1){i=d;d=d-1|0;if(C[(h+16|0)+(i<<3)>>3]==0){continue}break}d=IL(h+16|0,h,(k>>>20|0)-1046|0,i+1|0,1);a=C[h>>3];if((e|0)<0){C[b>>3]=-a;C[b+8>>3]=-C[h+8>>3];d=0-d|0;break a}C[b>>3]=a;C[b+8>>3]=C[h+8>>3]}fb=h+48|0;return d}function Dqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=fb-560|0;fb=f;a:{if(!cd(b,1464)){break a}if(!rr(b,f+556|0)){break a}Bd(a,1);Lb(Lb(dg(a+1074312|0,83),84,1),85,1);b:{if(ne(f+556|0,25252)){d=f+32|0;e=tc(d,8430);Ab(a+1298344|0,e);tb(e);e=tc(d,14825);Ab(a+1298356|0,e);tb(e);e=tc(d,14890);Ab(a+1298368|0,e);break b}if(!ne(f+556|0,15580)){break a}d=f+32|0;e=tc(d,8604);Ab(a+1298344|0,e);tb(e);e=tc(d,12340);Ab(a+1298356|0,e);tb(e);e=tc(d,15491);Ab(a+1298368|0,e)}tb(e);r=a+1298404|0,s=x[Fc(d,28)>>2],x[r>>2]=s;cd(b,0);TZ(b,a+1298308|0,20);w[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(g>>>0>40){break a}d=f+554|0;Iw(d,b);m=Jc(d);if(y[f+554|0]>128){break a}e=f+32|0;d=fb-16|0;fb=d;c:{if(!Mb(x[b>>2],x[b+8>>2],512)){cY(e);break c}xE(d+8|0,e);rd(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;d=0;e=y[m|0];while(1){n=(d|0)==512;if(!n){g=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=y[g|0]){continue}break a}break}if(!c){break a}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;x[a+480208>>2]=x[a+480208>>2]|18874368;Yh(a,0);xg(Xb(x[a+484360>>2],y[a+484376|0]),y[f+554|0]);l=a+484344|0;Vf(l,y[f+554|0]);while(1)if(y[f+554|0]<=i>>>0){if(!(c&2)){break a}cd(b,(y[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(D(d,104)+a|0)+484380|0;if(x[c>>2]){fg(Xc(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}else{r=_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],i),s=i,w[r>>1]=s;d:{if(!Ng(l,i&65535,64)){break d}q=i<<2;e=0;e:while(1){if((e|0)==4){r=f,s=wb(x[Wb(x[l>>2],i)>>2]),x[r+24>>2]=s;e=0;while(1){if((e|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{v[f+30|0]=o;v[f+31|0]=p;d=h&255;if(d){break g}h=0;break f}}else{g=x[f+24>>2];h:{if((y[g+3|0]&254)!=16){break h}v[g+3|0]=16;h=0;j=y[g+5|0];if(j>>>0<16){break h}h=j>>>4|0;v[g+5|0]=h;k=h;g=j&15;h=(g|0)!=(h|0)&(g|0)!=0;o=h?k:o;p=h?g:p}d=d+1|0;JC(f+24|0);continue}break}ye(Wb(x[l>>2],i),Ye(Ne(f+8|0,16,y[(d+f|0)+29|0]),e));h=h+1|0;h=(h&255)==3?1:h}e=e+1|0;continue}}cd(b,(y[f+32+(e+q)|0]<<8)+1468|0);g=0;d=Wb(x[l>>2],i);d=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,e&65535);while(1)if((g|0)==64){e=e+1|0;continue e}else{k=f+8|0;X$(k,b,d);j=y[f+8|0];k=y[Jc(k)|0];i:{if(!(!(j|k)|(j-5&255)>>>0<5|(j|0)==14&k>>>0>15)){Bf(d,j,k);break i}v[d+3|0]=0}d=d+24|0;g=g+1|0;continue}}}i=i+1|0;continue}}else{e=f+32|0;MC(b,e);g=UC(e,(D(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}}fb=f+560|0;return n|0}function qn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb+-64|0;fb=e;h=Nb(a);x[31725]=0;a=R(283,b|0)|0;c=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}c=x[b+8>>2];d=x[b>>2];x[31725]=0;c=U(152,d|0,c|0,a|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}if(c){break d}x[31725]=0;a=R(204,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}x[31725]=0;P(185,b|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break c}}a=N()|0;break a}x[31725]=0;S(187,e+24|0,b|0,a|0);b=x[31725];x[31725]=0;f:{g:{h:{if((b|0)!=1){b=e+24|0;c=ic(e+44|0,b);ub(b);if(a>>>0<10){break g}x[31725]=0;b=R(738,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}if(!b){break g}x[31725]=0;b=R(283,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}x[e+20>>2]=b;a=a-10|0;wc(e+20|0,a>>>0>25264513?-1:D(a,170));x[31725]=0;d=x[e+20>>2];O(289,h|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){break h}break b}a=N()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=x[c+8>>2];f=x[c>>2];x[31725]=0;a=P(739,f|0,a|0)|0;f=x[31725];x[31725]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}x[31725]=0;a=R(535,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}x[31725]=0;a=R(199,c|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}g=x[c+8>>2];i=x[c>>2];x[31725]=0;g=U(152,i|0,g|0,a|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}if(!g){continue}oe(e+24|0,x[h>>2],x[h+4>>2]);Er(e+8|0,x[e+24>>2],x[e+28>>2],b,a);x[31725]=0;co(473,e,c,x[e+8>>2],x[e+12>>2]);f=x[31725];x[31725]=0;if((f|0)!=1){d=d-a|0;b=a+b|0;continue i}break b}x[31725]=0;a=R(199,c|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>d>>>0){continue}x[31725]=0;i=P(740,c|0,e+16|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+16|0;i=ec(f);pv(f,i,Pe(wb(x[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(d>>>0<8){continue}x[31725]=0;a=P(740,c|0,e+16|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}if(!a){continue}a=e+16|0;f=ec(a);pv(a,f,Pe(wb(x[h>>2]),b));pv(a,f,Pe(Pe(wb(x[h>>2]),b),4));d=d-8|0;b=b+8|0;continue i}x[31725]=0;a=R(199,c|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}break}d=d-a|0;b=a+b|0;continue}d=d-g|0;continue}break}if(!d){break f}Nb(dc(h));break f}x[31725]=0;S(335,c|0,h|0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}}ub(c)}fb=e- -64|0;return}a=N()|0;ub(c)}dc(h);Q(a|0);p()}function se(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31725]=0;O(116,b|0,Yc(e,d)|0);d=x[31725];x[31725]=0;d:{if((d|0)!=1){e:{while(1){if(Yc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Wd(c,a)>>2];x[31725]=0;O(117,b|0,(d>>>0>=128?63:d)<<24>>24);d=x[31725];x[31725]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31725]=0;O(116,b|0,Yc(e,d)|0);d=x[31725];x[31725]=0;f:{if((d|0)!=1){g:{while(1){if(Yc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Wd(c,a)>>2];x[31725]=0;O(117,b|0,(d>>>0>=256?63:d)<<24>>24);d=x[31725];x[31725]=0;if((d|0)==1){break g}a=a+1|0;continue}break}break f}}break a}return;case 3:ff(a,c,48928);return;case 4:ff(a,c,49952);return;case 5:ff(a,c,50976);return;case 6:ff(a,c,52e3);return;case 7:ff(a,c,53024);return;case 8:ff(a,c,54048);return;case 9:ff(a,c,55072);return;case 10:ff(a,c,56096);return;case 11:ff(a,c,57120);return;case 12:ff(a,c,58144);return;case 13:ff(a,c,59168);return;case 14:ff(a,c,60192);return;case 15:ff(a,c,61216);return;case 16:ff(a,c,62240);return;case 17:ff(a,c,63264);return;case 18:ff(a,c,64288);return;case 19:ff(a,c,65312);return;case 20:ff(a,c,66336);return;case 21:ff(a,c,67360);return;case 22:ff(a,c,68384);return;case 23:ff(a,c,69408);return;case 24:yx(a,c,70432);return;case 25:yx(a,c,48928);return;case 26:yx(a,c,67360);return;default:a=ac(8);x[31725]=0;b=P(16,a|0,11106)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}b=N()|0;jc(a);Q(b|0);p();case 0:break c}}e=fb-16|0;fb=e;f=Fb(a);h:{while(1){i:{j:{k:{if(Yc(x[c+4>>2],y[c+11|0])>>>0>g>>>0){b=x[Wd(c,g)>>2];if(b>>>0>=2097152){x[31725]=0;O(117,f|0,63);a=x[31725];x[31725]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;v[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=y[e+10|0]|64}else{a=y[e+10|0]}x[31725]=0;O(117,f|0,a<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){break j}break i}fb=e+16|0;break h}i=(2<<a)+255<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=y[j|0];x[31725]=0;O(117,f|0,(a|i)<<24>>24);h=x[31725];x[31725]=0;a=d;break l}x[31725]=0;a=a-1|0;O(117,f|0,v[a+(e+10|0)|0]|-128);h=x[31725];x[31725]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=N()|0;tb(f);Q(a|0);p()}return}da(b|0,125132,17);p()}a=N()|0;tb(b);Q(a|0);p()}function zP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-192|0;fb=d;f=x[b+4>>2];a:{if(!f){break a}e=x[b>>2];g=y[Il(e,f)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Ul(d+168|0,e,f,f-1|0);f=x[d+172>>2];e=x[d+168>>2];x[b>>2]=e;x[b+4>>2]=f}g=d+168|0;ge(g);e=x[d+168>>2];ge(d+156|0);e=Hl(e,x[d+160>>2],b);ge(g);b:{c:{d:{e:{if((e|0)==x[d+172>>2]){a=x[b>>2];e=qc(d+184|0,22255);g=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=g;if(Ic(a,f,d)){a=ac(8);x[31725]=0;c=P(36,d+168|0,10482)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;if(!c){break e}a=ac(8);c=x[b+4>>2];b=x[b>>2];x[31725]=0;f=gi(d+156|0,b,c);b=x[31725];x[31725]=0;f:{g:{h:{if((b|0)!=1){x[31725]=0;S(1017,d+168|0,18282,f|0);b=x[31725];x[31725]=0;if((b|0)==1){break h}pc(a,d+168|0);c=0;x[31725]=0;S(99,a|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;tb(d+168|0);break g}b=N()|0;break f}b=N()|0;c=1}tb(f);if(!c){break c}}jc(a);break c}if(x[e+4>>2]){a=ac(8);x[31725]=0;c=P(36,d+168|0,11584)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}b=x[b>>2];c=qc(d+148|0,22255);e=x[c+4>>2];x[d+72>>2]=x[c>>2];x[d+76>>2]=e;if(Ic(b,f,d+72|0)){a=ac(8);x[31725]=0;c=P(36,d+168|0,10482)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=qc(d+140|0,7462);e=x[c+4>>2];x[d+64>>2]=x[c>>2];x[d+68>>2]=e;i:{if(!Ic(b,f,d- -64|0)){c=qc(d+132|0,7444);e=x[c+4>>2];x[d+56>>2]=x[c>>2];x[d+60>>2]=e;if(!Ic(b,f,d+56|0)){break i}}e=y[a+60|0]!=0;break e}c=qc(d+124|0,6989);e=x[c+4>>2];x[d+48>>2]=x[c>>2];x[d+52>>2]=e;j:{if(!Ic(b,f,d+48|0)){c=qc(d+116|0,6970);e=x[c+4>>2];x[d+40>>2]=x[c>>2];x[d+44>>2]=e;if(!Ic(b,f,d+40|0)){break j}}e=y[a+61|0]!=0;break e}c=qc(d+108|0,7073);e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Ic(b,f,d+32|0)){e=y[a+62|0]!=0;break e}c=qc(d+100|0,6064);e=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=e;if(Ic(b,f,d+24|0)){e=y[a+63|0]!=0;break e}c=qc(d+92|0,7511);e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;if(Ic(b,f,d+16|0)){e=y[a+64|0]!=0;break e}c=qc(d+84|0,13509);e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;e=0;if(!Ic(b,f,d+8|0)){break e}e=x[x[a+24>>2]+24668>>2]!=0}fb=d+192|0;return e|0}b=N()|0;jc(a)}Q(b|0)}p()}function Wka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;x[a+24588>>2]=0;x[a+24592>>2]=0;x[a+8>>2]=42032;x[a+4>>2]=0;x[a>>2]=30576;b=a+24596|0;x[b>>2]=0;x[b+4>>2]=0;_q(a+24604|0);IS(a+24648|0,0);x[a+397448>>2]=0;x[a+397452>>2]=0;b=a+397456|0;x[b>>2]=8;x[b+4>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;v[b+12|0]=0;x[b+8>>2]=0;w[b+24>>1]=0;Tb(b+28|0,0,40);Tb(b+68|0,0,49824);Tb(b+49892|0,0,32832);v[a+480224|0]=0;w[a+480212>>1]=0;x[a+480204>>2]=0;x[a+480208>>2]=0;x[a+480180>>2]=0;x[a+480184>>2]=0;b=a+480186|0;w[b>>1]=0;w[b+2>>1]=0;w[b+4>>1]=0;w[b+6>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;h=Nb(a+480248|0);x[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;kF(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Nb(c);x[f+12>>2]=a;x[31725]=0;i=P(852,a+484360|0,a|0)|0;b=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=a+900380|0;b=a+484380|0;while(1){x[31725]=0;b=R(711,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break i}b=b+104|0;if((c|0)!=(b|0)){continue}break}x[31725]=0;R(853,a+901404|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break h}d=a+906300|0;b=0;while(1){BS(d+D(b,160)|0);b=b+1|0;if((b|0)!=250){continue}break}x[a+946300>>2]=0;e=a+1074304|0;g=a+946304|0;b=g;while(1){b=dv(b)+32|0;if((e|0)!=(b|0)){continue}break}x[a+1074304>>2]=0;x[a+1074308>>2]=0;hs(a+1074312|0);x[31725]=0;X(854);b=x[31725];x[31725]=0;if((b|0)==1){break g}s=a,t=AS(),x[s+1074328>>2]=t;b=a+1074332|0;x[b+12>>2]=1065353216;rS(b,4);x[31725]=0;e=R(855,a+1074376|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break g}x[31725]=0;j=U(605,a+1298264|0,a|0,255)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}k=sc(a+1298300|0);l=sc(a+1298304|0);m=Fb(a+1298308|0);n=Fb(a+1298320|0);o=Fb(a+1298332|0);q=GS(a+1298344|0);r=Nb(a+1298412|0);v[a+1298424|0]=0;b=a+1298432|0;x[b>>2]=0;x[b+4>>2]=0;x[b+32>>2]=0;x[b+36>>2]=1072693248;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[a+1298472>>2]=0;Jq(a+12|0);VA(a+8204|0);VA(a+12300|0);b=a+1074408|0;x[b>>2]=4;x[b+4>>2]=16;x[a+480216>>2]=4;x[a+480220>>2]=16;Tb(c,0,1024);zS(g);x[31725]=0;b=R(856,12)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;s=a,t=Nb(b),x[s+4>>2]=t;return a|0}b=N()|0;break a}b=N()|0;break b}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;FS(r);YA(q);tb(o);tb(n);tb(m);XA(l);WA(k);Qu(j)}kB(e)}ES(d)}_B(i)}wS(f);uc(h);Q(b|0);p()}function ooa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb+-64|0;fb=d;w[d+62>>1]=c;Gf(d+62|0,32);j=Nb(a);x[31725]=0;n=z[d+62>>1];O(539,j|0,n|0);a=x[31725];x[31725]=0;a:{b:{if((a|0)!=1){c:{d:{while(1){if((o&65535)>>>0>=n>>>0){break d}f=1;c=z[b+480190>>1];a=c+1|0;w[d+60>>1]=a;e:{f:{g:{if((a&65535)>>>0<4e3){break g}h:{while(1){g=f&65535;if(g>>>0>c>>>0){break h}i:{e=ui(b,g);if(!je(x[e>>2],x[e+20>>2])){if(!Ib(LC(wb(x[j>>2]),wb(x[j+4>>2]),f),wb(x[j+4>>2]))){break i}c=z[b+480190>>1]}f=f+1|0;continue}break}w[d+60>>1]=f;a=1;while(1){c=a&65535;if(c>>>0>z[b+480192>>1]){a=f}else{j:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break j}c=c+236|0;e=Ar(c);while(1){if((c|0)==(e|0)){break j}if((g|0)==z[c>>1]){w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}}if((a&65535)>>>0<4e3){break g}f=Zo(d+48|0);x[31725]=0;a=P(779,b|0,f|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}if(!a){break e}x[31725]=0;O(780,b|0,f|0);c=x[31725];x[31725]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=z[b+480192>>1]){k:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break k}c=c+236|0;g=Ar(c);while(1){if((c|0)==(g|0)){break k}e=z[c>>1];l:{if(e>>>0>=A[d+52>>2]){break l}Jb(d+40|0,x[f>>2],e);if(Hb(x[x[d+40>>2]>>2],x[d+44>>2])){break l}w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}tn(d+24|0,x[f>>2]);LV(d+32|0,x[d+24>>2],x[d+28>>2],1);fr(d+16|0,x[f>>2],x[d+52>>2]);l=fb-16|0;fb=l;g=d+40|0;e=gc(l,x[d+32>>2],x[d+36>>2]);a=sn(x[d+16>>2],x[d+20>>2],x[d+32>>2],x[d+36>>2]);c=fb-16|0;fb=c;x[c+12>>2]=a;h=x[e+4>>2];m:{if(h){i=32-h|0;x[c+8>>2]=i;m=x[Gb(c+8|0,c+12|0)>>2];k=-1<<h&-1>>>i-m;i=x[e>>2];k=k&(x[i>>2]^-1);if(k){gc(g,i,nva(k));break m}if((a|0)==(m|0)){LV(g,i,h,a);break m}a=a-m|0;x[c+12>>2]=a;x[e>>2]=i+4}while(1){if(a>>>0>=32){h=x[e>>2];i=x[h>>2];if((i|0)!=-1){gc(g,h,nva(i^-1));break m}else{x[e>>2]=h+4;a=a-32|0;x[c+12>>2]=a;continue}}break}e=x[e>>2];if(!a){gc(g,e,0);break m}h=(x[e>>2]^-1)&-1>>>32-a;if(!h){gc(g,e,a);break m}gc(g,e,nva(h))}fb=c+16|0;fb=l+16|0;tn(d+8|0,x[f>>2]);a=sn(x[d+40>>2],x[d+44>>2],x[d+8>>2],x[d+12>>2]);w[d+60>>1]=a;uf(f);if((a&65535)>>>0>3999){break f}}x[31725]=0;O(259,j|0,d+60|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}if(z[b+480190>>1]>=(a&65535)>>>0){break f}w[b+480190>>1]=a}o=o+1|0;continue}break}uf(f)}fb=d- -64|0;return}c=N()|0;break a}c=N()|0;break a}c=N()|0;uf(f)}md(j);Q(c|0);p()}function Zpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=fb-16|0;fb=g;a:{if(!Mb(x[a>>2],x[a+8>>2],2)){Ng(c+484344|0,b,64);break a}k=c+484344|0;l=Kd(Wk(a),1,1024);if(!Ng(k,b,l)){break a}n=z[c+480188>>1];b:while(1){if((j|0)==(l|0)){break a}e=Wb(x[k>>2],b);cf(g+8|0,x[e>>2],x[x[e+48>>2]+12>>2],j);i=0;while(1)if((i|0)==(n|0)){j=j+1|0;continue b}else{e=Wc(x[g+8>>2],i);f=g+4|0;tm(f,a);o=af(f);f=fj(f);h=y[g+4|0];c:{if((h-1&255)>>>0>35){break c}v[e|0]=h+48;m=y[Jc(g+4|0)|0];h=m+1|0;v[e+1|0]=h;p=h;h=h&255;if((p|0)!=(h|0)|h>>>0>z[c+480190>>1]){break c}h=ui(c,h);if(!(!y[xb(d,i)|0]|z[h+30>>1]>255)){v[e+4|0]=64;v[e+2|0]=1}h=h+68|0;d:{if(x[yb(h,0)>>2]==1){if(y[xb(d,i)|0]){break d}}if(x[yb(h,0)>>2]){break c}if(y[xb(d,i)|0]){break c}}v[e+1|0]=m+101}e:{f:{switch(y[o|0]){case 1:if(!y[f|0]){break e}v[e+3|0]=2;v[e+5|0]=y[f|0];break e;case 2:if(!y[f|0]){break e}v[e+3|0]=3;v[e+5|0]=y[f|0];break e;case 12:if(!y[f|0]){break e}v[e+3|0]=1;v[e+5|0]=y[f|0];break e;case 13:if(!y[f|0]){break e}v[e+3|0]=39;v[g|0]=15;q=e,r=y[Rb(g,f)|0]|16,v[q+5|0]=r;break e;case 30:if(!y[f|0]){break e}v[e+3|0]=38;v[g|0]=15;q=e,r=y[Rb(g,f)|0]|16,v[q+5|0]=r;break e;case 21:if(!y[f|0]){break e}v[e+3|0]=39;v[g|0]=15;q=e,r=y[Rb(g,f)|0]|80,v[q+5|0]=r;break e;case 17:if(!y[f|0]){break e}v[e+3|0]=38;v[g|0]=15;q=e,r=y[Rb(g,f)|0]|80,v[q+5|0]=r;break e;case 15:v[e+3|0]=19;v[e+5|0]=y[f|0]!=0;break e;case 25:v[e+3|0]=12;v[e+5|0]=y[f|0];break e;case 27:ap(e);v[e|0]=255;break e;case 28:if(y[f|0]>31){break e}v[e+3|0]=16;v[e+5|0]=y[f|0];break e;case 31:h=y[f|0];if(h&15){q=e,r=y[xb(d,i)|0]?22:11,v[q+3|0]=r;v[e+5|0]=y[f|0]&15;h=y[f|0]}g:{h:{switch(h>>>4|0){case 4:if((h|0)!=64){break g}case 0:case 1:case 2:case 3:if(y[xb(d,i)|0]){v[e+3|0]=21;v[e+5|0]=y[f|0];break g}v[e+2|0]=1;f=y[f|0];v[e+3|0]=0;v[e+4|0]=f;break g;case 5:v[e+5|0]=y[e+5|0]<<4;break g;case 6:v[g|0]=y[e+5|0];v[g+3|0]=14;q=e,r=y[Rb(g,g+3|0)|0]|240,v[q+5|0]=r;break g;case 7:v[g|0]=y[e+5|0];v[g+3|0]=14;q=e,r=y[Rb(g,g+3|0)|0]<<4|15,v[q+5|0]=r;break g;default:break h}}v[e+3|0]=0}if((y[e+3|0]-21&255)>>>0>1){break e}f=xb(d,i);f=Wc(x[g+8>>2],v[f|0]+i|0);qw(g,y[f+3|0],y[f+5|0],1);if(y[g|0]){h=z[g>>1];v[f+2|0]=h;v[f+4|0]=h>>>8}v[f+3|0]=y[e+3|0];v[f+5|0]=y[e+5|0];break e;case 0:break e;default:break f}}v[e+3|0]=0}i=i+1|0;continue}}}fb=g+16|0}function cba(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=fb-160|0;fb=d;x[d+156>>2]=c;a:{b:{c:{if(b>=.8){x[31725]=0;e=ca(1152)|0;f=x[31725];x[31725]=0;d:{e:{f:{if((f|0)!=1){x[d+72>>2]=e;x[31725]=0;c=R(1153,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}x[d+152>>2]=c;Ao(e,c);a=Ge(d+132|0,a);x[31725]=0;c=x[a+12>>2];x[d+56>>2]=x[a+8>>2];x[d+60>>2]=c;x[d- -64>>2]=x[a+16>>2];c=x[a+4>>2];x[d+48>>2]=x[a>>2];x[d+52>>2]=c;a=U(1145,e|0,d+48|0,15)|0;c=x[31725];x[31725]=0;if((c|0)==1){break f}if(a){x[31725]=0;W(857,e|0);a=x[31725];x[31725]=0;g=1;if((a|0)==1){break f}}wh(d+152|0);xh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;wh(d+152|0);break d}c=T(0)|0}xh(d+72|0);break c}if(b>=.6){x[31725]=0;e=ca(1152)|0;f=x[31725];x[31725]=0;g:{h:{i:{if((f|0)!=1){x[d+72>>2]=e;x[31725]=0;c=R(1153,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break h}x[d+152>>2]=c;Ao(e,c);a=Ge(d+112|0,a);x[31725]=0;c=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=c;x[d+40>>2]=x[a+16>>2];c=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=c;a=U(1145,e|0,d+24|0,2)|0;c=x[31725];x[31725]=0;if((c|0)==1){break i}if(a){x[31725]=0;W(857,e|0);a=x[31725];x[31725]=0;g=.8;if((a|0)==1){break i}}wh(d+152|0);xh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;wh(d+152|0);break g}c=T(0)|0}xh(d+72|0);break c}g=.2;if(b>=.2){x[31725]=0;e=ca(1152)|0;f=x[31725];x[31725]=0;j:{k:{l:{if((f|0)!=1){x[d+72>>2]=e;x[31725]=0;c=R(1153,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break k}x[d+152>>2]=c;Ao(e,c);a=Ge(d+92|0,a);x[31725]=0;c=x[a+12>>2];x[d+8>>2]=x[a+8>>2];x[d+12>>2]=c;x[d+16>>2]=x[a+16>>2];c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;a=U(1145,e|0,d|0,0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break l}g=0;if(a){x[31725]=0;W(857,e|0);a=x[31725];x[31725]=0;g=.6;if((a|0)==1){break l}}wh(d+152|0);xh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;wh(d+152|0);break j}c=T(0)|0}xh(d+72|0);break c}if(!(b>=.1)){break b}x[31725]=0;S(188,d+72|0,a|0,2048);c=x[31725];x[31725]=0;if((c|0)!=1){c=$e(d+72|0);a=x[a>>2];x[31725]=0;e=x[d+72>>2];a=R(156,a|0)|0;f=x[31725];x[31725]=0;m:{if((f|0)==1){break m}x[31725]=0;a=jI(1154,3,0,c,e,a,0);c=x[31725];x[31725]=0;if((c|0)==1){break m}g=C[(a<<3)+79528>>3];Kc(d+72|0);break b}c=T(0)|0;Kc(d+72|0);break c}c=T(0)|0}Y(c|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;g=0;if((a|0)==1){break a}}Vc(d+156|0);fb=d+160|0;return+g}a=N()|0;Vc(d+156|0);Q(a|0);p()}function NS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-48|0;fb=i;d=fb-16|0;fb=d;x[d>>2]=b;x[d+4>>2]=c;g=fb-16|0;fb=g;e=x[d+4>>2];f=e;h=fb-16|0;fb=h;j=x[d>>2];e=x[vb(h+12|0,pva(j,e,500654080,20))>>2];fb=h+16|0;h=fb-16|0;fb=h;k=KS(h+8|0,e);l=x[k>>2];fb=h+16|0;h=x[k+4>>2];if(j>>>0<l>>>0&(h|0)>=(f|0)|(f|0)<(h|0)){h=x[vb(g+12|0,1)>>2];f=fb-16|0;fb=f;e=x[vb(f+12|0,e-h|0)>>2];fb=f+16|0}fb=g+16|0;e=x[vb(d+12|0,e)>>2];fb=d+16|0;f=fb-16|0;fb=f;d=fb-16|0;fb=d;g=e+719468|0;k=(((e|0)>-719469?g:e+573372|0)|0)/146097|0;g=D(k,-146097)+g|0;h=((g>>>0)/36524|0)+g-(((g>>>0)/146096|0)+((g>>>0)/1460|0))|0;j=(h>>>0)/365|0;h=((g-((h>>>0)/1460|0)|0)+((h>>>0)/36500|0)|0)+D(j,-365)|0;l=D(h,5)+2|0;g=(l>>>0)/153|0;k=j+D(k,400)|0;j=g+(l>>>0<1530?3:-9)|0;k=Gw(d+14|0,k+(j>>>0<3)|0);j=rq(d+13|0,j);g=rq(d+12|0,(h-((D(g,153)+2>>>0)/5|0)|0)+1|0);JS(f+12|0,z[k>>1],j,g);fb=d+16|0;d=x[f+12>>2];w[i+44>>1]=d;w[i+46>>1]=d>>>16;fb=f+16|0;d=fb-16|0;fb=d;e=KS(d,e);g=x[e>>2];c=we(d+8|0,b-g|0,c-(x[e+4>>2]+(b>>>0<g>>>0)|0)|0);b=x[c>>2];fb=d+16|0;g=fb-16|0;fb=g;c=x[c+4>>2];d=ZA(g+8|0,0);m=i,n=LS(b,c,x[d>>2],x[d+4>>2]),v[m+8|0]=n;d=fb-16|0;fb=d;e=we(d+8|0,0,0);f=x[e>>2];fb=d+16|0;if(!(LS(b,c,f,x[e+4>>2])^1)){d=fb-16|0;fb=d;c=we(d+8|0,0-b|0,0-(((b|0)!=0)+c|0)|0);b=x[c>>2];fb=d+16|0;c=x[c+4>>2]}d=fb-16|0;fb=d;e=x[vb(d+12|0,pva(b,c,-694967296,0))>>2];fb=d+16|0;x[i+12>>2]=e;d=fb-16|0;fb=d;f=fb-16|0;fb=f;e=we(f+8|0,ova(e,e>>31,-694967296,0),hb);h=x[e>>2];e=x[e+4>>2];fb=f+16|0;x[d>>2]=h;x[d+4>>2]=e;e=x[d>>2];b=we(d+8|0,b-e|0,c-(x[d+4>>2]+(b>>>0<e>>>0)|0)|0);c=x[b>>2];e=x[b+4>>2];f=e;fb=d+16|0;b=fb-16|0;fb=b;d=x[vb(b+12|0,pva(c,e,6e7,0))>>2];fb=b+16|0;x[i+16>>2]=d;b=fb-16|0;fb=b;e=fb-16|0;fb=e;d=we(e+8|0,ova(d,d>>31,6e7,0),hb);h=x[d>>2];d=x[d+4>>2];fb=e+16|0;x[b>>2]=h;x[b+4>>2]=d;d=x[b>>2];d=we(b+8|0,c-d|0,f-(x[b+4>>2]+(c>>>0<d>>>0)|0)|0);c=x[d>>2];fb=b+16|0;d=x[d+4>>2];e=_A(c,d);x[i+24>>2]=e;f=hb;x[i+28>>2]=f;b=fb-16|0;fb=b;e=Eu(b,e,f);f=x[e>>2];c=we(b+8|0,c-f|0,d-(x[e+4>>2]+(c>>>0<f>>>0)|0)|0);d=x[c>>2];fb=b+16|0;m=i,n=sR(d,x[c+4>>2]),x[m+32>>2]=n;x[i+36>>2]=hb;fb=g+16|0;a=MS(a);x[a>>2]=z[i+44>>1]<<16>>16;m=a,n=Pf(y[i+46|0]),x[m+4>>2]=n;m=a,n=Pf(y[i+47|0]),x[m+8>>2]=n;x[a+12>>2]=x[i+12>>2];x[a+16>>2]=x[i+16>>2];b=x[i+28>>2];x[a+24>>2]=x[i+24>>2];x[a+28>>2]=b;fb=i+48|0}function z_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-80|0;fb=g;a:{b:{c:{d:{e:{f:{g:{if(Ad(x[b+4>>2],y[b+11|0])){Fb(a);break g}k=Nb(g+68|0);x[g+56>>2]=0;x[g+60>>2]=0;h=x[c>>2];x[31725]=0;n=R(38,h|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}h=Kb(b);j=Cb(x[b+4>>2],y[b+11|0]);i=Qk(n);f=fb-16|0;fb=f;x[f+12>>2]=i;x[f+8>>2]=0;i=x[Ze(f+8|0,f+12|0)>>2];fb=f+16|0;x[31725]=0;O(39,k|0,D(j,i+1|0)|0);f=x[31725];x[31725]=0;if((f|0)==1){break c}o=(j<<2)+h|0;j=x[k>>2];m=j+Sc(j,x[k+4>>2])|0;q=(d|0)!=2;h:{while(1){i:{j:{k:{l:{if(!q){while(1){x[g+48>>2]=0;x[g+52>>2]=0;x[31725]=0;f=h+4|0;i=za(40,n|0,g+56|0,h|0,f|0,g+52|0,j|0,m|0,g+48|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break f}if((i|0)!=1){break l}if((f|0)!=x[g+52>>2]){l=1;break k}else{j=x[g+48>>2];h=f;continue}}}x[g+48>>2]=0;x[g+52>>2]=0;x[31725]=0;i=za(40,n|0,g+56|0,h|0,o|0,g+52|0,j|0,m|0,g+48|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}l=1;if((i|0)==1){break k}}l=2;f=x[g+48>>2];if((i|0)!=2|(m|0)!=(f|0)){break j}}h=x[k+4>>2];f=x[k>>2];x[31725]=0;O(39,k|0,Sc(f,h)<<1);h=x[31725];x[31725]=0;if((h|0)==1){break d}h=x[k>>2];f=x[g+48>>2];j=h+(f-j|0)|0;m=Sc(h,x[k+4>>2])+h|0;i=l;break i}m:{n:{o:{p:{q:{switch(d|0){case 0:if(x[g+52>>2]!=(h|0)|(f|0)!=(j|0)|(i|0)!=2){break p}x[31725]=0;v[g+47|0]=1;h=P(41,g+8|0,22256)|0;f=x[31725];x[31725]=0;r:{s:{t:{if((f|0)!=1){x[31725]=0;S(42,g+20|0,h|0,b|0);f=x[31725];x[31725]=0;if((f|0)==1){break t}x[31725]=0;aa(43,g+32|0,g+20|0,c|0,1,g+47|0);f=x[31725];x[31725]=0;if((f|0)==1){break s}tb(g+32|0);Qb(g+20|0);Qb(h);if(y[g+47|0]){break o}x[31725]=0;aa(43,a|0,b|0,c|0,2,0);a=x[31725];x[31725]=0;if((a|0)!=1){break h}f=N()|0;break a}f=N()|0;break a}f=N()|0;break r}f=N()|0;Qb(g+20|0)}Qb(h);break a;case 1:break q;default:break p}}v[e|0]=(i|0)!=2|x[g+52>>2]!=(h|0)|(f|0)!=(j|0);Fb(a);break h}if((i|0)==2){break n}break m}f=x[g+48>>2]}x[g+52>>2]=x[g+52>>2]+4;v[f|0]=63;f=x[g+48>>2]+1|0;x[g+48>>2]=f}j=f}l=(i|0)==2;h=x[g+52>>2];i=o>>>0>h>>>0;if(l&i&f>>>0<m>>>0|i&(d|0)==2){continue}break}b=x[k>>2];x[31725]=0;U(44,a|0,b|0,f|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break e}}dc(k)}fb=g+80|0;return}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0}dc(k);Q(f|0);p()}function IV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-32|0;fb=c;e=y[a+13|0];a:{if(e&227|(e&24)==16){break a}e=y[a+8|0];f=y[a+6|0]|y[a+7|0]<<8;v[c+22|0]=0;v[c+26|0]=e;w[c+24>>1]=f;w[c+20>>1]=0;while(1){if((d|0)!=3){e=y[xb(c+24|0,d)|0];h=xb(c+20|0,d),i=e,v[h|0]=i;d=d+1|0;continue}break}e=eg(c+20|0);f=y[a+11|0];g=y[a+9|0]|y[a+10|0]<<8;d=0;v[c+18|0]=0;v[c+26|0]=f;w[c+24>>1]=g;w[c+16>>1]=0;while(1){if((d|0)!=3){f=y[xb(c+24|0,d)|0];h=xb(c+16|0,d),i=f,v[h|0]=i;d=d+1|0;continue}break}d=0;if(eg(c+16|0)>>>0<e>>>0){break a}e=a+6|0;d=a+9|0;f=y[d+2|0];g=y[d|0]|y[d+1|0]<<8;d=0;v[c+22|0]=0;v[c+26|0]=f;w[c+24>>1]=g;w[c+20>>1]=0;while(1){if((d|0)!=3){f=y[xb(c+24|0,d)|0];h=xb(c+20|0,d),i=f,v[h|0]=i;d=d+1|0;continue}break}f=eg(c+20|0);g=y[e+2|0];e=y[e|0]|y[e+1|0]<<8;d=0;v[c+18|0]=0;v[c+26|0]=g;w[c+24>>1]=e;w[c+16>>1]=0;while(1){if((d|0)!=3){e=y[xb(c+24|0,d)|0];h=xb(c+16|0,d),i=e,v[h|0]=i;d=d+1|0;continue}break}e=eg(c+16|0);b:{if(!((b|0)==2|(e|0)==(f|0))){d=0;if((y[a+14|0]|y[a+15|0]<<8)>>>0>=100){break b}break a}if((e|0)==(f|0)|(b|0)!=2){break b}d=0;if((y[a+14|0]|y[a+15|0]<<8)<<16>>16<0){break a}}b=y[a+13|0];e=f-e|0;if(e&1){d=0;if(b&4){break a}}c:{if(b&8){b=y[a+5|0];f=y[a+3|0]|y[a+4|0]<<8;d=0;v[c+22|0]=0;w[c+24>>1]=f;v[c+26|0]=b;w[c+20>>1]=0;while(1){if((d|0)!=3){b=y[xb(c+24|0,d)|0];h=xb(c+20|0,d),i=b,v[h|0]=i;d=d+1|0;continue}break}if(!eg(c+20|0)){break c}}b=y[a+5|0];f=y[a+3|0]|y[a+4|0]<<8;d=0;v[c+22|0]=0;v[c+26|0]=b;w[c+24>>1]=f;w[c+20>>1]=0;while(1){if((d|0)!=3){b=y[xb(c+24|0,d)|0];h=xb(c+20|0,d),i=b,v[h|0]=i;d=d+1|0;continue}break}if(eg(c+20|0)){b=a+3|0;f=y[b+2|0];g=y[b|0]|y[b+1|0]<<8;d=0;v[c+18|0]=0;w[c+24>>1]=g;v[c+26|0]=f;w[c+16>>1]=0;while(1){if((d|0)!=3){f=y[xb(c+24|0,d)|0];h=xb(c+16|0,d),i=f,v[h|0]=i;d=d+1|0;continue}break}if(eg(c+16|0)>>>0>=e>>>0){break c}e=y[a+2|0];a=y[a|0]|y[a+1|0]<<8;d=0;v[c+14|0]=0;w[c+24>>1]=a;v[c+26|0]=e;w[c+12>>1]=0;while(1){if((d|0)!=3){a=y[xb(c+24|0,d)|0];h=xb(c+12|0,d),i=a,v[h|0]=i;d=d+1|0;continue}break}a=eg(c+12|0);e=y[b+2|0];b=y[b|0]|y[b+1|0]<<8;d=0;v[c+10|0]=0;v[c+26|0]=e;w[c+24>>1]=b;w[c+8>>1]=0;while(1){if((d|0)!=3){b=y[xb(c+24|0,d)|0];h=xb(c+8|0,d),i=b,v[h|0]=i;d=d+1|0;continue}break}d=0;if(eg(c+8|0)>>>0<=a>>>0){break a}}d=1;break a}d=0}fb=c+32|0;return d}function y1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-368|0;fb=e;xc(b);d=fb-16|0;fb=d;h=e+330|0;hF(d+8|0,h);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(g|0)==(i|0);if(!d){gF(h)}a:{if(!d){break a}if(!jF(e+330|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(iF(y[e+365|0]),hb))){break a}b:{if(!c){break b}Bd(a,2097152);gg(a);Yh(a,1);w[a+480188>>1]=8;x[a+480196>>2]=y[e+362|0];x[a+480204>>2]=D(y[e+363|0],1e4);w[a+480190>>1]=y[e+364|0];d=y[e+367|0];if(d>>>0<y[e+366|0]){bf(Xb(x[a+484360>>2],y[a+484376|0]),d)}d=e- -64|0;f=tc(d,6554);Ab(a+1298344|0,f);tb(f);f=tc(d,11148);Ab(a+1298356|0,f);tb(f);n=a+1298404|0,o=x[Fc(d,4)>>2],x[n>>2]=o;Dw(b,d);Vr(Xb(x[a+484360>>2],y[a+484376|0]),d,y[e+366|0],65535,65535);f=1;while(1){i=f&65535;if(i>>>0>z[a+480190>>1]){Vb(b,D(64-y[e+364|0]|0,37));h=a+484344|0;Vf(h,y[e+365|0]);i=c&1;f=0;while(1)if(y[e+365|0]<=f>>>0){if(!(c&2)){break b}c=Xc(e+24|0,8,1,0,0);f=1;while(1){d=f&65535;if(d>>>0>z[a+480190>>1]){break b}fg(c,(D(d,104)+a|0)+484380|0,b);f=f+1|0;continue}}else{c:{d:{if(i){if(Ng(h,f&65535,64)){break d}}Vb(b,2048);break c}d=Wb(x[h>>2],f);n=e,o=wb(x[d>>2]),x[n+24>>2]=o;j=wb(x[d+4>>2]);while(1){d=x[e+24>>2];if(!Ib(d,j)){break c}g=e+12|0;tm(g,b);l=Jc(g);m=af(g);g=fj(g);k=y[e+12|0];if((k-1&255)>>>0<=106){v[d|0]=k+13}v[d+1|0]=y[l|0];Bf(d,y[m|0],y[g|0]);vg(e+24|0);continue}}f=f+1|0;continue}}else{d=e+24|0;fF(b,d);h=fb-16|0;fb=h;g=(D(i,104)+a|0)+484380|0;ld(g,0);v[g+37|0]=y[d+22|0]<<4;v[h+15|0]=y[d+23|0];v[h+14|0]=64;n=g,o=y[Rb(h+15|0,h+14|0)|0]<<2,w[n+30>>1]=o;v[g+36|0]=y[d+24|0];x[g>>2]=y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24);j=y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24);if(!(j>>>0<3|j+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))>>>0>(y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24))>>>0)){w[g+34>>1]=z[g+34>>1]|2;x[g+4>>2]=y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24);x[g+8>>2]=(y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24))+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))}fb=h+16|0;Zk(e,2,d);d=e+12|0;Cc(d,e);zc(((i<<5)+a|0)+946304|0,d);f=f+1|0;tb(d);continue}}}f=1}fb=e+368|0;return f|0}function Lua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;m=fb-32|0;fb=m;d=b;b=x[a>>2];b=(sp(d,wb(b))<<1)+b|0;f=x[a+4>>2];a:{b:{if(f>>>0<A[zb(a)>>2]){if((b|0)!=(f|0)){break b}d=fb-16|0;fb=d;a=$h(d+4|0,a,1);ij(x[a+4>>2],y[c|0]|y[c+1|0]<<8);x[a+4>>2]=x[a+4>>2]+2;hc(a);fb=d+16|0;break a}d=zb(a);g=ok(m+12|0,pk(a,Zc(x[a>>2],f)+1|0),b-x[a>>2]>>1,d);x[31725]=0;O(296,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){h=fb-16|0;fb=h;c=x[g+4>>2];k=zb(a);d=vb(h+12|0,b);f=vb(h+8|0,x[a>>2]);i=vb(h+4|0,x[g+4>>2]);e=x[d>>2];j=x[f>>2];d=fb+-64|0;fb=d;f=x[i>>2];x[d+56>>2]=f;x[d+60>>2]=e;x[d+52>>2]=f;f=Se(d+24|0,k,d+52|0,d+56|0);x[d+16>>2]=x[f+8>>2];i=x[f+4>>2];x[d+8>>2]=x[f>>2];x[d+12>>2]=i;Re(d+36|0,d+8|0);while(1){if(pd(e,j)){f=nE(x[d+56>>2]);e=On(e);ij(f,y[e|0]|y[e+1|0]<<8);e=jj(d+60|0);jj(d+56|0);e=x[e>>2];continue}break}Qe(d+36|0);n=x[d+56>>2];if(!y[d+48|0]){i=fb-16|0;fb=i;e=vb(i+12|0,x[x[d+44>>2]>>2]);l=x[vb(i+8|0,x[x[d+40>>2]>>2])>>2];j=fb-16|0;fb=j;e=x[e>>2];x[j+12>>2]=e;while(1){if(di(e,l)){f=fb-16|0;fb=f;x[f+12>>2]=e;x[f+12>>2]=x[f+12>>2]+2;fb=f+16|0;nE(x[f+12>>2]);e=x[Md(j+12|0)>>2];continue}break}fb=j+16|0;fb=i+16|0}fb=d- -64|0;x[g+4>>2]=n;f=x[a+4>>2];d=fb-48|0;fb=d;e=x[g+8>>2];x[d+44>>2]=e;x[d+40>>2]=e;e=Se(d+12|0,k,d+40|0,d+44|0);x[d+8>>2]=x[e+8>>2];i=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=i;Re(d+24|0,d);while(1){if((b|0)!=(f|0)){ij(x[d+44>>2],y[b|0]|y[b+1|0]<<8);x[d+44>>2]=x[d+44>>2]+2;b=b+2|0;continue}break}b=d+24|0;Qe(b);e=x[d+44>>2];oE(b);fb=d+48|0;x[g+8>>2]=e;Ub(a,g+4|0);Ub(a+4|0,g+8|0);Ub(zb(a),nc(g));x[g>>2]=x[g+4>>2];fb=h+16|0;b=c;kj(g);break a}a=N()|0;kj(g);Q(a|0);p()}i=fb-16|0;fb=i;e=x[a+4>>2];g=(e-(b+2|0)|0)+b|0;j=$h(i+4|0,a,f-g>>1);h=x[j+4>>2];d=g;while(1){if(d>>>0>=f>>>0){hc(j);h=fb-16|0;fb=h;j=h+8|0;d=e;e=fb-32|0;fb=e;Id(e+24|0,b,g);k=e+16|0;n=x[e+24>>2];g=fb-16|0;fb=g;l=x[e+28>>2];f=l;while(1){if((f|0)!=(n|0)){f=f-2|0;d=h0(d-2|0,f);continue}break}x[g+12>>2]=d;Ac(k,l,g+12|0);fb=g+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(j,d,e+12|0);fb=e+32|0;fb=h+16|0;fb=i+16|0}else{ij(h,y[d|0]|y[d+1|0]<<8);h=h+2|0;x[j+4>>2]=h;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&A[a+4>>2]>c>>>0)<<1)+c|0;c=y[a|0];v[b+1|0]=y[a+1|0];v[b|0]=c}wb(b);fb=m+32|0}function Aba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-144|0;fb=d;h=XM(d+128|0);x[h>>2]=48700;Nb(h+4|0);Ao(x[a+24>>2],h);e=x[a+24>>2];i=y[a+62|0];f=y[a+61|0];g=y[a+60|0];b=Ge(d+108|0,b);x[31725]=0;j=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=j;x[d+16>>2]=x[b+16>>2];j=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=j;b=g?13:15;b=f?b&14:b;b=U(1145,e|0,d|0,(i?b&3:b)|0)|0;e=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=ac(8);x[31725]=0;c=P(36,d+96|0,12010)|0;a=x[31725];x[31725]=0;if((a|0)!=1){pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;jc(b);break b}if(!y[a+63|0]){x[31725]=0;O(1146,a|0,a+36|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}}v[a+28|0]=1;Ao(x[a+24>>2],x[a+4>>2]);x[31725]=0;O(1147,d+96|0,h|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}k=d,l=wb(x[d+96>>2]),x[k+92>>2]=l;e=a+68|0;i=wb(x[d+100>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=x[d+92>>2];if(!Ib(b,i)){k=d,l=$i(x[c>>2]),x[k+80>>2]=l;c=Rf(c);while(1){b=x[d+80>>2];if(!Zg(b,c)){break d}x[31725]=0;e=td(b);b=P(72,d+20|0,e|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break h}x[31725]=0;V(1018,a|0,b|0,e+12|0,0);e=x[31725];x[31725]=0;if((e|0)==1){break g}tb(b);ah(d+80|0);continue}}f=x[a+24>>2];g=x[b>>2];x[31725]=0;j=f;f=b+4|0;S(1148,j|0,g|0,f|0);g=x[31725];x[31725]=0;if((g|0)!=1){b=x[b>>2];x[31725]=0;O(1149,d+44|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break r}x[31725]=0;O(1065,d+56|0,d+44|0);b=x[31725];x[31725]=0;if((b|0)==1){break q}x[31725]=0;b=P(36,d+32|0,18382)|0;g=x[31725];x[31725]=0;if((g|0)==1){break p}x[31725]=0;S(1021,d+68|0,d+56|0,b|0);g=x[31725];x[31725]=0;if((g|0)==1){break o}x[31725]=0;S(545,d+80|0,d+68|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break n}x[31725]=0;O(180,e|0,d+80|0);f=x[31725];x[31725]=0;if((f|0)==1){break m}tb(d+80|0);tb(d+68|0);tb(b);tb(d+56|0);tb(d+44|0);$o(d+92|0);continue}break}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;break j}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+80|0)}tb(d+68|0)}tb(b)}tb(d+56|0)}tb(d+44|0);break f}a=N()|0;break f}a=N()|0;tb(b)}vz(d+96|0);break b}a=N()|0;break b}vz(d+96|0);Zt(h);fb=d+144|0;return}a=N()|0}Zt(h);Q(a|0)}p()}function Noa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=fb-16|0;fb=k;e=x[b>>2];d=Lg(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){n=fb-32|0;fb=n;d=c-d|0;f=x[zb(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){h=fb-16|0;fb=h;e=jC(h+4|0,b,d);d=x[e+4>>2];g=x[e+8>>2];while(1){if((d|0)==(g|0)){hc(e);fb=h+16|0}else{VV(d);d=d+32|0;x[e+4>>2]=d;continue}break}break b}h=zb(b);h=gv(n+12|0,ar(b,Lg(x[b>>2],e)+d|0),Lg(x[b>>2],x[b+4>>2]),h);g=fb-16|0;fb=g;d=WV(g+4|0,h+8|0,d);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){VV(e);e=x[d>>2]+32|0;x[d>>2]=e;continue}break}he(d);fb=g+16|0;l=fb-16|0;fb=l;d=vb(l+12|0,x[b+4>>2]);e=vb(l+8|0,x[b>>2]);f=x[vb(l+4|0,x[h+4>>2])>>2];m=fb-16|0;fb=m;o=m+8|0;g=fb-32|0;fb=g;Id(g+24|0,x[d>>2],x[e>>2]);p=g+16|0;d=x[g+24>>2];q=x[g+28>>2];j=fb-16|0;fb=j;x[j+8>>2]=f;x[j+12>>2]=d;while(1){if(pd(d,q)){d=nn(d);e=nn(x[j+8>>2]);f=y[d+28|0]|y[d+29|0]<<8|(y[d+30|0]<<16|y[d+31|0]<<24);i=y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24);v[e+24|0]=i;v[e+25|0]=i>>>8;v[e+26|0]=i>>>16;v[e+27|0]=i>>>24;v[e+28|0]=f;v[e+29|0]=f>>>8;v[e+30|0]=f>>>16;v[e+31|0]=f>>>24;f=y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24);i=y[d+16|0]|y[d+17|0]<<8|(y[d+18|0]<<16|y[d+19|0]<<24);v[e+16|0]=i;v[e+17|0]=i>>>8;v[e+18|0]=i>>>16;v[e+19|0]=i>>>24;v[e+20|0]=f;v[e+21|0]=f>>>8;v[e+22|0]=f>>>16;v[e+23|0]=f>>>24;f=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);i=y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24);v[e+8|0]=i;v[e+9|0]=i>>>8;v[e+10|0]=i>>>16;v[e+11|0]=i>>>24;v[e+12|0]=f;v[e+13|0]=f>>>8;v[e+14|0]=f>>>16;v[e+15|0]=f>>>24;f=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[e|0]=d;v[e+1|0]=d>>>8;v[e+2|0]=d>>>16;v[e+3|0]=d>>>24;v[e+4|0]=f;v[e+5|0]=f>>>8;v[e+6|0]=f>>>16;v[e+7|0]=f>>>24;d=_o(j+12|0);_o(j+8|0);d=x[d>>2];continue}break}Ac(p,d,j+8|0);fb=j+16|0;d=x[g+16>>2];x[g+12>>2]=x[g+20>>2];Ac(o,d,g+12|0);fb=g+32|0;fb=m+16|0;x[h+4>>2]=x[m+12>>2];Ub(b,h+4|0);Ub(b+4|0,h+8|0);Ub(zb(b),nc(h));x[h>>2]=x[h+4>>2];fb=l+16|0;YV(h)}fb=n+32|0;break a}if(c>>>0<d>>>0){jY(b,e+(c<<5)|0)}}if(Mb(x[a>>2],x[a+8>>2],c<<5)){c=x[b>>2];bc(k+8|0,c,Lg(c,x[b+4>>2])<<5);rd(k,a,x[k+8>>2],x[k+12>>2])}fb=k+16|0}function sda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;m=fb-32|0;fb=m;j=rf(m+20|0,1,0);a:{b:{while(1){e=Kb(j);i=e+Cb(x[j+4>>2],y[j+11|0])|0;g=x[b>>2];d=x[b+4>>2];if(!((d|0)>0|(d|0)>=0|(e|0)==(i|0))){v[e|0]=45;e=e+1|0;g=TN(g,d);d=hb}k=m+12|0;c:{d:{switch(c<<31|c-2>>>1){case 4:SN(k,e,i,g,d);break c;case 0:f=64-cu(g|1,d)|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<17){while(1){e=e-1|0;v[e|0]=y[(g&1)+15477|0];h=!d&g>>>0>1|(d|0)!=0;f=d;d=d>>>1|0;g=(f&1)<<31|g>>>1;if(h){continue}break}}else{e=e-4|0;jn((g<<2&60)+78800|0,4,e);f=d;d=d>>>4|0;g=(f&15)<<28|g>>>4;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;case 3:f=(66-cu(g|1,d)>>>0)/3|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<65){while(1){e=e-1|0;v[e|0]=y[(g&7)+14762|0];h=!d&g>>>0>7|(d|0)!=0;f=d;d=d>>>3|0;g=(f&7)<<29|g>>>3;if(h){continue}break}}else{e=e-2|0;jn((g<<1&126)+78864|0,2,e);f=d;d=d>>>6|0;g=(f&63)<<26|g>>>6;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;case 7:f=67-cu(g|1,d)>>>2|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<257){while(1){e=e-1|0;v[e|0]=y[(g&15)+11165|0];h=!d&g>>>0>15|(d|0)!=0;f=d;d=d>>>4|0;g=(f&15)<<28|g>>>4;if(h){continue}break}}else{e=e-2|0;jn((g<<1&510)+78992|0,2,e);f=d;d=d>>>8|0;g=(f&255)<<24|g>>>8;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;default:break d}}f=g;h=d;n=D(c,c);q=D(n,c);r=D(n,n);o=0;e:{while(1){l=o|1;if(!h&c>>>0>f>>>0){break e}l=o|2;if(!h&f>>>0<n>>>0){break e}l=o|3;if(!h&f>>>0<q>>>0){break e}if(!h&f>>>0<r>>>0){l=o+4|0}else{o=o+4|0;f=qva(f,h,r,0);h=hb;continue}break}}h=l;if((h|0)>(i-e|0)){x[k+4>>2]=61;x[k>>2]=i;break c}q=e+h|0;e=q;while(1){e=e-1|0;h=qva(g,d,c,0);f=hb;s=e,t=y[(g-ova(h,f,c,0)|0)+4895|0],v[s|0]=t;n=!d&c>>>0<=g>>>0|(d|0)!=0;g=h;d=f;if(n){continue}break}x[k+4>>2]=0;x[k>>2]=q}if(!x[m+16>>2]){break b}d=ri(Cb(x[j+4>>2],y[j+11|0]));x[31725]=0;O(45,j|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break a}c=x[m+12>>2];b=Kb(j);x[31725]=0;O(46,j|0,c-b|0);b=x[31725];x[31725]=0;f:{if((b|0)!=1){x[31725]=0;O(47,a|0,j|0);a=x[31725];x[31725]=0;if((a|0)!=1){break f}break a}break a}tb(j);fb=m+32|0;return}a=N()|0;tb(j);Q(a|0);p()}function gka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-16|0;fb=h;f=x[a+8>>2];e=x[a>>2];x[31725]=0;f=P(623,e|0,f|0)|0;e=x[31725];x[31725]=0;a:{b:{if((e|0)!=1){if(f){break b}x[31725]=0;f=R(199,a|0)|0;e=x[31725];x[31725]=0;c:{if((e|0)==1){break c}x[31725]=0;j=d+484344|0;k=Kd(f+1|0,1,1024);f=U(198,j|0,b|0,k|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}if(!f){break b}d=z[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}f=x[a+8>>2];e=x[a>>2];x[31725]=0;f=U(152,e|0,f|0,1)|0;e=x[31725];x[31725]=0;d:{if((e|0)!=1){if(!f){break b}x[31725]=0;i=R(199,a|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}e=x[j>>2];w[h+14>>1]=i&31;w[h+12>>1]=l;e=Wb(e,b);e=jd(x[e>>2],x[x[e+48>>2]+12>>2],d,z[Nc(h+14|0,h+12|0)>>1]);if(i>>>0<32){continue}e:{if(i<<24>>24>=0){break e}x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break a}v[e+5|0]=g;x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;f:{g:{if((f|0)!=1){if(g>>>0<26){break g}break f}break a}f=y[g+41152|0];v[e+3|0]=f;h:{switch(f-1|0){case 0:if(!y[e+5|0]){break f}break e;case 12:if(y[e+2|0]){break e}v[e+2|0]=1;f=y[e+5|0];v[e+5|0]=0;v[e+3|0]=0;m=e,n=Kd(f,0,64),v[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:f=y[e+5|0]&240;if(!f){break e}v[e+5|0]=f;break e;case 8:f=y[e+5|0];if(f>>>0<=128){m=e,n=bh(f<<1),v[m+5|0]=n;break e}if((f|0)!=164){break e}v[e+5|0]=145;v[e+3|0]=20;break e;case 13:f=y[e+5|0];v[e+5|0]=D(f>>>4|0,10)+(f&15);break e;case 18:rw(e);break e;case 16:if(y[e+5|0]>31){break e}v[e+3|0]=16;break e;case 27:break h;default:break e}}g=y[e+5|0];f=g&240;i:{if((f|0)==16){f=2}else{if((f|0)!=32){break i}f=3}v[e+3|0]=f}v[e+5|0]=g&15|224;break e}v[e+3|0]=0}j:{k:{if(!(i&64)){break k}x[31725]=0;O(200,h+10|0,a|0);f=x[31725];x[31725]=0;if((f|0)==1){break j}v[e+1|0]=y[h+10|0];g=y[Jc(h+10|0)|0];v[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break k}}v[e|0]=f}if(!(i&32)){continue}v[e+2|0]=1;x[31725]=0;g=R(199,a|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break a}v[e+4|0]=g;if(!c){continue}v[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}ub(a);fb=h+16|0;return}b=N()|0;ub(a);Q(b|0);p()}function Xu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=fb-16|0;fb=j;g=x[a+24>>2];h=OB(g,y[a+32|0]);i=x[h>>2];a:{if(Zc(i,x[h+4>>2])>>>0<=b>>>0){break a}if(rU(x[g+484344>>2],x[g+484348>>2],z[_b(i,b)>>1])>>>0<=c>>>0){break a}h=x[a>>2];b:{if(Ud(h,x[a+4>>2])>>>0>b>>>0){if(A[Hd(h,b)+4>>2]>c>>>0){break b}}So(a,0);if(Ud(x[a>>2],x[a+4>>2])>>>0<=b>>>0){break a}g=x[a+24>>2]}bc(j,x[d>>2],z[g+480188>>1]);h=j+8|0;l=x[j>>2];d=e?-2046629010:-2078137563;i=e?-1352371636:-873292572;e=x[j+4>>2];while(1){if(!f&(e|0)==(k|0)){x[h>>2]=d;x[h+4>>2]=i}else{g=y[xW(l,k)+841|0];m=g^ova(d^k,f^i,435,256);g=!g;d=(q=d,r=ova(m,hb,435,256),s=g,s?q:r);i=g?i:hb;k=k+1|0;f=k?f:f+1|0;continue}break}g=0;d=kn(j,b,c);i=fb-16|0;fb=i;k=a+12|0;e=k;f=gU(z[d>>1],x[d+4>>2],ce(e),ec(e));c:{if(Ib(f,rg(e))){l=z[d>>1];m=x[d+4>>2];d=td(f);if(!Wl(l,m,z[d>>1],x[d+4>>2])){break c}}f=rg(e)}d=x[vb(i+12|0,f)>>2];fb=i+16|0;if(Zg(d,Rf(k))){e=td(d);g=lc(x[e+8>>2],x[e+12>>2])^1}i=x[h>>2]!=-2078137563|x[h+4>>2]!=-873292572;Jb(j,x[Hd(x[a>>2],b)>>2],c);f=1;n=Hb(x[x[j>>2]>>2],x[j+4>>2])^1;e=g|i;if(!(n|e)){break a}d:{e:{f:{g:{if(g){m=td(d);e=wb(x[m+8>>2]);o=wb(x[m+12>>2]);d=x[h>>2];p=x[h+4>>2];l=fb-16|0;fb=l;x[l+12>>2]=e;while(1){h:{if(!Ib(e,o)){break h}if(go(x[e>>2],x[e+4>>2],d,p)){break h}e=x[_u(l+12|0)>>2];continue}break}fb=l+16|0;if(Ib(e,wb(x[m+12>>2]))){break a}if(!i){break e}break g}if(i){break g}if(!e){break d}break f}x[a+28>>2]=x[a+28>>2]+1}if(g|n){break e}d=eU(k,kn(j,b,c));i:{if(A[d+4>>2]<A[zb(d)>>2]){e=fb-16|0;fb=e;d=dU(e+4|0,d);bU(x[d+4>>2]);x[d+4>>2]=x[d+4>>2]+8;hc(d);fb=e+16|0;break i}f=fb-32|0;fb=f;e=zb(d);e=ms(f+12|0,ns(d,kh(x[d>>2],x[d+4>>2])+1|0),kh(x[d>>2],x[d+4>>2]),e);bU(x[e+8>>2]);x[e+8>>2]=x[e+8>>2]+8;NB(d,e);ls(e);fb=f+32|0}}d=eU(k,kn(j,b,c));j:{if(A[d+4>>2]<A[zb(d)>>2]){e=fb-16|0;fb=e;d=dU(e+4|0,d);cU(x[d+4>>2],x[h>>2],x[h+4>>2]);x[d+4>>2]=x[d+4>>2]+8;hc(d);fb=e+16|0;break j}f=fb-32|0;fb=f;e=zb(d);e=ms(f+12|0,ns(d,kh(x[d>>2],x[d+4>>2])+1|0),kh(x[d>>2],x[d+4>>2]),e);cU(x[e+8>>2],x[h>>2],x[h+4>>2]);x[e+8>>2]=x[e+8>>2]+8;NB(d,e);ls(e);fb=f+32|0}}Jb(j,x[Hd(x[a>>2],b)>>2],c);Jf(j,1);f=0}fb=j+16|0;return f|0}function mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;y=x[a+16>>2];z=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;r=x[a+128>>2];if(r){k=x[a+8>>2];g=x[a+12>>2];s=Gg(k,g,r);t=hb;h=x[a+76>>2];hg(x[a>>2],x[a+4>>2],vf(k,g,d),hb);q=hb>>>0>h>>>0?d:0}else{q=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;q=q-1|0;h=q;s=h?s:0;t=h?t:0;k=(((g&2147483647)<<1|b>>>31)&-2)+y|0;g=r;a:{b:while(1){c:{if((g|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){be(j,i>>>3<<16>>16);ae(j,4);Pb(f+40|0,s,t);g=g-1|0;continue b}else{i=(v[k+(b+h|0)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b+g|0)|0]<<8)+i|0;b=b+1|0;continue}break}be(j,i>>>3<<16>>16);ae(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Eg(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;w=e<<8;e=w;e=ova(h,G,e,e>>31);m=hb;n=e;e=Yb(l,-16777216,16776704);e=ova(k,F,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Yb(H,-16777216,16776704);m=ova(i,E,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Rc(m,e,24);x[g+4>>2]=e-(w&C);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];p=x[a+28>>2]+p|0;x[c>>2]=x[c>>2]+D(x[f>>2],p>>12);o=b+o|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],o>>12);Pb(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Fb(a);x[31725]=0;X(86);c=x[31725];x[31725]=0;a:{b:{if((c|0)==1){c=Ua(48492,125e3,125584,0)|0;d=gb;c:{d:{e:{if(($(48492)|0)==(d|0)){c=Y(c|0)|0;x[31725]=0;b=P(991,a|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;b=P(991,b|0,18382)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;d=P(991,b|0,18358)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31725]=0;P(991,d|0,(b?b:22255)|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;break a}f:{if(($(125e3)|0)==(d|0)){c=Y(c|0)|0;x[31725]=0;b=P(991,a|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break f}x[31725]=0;b=P(991,b|0,18382)|0;d=x[31725];x[31725]=0;if((d|0)==1){break f}x[31725]=0;d=P(991,b|0,18333)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31725]=0;P(991,d|0,(b?b:22255)|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;break a}e=$(125584)|0;c=Y(c|0)|0;g:{if((d|0)==(e|0)){x[31725]=0;b=P(991,a|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}x[31725]=0;b=P(991,b|0,18382)|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}x[31725]=0;d=P(991,b|0,18349)|0;b=x[31725];x[31725]=0;if((b|0)==1){break g}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31725]=0;P(991,d|0,(b?b:22255)|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break g}x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;break a}x[31725]=0;b=P(991,a|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}x[31725]=0;b=P(991,b|0,18382)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}x[31725]=0;P(991,b|0,13775)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;break a}b=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){break a}break c}b=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){break a}break c}b=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)==1){break c}break a}b=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){break a}}T(0)|0;Sb()}p()}return}tb(a);Q(b|0);p()}function c1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=fb-48|0;fb=f;l=f+29|0;m=f+27|0;n=ch(f+42|0);while(1){a:{if(A[a+12>>2]>j>>>0){cf(f+32|0,x[a>>2],x[x[a+48>>2]+12>>2],j);b:while(1){if(!Mb(x[c>>2],x[c+8>>2],1)){break a}e=Zd(c);if((e|0)==255){break a}g=n;k=e<<24>>24;e=k&31;if(e>>>0<z[x[x[a+48>>2]+12>>2]+480188>>1]){g=Wc(x[f+32>>2],e)}d=1;if(!(k&64)){e=Zd(c);i=e<<24>>24;d=255;e=e&127;c:{d:{if((e|0)==1){break d}d=e-1|0;if(b?d>>>0<=120:0){break d}if((e-109&255)>>>0<159|b){break c}d=e+13|0}v[g|0]=d}q=g,r=Zd(c),v[q+1|0]=r;d=(i|0)<0}i=g+3|0;e=g+5|0;while(1){e:{f:{g:{if(d&1){w[f+28>>1]=y[g+4|0]|y[g+5|0]<<8;x[f+24>>2]=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);d=Zd(c);h=d&63;o=d<<24>>24;if(d&64){v[g+4|0]=h;v[g+2|0]=1;break e}d=Zd(c);v[e|0]=d;if(h>>>0<=15){Bf(g,h,d);h:{i:{j:{d=y[g+3|0];switch(d-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}v[i|0]=9;v[e|0]=D(y[e|0]&15,17);break f}v[g+2|0]=1;v[g+3|0]=0;x[f+20>>2]=y[g+5|0]+1>>>1;x[f+16>>2]=64;q=g,r=x[ud(f+20|0,f+16|0)>>2],v[q+4|0]=r;break f}if((d|0)!=19){break f}if(y[e|0]==128){break g}rw(g);break f}if(h>>>0>44){break f}v[i|0]=y[h+24592|0];k:{switch(h-16|0){case 0:if(d>>>0>1){break g}v[e|0]=d|158;break f;case 1:case 2:v[f+20|0]=15;q=e,r=y[Rb(f+20|0,e)|0]|224,v[q|0]=r;break f;case 5:case 6:x[f+20>>2]=16;x[f+16>>2]=d+1;q=e,r=x[ud(f+20|0,f+16|0)>>2]/2|240,v[q|0]=r;break f;case 14:l:{m:{n:{o:{p:{h=d>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}v[i|0]=2;v[e|0]=d|240;break f}v[i|0]=3;v[e|0]=d|240;break f}v[i|0]=11;v[e|0]=(d<<3&120)+8|15;break f}v[i|0]=11;v[e|0]=(d&15)+1>>>1|240;break f;case 12:break k;default:break f}}x[f+20>>2]=d+1>>>1;x[f+16>>2]=64;q=e,r=x[ud(f+20|0,f+16|0)>>2],v[q|0]=r;break f}if((k|0)>=0){continue b}break a}v[i|0]=0}GE(i,e,m,l);d=y[f+27|0];p=yi(d);h=y[i|0];if(p>>>0<=yi(h)>>>0){break e}if(!y[g+2|0]){qw(f+14|0,h,y[g+5|0],1);h=y[f+14|0];v[g+4|0]=y[f+15|0];v[g+2|0]=h}v[i|0]=d;v[e|0]=y[f+29|0]}d=(o|0)<0;continue}}}fb=f+48|0;return}j=j+1|0;continue}}function Qga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,C=0,D=0,F=E(0),G=E(0),H=E(0),I=0,J=0,K=0,L=0,M=E(0),N=E(0),O=E(0),P=E(0),Q=E(0),R=E(0),S=0,T=0,U=E(0);if(Ai(a+44|0)){f=x[a+44>>2];y=Hc(f,0);z=Hc(f,1);f=x[a+56>>2];A=Hc(f,0);C=Hc(f,1);n=x[a+4300>>2];s=x[a+4296>>2];m=s+1|0;k=a+4304|0;f=a+4272|0;t=m+x[yb(f,0)>>2]&4095;o=k+(t<<4)|0;u=m+x[yb(f,1)>>2]&4095;j=((u<<4)+k|0)+4|0;v=m+x[yb(f,2)>>2]&4095;p=((v<<4)+k|0)+8|0;i=x[yb(f,3)>>2];g=x[yb(f,4)>>2]+n|0;w=i+m&4095;D=((w<<4)+k|0)+12|0;q=x[yb(f,5)>>2]+n|0;i=a+4232|0;I=a+69840|0;J=a+78032|0;m=d;while(1){if(m){u=u-1&4095;f=((u<<4)+k|0)+4|0;e=B[f>>2];K=g&1023;g=(K<<3)+I|0;r=B[g>>2];M=B[D>>2];N=B[p>>2];O=B[j>>2];P=B[o>>2];Q=B[z>>2];R=B[y>>2];F=B[yb(i,0)>>2];G=B[g+4>>2];j=yb(i,0);t=t-1&4095;o=(t<<4)+k|0;h=B[o>>2];H=B[j>>2];g=n<<3;j=g+I|0;l=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[j+4>>2]=l+E(e*E(-.6180340051651001));l=h;h=E(E(G*H)+E(h*E(-.6180340051651001)));B[j>>2]=l+E(h*E(.6180340051651001));B[o>>2]=e;B[f>>2]=h;w=w-1&4095;j=(w<<4)+k|0;D=j+12|0;e=B[D>>2];L=q&1023;p=(L<<3)+J|0;r=B[p>>2];F=B[yb(i,1)>>2];G=B[p+4>>2];S=yb(i,1);v=v-1&4095;q=(v<<4)+k|0;p=q+8|0;h=B[p>>2];H=B[S>>2];g=g+J|0;l=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[g+4>>2]=l+E(e*E(-.6180340051651001));l=h;h=E(E(G*H)+E(h*E(-.6180340051651001)));B[g>>2]=l+E(h*E(.6180340051651001));B[q+8>>2]=e;B[j+12>>2]=h;h=e;e=E(R+E(1.0000000031710769e-30));B[A>>2]=h+E(E(e*B[a+4224>>2])+B[o>>2]);h=E(Q+E(1.0000000031710769e-30));B[C>>2]=E(E(h*B[a+4224>>2])+B[f>>2])+B[j+12>>2];g=(s<<4)+k|0;l=e;e=B[a+4228>>2];r=E(l*e);T=g,U=E(r+E(E(B[o>>2]*B[yb(i,2)>>2])+E(P*B[yb(i,3)>>2]))),B[T>>2]=U;e=E(h*e);T=g,U=E(e+E(E(B[f>>2]*B[yb(i,4)>>2])+E(O*B[yb(i,5)>>2]))),B[T+4>>2]=U;T=g,U=E(E(E(B[q+8>>2]*B[yb(i,6)>>2])+E(N*B[yb(i,7)>>2]))-e),B[T+8>>2]=U;T=g,U=E(r+E(E(B[j+12>>2]*B[yb(i,8)>>2])+E(M*B[yb(i,9)>>2]))),B[T+12>>2]=U;m=m-1|0;C=C+4|0;A=A+4|0;z=z+4|0;y=y+4|0;q=L-1|0;g=K-1|0;n=n-1&1023;s=s-1&4095;j=f;continue}else{x[a+4300>>2]=n;x[a+4296>>2]=s;f=a;a=x[a+56>>2];Qi(f,b,c,Hc(a,0),Hc(a,1),d)}break}}}function Sz(a){a=a|0;var b=0,c=0,d=E(0),e=0;Tb(a+4960|0,0,76);v[a+5044|0]=0;x[a+5036>>2]=0;x[a+5040>>2]=0;b=x[a+4292>>2];d=B[a+4268>>2];x[31725]=0;e=a+4504|0;if(d<E(4294967296)&d>=E(0)){c=~~d>>>0}else{c=0}aa(979,e|0,67,5,c|0,b|0);b=x[31725];x[31725]=0;a:{if((b|0)==1){break a}b=x[a+4296>>2];x[31725]=0;aa(979,a+4528|0,62,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4300>>2];x[31725]=0;aa(979,a+4552|0,53,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4304>>2];x[31725]=0;aa(979,a+4576|0,43,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4308>>2];x[31725]=0;aa(979,a+4600|0,32,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4312>>2];x[31725]=0;aa(979,a+4624|0,22,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4316>>2];x[31725]=0;aa(979,a+4648|0,75,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4320>>2];x[31725]=0;aa(979,a+4672|0,69,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4324>>2];x[31725]=0;aa(979,a+4696|0,60,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4328>>2];x[31725]=0;aa(979,a+4720|0,48,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4332>>2];x[31725]=0;aa(979,a+4744|0,36,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4336>>2];x[31725]=0;aa(979,a+4768|0,25,5,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;aa(979,a+4792|0,0,0,0,0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4344>>2];x[31725]=0;aa(979,a+4816|0,3,0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+4348>>2];x[31725]=0;aa(979,a+4840|0,3,0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;aa(979,a+4864|0,407,1,c|0,0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;aa(979,a+4888|0,400,1,c|0,0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;aa(979,a+4912|0,10,0,c|0,-1);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;aa(979,a+4936|0,10,0,c|0,-1);c=x[31725];x[31725]=0;if((c|0)==1){break a}v[a+5045|0]=1;return}c=T(125e3)|0;if((gb|0)==($(125e3)|0)){Y(c|0)|0;v[a+5045|0]=0;Z();return}Q(c|0);p()}function eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=E(0),l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=E(0),w=0,z=0,A=0,C=0,D=0,G=0,H=E(0),I=0,J=0,K=0,L=0,M=0,N=E(0),O=0,P=E(0);a:{if(!x[a+4316>>2]){break a}if(!Ai(a+44|0)){break a}D=a+4300|0;G=a+4288|0;I=a+4264|0;J=a+4276|0;e=x[a+44>>2];r=Hc(e,0);s=Hc(e,1);e=x[a+56>>2];t=Hc(e,0);u=Hc(e,1);K=ib[x[x[a>>2]+196>>2]](a)|0;v=E(E(ib[x[x[a>>2]+204>>2]](a))/E(100));H=E(ib[x[x[a>>2]+192>>2]](a));w=ib[x[x[a>>2]+216>>2]](a)|0;L=w&1;o=x[a+4324>>2];l=x[a+4320>>2];m=x[a+4328>>2];j=x[a+4312>>2];M=x[a+4276>>2];p=x[a+4264>>2];z=x[a+4256>>2];A=y[a+4260|0];C=d;while(1){if(C){h=B[s>>2];k=B[r>>2];i=x[a+4316>>2];e=Do(i,j+z|0);i=Do(i,j);b:{if(A){O=yb(G,m),P=k,B[O>>2]=P;O=yb(D,m),P=h,B[O>>2]=P;q=yb(p,e);O=yb(p,i),P=E(E(B[q>>2]*v)+k),B[O>>2]=P;g=E(E(B[yb(M,e)>>2]*v)+h);e=J;break b}g=E(E(B[yb(p,e)>>2]*v)+E(E(k+h)*E(.5)));e=I}O=yb(x[e>>2],i),P=g,B[O>>2]=P;c:{if(K){f=B[a+4244>>2];g=E(f+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f+B[a+4240>>2]);B[a+4240>>2]=f;if(g>E(1)){g=E(g+E(-2));B[a+4236>>2]=g}if(f>E(1)){f=E(f+E(-2));B[a+4240>>2]=f}g=E(F(g));g=E(E(g+g)+E(-1));f=E(F(f));f=E(E(f+f)+E(-1));break c}f=B[a+4240>>2];n=B[a+4244>>2];g=E(E(f*n)+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f-E(g*n));B[a+4240>>2]=f}if(A){e=(m+2|0)%3|0;k=B[yb(G,e)>>2];h=B[yb(D,e)>>2]}e=x[a+4316>>2];i=yb(p,Do(e,j+l|0));q=e;e=j+4096|0;N=B[yb(p,Do(q,e+l|0))>>2];n=B[i>>2];B[t>>2]=E(E(E(E(E(N-n)*E(E(l&4095)*E(.000244140625)))+n)-k)*H)+k;l=x[(A?4276:4264)+a>>2];i=x[a+4316>>2];q=yb(l,Do(i,j+o|0));n=B[yb(l,Do(i,e+o|0))>>2];k=B[q>>2];B[u>>2]=E(E(E(E(E(n-k)*E(E(o&4095)*E(.000244140625)))+k)-h)*H)+h;m=((m|0)<=0?m+3|0:m)-1|0;x[a+4328>>2]=m;j=(((j|0)<=0?x[a+4316>>2]<<12:0)+j|0)-4096|0;x[a+4312>>2]=j;h=L?f:g;f=B[a+4248>>2];h=E(h*f);d:{if(E(F(h))<E(2147483648)){e=~~h;break d}e=-2147483648}o=(w>>>0>1?e:0-e|0)+z|0;x[a+4324>>2]=o;s=s+4|0;r=r+4|0;g=E(g*f);e:{if(E(F(g))<E(2147483648)){e=~~g;break e}e=-2147483648}l=(w>>>0<4?e:0-e|0)+z|0;x[a+4320>>2]=l;C=C-1|0;u=u+4|0;t=t+4|0;continue}else{e=a;a=x[a+56>>2];Qi(e,b,c,Hc(a,0),Hc(a,1),d)}break}}}function lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;y=x[a+16>>2];z=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;q=x[a+128>>2];if(q){i=x[a+8>>2];g=x[a+12>>2];r=Gg(i,g,q);s=hb;h=x[a+76>>2];hg(x[a>>2],x[a+4>>2],vf(i,g,d),hb);p=hb>>>0>h>>>0?d:0}else{p=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;p=p-1|0;h=p;r=h?r:0;s=h?s:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=q;while(1)if((b|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;be(j,(w[(b<<1|2)+i>>1]+w[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);ae(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Eg(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];t=x[a+68>>2];E=t>>31;i=x[a+64>>2];F=i>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;v=e<<8;e=v;e=ova(h,G,e,e>>31);l=hb;m=e;e=Yb(k,-16777216,16776704);e=ova(i,F,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Yb(H,-16777216,16776704);l=ova(t,E,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Rc(l,e,24);x[g+4>>2]=e-(v&C);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];o=x[a+28>>2]+o|0;x[c>>2]=x[c>>2]+D(x[f>>2],o>>12);n=b+n|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],n>>12);Pb(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;be(j,(w[(g<<1|2)+i>>1]+w[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);ae(j,4);Pb(f+40|0,r,s);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function qma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;u=x[a+16>>2];w=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;p=x[a+128>>2];if(p){k=x[a+8>>2];g=x[a+12>>2];q=Gg(k,g,p);r=hb;h=x[a+76>>2];hg(x[a>>2],x[a+4>>2],vf(k,g,d),hb);o=hb>>>0>h>>>0?d:0}else{o=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;o=o-1|0;h=o;q=h?q:0;r=h?r:0;k=(((g&2147483647)<<1|b>>>31)&-2)+u|0;g=p;a:{b:while(1){c:{if((g|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){be(j,i>>>3<<16>>16);ae(j,4);Pb(f+40|0,q,r);g=g-1|0;continue b}else{i=(v[k+(b+h|0)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b+g|0)|0]<<8)+i|0;b=b+1|0;continue}break}be(j,i>>>3<<16>>16);ae(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Eg(j,w);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;t=e<<8;e=t;e=ova(h,G,e,e>>31);m=hb;n=e;e=Yb(l,-16777216,16776704);e=ova(k,F,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Yb(H,-16777216,16776704);m=ova(i,E,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Rc(m,e,24);x[g+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],y);Pb(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function OQ(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;a:{b:{c:{if(!mn(f,g,h,i,0,0,0,0)){break c}l=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){k=4;if(n){break e}k=f|h|(g|l)?3:2;break d}k=!(f|h|(g|l))}}s=e>>>16|0;o=s&32767;if((o|0)==32767){break c}if(k){break b}}Vd(j+16|0,b,c,d,e,f,g,h,i);b=x[j+16>>2];d=x[j+20>>2];e=x[j+24>>2];c=x[j+28>>2];tR(j,b,d,e,c,b,d,e,c);d=x[j+8>>2];e=x[j+12>>2];h=x[j>>2];i=x[j+4>>2];break a}k=d;p=e&2147483647;n=h;m=i&2147483647;if((mn(b,c,k,p,f,g,h,m)|0)<=0){if(mn(b,c,k,p,f,g,n,m)){h=b;i=c;break a}Vd(j+112|0,b,c,d,e,0,0,0,0);d=x[j+120>>2];e=x[j+124>>2];h=x[j+112>>2];i=x[j+116>>2];break a}q=i>>>16&32767;if(o){i=c;h=b}else{Vd(j+96|0,b,c,k,p,0,0,0,1081540608);k=x[j+104>>2];h=x[j+108>>2];p=h;o=(h>>>16|0)-120|0;i=x[j+100>>2];h=x[j+96>>2]}if(!q){Vd(j+80|0,f,g,n,m,0,0,0,1081540608);n=x[j+88>>2];f=x[j+92>>2];m=f;q=(f>>>16|0)-120|0;g=x[j+84>>2];f=x[j+80>>2]}r=n;t=m&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;f:{if((l|0)>0|(l|0)>=0){k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(!(h|n|(i|l))){Vd(j+32|0,b,c,d,e,0,0,0,0);d=x[j+40>>2];e=x[j+44>>2];h=x[j+32>>2];i=x[j+36>>2];break a}l=l<<1|n>>>31;k=n<<1|i>>>31;break f}l=p<<1|k>>>31;k=k<<1|i>>>31}p=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((o|0)>(q|0)){continue}break}o=q}m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;m=l;g:{if((l|0)<0){n=k;m=p;break g}k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(h|n|(i|m)){break g}Vd(j+48|0,b,c,d,e,0,0,0,0);d=x[j+56>>2];e=x[j+60>>2];h=x[j+48>>2];i=x[j+52>>2];break a}if((m|0)==65535|m>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m<<1|n>>>31;n=c|n<<1;m=b;if(b>>>0<65536){continue}break}}b=s&32768;if((o|0)<=0){Vd(j- -64|0,h,i,n,m&65535|(b|o+120)<<16,0,0,0,1065811968);d=x[j+72>>2];e=x[j+76>>2];h=x[j+64>>2];i=x[j+68>>2];break a}d=n;e=m&65535|(b|o)<<16}x[a>>2]=h;x[a+4>>2]=i;x[a+8>>2]=d;x[a+12>>2]=e;fb=j+128|0}function Toa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-112|0;fb=d;a:{b:{c:{d:{switch(y[a|0]-23|0){case 0:e=v[a+1|0];f=d,g=GD(c,+y[a+2|0]*1e4/240),v[f+12|0]=g;x[d+88>>2]=127;x[d+76>>2]=(D(y[a+3|0],127)>>>0)/185;f=d,g=x[ud(d+88|0,d+76|0)>>2],v[f+111|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:lw(d+76|0,15638);x[31725]=0;O(560,d- -64|0,d+12|0);a=x[31725];x[31725]=0;f:{g:{h:{i:{if((a|0)!=1){x[31725]=0;O(560,d+52|0,d+111|0);a=x[31725];x[31725]=0;if((a|0)==1){break i}x[31725]=0;V(561,d+88|0,d+76|0,d- -64|0,d+52|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}a=d+88|0;ee(d+100|0,a);sf(b,x[d+100>>2],x[d+104>>2]);tb(a);tb(d+52|0);tb(d- -64|0);Eb(d+76|0);break b}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;case 1:lw(d+76|0,15585);x[31725]=0;O(560,d- -64|0,d+12|0);a=x[31725];x[31725]=0;j:{k:{l:{m:{if((a|0)!=1){x[31725]=0;O(560,d+52|0,d+111|0);a=x[31725];x[31725]=0;if((a|0)==1){break m}x[31725]=0;V(561,d+88|0,d+76|0,d- -64|0,d+52|0);a=x[31725];x[31725]=0;if((a|0)==1){break l}a=d+88|0;ee(d+44|0,a);sf(b,x[d+44>>2],x[d+48>>2]);tb(a);tb(d+52|0);tb(d- -64|0);Eb(d+76|0);break b}a=N()|0;break j}a=N()|0;break k}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;default:break e}}a=qc(d+36|0,15665);sf(b,x[a>>2],x[a+4>>2]);break b;case 1:break d;default:break a}}c=v[a+1|0];v[d+111|0]=(c|0)<5?c:0;c=v[a+2|0];v[d+35|0]=(c|0)<0?127:c;a=v[a+3|0];v[d+34|0]=(a|0)<0?127:a;a=fb-16|0;fb=a;c=Dc(a+4|0,4048);_c(d+76|0,c);tb(c);fb=a+16|0;x[31725]=0;O(560,d- -64|0,d+111|0);a=x[31725];x[31725]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){x[31725]=0;O(560,d+52|0,d+35|0);a=x[31725];x[31725]=0;if((a|0)==1){break s}x[31725]=0;O(560,d+12|0,d+34|0);a=x[31725];x[31725]=0;if((a|0)==1){break r}x[31725]=0;aa(742,d+88|0,d+76|0,d- -64|0,d+52|0,d+12|0);a=x[31725];x[31725]=0;if((a|0)==1){break q}a=d+88|0;ee(d+24|0,a);sf(b,x[d+24>>2],x[d+28>>2]);tb(a);tb(d+12|0);tb(d+52|0);tb(d- -64|0);Eb(d+76|0);break b}a=N()|0;break n}a=N()|0;break o}a=N()|0;break p}a=N()|0;tb(d+12|0)}tb(d+52|0)}tb(d- -64|0)}}Eb(d+76|0);Q(a|0);p()}e=1}fb=d+112|0;return e|0}function ora(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-16|0;fb=f;a:{b:{if(!c){break b}n=f,o=Zd(a),v[n+8|0]=o;vo(b,f+8|0);j=c-1|0;while(1){e=1;if(!j){break a}c:{c=g<<1&254;d:{if(!c){if(!Af(a,f+8|0)){break b}d=y[f+8|0]<<1|1;c=d&255;if(d>>>0<256){break d}break c}if((g&65535)>>>0>127){break c}}if(!Af(a,f+8|0)){break b}f$(b,f+8|0);j=j-1|0;g=c;continue}e=1;while(1){e:{f:{g:{g=c<<1&254;if(g){c=(c&65535)>>>0>127}else{if(!Af(a,f+8|0)){break g}c=y[f+8|0]<<1|1;g=c&255;c=c>>>0>255}e=mr(e,1)+c|0;c=g<<1&254;if(c){break f}if(!Af(a,f+8|0)){break g}d=y[f+8|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}c=0;break e}if(g>>>0>127){continue}}break}h:{if((e|0)<=2){h=0;d=e-2|0;break h}if(!Af(a,f+8|0)){break b}d=mr(e-3|0,8)|y[f+8|0];h=((d|0)>1279?2:1)+((d|0)>31999)|0;l=d^-1;d=0}e=c<<1&254;if(e){c=c>>>0>127}else{if(!Af(a,f+8|0)){break b}c=y[f+8|0]<<1|1;e=c&255;c=c>>>0>255}i=mr(d,1);g=e<<1&254;if(g){d=e>>>0>127}else{if(!Af(a,f+8|0)){break b}d=y[f+8|0]<<1|1;g=d&255;d=d>>>0>255}e=1;c=mr(c+i|0,1)+d|0;if(!c){while(1){i:{j:{k:{c=g<<1&254;if(c){d=(g&65535)>>>0>127}else{if(!Af(a,f+8|0)){break k}d=y[f+8|0]<<1|1;c=d&255;d=d>>>0>255}e=mr(e,1)+d|0;g=c<<1&254;if(g){break j}if(!Af(a,f+8|0)){break k}c=y[f+8|0]<<1|1;g=c&255;if(c>>>0>255){continue}break i}g=0;break i}if(c>>>0>127){continue}}break}c=e+2|0}d=c+h|0;e=0;if(d>>>0>j>>>0|(d|0)<=0|(l|0)>=0){break a}c=x[b+4>>2];e=0;if((0-Sc(x[b>>2],c)|0)>(l|0)){break a}c=vb(f+12|0,wb(c));v[f+8|0]=0;i=f+8|0;m=fb-32|0;fb=m;e=x[c>>2];c=x[b>>2];h=Hk(e,wb(c))+c|0;c=x[zb(b)>>2];k=x[b+4>>2];l:{if(d>>>0<=c-k>>>0){c=d;e=k-h|0;if(c>>>0>e>>>0){Hp(b,d-e|0,i);c=e;if(!c){break l}}h$(b,h,k,d+h|0);Vh(h,c,i+(h>>>0<=i>>>0?i>>>0<A[b+4>>2]?d:0:0)|0);break l}c=zb(b);c=wn(m+12|0,cm(b,Sc(x[b>>2],k)+d|0),h-x[b>>2]|0,c);uZ(c,d,i);h=g$(b,c,h);un(c)}wb(h);fb=m+32|0;n=f,o=Pe(YC(wb(x[b+4>>2]),d),l),x[n+8>>2]=o;n=f,o=YC(wb(x[b+4>>2]),d),x[n+4>>2]=o;c=d;while(1){e=y[AY(f+8|0)|0];n=AY(f+4|0),o=e,v[n|0]=o;e=c>>>0>1;c=c-1|0;if(e){continue}break}j=j-d|0;continue}}e=0}fb=f+16|0;return e|0}
function yP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-112|0;fb=d;f=x[b+4>>2];a:{if(!f){break a}e=x[b>>2];h=y[Il(e,f)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}Ul(d+88|0,e,f,f-1|0);f=x[d+92>>2];e=x[d+88>>2];x[b>>2]=e;x[b+4>>2]=f}h=d+88|0;ge(h);e=x[d+88>>2];ge(d+76|0);e=Hl(e,x[d+80>>2],b);ge(h);b:{c:{d:{e:{if((e|0)==x[d+92>>2]){a=x[b>>2];e=qc(d+104|0,22255);h=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=h;if(Ic(a,f,d)){a=ac(8);x[31725]=0;c=P(36,d+88|0,10482)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}g=0;if(!c){break e}c=ac(8);a=x[b+4>>2];b=x[b>>2];x[31725]=0;f=gi(d+76|0,b,a);a=x[31725];x[31725]=0;f:{g:{h:{if((a|0)!=1){x[31725]=0;S(1017,d+88|0,18282,f|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}pc(c,d+88|0);a=0;x[31725]=0;S(99,c|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;tb(d+88|0);break g}b=N()|0;break f}b=N()|0;a=1}tb(f);if(!a){break c}}jc(c);break c}if(x[e+4>>2]!=2){a=ac(8);x[31725]=0;c=P(36,d+88|0,11584)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}b=x[b>>2];c=qc(d+68|0,22255);e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Ic(b,f,d+32|0)){a=ac(8);x[31725]=0;c=P(36,d+88|0,10482)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=qc(d+60|0,7759);e=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=e;if(Ic(b,f,d+24|0)){g=1;if(!Ed(y[a+28|0])){break e}g=65536/+A[x[a+24>>2]+480244>>2];break e}c=qc(d+52|0,7811);e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;if(Ic(b,f,d+16|0)){g=1;if(!Ed(y[a+28|0])){break e}g=+A[x[a+24>>2]+480240>>2]*152587890625e-16;break e}c=qc(d+44|0,7829);e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;g=0;if(!Ic(b,f,d+8|0)){break e}g=+A[x[a+24>>2]+480236>>2]*152587890625e-16}fb=d+112|0;return+g}b=N()|0;jc(a)}Q(b|0)}p()}function Sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}u=b+196648|0;break a}u=b+131112|0;break a}u=b+262184|0}A=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+32>>2];C=x[a+28>>2];E=x[a+72>>2];z=x[a+68>>2];F=z>>31;l=x[a+64>>2];G=l>>31;j=x[a+60>>2];H=j>>31;while(1){if(d){b=x[f+16>>2];v=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+A|0;b=(b>>>16&65520)+u|0;m=w[b+14>>1];s=w[b+12>>1];t=w[b+10>>1];y=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];q=0;r=0;while(1){if((r|0)!=2){k=v+(r<<1)|0;x[(f+8|0)+(r<<2)>>2]=(((((((D(w[k-8>>1],e)+D(w[k-12>>1],b)|0)+D(w[k-4>>1],i)|0)+D(w[k>>1],g)|0)+D(w[k+4>>1],y)|0)+D(w[k+8>>1],t)|0)+D(s,w[k+12>>1])|0)+D(m,w[k+16>>1])|0)/32768;r=r+1|0;continue}break}while(1){if((q|0)!=2){t=(f+8|0)+(q<<2)|0;e=x[t>>2];b=(f+28|0)+(q<<3)|0;y=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;s=e<<8;e=s;e=ova(j,H,e,e>>31);i=hb;v=e;e=Yb(g,-16777216,16776704);e=ova(l,G,e,e>>31);g=v+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Yb(y,-16777216,16776704);i=ova(z,F,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[b+4>>2]=e-(s&E);x[t>>2]=(e|0)/256;q=q+1|0;continue}break}p=p+C|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],p>>12);o=o+B|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],o>>12);Pb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Npa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;d=c+4|0;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+56;a=x[d+4>>2];x[31725]=0;O(684,a|0,b|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){x[d+4>>2]=x[d+4>>2]+56;hc(d);fb=c+16|0;break a}a=N()|0;hc(d);Q(a|0);p()}return}k=fb-32|0;fb=k;j=zb(a);d=k+12|0;e=yv(x[a>>2],x[a+4>>2])+1|0;h=fb-16|0;fb=h;x[h+12>>2]=e;f=fb-16|0;fb=f;x[f+12>>2]=76695844;x[f+8>>2]=2147483647;c=x[Gb(f+12|0,f+8|0)>>2];fb=f+16|0;b:{if(c>>>0>=e>>>0){e=AX(a);if(e>>>0<c>>>1>>>0){x[h+8>>2]=e<<1;c=x[ad(h+8|0,h+12|0)>>2]}fb=h+16|0;break b}dd();p()}f=yv(x[a>>2],x[a+4>>2]);h=fb-16|0;fb=h;Kg(d+12|0,j);c:{if(!c){c=0;break c}if(c>>>0>=76695845){bk();p()}e=Ec(D(c,56));x[h+12>>2]=c;x[h+8>>2]=e;i=x[h+12>>2];c=x[h+8>>2]}x[d>>2]=c;e=c+D(f,56)|0;x[d+8>>2]=e;x[d+4>>2]=e;l=nc(d),m=c+D(i,56)|0,x[l>>2]=m;fb=h+16|0;c=x[d+8>>2];x[31725]=0;O(684,c|0,b|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[d+8>>2]=x[d+8>>2]+56;h=fb-16|0;fb=h;f=zb(a);e=vb(h+12|0,x[a+4>>2]);c=vb(h+8|0,x[a>>2]);b=vb(h+4|0,x[d+4>>2]);i=x[e>>2];c=x[c>>2];g=fb+-64|0;fb=g;b=x[b>>2];x[g+56>>2]=b;x[g+60>>2]=i;x[g+52>>2]=b;e=Se(g+24|0,f,g+52|0,g+56|0);x[g+16>>2]=x[e+8>>2];b=x[e+4>>2];x[g+8>>2]=x[e>>2];x[g+12>>2]=b;Re(g+36|0,g+8|0);while(1){if(pd(i,c)){b=xX(x[g+56>>2]);f=BX(i);e=$l(b,f);$l(e+12|0,f+12|0);AC(e+24|0,f+24|0);w[e+52>>1]=z[f+52>>1];b=x[f+48>>2];x[e+44>>2]=x[f+44>>2];x[e+48>>2]=b;b=x[f+40>>2];x[e+36>>2]=x[f+36>>2];x[e+40>>2]=b;b=yX(g+60|0);yX(g+56|0);i=x[b>>2];continue}break}Qe(g+36|0);e=x[g+56>>2];if(!y[g+48|0]){j=fb-16|0;fb=j;c=vb(j+12|0,x[x[g+44>>2]>>2]);b=x[vb(j+8|0,x[x[g+40>>2]>>2])>>2];f=fb-16|0;fb=f;i=x[c>>2];x[f+12>>2]=i;while(1){if(di(i,b)){c=fb-16|0;fb=c;x[c+12>>2]=i;x[c+12>>2]=x[c+12>>2]+56;fb=c+16|0;hr(xX(x[c+12>>2]));c=f+12|0;x[c>>2]=x[c>>2]+56;i=x[c>>2];continue}break}fb=f+16|0;fb=j+16|0}fb=g- -64|0;x[d+4>>2]=e;Ub(a,d+4|0);Ub(a+4|0,d+8|0);Ub(zb(a),nc(d));x[d>>2]=x[d+4>>2];fb=h+16|0;zX(d);fb=k+32|0;break d}a=N()|0;zX(d);Q(a|0);p()}}function Tma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}u=b+196648|0;break a}u=b+131112|0;break a}u=b+262184|0}B=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;C=x[a+32>>2];E=x[a+28>>2];F=x[a+72>>2];A=x[a+68>>2];G=A>>31;l=x[a+64>>2];H=l>>31;j=x[a+60>>2];I=j>>31;while(1){if(d){b=x[f+16>>2];y=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+B|0;b=(b>>>16&65520)+u|0;m=w[b+14>>1];s=w[b+12>>1];t=w[b+10>>1];z=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];q=0;r=0;while(1){if((r|0)!=2){k=r+y|0;x[(f+8|0)+(r<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],i)|0)+D(v[k|0],g)|0)+D(v[k+2|0],z)|0)+D(v[k+4|0],t)|0)+D(s,v[k+6|0])|0)+D(m,v[k+8|0])<<8)/32768;r=r+1|0;continue}break}while(1){if((q|0)!=2){t=(f+8|0)+(q<<2)|0;e=x[t>>2];b=(f+28|0)+(q<<3)|0;z=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;s=e<<8;e=s;e=ova(j,I,e,e>>31);i=hb;y=e;e=Yb(g,-16777216,16776704);e=ova(l,H,e,e>>31);g=y+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Yb(z,-16777216,16776704);i=ova(A,G,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[b+4>>2]=e-(s&F);x[t>>2]=(e|0)/256;q=q+1|0;continue}break}p=p+E|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],p>>12);o=o+C|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],o>>12);Pb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function ye(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;e=x[a>>2];a:{if(lc(e,x[a+4>>2])){break a}f=x[b+4>>2];if(f>>>0>=A[a+12>>2]){break a}i=z[b+8>>1];j=x[x[a+48>>2]+12>>2];c=z[j+480188>>1];if(i>>>0>=c>>>0&(i|0)!=65535){break a}d=c-1|0;c=(i|0)==65535;l=c?d:i;c=c?0:i;e=jd(e,j,f,c);g=y[b+12|0];k=g&4;b:{c:{if(g&2){break c}i=y[b+10|0];f=e;d=c;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!k){if((i|0)!=y[f+3|0]){break d}break b}if((i|0)==y[f+2|0]){break b}}f=f+6|0;d=d+1|0;continue}}i=l&65535;d=e;f=c;while(1){if(i>>>0>=(f&65535)>>>0){e:{if(!k){if(y[d+3|0]){break e}v[d+3|0]=y[b+10|0];v[d+5|0]=y[b+11|0];break b}if(y[d+2|0]){break e}v[d+2|0]=y[b+10|0];v[d+4|0]=y[b+11|0];break b}d=d+6|0;f=f+1|0;continue}break}f:{if(!(g&1)){break f}d=x[j+480180>>2]&2;g:{h:{i:{if(!k){while(1){if((c&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(y[e+3|0]-9|0){case 4:if(!Wv(x[x[j+8>>2]+88>>2],1)){break j}d=1;v[e+2|0]=1;v[e+4|0]=y[e+5|0];v[e+3|0]=y[b+10|0];v[e+5|0]=y[b+11|0];break a;case 0:break k;default:break j}}l:{if(d){f=y[e+5|0];if(f>>>0>128){break j}v[e+2|0]=2;v[e+3|0]=y[b+10|0];a=1;break l}v[e+2|0]=2;v[e+3|0]=y[b+10|0];f=y[e+5|0];a=2}v[e+4|0]=a+(f&255)>>>a;v[e+5|0]=y[b+11|0];break b}e=e+6|0;c=c+1|0;continue}break}if(!k){break i}}f=y[b+11|0];c=13;m:{switch(y[b+10|0]-1|0){case 1:c=9;f=zi(f<<(d?1:2));break;case 0:break m;default:break g}}v[b+11|0]=f;v[b+10|0]=c;g=g&254;break h}v[h+15|0]=0;v[h+14|0]=0;e=b;c=y[b+10|0];n:{if(!(!d|(c|0)!=9)){c=y[b+11|0];if(c>>>0>128){break g}d=2;c=c>>>1|0;break n}f=h+12|0;qw(f,c,y[b+11|0],1);c=h+4|0;VD(c,h+15|0,h+14|0);UD(c,f);g=y[b+12|0];d=y[h+15|0];if(!d){break g}c=y[h+14|0]}v[e+11|0]=c;v[b+10|0]=d;g=g&254}v[b+12|0]=g}d=1;if(g&1){break f}v[b+12|0]=g^4;if(ye(a,b)){break a}}d=0;o:{p:{switch(x[b>>2]-1|0){case 0:c=x[b+4>>2]+1|0;if(c>>>0>=A[a+12>>2]){break a}x[b+4>>2]=c;break o;case 1:break p;default:break a}}c=x[b+4>>2];if(!c){break a}x[b+4>>2]=c-1}v[b+12|0]=y[b+12|0]|1;d=ye(a,b);break a}d=1}fb=h+16|0;return d}function BU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;c=fb-176|0;fb=c;i=1;p=2;d=x[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;v=D(i,3);w=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=x[a+12>>2];continue a}d=x[a>>2];e=Xd(d,h<<1);NR(c+160|0,C[e>>3],C[e+8>>3]);d=Xd(d,h);NR(c+144|0,C[d>>3],C[d+8>>3]);Ti(c+128|0,C[c+144>>3],C[c+152>>3],C[c+160>>3],C[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=x[b>>2];e=Xd(f,d);g=e+8|0;j=x[g+4>>2];x[c+120>>2]=x[g>>2];x[c+124>>2]=j;g=x[e+4>>2];x[c+112>>2]=x[e>>2];x[c+116>>2]=g;k=d+i|0;g=Xd(f,k);n=C[g+8>>3];o=C[g>>3];r=d+w|0;g=Xd(f,r);j=x[g+12>>2];x[c+104>>2]=x[g+8>>2];x[c+108>>2]=j;j=x[g+4>>2];x[c+96>>2]=x[g>>2];x[c+100>>2]=j;s=d+v|0;f=Xd(f,s);t=C[f+8>>3];u=C[f>>3];g=c+80|0;f=c+112|0;Ml(g,f,o,n);j=c- -64|0;Gj(j,f,o,n);l=c+96|0;Ml(c+48|0,l,u,t);f=c+16|0;Gj(f,l,u,t);Ti(c+32|0,0,1,C[c+16>>3],C[c+24>>3]);Ml(f,g,C[c+48>>3],C[c+56>>3]);l=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=l;l=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=l;Ml(c,j,C[c+32>>3],C[c+40>>3]);Ti(f,C[c+160>>3],C[c+168>>3],C[c>>3],C[c+8>>3]);e=Xd(x[b>>2],k);k=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=k;k=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=k;Gj(c,g,C[c+48>>3],C[c+56>>3]);Ti(f,C[c+144>>3],C[c+152>>3],C[c>>3],C[c+8>>3]);e=Xd(x[b>>2],r);g=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=g;Gj(c,j,C[c+32>>3],C[c+40>>3]);Ti(f,C[c+128>>3],C[c+136>>3],C[c>>3],C[c+8>>3]);e=Xd(x[b>>2],s);f=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=f;f=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=x[b>>2];a=Xd(h,d+i|0);m=Xd(h,d);n=C[a>>3];o=C[a+8>>3];Gj(c+160|0,m,n,o);h=x[c+172>>2];x[a+8>>2]=x[c+168>>2];x[a+12>>2]=h;h=x[c+164>>2];x[a>>2]=x[c+160>>2];x[a+4>>2]=h;yA(Xd(x[b>>2],d),n,o);d=d+1|0;continue}}fb=c+176|0}function pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;u=x[a+16>>2];v=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;o=x[a+128>>2];if(o){i=x[a+8>>2];g=x[a+12>>2];p=Gg(i,g,o);q=hb;h=x[a+76>>2];hg(x[a>>2],x[a+4>>2],vf(i,g,d),hb);n=hb>>>0>h>>>0?d:0}else{n=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;n=n-1|0;h=n;p=h?p:0;q=h?q:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+u|0;b=o;while(1)if((b|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;be(j,(w[(b<<1|2)+i>>1]+w[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);ae(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Eg(j,v);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];r=x[a+68>>2];E=r>>31;i=x[a+64>>2];F=i>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;t=e<<8;e=t;e=ova(h,G,e,e>>31);l=hb;m=e;e=Yb(k,-16777216,16776704);e=ova(i,F,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Yb(H,-16777216,16776704);l=ova(r,E,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Rc(l,e,24);x[g+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(y,x[f+4>>2]);Pb(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;be(j,(w[(g<<1|2)+i>>1]+w[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);ae(j,4);Pb(f+40|0,p,q);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function psa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,j=E(0);d=fb-96|0;fb=d;c=fb-16|0;fb=c;e=b+16|0;qZ(c+8|0,e);f=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((f|0)!=(g|0)){Tb(e,0,128)}v[b+79|0]=0;v[b+143|0]=0;x[b+152>>2]=-2147483648;x[b+156>>2]=-2147483648;c=d+56|0;fe(c,a,Pg(a));f=ic(d+76|0,c);ub(c);x[31725]=0;c=R(204,f|0)|0;e=x[31725];x[31725]=0;a:{b:{if((e|0)==1){break b}x[31725]=0;O(289,b+4|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}oe(d+48|0,x[b+4>>2],x[b+8>>2]);x[31725]=0;co(473,d+56|0,f,x[d+48>>2],x[d+52>>2]);c=x[31725];x[31725]=0;if((c|0)!=1){x[31725]=0;c=R(153,a|0)|0;e=x[31725];x[31725]=0;c:{if((e|0)==1){break c}x[31725]=0;S(187,d+28|0,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}a=d+28|0;c=ic(d+56|0,a);ub(a);a=x[c>>2];x[31725]=0;a=R(174,a|0)|0;e=x[31725];x[31725]=0;d:{if((e|0)!=1){e:{f:{g:{if(!a){break g}while(1){a=x[c+8>>2];e=x[c>>2];x[31725]=0;a=U(152,e|0,a|0,5)|0;e=x[31725];x[31725]=0;if((e|0)==1){break f}if(!a){break g}x[31725]=0;P(474,c|0,d+24|0)|0;a=x[31725];x[31725]=0;h:{if((a|0)!=1){a=4;e=y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24);if((e|0)==1414682436|(e|0)==1196380752){break h}x[31725]=0;a=R(153,c|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break h}a=N()|0;break d}a=N()|0;break d}x[31725]=0;S(187,d+4|0,c|0,a|0);a=x[31725];x[31725]=0;i:{j:{if((a|0)!=1){a=d+4|0;e=ic(d+28|0,a);ub(a);if((y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24))!=1414682436){break j}x[31725]=0;h=E(xa(475,e|0));a=x[31725];x[31725]=0;if((a|0)==1){break e}i=b,j=Pd(h,E(0)),B[i+144>>2]=j;break i}a=N()|0;break d}if((y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24))!=1196380752){break i}x[31725]=0;a=R(153,e|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break e}x[b+148>>2]=a}ub(e);continue}}ub(c);ub(f);fb=d+96|0;return}a=N()|0;break d}a=N()|0;ub(e);break d}a=N()|0}ub(c);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0}ub(f);Q(a|0);p()}function o8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-16|0;fb=j;k=Oy(x[g>>2]);o=uy(x[g>>2]);th(j+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[31725]=0;g=P(1234,k|0,g<<24>>24)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[31725]=0;g=P(1234,k|0,48)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;g=v[i+1|0];x[31725]=0;g=P(1234,k|0,g|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Od();if(!SK(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Od();if(!Oh(h)){break d}g=g+1|0;continue}}e:{if(Ad(x[j+8>>2],y[j+15|0])){h=x[f>>2];x[31725]=0;V(1228,k|0,i|0,g|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i<<2);break e}Im(i,g);x[31725]=0;r=R(1226,o|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){jt((i-a<<2)+d|0,x[f>>2]);break e}f:{if(v[cc(j+4|0,l)|0]<=0){break f}if(v[cc(j+4|0,l)|0]!=(m|0)){break f}m=x[f>>2];x[f>>2]=m+4;x[m>>2]=r;l=(Cb(x[j+8>>2],y[j+15|0])-1>>>0>l>>>0)+l|0;m=0}q=v[h|0];x[31725]=0;q=P(1234,k|0,q|0)|0;n=x[31725];x[31725]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+4;x[n>>2]=q;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=y[g|0];if((i|0)==46){x[31725]=0;i=R(1229,o|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}l=x[f>>2];h=l+4|0;x[f>>2]=h;x[l>>2]=i;g=g+1|0;break g}x[31725]=0;i=P(1234,k|0,i<<24>>24)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;g=g+1|0;continue}break}h=x[f>>2]}x[31725]=0;V(1228,k|0,g|0,c|0,h|0);i=x[31725];x[31725]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g<<2)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;tb(j+4|0);fb=j+16|0;return}a=N()|0;tb(j+4|0);Q(a|0);p()}function Qi(a,b,c,d,e,f){var g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=E(0),o=E(0),p=E(0),q=0,r=E(0);m=ib[x[x[a>>2]+140>>2]](a)|0;g=x[a+20>>2];h=m?h:y[g+25|0];j=B[g+144>>2];k=E(1);if(!(ib[x[x[a>>2]+140>>2]](a)|0)){k=B[x[a+20>>2]+144>>2]}j=E(E(1)-j);a:{if((ib[x[x[a>>2]+156>>2]](a)|0)<=0){break a}if(!EQ(y[x[a+20>>2]+24|0])){break a}j=E(E(j+j)+E(-1));k=E(-j)}n=B[a+4196>>2];k=E(k*n);j=E(j*n);g=0;l=x[a+44>>2];m=Hc(l,0);l=Hc(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;B[i>>2]=B[i>>2]+E(E(B[d+g>>2]*j)+E(k*B[g+m>>2]));i=c+g|0;B[i>>2]=B[i>>2]+E(E(B[e+g>>2]*j)+E(k*B[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[h+m>>2]-E(B[d+h>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]+E(B[h+l>>2]-E(B[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[d+h>>2]-E(B[h+m>>2]*k));i=c+h|0;B[i>>2]=B[i>>2]+E(B[e+h>>2]-E(B[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]-E(B[d+h>>2]-E(B[h+m>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]-E(B[e+h>>2]-E(B[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=B[i>>2];q=i;r=k;n=B[h+m>>2];i=c+h|0;o=B[i>>2];p=B[h+l>>2];k=E(E(E(E(k+n)+o)+p)*E(.5));B[q>>2]=r-E(E(k+E(k-E(B[d+h>>2]*j)))-n);B[i>>2]=o-E(E(k+E(k-E(B[e+h>>2]*j)))-p);g=g+1|0;continue}}g=EQ(y[x[a+20>>2]+24|0]);j=g?E(j*E(.5)):j;k=g?E(k*E(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=E(B[d+g>>2]-B[g+m>>2]);o=E(B[g+l>>2]-B[e+g>>2]);B[i>>2]=B[i>>2]+E(E(j*n)+E(k*o));g=c+g|0;B[g>>2]=B[g>>2]+E(E(k*n)+E(j*o));h=h+1|0;continue}}i:{if(!((y[x[a+20>>2]+24|0]&4)>>>2|0)){break i}if(ib[x[x[a>>2]+140>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;B[d>>2]=B[a+m>>2]+B[d>>2];d=a+c|0;B[d>>2]=B[a+l>>2]+B[d>>2];g=g+1|0;continue}}}function DK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=x[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=x[d>>2];if(!g){break l}if(!a){d=c;break j}x[d>>2]=0;d=c;break k}m:{if(!x[x[124231]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=v[e|0];if(d){x[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}x[a>>2]=0;x[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return Cf(e)}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=y[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}f=e+1|0;n:{if(!(g&33554432)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+2|0;if(!(g&524288)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=y[e|0];o:{if(e&3|g-1>>>0>126){break o}g=x[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=x[e+4>>2];e=e+4|0;if(!((g-16843009|g)&-2139062144)){continue}break}}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+111520>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=y[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=x[e>>2];if((g|g-16843009)&-2139062144){break s}x[a>>2]=g&255;x[a+4>>2]=y[e+1|0];x[a+8>>2]=y[e+2|0];x[a+12>>2]=y[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=y[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}x[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+111520>>2];f=1;continue}i=y[e|0];f=i>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{h=e+1|0;f=i-128|g<<6;v:{if((f|0)>=0){break v}i=y[h|0]-128|0;if(i>>>0>63){break u}h=e+2|0;f=i|f<<6;if((f|0)>=0){break v}h=y[h|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;x[a>>2]=f;d=d-1|0;a=a+4|0;break t}x[31600]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=y[e|0]}if(g&255){break d}if(a){x[a>>2]=0;x[b>>2]=0}return c-d|0}x[31600]=25;if(!a){break b}}x[b>>2]=e}return-1}x[b>>2]=e;return c}function y8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-16|0;fb=j;k=Aw(x[g>>2]);o=By(x[g>>2]);th(j+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[31725]=0;g=P(29,k|0,g<<24>>24)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[31725]=0;g=P(29,k|0,48)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;g=v[i+1|0];x[31725]=0;g=P(29,k|0,g|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Od();if(!SK(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Od();if(!Oh(h)){break d}g=g+1|0;continue}}e:{if(Ad(x[j+8>>2],y[j+15|0])){h=x[f>>2];x[31725]=0;V(1215,k|0,i|0,g|0,h|0);h=x[31725];x[31725]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i|0);break e}Im(i,g);x[31725]=0;r=R(1213,o|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Im((i-a|0)+d|0,x[f>>2]);break e}f:{if(v[cc(j+4|0,m)|0]<=0){break f}if(v[cc(j+4|0,m)|0]!=(l|0)){break f}l=x[f>>2];x[f>>2]=l+1;v[l|0]=r;m=(Cb(x[j+8>>2],y[j+15|0])-1>>>0>m>>>0)+m|0;l=0}q=v[h|0];x[31725]=0;q=P(29,k|0,q|0)|0;n=x[31725];x[31725]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+1;v[n|0]=q;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=y[g|0];if((i|0)!=46){break g}x[31725]=0;i=R(1216,o|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0}i=x[f>>2];x[31725]=0;V(1215,k|0,g|0,c|0,i|0);i=x[31725];x[31725]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g|0)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;tb(j+4|0);fb=j+16|0;return}x[31725]=0;i=P(29,k|0,i<<24>>24)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0;continue}}a=N()|0;tb(j+4|0);Q(a|0);p()}function jga(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=fb-80|0;fb=j;a:{b:{c:{k=gr(1,32);d:{e:{if(!k){a=Ym(ac(4));x[31725]=0;S(99,a|0,125e3,34);a=x[31725];x[31725]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:983;x[k>>2]=f;c=qg(j+68|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[31725]=0;e=P(36,j+56|0,e|0)|0;m=x[31725];x[31725]=0;j:{if((m|0)!=1){x[31725]=0;m=P(994,c|0,e|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break j}x[31725]=0;O(274,m|0,l|0);l=x[31725];x[31725]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[31725]=0;e=P(36,j+44|0,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break g}hu(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[31725]=0;a=R(856,104)|0;m=x[31725];x[31725]=0;k:{l:{m:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[31725]=0;b=P(995,f|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break m}x[j+20>>2]=b;b=x[re(j+24|0,j+20|0)>>2];d=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=d;x[31725]=0;d=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=d;b=ba(1025,a|0,j|0,b|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break k}i=T(0)|0;Vc(j+20|0);break l}i=T(0)|0;break f}i=T(0)|0}Db(a);break f}x[k+28>>2]=b;Vc(j+20|0);x[k+24>>2]=b+8;Vl(c);break d}i=T(0)|0}Vl(c);Y(i|0)|0;x[31725]=0;V(989,11340,k|0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){a=x[k+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[k+24>>2]=0;x[k+28>>2]=0;a=x[k+20>>2];if(a){Db(a);x[k+20>>2]=0}Db(k);k=0;break d}i=T(0)|0;break e}i=T(0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break b}}Y(i|0)|0;k=0;x[31725]=0;V(989,11340,0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Z()}fb=j+80|0;return k|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Sb()}p()}function Wma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}y=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}z=x[a+24>>2];A=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+72>>2];v=x[a+68>>2];C=v>>31;l=x[a+64>>2];E=l>>31;j=x[a+60>>2];F=j>>31;while(1){if(d){b=x[f+16>>2];t=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=(b>>>16&65520)+s|0;m=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];u=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){k=t+(p<<1)|0;x[(f+8|0)+(p<<2)>>2]=(((((((D(w[k-8>>1],e)+D(w[k-12>>1],b)|0)+D(w[k-4>>1],i)|0)+D(w[k>>1],g)|0)+D(w[k+4>>1],u)|0)+D(w[k+8>>1],r)|0)+D(q,w[k+12>>1])|0)+D(m,w[k+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){r=(f+8|0)+(o<<2)|0;e=x[r>>2];b=(f+28|0)+(o<<3)|0;u=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;q=e<<8;e=q;e=ova(j,F,e,e>>31);i=hb;t=e;e=Yb(g,-16777216,16776704);e=ova(l,E,e,e>>31);g=t+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Yb(u,-16777216,16776704);i=ova(v,C,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[b+4>>2]=e-(q&B);x[r>>2]=(e|0)/256;o=o+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],A);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],z);Pb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Fv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Fd(b)}if(b>>>0>=4294967232){x[31600]=48;return 0}f=b>>>0<11?16:b+11&-8;e=a-8|0;i=x[e+4>>2];d=i&-8;a:{if(!(i&3)){if(f>>>0<256){break a}if(d>>>0>=f+4>>>0){c=e;if(d-f>>>0<=x[31721]<<1>>>0){break a}}c=0;break a}g=d+e|0;b:{if(d>>>0>=f>>>0){c=d-f|0;if(c>>>0<16){break b}x[e+4>>2]=i&1|f|2;d=e+f|0;x[d+4>>2]=c|3;x[g+4>>2]=x[g+4>>2]|1;Cv(d,c);break b}if(x[31607]==(g|0)){d=d+x[31604]|0;if(d>>>0<=f>>>0){break a}x[e+4>>2]=i&1|f|2;c=e+f|0;d=d-f|0;x[c+4>>2]=d|1;x[31604]=d;x[31607]=c;break b}if(x[31606]==(g|0)){d=d+x[31603]|0;if(d>>>0<f>>>0){break a}c=d-f|0;c:{if(c>>>0>=16){x[e+4>>2]=i&1|f|2;h=e+f|0;x[h+4>>2]=c|1;d=d+e|0;x[d>>2]=c;x[d+4>>2]=x[d+4>>2]&-2;break c}x[e+4>>2]=d|i&1|2;c=d+e|0;x[c+4>>2]=x[c+4>>2]|1;c=0}x[31606]=h;x[31603]=c;break b}h=x[g+4>>2];if(h&2){break a}j=d+(h&-8)|0;if(j>>>0<f>>>0){break a}l=j-f|0;d:{if(h>>>0<=255){c=x[g+12>>2];d=x[g+8>>2];if((c|0)==(d|0)){n=126404,o=x[31601]&rva(-2,h>>>3|0),x[n>>2]=o;break d}x[d+12>>2]=c;x[c+8>>2]=d;break d}k=x[g+24>>2];d=x[g+12>>2];e:{if((g|0)!=(d|0)){c=x[g+8>>2];x[c+12>>2]=d;x[d+8>>2]=c;break e}f:{c=g+20|0;h=x[c>>2];if(!h){h=x[g+16>>2];if(!h){break f}c=g+16|0}while(1){m=c;d=h;c=d+20|0;h=x[c>>2];if(h){continue}c=d+16|0;h=x[d+16>>2];if(h){continue}break}x[m>>2]=0;break e}d=0}if(!k){break d}c=x[g+28>>2];h=(c<<2)+126708|0;g:{if(x[h>>2]==(g|0)){x[h>>2]=d;if(d){break g}n=126408,o=x[31602]&rva(-2,c),x[n>>2]=o;break d}x[(x[k+16>>2]==(g|0)?16:20)+k>>2]=d;if(!d){break d}}x[d+24>>2]=k;c=x[g+16>>2];if(c){x[d+16>>2]=c;x[c+24>>2]=d}c=x[g+20>>2];if(!c){break d}x[d+20>>2]=c;x[c+24>>2]=d}if(l>>>0<=15){x[e+4>>2]=i&1|j|2;c=e+j|0;x[c+4>>2]=x[c+4>>2]|1;break b}x[e+4>>2]=i&1|f|2;c=e+f|0;x[c+4>>2]=l|3;d=e+j|0;x[d+4>>2]=x[d+4>>2]|1;Cv(c,l)}c=e}if(c){return c+8|0}c=Fd(b);if(!c){return 0}e=x[a-4>>2];e=(e&3?-4:-8)+(e&-8)|0;yc(c,a,b>>>0>e>>>0?e:b);Db(a);return c}function _1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-112|0;fb=d;xc(b);Tp(a);a:{if(!Ci(b,d+104|0)){break a}if(!iG(d+104|0)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],4)){break a}px(a);n=d,o=ox(),x[n+84>>2]=o;c=d+84|0;nx(mj(x[a+4>>2])+32|0,c);rs(c);k=x[mj(x[a+4>>2])+32>>2];c=lh(x[b>>2]);if(c&1){break a}e=c-4|0;cd(b,e);g=fb-16|0;fb=g;c=g+13|0;ax(c,b);h=y[xb(c,0)|0];i=y[xb(c,1)|0];c=y[xb(c,2)|0];fb=g+16|0;h=c|(i<<8|h<<16);if(!h){break a}x[31725]=0;O(39,k|0,h|0);c=x[31725];x[31725]=0;c:{if((c|0)==1){b=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break c}Y(b|0)|0;Z();break a}cd(b,4);c=d+84|0;hG(c,b,e);Tn(d- -64|0,c);mf(d+76|0,x[d+64>>2],x[d+68>>2]);c=x[d+80>>2];i=x[k>>2];e=fb-32|0;fb=e;b=x[d+76>>2];n=e,o=y[xb(b,0)|0],v[n+28|0]=o;n=e,o=y[xb(b,1)|0],v[n+29|0]=o;n=e,o=y[xb(b,2)|0],v[n+30|0]=o;n=e,o=y[xb(b,3)|0],v[n+31|0]=o;g=hs(e+12|0);c=b+c|0;x[g+12>>2]=c-4;x[g+8>>2]=b;sk(g,y[c-1|0]);c=h;d:while(1){e:{f:{g:{if(!c){break g}if(sk(g,1)){break f}b=1;while(1){f=sk(g,2);b=f+b|0;if((f|0)==3){continue}break}x[e+8>>2]=b;wc(e+8|0,c);b=0;f=x[e+8>>2];while(1)if((b|0)==(f|0)){if(!c){break g}break f}else{c=c-1|0;n=i+c|0,o=sk(g,8),v[n|0]=o;b=b+1|0;continue}}fb=e+32|0;break e}f=sk(g,2);b=f+2|0;x[e+8>>2]=b;h:{if((f|0)==3){i:{if(!sk(g,1)){b=5;f=7;break i}f=y[xb(e+28|0,3)|0]}f=sk(g,f);while(1){j=sk(g,3);b=j+b|0;if((j|0)==7){continue}break}x[e+8>>2]=b;break h}f=sk(g,y[xb(e+28|0,f)|0])}wc(e+8|0,c);b=0;m=x[e+8>>2];while(1){if((b|0)==(m|0)){continue d}j=0;l=c+f|0;if(h>>>0>l>>>0){j=y[i+l|0]}c=c-1|0;v[i+c|0]=j;b=b+1|0;continue}}break}oe(d+24|0,x[k>>2],x[k+4>>2]);mf(d+32|0,x[d+24>>2],x[d+28>>2]);b=Nd(d+16|0);x[31725]=0;c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;b=jg(162,d+44|0,x[d+32>>2],x[d+36>>2],d+8|0);c=x[31725];x[31725]=0;if((c|0)!=1){hd(mj(x[a+4>>2])+12|0,b);ub(b);Kc(d+84|0);break b}b=N()|0;Kc(d+84|0)}Q(b|0);p()}f=1}fb=d+112|0;return f|0}function Ou(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=D(c,872)+b|0;f=e+704|0;x[f>>2]=x[f>>2]|524288;a:{b:{if(!(y[a+480208|0]&8)){if(Ob(a+1074312|0,15)|x[a+480180>>2]==268435456){break b}break a}if(x[a+480180>>2]!=268435456){break a}}h=D(c,872)+b|0;d=d?d:y[(D(c,872)+b|0)+1427|0];v[h+1427|0]=d;v[h+1428|0]=d}if(d){w[(D(c,872)+b|0)+1384>>1]=d}c:{g=e+616|0;i=x[g+656>>2];if(Uj(i)){a=z[(D(c,872)+b|0)+1384>>1];if(!a){break c}e=0;d=x[b+16>>2];e=d?x[(D(c,872)+b|0)+1472>>2]:e;k=0-a|0;j=a;g=D(c,872)+b|0;h=g+1324|0;a=x[h>>2];l=(+(d>>>0)+1)*+(((a|0)<0?k:j)|0)/+A[b+40>>2];d:{if(F(l)<2147483648){d=~~l;break d}d=-2147483648}g=g+1472|0;x[g>>2]=d;if(y[f+2|0]&16){d=D(x[x[i+44>>2]+36>>2]+1|0,d);x[g>>2]=d}d=d-e|0;f=d>>31;e=a>>31;if((e^a)-e>>>0<=(d^f)-f>>>0){if(!a){break c}b=D(c,872)+b|0;c=b+1468|0;x[c>>2]=a+x[c>>2];x[h>>2]=0;a=b+1467|0;v[a|0]=y[a|0]|64;return 0}b=D(c,872)+b|0;c=b+1468|0;x[c>>2]=d+x[c>>2];x[h>>2]=a-d;a=b+1467|0;v[a|0]=y[a|0]|64;break c}h=a+1074312|0;e:{if(!(!Ob(h,118)|!(y[f+1|0]&2))){d=0;if(Tc(y[(D(c,872)+b|0)+1404|0])){break e}}f=1;i=D(c,872)+b|0;e=i+1467|0;f:{if(!(v[e|0]&1)){break f}d=x[a+480180>>2];if(d&524352){break f}if(x[b+40>>2]==1){if(Ob(h,6)){break f}d=x[a+480180>>2]}f=0;if((d|0)!=8){break f}f=(y[a+480208|0]&2)>>>1|0}j=x[a+480180>>2];d=z[i+1384>>1];if(!((j|0)!=268435456|d>>>0<240)){f=v[e|0]&1;d=d-240|0}d=d<<((j|0)==64?1:2);i=D(c,872)+b|0;b=i+1316|0;g:{if(!x[b>>2]){break g}c=i+1324|0;if(!(x[c>>2]!=0&f)){break g}j=Jj(a)?d:0-d|0;k=x[b>>2];m=x[c>>2];if(!(!(y[e|0]&16)&(k|0)>=(m|0))){Fk(a,g,b,j,1);c=x[c>>2];if((c|0)>=x[b>>2]){break g}x[b>>2]=c;break g}if((k|0)<=(m|0)){break g}Fk(a,g,b,0-j|0,1);g=x[b>>2];c=x[c>>2];h:{if((g|0)<(c|0)){x[b>>2]=c;break h}if((c|0)!=(g|0)){break g}}if(!Ob(h,112)){break g}v[e|0]=y[e|0]|16}c=x[b>>2];b=i+1324|0;i:{if((c|0)!=x[b>>2]){break i}if(!Ob(h,25)&x[a+480180>>2]!=1){break i}x[b>>2]=0}d=f?d:0}return d}return 0}function Loa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=fb-16|0;fb=j;e=x[b>>2];d=Lk(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){n=fb-32|0;fb=n;e=c-d|0;d=x[zb(b)>>2];f=x[b+4>>2];b:{if(e>>>0<=d-f>>4>>>0){f=fb-16|0;fb=f;e=hv(f+4|0,b,e);d=x[e+4>>2];g=x[e+8>>2];while(1){if((d|0)==(g|0)){hc(e);fb=f+16|0}else{Lr(d);d=d+16|0;x[e+4>>2]=d;continue}break}break b}d=zb(b);f=$V(n+12|0,aW(b,Lk(x[b>>2],f)+e|0),Lk(x[b>>2],x[b+4>>2]),d);g=fb-16|0;fb=g;d=g+4|0;x[d>>2]=x[f+8>>2];i=x[f+8>>2];x[d+8>>2]=f+8;x[d+4>>2]=i+(e<<4);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){Lr(e);e=x[d>>2]+16|0;x[d>>2]=e;continue}break}he(d);fb=g+16|0;k=fb-16|0;fb=k;d=vb(k+12|0,x[b+4>>2]);e=vb(k+8|0,x[b>>2]);h=x[vb(k+4|0,x[f+4>>2])>>2];l=fb-16|0;fb=l;o=l+8|0;g=fb-32|0;fb=g;Id(g+24|0,x[d>>2],x[e>>2]);p=g+16|0;d=x[g+24>>2];q=x[g+28>>2];i=fb-16|0;fb=i;x[i+8>>2]=h;x[i+12>>2]=d;while(1){if(pd(d,q)){e=kC(d);d=kC(x[i+8>>2]);h=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);m=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);v[d+8|0]=m;v[d+9|0]=m>>>8;v[d+10|0]=m>>>16;v[d+11|0]=m>>>24;v[d+12|0]=h;v[d+13|0]=h>>>8;v[d+14|0]=h>>>16;v[d+15|0]=h>>>24;h=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[d|0]=e;v[d+1|0]=e>>>8;v[d+2|0]=e>>>16;v[d+3|0]=e>>>24;v[d+4|0]=h;v[d+5|0]=h>>>8;v[d+6|0]=h>>>16;v[d+7|0]=h>>>24;d=br(i+12|0);br(i+8|0);d=x[d>>2];continue}break}Ac(p,d,i+8|0);fb=i+16|0;d=x[g+16>>2];x[g+12>>2]=x[g+20>>2];Ac(o,d,g+12|0);fb=g+32|0;fb=l+16|0;x[f+4>>2]=x[l+12>>2];Ub(b,f+4|0);Ub(b+4|0,f+8|0);Ub(zb(b),nc(f));x[f>>2]=x[f+4>>2];fb=k+16|0;d=x[f+4>>2];e=x[f+8>>2];while(1){if((d|0)!=(e|0)){e=e-16|0;x[f+8>>2]=e;continue}break}d=x[f>>2];if(d){ys(f);Db(d)}}fb=n+32|0;break a}if(c>>>0<d>>>0){bW(b,e+(c<<4)|0)}}if(Mb(x[a>>2],x[a+8>>2],c<<4)){c=x[b>>2];bc(j+8|0,c,Lk(c,x[b+4>>2])<<4);rd(j,a,x[j+8>>2],x[j+12>>2])}fb=j+16|0}function EP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=fb-80|0;fb=j;a:{b:{c:{d:{e:{f:{k=gr(1,28);if(!k){a=Ym(ac(4));x[31725]=0;S(99,a|0,125e3,34);a=x[31725];x[31725]=0;if((a|0)!=1){break a}break f}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:983;x[k>>2]=f;c=qg(j+68|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[31725]=0;e=P(36,j+56|0,e|0)|0;m=x[31725];x[31725]=0;k:{if((m|0)!=1){x[31725]=0;m=P(994,c|0,e|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break k}x[31725]=0;O(274,m|0,l|0);l=x[31725];x[31725]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[31725]=0;e=P(36,j+44|0,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break h}hu(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[31725]=0;a=R(856,80)|0;m=x[31725];x[31725]=0;l:{m:{n:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[31725]=0;b=P(995,f|0,d|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break n}x[j+20>>2]=b;b=x[re(j+24|0,j+20|0)>>2];d=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=d;x[31725]=0;d=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=d;b=ba(996,a|0,j|0,b|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break l}i=T(0)|0;Vc(j+20|0);break m}i=T(0)|0;break g}i=T(0)|0}Db(a);break g}x[k+24>>2]=b;Vc(j+20|0);Vl(c);i=k;break d}i=T(0)|0}Vl(c);Y(i|0)|0;x[31725]=0;V(989,15176,k|0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break f}a=x[k+24>>2];if(a){Db(Bq(a))}i=0;x[k+24>>2]=0;a=x[k+20>>2];if(a){Db(a);x[k+20>>2]=0}Db(k);break d}i=T(0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[31725]=0;V(989,15176,0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Z()}fb=j+80|0;return i|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Sb()}p()}function Xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}z=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}A=x[a+24>>2];B=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;C=x[a+72>>2];y=x[a+68>>2];E=y>>31;l=x[a+64>>2];F=l>>31;j=x[a+60>>2];G=j>>31;while(1){if(d){b=x[f+16>>2];t=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+z|0;b=(b>>>16&65520)+s|0;m=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];u=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){k=p+t|0;x[(f+8|0)+(p<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],i)|0)+D(v[k|0],g)|0)+D(v[k+2|0],u)|0)+D(v[k+4|0],r)|0)+D(q,v[k+6|0])|0)+D(m,v[k+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){r=(f+8|0)+(o<<2)|0;e=x[r>>2];b=(f+28|0)+(o<<3)|0;u=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;q=e<<8;e=q;e=ova(j,G,e,e>>31);i=hb;t=e;e=Yb(g,-16777216,16776704);e=ova(l,F,e,e>>31);g=t+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Yb(u,-16777216,16776704);i=ova(y,E,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[b+4>>2]=e-(q&C);x[r>>2]=(e|0)/256;o=o+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],B);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],A);Pb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Xla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=fb-16|0;fb=i;c=Hf(a,c);$d(i,x[a+36>>2]);a:{if(!c){Pc(i,a+32|0,5);e=0;if(Hb(x[x[i>>2]>>2],x[i+4>>2])){break a}}e=fb-240|0;fb=e;h=Qm(e+128|0,x[a+36>>2]);x[31725]=0;g=P(463,e+116|0,26168)|0;f=x[31725];x[31725]=0;b:{c:{d:{e:{if((f|0)!=1){x[31725]=0;x[e+96>>2]=19989250;x[e+100>>2]=0;S(464,h|0,g|0,e+96|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}Eb(g);if(!wl(y[h|0])){break d}break b}a=N()|0;break c}a=N()|0;Eb(g);break c}v[e+115|0]=0;x[31725]=0;g=P(463,e+96|0,5505)|0;f=x[31725];x[31725]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){x[31725]=0;S(465,h|0,e+115|0,g|0);f=x[31725];x[31725]=0;if((f|0)==1){break p}Eb(g);g=Fb(e+84|0);x[31725]=0;f=P(463,e+72|0,10094)|0;j=x[31725];x[31725]=0;if((j|0)==1){break o}x[31725]=0;S(789,h|0,g|0,f|0);j=x[31725];x[31725]=0;if((j|0)==1){break n}Eb(f);x[31725]=0;S(260,e+60|0,(y[e+115|0]?0:d)|0,g|0);d=x[31725];x[31725]=0;if((d|0)==1){break m}d=e+60|0;wp(b,d);tb(d);w[e+58>>1]=0;x[31725]=0;d=P(463,e+44|0,10783)|0;f=x[31725];x[31725]=0;if((f|0)==1){break g}x[31725]=0;U(493,h|0,e+58|0,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break l}Eb(d);Gf(e+58|0,4e3);x[31725]=0;d=P(463,e+32|0,13541)|0;f=x[31725];x[31725]=0;if((f|0)==1){break k}j=z[e+58>>1];f=x[vb(e+28|0,j)>>2];x[31725]=0;V(790,h|0,b|0,d|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break j}Eb(d);w[e+26>>1]=65535;x[31725]=0;d=P(463,e+12|0,8964)|0;f=x[31725];x[31725]=0;if((f|0)==1){break i}x[31725]=0;k=U(493,h|0,e+26|0,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break h}f=z[e+26>>1];Eb(d);if(f>>>0<j>>>0&k){bf(b,f)}tb(g);break b}a=N()|0;break c}a=N()|0;Eb(g);break c}a=N()|0;break f}a=N()|0;Eb(f);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0}tb(g)}Ch(h);Q(a|0);p()}Ch(h);fb=e+240|0;e=c}gf(a,e);fb=i+16|0}function aua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-1104|0;fb=d;x[d+1100>>2]=c;i=aE(d+40|0,b);r=Ir(i);e=Nb(a);x[31725]=0;a=R(204,b|0)|0;c=x[31725];x[31725]=0;a:{if((c|0)!=1){x[d+12>>2]=a;x[d+36>>2]=85899345;t=d,u=D(x[Gb(d+12|0,d+36|0)>>2],50),x[t+24>>2]=u;a=x[Gb(d+1100|0,d+24|0)>>2];x[31725]=0;O(330,e|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;h=R(342,d+24|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;f=P(343,d+12|0,8192)|0;a=x[31725];x[31725]=0;b:{if((a|0)!=1){a=x[h>>2];c=0;while(1){if((c|0)!=256){g=yb(a,c);v[g+2|0]=c;w[g>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){g=0;n=257;while(1){s=m&255;e:{while(1){j=n&65535;while(1){x[31725]=0;o=P(160,i|0,s|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(Sc(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:g;a=x[h>>2];l=8192;while(1){c=c&65535;a=yb(a,c);l=l-1|0;q=l&65535;t=xb(x[f>>2],q),u=y[a+2|0],v[t|0]=u;a=x[h>>2];c=z[yb(a,c)>>1];if(c>>>0<8192){continue}break}a=vb(d+8|0,wb(x[e+4>>2]));c=Pe(wb(x[f>>2]),q);l=wb(x[f+4>>2]);a=x[a>>2];x[31725]=0;V(331,e|0,a|0,c|0,l|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=x[f>>2];x[31725]=0;O(344,e|0,xb(a,q)|0);a=x[31725];x[31725]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=o;continue}if(Sc(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){continue}break}a=y[xb(x[f>>2],q)|0];c=yb(x[h>>2],j);w[c>>1]=g;v[c+2|0]=a;a=n+1|0;n=8192;g=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<s)+m|0;n=a;continue}break}break}a=Ir(i);x[31725]=0;P(151,b|0,((a-r|0)+3&-4)+r|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}dc(f);uc(h);ub(i);fb=d+1104|0;return}c=N()|0;dc(f);break b}c=N()|0}uc(h);break a}c=N()|0;break a}c=N()|0;break a}c=N()|0}dc(e);ub(i);Q(c|0);p()}function CU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;c=fb-176|0;fb=c;e=x[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=x[a+12>>2]}else{i=x[b>>2];h=Xd(i,e+l|0);d=Xd(i,e);o=C[h>>3];p=C[h+8>>3];Gj(c+160|0,d,o,p);i=x[c+172>>2];x[h+8>>2]=x[c+168>>2];x[h+12>>2]=i;i=x[c+164>>2];x[h>>2]=x[c+160>>2];x[h+4>>2]=i;yA(Xd(x[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){w=D(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=x[a>>2];e=Xd(d,j<<1);d=Xd(d,j);o=C[d>>3];p=C[d+8>>3];r=C[e>>3];s=C[e+8>>3];Ti(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=x[b>>2];d=Xd(f,e);g=x[d+12>>2];x[c+152>>2]=x[d+8>>2];x[c+156>>2]=g;g=x[d+4>>2];x[c+144>>2]=x[d>>2];x[c+148>>2]=g;g=c+128|0;t=e+h|0;k=Xd(f,t);Ti(g,r,s,C[k>>3],C[k+8>>3]);u=e+y|0;k=Xd(f,u);Ti(c+112|0,o,p,C[k>>3],C[k+8>>3]);m=C[c+160>>3];n=C[c+168>>3];v=e+w|0;f=Xd(f,v);Ti(c+96|0,m,n,C[f>>3],C[f+8>>3]);k=c+80|0;f=c+144|0;m=C[c+112>>3];n=C[c+120>>3];Ml(k,f,m,n);q=c- -64|0;Gj(q,f,m,n);m=C[c+96>>3];n=C[c+104>>3];Ml(c+48|0,g,m,n);f=c+16|0;Xl(f,-0,-1);Gj(c,g,m,n);Ti(c+32|0,C[c+16>>3],C[c+24>>3],C[c>>3],C[c+8>>3]);Ml(f,k,C[c+48>>3],C[c+56>>3]);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Gj(f,k,C[c+48>>3],C[c+56>>3]);d=Xd(x[b>>2],t);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Ml(f,q,C[c+32>>3],C[c+40>>3]);d=Xd(x[b>>2],u);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Gj(f,q,C[c+32>>3],C[c+40>>3]);d=Xd(x[b>>2],v);f=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=f;f=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=f;e=e+1|0;continue}}}break}fb=c+176|0}function TO(a,b,c){a=a|0;b=E(b);c=c|0;var d=0,e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),k=E(0),m=0,n=0,o=0;d=fb-16|0;fb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(q(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=E(E(-1)/E(b*b));if(!(a&2147483647)){break e}e=E(E(b-b)/E(0));if((a|0)<0){break e}a=(q(E(b*E(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=E(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=E((a>>>23|0)+c|0);b=E((l(2,(a&8388607)+1060439283|0),r())+E(-1));f=E(b*E(b*E(.5)));g=E(b/E(b+E(2)));h=E(g*g);i=E(h*h);e=b;b=(l(2,(q(E(b-f)),j(2))&-4096),r());f=E(E(g*E(f+E(E(h*E(E(i*E(.2849878668785095))+E(.6666666269302368)))+E(i*E(E(i*E(.24279078841209412))+E(.40000972151756287))))))+E(E(e-b)-f));b=E(E(k*E(.3010292053222656))+E(E(b*E(.434326171875))+E(E(f*E(.434326171875))+E(E(k*E(7.903415166765626e-7))+E(E(f+b)*E(-3168997136526741e-20))))))}e=b}b=E(e*E(2e3));if(!(E(F(b))<E(2147483648))){break c}a=~~b;break b;case 1:a=(D(x[a+24604>>2],100)|0)/128|0;break b;case 2:c=fb-16|0;fb=c;h:{i:{j:{k:{a=y[a+24648|0];if(a>>>0>=6){a=ac(8);x[31725]=0;c=P(36,c+4|0,5123)|0;d=x[31725];x[31725]=0;if((d|0)==1){break k}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break i}d=N()|0;tb(c);break j}fb=c+16|0;a=x[(a<<2)+79544>>2];break h}d=N()|0;jc(a)}Q(d|0)}p()}break b;case 3:x[d+4>>2]=0;m=x[a+24640>>2];c=fb-80|0;fb=c;a=x[a+24636>>2];x[c+40>>2]=a;x[c>>2]=m;n=c+40|0;o=x[Ze(n,c)>>2];l:{if((a|0)==x[_q(n)+32>>2]){a=-1;if(x[_q(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}x[d+4>>2]=a;fb=c+80|0;a=x[d+4>>2];break b;default:break d}}c=ac(8);x[31725]=0;d=P(36,d+4|0,10385)|0;a=x[31725];x[31725]=0;m:{if((a|0)!=1){pc(c,d);x[31725]=0;S(99,c|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break m}a=N()|0;jc(c)}Q(a|0);p()}a=-2147483648}fb=d+16|0;return a|0}p()}function xP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-96|0;fb=d;g=x[b+4>>2];a:{if(!g){break a}e=x[b>>2];f=y[Il(e,g)|0];if((f|0)==33){c=1}else{if((f|0)!=63){break a}c=0}Ul(d+72|0,e,g,g-1|0);g=x[d+76>>2];e=x[d+72>>2];x[b>>2]=e;x[b+4>>2]=g}f=d+72|0;ge(f);e=x[d+72>>2];ge(d+60|0);e=Hl(e,x[d+64>>2],b);ge(f);b:{c:{d:{e:{if((e|0)==x[d+76>>2]){a=x[b>>2];e=qc(d+88|0,22255);f=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=f;if(Ic(a,g,d)){a=ac(8);x[31725]=0;c=P(36,d+72|0,10482)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;f=0;if(!c){break e}a=ac(8);c=x[b+4>>2];b=x[b>>2];x[31725]=0;e=gi(d+60|0,b,c);b=x[31725];x[31725]=0;f:{g:{h:{if((b|0)!=1){x[31725]=0;S(1017,d+72|0,18282,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break h}pc(a,d+72|0);c=0;x[31725]=0;S(99,a|0,48492,1006);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=N()|0;tb(d+72|0);break g}b=N()|0;break f}b=N()|0;c=1}tb(e);if(!c){break c}}jc(a);break c}if(x[e+4>>2]!=1){a=ac(8);x[31725]=0;c=P(36,d+72|0,11584)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}b=x[b>>2];c=qc(d+52|0,22255);e=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=e;if(Ic(b,g,d+24|0)){a=ac(8);x[31725]=0;c=P(36,d+72|0,10482)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=qc(d+44|0,10974);e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;if(Ic(b,g,d+16|0)){e=x[a+8>>2];f=e>>31;break e}c=qc(d+36|0,8627);e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;e=0;f=0;if(!Ic(b,g,d+8|0)){break e}e=Ck(y[x[a+32>>2]+140|0]);f=0}fb=d+96|0;hb=f;return e|0}b=N()|0;jc(a)}Q(b|0)}p()}function vP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-96|0;fb=e;f=x[c+4>>2];a:{if(!f){g=x[c>>2];break a}g=x[c>>2];h=y[Il(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Ul(e+72|0,g,f,f-1|0);f=x[e+76>>2];g=x[e+72>>2];x[c>>2]=g;x[c+4>>2]=f}i=e+72|0;ge(i);h=x[e+72>>2];ge(e+60|0);h=Hl(h,x[e+64>>2],c);ge(i);b:{c:{d:{e:{if((h|0)==x[e+76>>2]){h=qc(e+88|0,22255);b=x[h+4>>2];x[e>>2]=x[h>>2];x[e+4>>2]=b;if(Ic(g,f,e)){c=ac(8);x[31725]=0;b=P(36,e+72|0,10482)|0;a=x[31725];x[31725]=0;if((a|0)==1){break d}pc(c,b);x[31725]=0;S(99,c|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}if(d){d=ac(8);b=x[c>>2];a=x[c+4>>2];x[31725]=0;b=gi(e+60|0,b,a);a=x[31725];x[31725]=0;f:{g:{h:{if((a|0)!=1){x[31725]=0;S(1017,e+72|0,18282,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}pc(d,e+72|0);c=0;x[31725]=0;S(99,d|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(e+72|0);break g}f=N()|0;break f}f=N()|0;c=1}tb(b);if(!c){break c}}jc(d);break c}Fb(a);break e}d=qc(e+52|0,22255);c=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=c;if(Ic(g,f,e+24|0)){c=ac(8);x[31725]=0;b=P(36,e+72|0,10482)|0;a=x[31725];x[31725]=0;if((a|0)!=1){pc(c,b);x[31725]=0;S(99,c|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}f=N()|0;jc(c);break c}d=qc(e+44|0,12421);c=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=c;if(Ic(g,f,e+16|0)){i:{switch(x[b+52>>2]){case 0:Dc(a,5601);break e;case 1:Dc(a,11285);break e;case 2:Dc(a,9206);break e;default:break i}}Fb(a);break e}d=qc(e+36|0,11522);c=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=c;if(Ic(g,f,e+8|0)){j:{switch(x[b+56>>2]){case 0:Dc(a,15627);break e;case 1:Dc(a,15632);break e;case 2:Dc(a,12695);break e;case 3:Dc(a,9270);break e;default:break j}}Fb(a);break e}Fb(a)}fb=e+96|0;return}f=N()|0;jc(c)}Q(f|0)}p()}function xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-96|0;fb=d;f=1;g=x[c+4>>2];h=y[c+11|0];a:{if(Ad(g,h)){break a}e=y[xz(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+84|0;tx(e,c,0,Yc(g,h)-1|0);Ab(c,e);tb(e)}e=d+84|0;ge(e);g=x[d+84>>2];ge(d+72|0);g=fN(g,x[d+76>>2],c);ge(e);b:{c:{d:{e:{f:{if((g|0)==x[d+88>>2]){if(Ld(c,22255)){a=ac(8);x[31725]=0;b=P(36,d+84|0,10482)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}if(!f){break f}a=ac(8);x[31725]=0;S(1008,d+84|0,18282,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,d+84|0);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}c=N()|0;tb(d+84|0);break c}c=N()|0;jc(a);break c}e=Fb(d+84|0);g:{h:{i:{j:{switch(x[g+4>>2]){case 0:ee(d- -64|0,c);x[31725]=0;c=x[d+68>>2];x[d+8>>2]=x[d+64>>2];x[d+12>>2]=c;b=U(1009,b|0,d+8|0,f|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){x[31725]=0;v[d+72|0]=b;O(1010,a|0,d+72|0);a=x[31725];x[31725]=0;if((a|0)!=1){break g}}break i;case 1:ee(d+56|0,c);x[31725]=0;c=x[d+60>>2];x[d+16>>2]=x[d+56>>2];x[d+20>>2]=c;b=kI(b,d+16|0,f);c=hb;f=x[31725];x[31725]=0;if((f|0)!=1){x[31725]=0;x[d+72>>2]=b;x[d+76>>2]=c;O(1012,a|0,d+72|0);a=x[31725];x[31725]=0;if((a|0)!=1){break g}}break i;case 2:ee(d+48|0,c);x[31725]=0;c=x[d+52>>2];x[d+24>>2]=x[d+48>>2];x[d+28>>2]=c;i=+oa(1013,b|0,d+24|0,f|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;C[d+72>>3]=i;O(1014,a|0,d+72|0);a=x[31725];x[31725]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}ee(d+40|0,c);x[31725]=0;c=x[d+44>>2];x[d+32>>2]=x[d+40>>2];x[d+36>>2]=c;V(1015,a|0,b|0,d+32|0,f|0);a=x[31725];x[31725]=0;if((a|0)!=1){break g}}c=N()|0;tb(e);break c}_c(a,e)}tb(e);break e}Fb(a)}fb=d+96|0;return}c=N()|0;jc(a)}Q(c|0)}p()}function I7(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=fb-1056|0;fb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+944|0;x[a+940>>2]=j;j=Hy(j,100,11182,a+16|0);x[a+48>>2]=1205;k=a+48|0;o=Be(a+520|0,0,k);x[a+48>>2]=1205;k=Be(a+512|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+528|0;f=a+944|0;break d}j=Od();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=sj(a+940|0,j,11182,a);if((j|0)!=-1){f=x[a+940>>2];Te(o,f);Te(k,Fd(j<<2));h=x[k>>2];if(!Pj(h)){break d}}x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break a}j=N()|0;break c}bd(a+508|0,x[d+28>>2]);x[31725]=0;r=R(1217,x[a+508>>2])|0;g=x[31725];x[31725]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[31725]=0;V(1228,r|0,f|0,f+j|0,h|0);g=x[31725];x[31725]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Fb(a+484|0);f=Fb(a+472|0);g=Fb(a+460|0);x[31725]=0;ka(1256,c|0,q|0,x[a+508>>2],a+504|0,a+500|0,a+496|0,i|0,f|0,g|0,a+456|0);c=x[31725];x[31725]=0;if((c|0)==1){break i}x[a+36>>2]=1205;c=Be(a+40|0,0,a+36|0);m=a+48|0;n=x[a+456>>2];k:{if((n|0)<(j|0)){l=((Cb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Cb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}l=(Cb(x[g+4>>2],y[g+11|0])+Cb(x[f+4>>2],y[f+11|0])|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Te(c,Fd(l<<2));m=x[c>>2];if(m){break h}x[31725]=0;X(1206);b=x[31725];x[31725]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}l=x[d+4>>2];x[31725]=0;ma(1257,m|0,a+36|0,a+32|0,l|0,h|0,(j<<2)+h|0,r|0,q|0,a+504|0,x[a+500>>2],x[a+496>>2],i|0,f|0,g|0,n|0);h=x[31725];x[31725]=0;if((h|0)!=1){x[31725]=0;b=ea(1237,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break b}}}j=N()|0;Lc(c)}Qb(g);Qb(f);tb(i)}Zb(a+508|0)}Lc(k);Lc(o);Q(j|0);p()}Lc(c);Qb(g);Qb(f);tb(i);Zb(a+508|0);Lc(k);Lc(o);fb=a+1056|0;return b|0}p()}function CW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=x[a>>2];e=Th(c,x[a+4>>2]);if(e>>>0<b>>>0){h=fb-32|0;fb=h;g=b-e|0;b=x[zb(a)>>2];c=x[a+4>>2];a:{if(g>>>0<=b-c>>8>>>0){e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(g<<8);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=e+16|0}else{dW(a);a=a+256|0;x[b+4>>2]=a;continue}break}break a}i=zb(a);b=h+12|0;e=a;f=Th(x[a>>2],c)+g|0;c=fb-16|0;fb=c;x[c+12>>2]=f;d=fb-16|0;fb=d;x[d+12>>2]=16777215;x[d+8>>2]=2147483647;a=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(a>>>0>=f>>>0){d=lC(e);if(d>>>0<a>>>1>>>0){x[c+8>>2]=d<<1;a=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}dd();p()}f=Th(x[e>>2],x[e+4>>2]);d=fb-16|0;fb=d;Kg(b+12|0,i);c:{if(!a){c=0;a=0;break c}if(a>>>0>=16777216){bk();p()}c=Ec(a<<8);x[d+12>>2]=a;x[d+8>>2]=c;c=x[d+8>>2];a=x[d+12>>2]}x[b>>2]=c;f=c+(f<<8)|0;x[b+8>>2]=f;x[b+4>>2]=f;l=nc(b),m=c+(a<<8)|0,x[l>>2]=m;fb=d+16|0;d=fb-16|0;fb=d;c=d+4|0;a=b;x[c>>2]=x[a+8>>2];b=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=b+(g<<8);b=x[c>>2];while(1){if(x[c+4>>2]!=(b|0)){dW(b);b=x[c>>2]+256|0;x[c>>2]=b;continue}break}he(c);fb=d+16|0;g=fb-16|0;fb=g;c=vb(g+12|0,x[e+4>>2]);d=vb(g+8|0,x[e>>2]);i=x[vb(g+4|0,x[a+4>>2])>>2];f=fb-16|0;fb=f;b=fb-32|0;fb=b;Id(b+24|0,x[c>>2],x[d>>2]);j=b+16|0;d=x[b+24>>2];k=x[b+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=i;x[c+12>>2]=d;while(1){if(pd(d,k)){d=fW(d);yc(fW(x[c+8>>2]),d,256);d=eW(c+12|0);eW(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[b+16>>2];x[b+12>>2]=x[b+20>>2];Ac(f+8|0,c,b+12|0);fb=b+32|0;fb=f+16|0;x[a+4>>2]=x[f+12>>2];Ub(e,a+4|0);Ub(e+4|0,a+8|0);Ub(zb(e),nc(a));x[a>>2]=x[a+4>>2];fb=g+16|0;e=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(e|0)){b=b-256|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){nc(a);Db(b)}}fb=h+32|0;return}if(b>>>0<e>>>0){gW(a,c+(b<<8)|0)}}function Hra(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=x[a>>2];c=Lv(e,x[a+4>>2]);if(c>>>0<=63){h=fb-32|0;fb=h;g=64-c|0;e=x[zb(a)>>2];b=x[a+4>>2];a:{if(g>>>0<=(e-b|0)/33>>>0){e=fb-16|0;fb=e;c=e+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+D(g,33);a=x[c+4>>2];b=x[c+8>>2];while(1){if((a|0)==(b|0)){hc(c);fb=e+16|0}else{$Y(a);a=a+33|0;x[c+4>>2]=a;continue}break}break a}i=zb(a);c=h+12|0;e=a;f=Lv(x[a>>2],b)+g|0;b=fb-16|0;fb=b;x[b+12>>2]=f;d=fb-16|0;fb=d;x[d+12>>2]=130150524;x[d+8>>2]=2147483647;a=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(a>>>0>=f>>>0){d=dZ(e);if(d>>>0<a>>>1>>>0){x[b+8>>2]=d<<1;a=x[ad(b+8|0,b+12|0)>>2]}fb=b+16|0;break b}dd();p()}f=Lv(x[e>>2],x[e+4>>2]);d=fb-16|0;fb=d;Kg(c+12|0,i);c:{if(!a){b=0;a=0;break c}if(a>>>0>=130150525){bk();p()}b=Ec(D(a,33));x[d+12>>2]=a;x[d+8>>2]=b;b=x[d+8>>2];a=x[d+12>>2]}x[c>>2]=b;f=b+D(f,33)|0;x[c+8>>2]=f;x[c+4>>2]=f;l=nc(c),m=b+D(a,33)|0,x[l>>2]=m;fb=d+16|0;d=fb-16|0;fb=d;b=d+4|0;x[b>>2]=x[c+8>>2];a=x[c+8>>2];x[b+8>>2]=c+8;x[b+4>>2]=a+D(g,33);a=x[b>>2];while(1){if(x[b+4>>2]!=(a|0)){$Y(a);a=x[b>>2]+33|0;x[b>>2]=a;continue}break}he(b);fb=d+16|0;g=fb-16|0;fb=g;b=vb(g+12|0,x[e+4>>2]);d=vb(g+8|0,x[e>>2]);i=x[vb(g+4|0,x[c+4>>2])>>2];f=fb-16|0;fb=f;a=fb-32|0;fb=a;Id(a+24|0,x[b>>2],x[d>>2]);j=a+16|0;d=x[a+24>>2];k=x[a+28>>2];b=fb-16|0;fb=b;x[b+8>>2]=i;x[b+12>>2]=d;while(1){if(pd(d,k)){d=bZ(d);yc(bZ(x[b+8>>2]),d,33);d=aZ(b+12|0);aZ(b+8|0);d=x[d>>2];continue}break}Ac(j,d,b+8|0);fb=b+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Ac(f+8|0,b,a+12|0);fb=a+32|0;fb=f+16|0;x[c+4>>2]=x[f+12>>2];Ub(e,c+4|0);Ub(e+4|0,c+8|0);Ub(zb(e),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;e=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)!=(e|0)){a=a-33|0;x[c+8>>2]=a;continue}break}a=x[c>>2];if(a){nc(c);Db(a)}}fb=h+32|0;return}if((c|0)!=64){cZ(a,e+2112|0)}}function Bma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;v=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;y=b+24|0;z=x[a+32>>2];A=x[a+28>>2];B=x[a+72>>2];t=x[a+68>>2];C=t>>31;u=x[a+64>>2];E=u>>31;m=x[a+60>>2];F=m>>31;j=x[a+8>>2];G=x[a+12>>2];while(1){if(d){b=x[f+16>>2];H=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+v|0;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=H+(p<<1)|0;x[(f+8|0)+(p<<2)>>2]=(((((D(w[i+8>>1],r)+D(w[i+4>>1],s)|0)+D(q,w[i+12>>1])|0)+D(l,w[i+16>>1])|0)/2|0)+((((D(w[i-8>>1],e)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)/2|0)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){r=(f+8|0)+(g<<2)|0;e=x[r>>2];b=(f+28|0)+(g<<3)|0;s=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;q=e<<8;e=q;e=ova(m,F,e,e>>31);k=hb;i=e;e=Yb(h,-16777216,16776704);e=ova(u,E,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(s,-16777216,16776704);k=ova(t,C,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(q&B);x[r>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+A|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+z|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Pb(f+16|0,j,G);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function M7(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=fb-448|0;fb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+336|0;x[a+332>>2]=j;j=Hy(j,100,11182,a+16|0);x[a+48>>2]=1205;k=a+48|0;o=Be(a+216|0,0,k);x[a+48>>2]=1205;k=Be(a+208|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+224|0;f=a+336|0;break d}j=Od();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=sj(a+332|0,j,11182,a);if((j|0)!=-1){f=x[a+332>>2];Te(o,f);Te(k,Fd(j));h=x[k>>2];if(!Pj(h)){break d}}x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break a}j=N()|0;break c}bd(a+204|0,x[d+28>>2]);x[31725]=0;r=R(28,x[a+204>>2])|0;g=x[31725];x[31725]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[31725]=0;V(1215,r|0,f|0,f+j|0,h|0);g=x[31725];x[31725]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Fb(a+184|0);f=Fb(a+172|0);g=Fb(a+160|0);x[31725]=0;ka(1254,c|0,q|0,x[a+204>>2],a+200|0,a+199|0,a+198|0,i|0,f|0,g|0,a+156|0);c=x[31725];x[31725]=0;if((c|0)==1){break i}x[a+36>>2]=1205;c=Be(a+40|0,0,a+36|0);m=a+48|0;n=x[a+156>>2];k:{if((n|0)<(j|0)){l=((Cb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Cb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}l=(Cb(x[g+4>>2],y[g+11|0])+Cb(x[f+4>>2],y[f+11|0])|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Te(c,Fd(l));m=x[c>>2];if(m){break h}x[31725]=0;X(1206);b=x[31725];x[31725]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}l=x[d+4>>2];x[31725]=0;ma(1255,m|0,a+36|0,a+32|0,l|0,h|0,h+j|0,r|0,q|0,a+200|0,v[a+199|0],v[a+198|0],i|0,f|0,g|0,n|0);h=x[31725];x[31725]=0;if((h|0)!=1){x[31725]=0;b=ea(23,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break b}}}j=N()|0;Lc(c)}tb(g);tb(f);tb(i)}Zb(a+204|0)}Lc(k);Lc(o);Q(j|0);p()}Lc(c);tb(g);tb(f);tb(i);Zb(a+204|0);Lc(k);Lc(o);fb=a+448|0;return b|0}p()}function Cma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=fb-48|0;fb=f;y=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;z=b+24|0;A=x[a+32>>2];B=x[a+28>>2];C=x[a+72>>2];t=x[a+68>>2];E=t>>31;u=x[a+64>>2];F=u>>31;m=x[a+60>>2];G=m>>31;j=x[a+8>>2];H=x[a+12>>2];while(1){if(d){b=x[f+16>>2];I=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=(((b>>>16|0)+4&131064)<<1)+z|0;l=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=p+I|0;x[(f+8|0)+(p<<2)>>2]=((((D(v[i+4|0],r)+D(v[i+2|0],s)|0)+D(q,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)<<8>>1)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){r=(f+8|0)+(g<<2)|0;e=x[r>>2];b=(f+28|0)+(g<<3)|0;s=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;q=e<<8;e=q;e=ova(m,G,e,e>>31);k=hb;i=e;e=Yb(h,-16777216,16776704);e=ova(u,F,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(s,-16777216,16776704);k=ova(t,E,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(q&C);x[r>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+B|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+A|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Pb(f+16|0,j,H);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function hga(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=fb-48|0;fb=k;a:{b:{c:{j=gr(1,32);d:{e:{if(!j){a=Ym(ac(4));x[31725]=0;S(99,a|0,125e3,34);a=x[31725];x[31725]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:983;x[j>>2]=f;c=qg(k+36|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[31725]=0;e=P(36,k+24|0,e|0)|0;m=x[31725];x[31725]=0;j:{if((m|0)!=1){x[31725]=0;m=P(994,c|0,e|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break j}x[31725]=0;O(274,m|0,l|0);l=x[31725];x[31725]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[31725]=0;e=P(36,k+12|0,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break g}hu(c,e)}tb(e);i=i+8|0;continue}}x[31725]=0;e=R(856,104)|0;i=x[31725];x[31725]=0;k:{l:{m:{if((i|0)!=1){x[31725]=0;d=P(995,f|0,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break m}x[k+4>>2]=d;d=x[re(k+8|0,k+4|0)>>2];x[31725]=0;a=ha(1026,e|0,a|0,b|0,d|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break k}i=T(0)|0;Vc(k+4|0);break l}i=T(0)|0;break f}i=T(0)|0}Db(e);break f}x[j+28>>2]=a;Vc(k+4|0);x[j+24>>2]=a+8;Vl(c);break d}i=T(0)|0}Vl(c);Y(i|0)|0;x[31725]=0;V(989,4973,j|0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){a=x[j+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[j+24>>2]=0;x[j+28>>2]=0;a=x[j+20>>2];if(a){Db(a);x[j+20>>2]=0}Db(j);j=0;break d}i=T(0)|0;break e}i=T(0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break b}}Y(i|0)|0;j=0;x[31725]=0;V(989,4973,0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Z()}fb=k+48|0;return j|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Sb()}p()}function ZX(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;v[a|0]=0;c=y[b|0];if(c){v[a|0]=c>>>0>96?-1:c+12|0}v[a+1|0]=y[b+1|0];c=y[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){v[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch(((c&240)+96&240)>>>4|0){case 0:v[a+2|0]=4;c=c&15;break b;case 1:v[a+2|0]=3;c=c&15;break b;case 2:v[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}v[a+2|0]=5;c=c&15}v[a+4|0]=c}c=y[b+6|0];e=y[b+4|0];d=y[b+5|0];d:{if(!(c|(e|d))){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}v[a+2|0]=15;v[a+3|0]=20;v[a+4|0]=c>>>3;v[f+15|0]=15;h=a,i=y[Rb(b+5|0,f+15|0)|0]|208,v[h+5|0]=i;break d;case 0:Bf(a,c,d);g=y[b+6|0]==15;break d;case 1:v[a+3|0]=2;h=a,i=bh(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 2:v[a+3|0]=3;h=a,i=bh(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 3:v[a+3|0]=4;h=a,i=bh(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 4:v[a+3|0]=5;v[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){v[a+5|0]=d;v[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}v[a+5|0]=145;v[a+3|0]=20;break d;case 12:v[a+3|0]=13;v[a+5|0]=c>>>1;break d;case 15:if(c){v[a+5|0]=c;v[a+3|0]=17;break d}v[a+3|0]=16;v[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}xD(a,c,d,1);g=(y[a+3|0]&254)==16;break d}v[a+5|0]=d;v[a+3|0]=18;break d}v[a+3|0]=31;v[a+5|0]=c>>>1;break d}v[a+3|0]=31;v[a+5|0]=c>>>1&120;break d}v[a+5|0]=159;v[a+3|0]=20;break d}v[a+3|0]=21;v[a+5|0]=c>>>2}b=y[b+3|0];l:{if(!b){break l}if(!y[a+3|0]){v[a+5|0]=b;v[a+3|0]=9;break l}if(y[a+2|0]){break l}v[a+2|0]=2;v[a+4|0]=b>>>2}fb=f+16|0;return g}function A7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;r=fb-16|0;fb=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!y[j|0]){break a}j=j+1|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=x[b+4>>2];x[r+8>>2]=x[b>>2];x[r+12>>2]=i;s=fb-16|0;fb=s;v=Nh(s+12|0,x[a+8>>2]);m=j-c|0;k=0;n=0;o=fb-1040|0;fb=o;q=x[e>>2];x[o+12>>2]=q;p=f?f:o+16|0;l=f?g-f>>2:256;e:{f:{g:{if(!(!q|!l)){while(1){i=m>>>2|0;if(!(m>>>0>131|i>>>0>=l>>>0)){i=q;break f}t=DK(p,o+12|0,i>>>0<l>>>0?i:l,b);i=x[o+12>>2];if((t|0)==-1){l=0;k=-1;break g}u=(o+16|0)!=(p|0)?t:0;l=l-u|0;p=(u<<2)+p|0;m=i?(m+q|0)-i|0:0;k=k+t|0;if(!i){break g}q=i;if(l){continue}break}break g}i=q}if(!i){break e}}if(!(!l|!m)){n=i;i=k;while(1){h:{k=yt(p,n,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:n=0;break i;case 0:break e;default:break j}}x[b>>2]=0;break i}n=k+n|0;x[o+12>>2]=n;i=i+1|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}n=i}if(f){x[e>>2]=n}fb=o+1040|0;Mh(v);fb=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{x[h>>2]=f;if(x[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=ey(f,c,j-c|0,r+8|0,x[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}x[e>>2]=c;break n}g=b}c=c+g|0;f=x[h>>2]+4|0;continue}break}x[e>>2]=c;break d}f=x[h>>2]+(k<<2)|0;x[h>>2]=f;if((f|0)==(g|0)){break k}c=x[e>>2];if((d|0)==(j|0)){j=d;continue}if(!ey(f,c,1,b,x[a+8>>2])){break m}}a=2;break c}x[h>>2]=x[h>>2]+4;c=x[e>>2]+1|0;x[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!y[j|0]){break b}j=j+1|0;continue}}x[e>>2]=c;a=1;break c}c=x[e>>2]}a=(c|0)!=(d|0)}fb=r+16|0;return a|0}f=x[h>>2];continue}}function _R(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;e=D(b,872)+a|0;j=e+1074992|0;a:{b:{i=x[e+1075080>>2];if(i&131072){e=x[a+480180>>2];i=1;c:{d:{e:{h=x[a+480208>>2];if(h&4096){if(!(e&16777248)){break e}i=!(h&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}h=a+480180|0;if(!i){break c}Jb(f+8|0,a+1074312|0,21);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break c}e=D(b,872)+a|0;g=e+1075811|0;v[g|0]=y[g|0]+(y[e+1075815|0]<<2)}g=D(b,872)+a|0;k=g+1075814|0;l=g+1075811|0;e=JA(a,y[k|0],y[l|0]);f:{if(Uj(x[j+656>>2])){B[d>>2]=B[d>>2]+E(E(E(D(y[g+1075816|0],e)|0)*E(.05000000074505806))/E(7680));c=g+1075843|0;d=y[c|0];v[c|0]=d&159|64;if(x[a+1074416>>2]!=(x[a+1074392>>2]+1|0)){break f}v[c|0]=d|96;break f}d=x[a+480208>>2];if((d&2101248)==2101248){break a}g=x[h>>2];if(d&4096?g&67633152:0){break a}e=g&5?(y[k|0]&3)==1?0-e|0:e:e;k=a+1074312|0;Jb(f+8|0,k,21);g=x[a+480208>>2];g:{if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){d=g&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(g&131072){break h}h=x[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?g&4?6:7:6}Jb(f+8|0,k,80);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break g}d=y[(D(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=0-((D(y[(D(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0)|0;Fk(a,j,c,d,0);e=x[j+656>>2];c=Kq(a,x[j+88>>2],e);if(!c){break f}ib[x[x[c>>2]+92>>2]](c,d,(e?v[e+33|0]:2)<<24>>24,b)}if(!i){break a}Jb(f+8|0,a+1074312|0,21);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}v[l|0]=y[l|0]+y[(D(b,872)+a|0)+1075815|0];break a}if(!(y[e+1075662|0]&2)){break a}a=Kq(a,i,x[j+656>>2]);if(!a){break a}ib[x[x[a>>2]+92>>2]](a,0,0,b);break a}a=D(b,872)+a|0;b=a+1075811|0;d=y[b|0];if(d&1){x[c>>2]=x[c>>2]+D(y[a+1075816|0],167)}v[b|0]=d+1}fb=f+16|0}function DP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=fb-48|0;fb=k;a:{b:{c:{d:{e:{f:{j=gr(1,28);if(!j){a=Ym(ac(4));x[31725]=0;S(99,a|0,125e3,34);a=x[31725];x[31725]=0;if((a|0)!=1){break a}break f}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:983;x[j>>2]=f;c=qg(k+36|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[31725]=0;e=P(36,k+24|0,e|0)|0;m=x[31725];x[31725]=0;k:{if((m|0)!=1){x[31725]=0;m=P(994,c|0,e|0)|0;n=x[31725];x[31725]=0;if((n|0)==1){break k}x[31725]=0;O(274,m|0,l|0);l=x[31725];x[31725]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[31725]=0;e=P(36,k+12|0,e|0)|0;l=x[31725];x[31725]=0;if((l|0)==1){break h}hu(c,e)}tb(e);i=i+8|0;continue}}x[31725]=0;e=R(856,80)|0;i=x[31725];x[31725]=0;l:{m:{n:{if((i|0)!=1){x[31725]=0;d=P(995,f|0,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break n}x[k+4>>2]=d;d=x[re(k+8|0,k+4|0)>>2];x[31725]=0;a=ha(1e3,e|0,a|0,b|0,d|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break l}i=T(0)|0;Vc(k+4|0);break m}i=T(0)|0;break g}i=T(0)|0}Db(e);break g}x[j+24>>2]=a;Vc(k+4|0);Vl(c);i=j;break d}i=T(0)|0}Vl(c);Y(i|0)|0;x[31725]=0;V(989,15075,j|0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break f}a=x[j+24>>2];if(a){Db(Bq(a))}i=0;x[j+24>>2]=0;a=x[j+20>>2];if(a){Db(a);x[j+20>>2]=0}Db(j);break d}i=T(0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[31725]=0;V(989,15075,0,g|0,h|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Z()}fb=k+48|0;return i|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Sb()}p()}function US(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=fb-16|0;fb=c;e=a+1074376|0;d=D(b,872);a:{if(x[(e+d|0)+704>>2]&134218752){break a}g=x[(a+d|0)+1075648>>2];if(!Lj(g)|y[g+15|0]&2){break a}e=wm(a,e,b,2,1)-1|0;if((e&255)>>>0>249){break a}h=x[vd(a+906300|0,e)>>2];if(!h){break a}d=D(b,872)+a|0;j=d+1075780|0;e=y[j|0];b:{if(y[d+1075782|0]==1){v[c+8|0]=64;d=y[Rb(d+1075784|0,c+8|0)|0];break b}f=y[d+1075783|0];if((f|0)!=46){d=255;if((f|0)!=13){break b}v[c+8|0]=64;d=y[Rb((D(b,872)+a|0)+1075785|0,c+8|0)|0];break b}d=y[(D(b,872)+a|0)+1075785|0]+3>>>2|0}i=a+1074312|0;Jb(c+8|0,i,2);if(Hb(x[x[c+8>>2]>>2],x[c+12>>2])){if(e){if(Tc(e)){e=y[xb(g+108|0,e-1|0)|0]}dn(a,b,e&255,z[(D(b,872)+a|0)+1075680>>1]);break a}if((d|0)==255){break a}ib[x[x[h>>2]+76>>2]](h,39,d,b);break a}k=x[g+4>>2];c:{if(!e){break c}f=y[g+35|0]?k<<2:x[(D(b,872)+a|0)+1075680>>2];l=w[(D(b,872)+a|0)+1075768>>1];Jb(c+8|0,i,28);m=c,n=f+(Hb(x[x[c+8>>2]>>2],x[c+12>>2])?l<<2:l)|0,x[m+4>>2]=n;Fe(c+4|0,0,256);f=e;if(Tc(e)){f=y[xb(g+108|0,e-1|0)|0]}Jb(c+8|0,i,117);if(!Hb(x[x[c+8>>2]>>2],x[c+12>>2])){if(Rl(y[j+2|0],y[j+3|0])){break c}}dn(a,b,f&255,z[c+4>>1])}a=y[g+35|0];Jb(c+8|0,i,101);a=(a|0)==1;f=(d|0)!=255;if(!Hb(x[x[c+8>>2]>>2],x[c+12>>2])){e=Tc(e)}if(((e?a:f)|0)!=1){break a}d:{switch(y[g+36|0]){case 1:a=x[h+20>>2];if((d|0)!=255){Iu(a,E(E(E(d<<1)/E(-127))+E(1)));break a}Iu(a,E(E(E(k<<1>>>0)/E(-127))+E(1)));break a;case 0:break d;default:break a}}if((d|0)!=255){v[c+8|0]=127;v[c+4|0]=d<<1;n=h,o=7,p=y[Rb(c+8|0,c+4|0)|0],q=b,m=x[x[h>>2]+76>>2],ib[m](n|0,o|0,p|0,q|0);break a}x[c+8>>2]=127;x[c+4>>2]=k<<1;q=h,p=7,o=y[Gb(c+8|0,c+4|0)|0],n=b,m=x[x[h>>2]+76>>2],ib[m](q|0,p|0,o|0,n|0)}fb=c+16|0}function vX(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;g=x[b>>2];h=x[b+4>>2];a:{if((h|0)==(f|0)){j=gc(l+8|0,e,f);b=fb-16|0;fb=b;c=sn(c,d,g,f);x[b+12>>2]=c;e=x[j>>2];b:{if((c|0)<=0){break b}if(f){d=32-f|0;x[b+8>>2]=d;h=c;c=x[ud(b+8|0,b+12|0)>>2];x[b+12>>2]=h-c;d=-1<<f&-1>>>d-c;x[e>>2]=x[e>>2]&(d^-1)|d&x[g>>2];c=c+x[j+4>>2]|0;x[j+4>>2]=c&31;e=(c>>>3&536870908)+e|0;x[j>>2]=e;g=g+4|0;c=x[b+12>>2]}d=(c|0)/32|0;iD(g,d,e);c=c-(d<<5)|0;x[b+12>>2]=c;d=d<<2;e=d+x[j>>2]|0;x[j>>2]=e;if((c|0)<=0){break b}c=-1>>>32-c|0;x[e>>2]=x[e>>2]&(c^-1)|c&x[d+g>>2];x[j+4>>2]=x[b+12>>2]}gc(a,e,x[j+4>>2]);fb=b+16|0;break a}j=a;i=gc(l,e,f);f=fb-16|0;fb=f;e=sn(c,d,g,h);x[f+12>>2]=e;c:{if((e|0)<=0){a=x[i+4>>2];b=x[i>>2];break c}d:{if(!h){a=x[i+4>>2];break d}k=32-h|0;x[f+8>>2]=k;c=f+8|0;b=x[ud(c,f+12|0)>>2];x[f+12>>2]=e-b;a=x[i+4>>2];e=x[g>>2];x[f+8>>2]=b;m=32-a|0;x[f+4>>2]=m;d=x[i>>2];n=x[d>>2];c=x[Gb(c,f+4|0)>>2];e=e&(-1<<h&-1>>>k-b);x[d>>2]=(-1<<a&-1>>>m-c^-1)&n|(a>>>0>h>>>0?e<<a-h:e>>>h-a|0);k=a+c|0;a=k&31;x[i+4>>2]=a;d=d+(k>>>3&536870908)|0;x[i>>2]=d;b=b-c|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|e>>>c+h;x[i+4>>2]=b;a=b}g=g+4|0;e=x[f+12>>2]}c=32-a|0;d=-1<<a;h=d^-1;while(1){if((e|0)>=32){b=x[i>>2];e=x[g>>2];x[b>>2]=h&x[b>>2]|e<<a;x[i>>2]=b+4;x[b+4>>2]=d&x[b+4>>2]|e>>>c;e=x[f+12>>2]-32|0;x[f+12>>2]=e;g=g+4|0;continue}break}b=x[i>>2];if((e|0)<=0){break c}g=x[g>>2];x[f+8>>2]=c;k=x[b>>2];h=c;c=x[ud(f+12|0,f+8|0)>>2];e=g&-1>>>32-e;x[b>>2]=k&(d&-1>>>h-c^-1)|e<<a;d=a+c|0;a=d&31;x[i+4>>2]=a;b=(d>>>3&536870908)+b|0;x[i>>2]=b;d=x[f+12>>2]-c|0;x[f+12>>2]=d;if((d|0)<=0){break c}x[b>>2]=x[b>>2]&(-1>>>32-d^-1)|e>>>c;a=x[f+12>>2];x[i+4>>2]=a}gc(j,b,a);fb=f+16|0}fb=l+16|0}function Dg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;h=x[a+8>>2]+(D(z[a+14>>1],(y[a+80|0]?c:0)+b|0)>>>1|0)|0;x[a+8>>2]=h;g=y[a+79|0]?z[x[a>>2]+3836>>1]:g;c=z[a+20>>1];j=z[a+22>>1];k=z[a+70>>1];a:{b:{c:{d:{switch(x[a+16>>2]){case 1:b=z[x[a>>2]+3832>>1];f=c+(b&z[a+46>>1]?0:z[a+26>>1]?z[a+48>>1]>>>z[x[a+52>>2]+((b>>>z[a+44>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;b=2;i=z[a+28>>1];if((i|0)<=f<<16>>16){break c}break b;case 2:if(y[a+78|0]){break b}case 3:b=0;f=z[x[a>>2]+3832>>1];f=c+(f&z[a+58>>1]?0:z[a+30>>1]?z[a+60>>1]>>>z[x[a+64>>2]+((f>>>z[a+56>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;if(f<<16>>16<511){break b}x[a+16>>2]=-1;w[a+20>>1]=511;x[a+72>>2]=0;break a;default:b=0;x[a+72>>2]=0;break a;case 0:break d}}b=1;f=z[x[a>>2]+3832>>1];f=c+(f&z[a+34>>1]?0:z[a+24>>1]?D((c^-1)<<16>>16,z[a+36>>1]>>>z[x[a+40>>2]+((f>>>z[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0)|0;w[a+20>>1]=f;if(f<<16>>16>0){break b}}x[a+16>>2]=b;w[a+20>>1]=i}g=((c+j|0)+k|0)+g<<3;if(e){d=(w[a+74>>1]+w[a+72>>1]>>e)+d|0}d=(h>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(z[a+12>>1]){case 0:d=(b&512)>>>9|0;b=z[((b&256?c^255:c)<<1)+26768>>1];break e;case 1:d=0;b=z[((b&512?0:b&256?c^255:c)<<1)+26768>>1];break e;case 2:d=0;b=z[((b&256?c^255:c)<<1)+26768>>1];break e;case 3:d=0;b=z[((b&256?0:c)<<1)+26768>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=z[(e<<1)+26768>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=z[(b<<1)+26768>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}w[a+74>>1]=z[a+72>>1];c=a;a=b+g&65535;a=a>>>0>=8191?8191:a;b=0-d^z[((a&255)<<1)+26256>>1]+1024>>>(a>>>8)<<1;w[c+72>>1]=b}return b<<16>>16}function Fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}u=x[a+24>>2];v=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;y=b+24|0;z=x[a+72>>2];r=x[a+68>>2];A=r>>31;s=x[a+64>>2];B=s>>31;m=x[a+60>>2];C=m>>31;j=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];F=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=F+(n<<1)|0;x[(f+8|0)+(n<<2)>>2]=(((((D(w[i+8>>1],p)+D(w[i+4>>1],q)|0)+D(o,w[i+12>>1])|0)+D(l,w[i+16>>1])|0)/2|0)+((((D(w[i-8>>1],e)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)/2|0)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){p=(f+8|0)+(g<<2)|0;e=x[p>>2];b=(f+28|0)+(g<<3)|0;q=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;o=e<<8;e=o;e=ova(m,C,e,e>>31);k=hb;i=e;e=Yb(h,-16777216,16776704);e=ova(s,B,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(q,-16777216,16776704);k=ova(r,A,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(o&z);x[p>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],v);x[c+4>>2]=x[c+4>>2]+D(u,x[f+12>>2]);Pb(f+16|0,j,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function mt(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=fb-128|0;fb=i;x[i+124>>2]=b;k=lt(c,d);x[i+4>>2]=1205;n=kt(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Fd(k);if(!j){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break a}break b}Te(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[31725]=0;h=P(1207,a|0,i+124|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}if((h|!k)==1){x[31725]=0;b=P(1207,a|0,i+124|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[31725]=0;o=R(1208,b|0)|0;b=x[31725];x[31725]=0;g:{if((b|0)!=1){if(g){break g}x[31725]=0;o=P(1209,e|0,o|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[31725]=0;R(1210,a|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Cb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=v[cc(b,q)|0];j:{if(g){break j}x[31725]=0;r=P(1209,e|0,r<<24>>24)|0;t=x[31725];x[31725]=0;if((t|0)!=1){break j}break b}k:{if((o&255)==(r&255)){s=1;if((Cb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=Ad(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Lc(n);fb=i+128|0;return d|0}}a=N()|0;Lc(n);Q(a|0)}p()}function it(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=fb-128|0;fb=i;x[i+124>>2]=b;k=lt(c,d);x[i+4>>2]=1205;n=kt(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Fd(k);if(!j){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break a}break b}Te(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[31725]=0;h=P(1222,a|0,i+124|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}if((h|!k)==1){x[31725]=0;b=P(1222,a|0,i+124|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[31725]=0;o=R(1223,b|0)|0;b=x[31725];x[31725]=0;g:{if((b|0)!=1){if(g){break g}x[31725]=0;o=P(1224,e|0,o|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[31725]=0;R(1225,a|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Cb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=x[Wd(b,q)>>2];j:{if(g){break j}x[31725]=0;r=P(1224,e|0,r|0)|0;t=x[31725];x[31725]=0;if((t|0)!=1){break j}break b}k:{if((o|0)==(r|0)){s=1;if((Cb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=Ad(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Lc(n);fb=i+128|0;return d|0}}a=N()|0;Lc(n);Q(a|0)}p()}function Pla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;g=fb-32|0;fb=g;f=EU(g+20|0,1<<x[b+12>>2]);e=x[f>>2];while(1){c=x[a>>2];if(kh(c,x[a+4>>2])>>>0>d>>>0){c=Ve(c,d);DU(Xd(e,d),C[c>>3]);d=d+1|0;continue}break}CU(b,f);w=g,y=wb(x[f>>2]),x[w>>2]=y;u=wb(x[f+4>>2]);while(1){d=x[g>>2];if(Ib(d,u)){m=C[d+8>>3];k=fb-32|0;fb=k;o(+C[d>>3]);e=j(1)|0;r=j(0)|0;o(+m);c=j(1)|0;s=j(0)|0;e=e&2147483647;q=c&2147483647;c=(e|0)==(q|0)&r>>>0<s>>>0|e>>>0<q>>>0;h=c?r:s;c=c?e:q;v=c;l(0,h|0);l(1,c|0);p=+n();t=c>>>20|0;i=p;a:{if((t|0)==2047){break a}c=(e|0)==(q|0)&r>>>0>s>>>0|e>>>0>q>>>0;l(0,(c?r:s)|0);c=c?e:q;l(1,c|0);m=+n();b:{if(!(h|v)){break b}c=c>>>20|0;if((c|0)==2047){break b}i=m+p;if((c-t|0)>=65){break a}c:{if(c>>>0>=1534){p=p*190109156629516e-225;m=m*190109156629516e-225;i=5.260135901548374e210;break c}i=1;if(t>>>0>572){break c}p=p*5.260135901548374e210;m=m*5.260135901548374e210;i=190109156629516e-225}NL(k+24|0,k+16|0,m);NL(k+8|0,k,p);i=i*M(C[k>>3]+C[k+16>>3]+C[k+8>>3]+C[k+24>>3]);break a}i=m}p=i;fb=k+32|0;DU(d,sq(p));$o(g);continue}break}BU(b,f);AU(f);h=x[f>>2];e=Lk(h,x[f+4>>2])>>>1|0;c=e>>>0<=1?1:e;d=1;while(1){if((c|0)!=(d|0)){PB(Xd(h,d),2);PB(Xd(h,d+e|0),0);d=d+1|0;continue}break}CU(b,f);w=g,y=wb(x[f>>2]),x[w+16>>2]=y;e=wb(x[f+4>>2]);while(1){h=x[g+16>>2];if(Ib(h,e)){zU(g,C[h>>3],C[h+8>>3]);c=x[g+12>>2];x[h+8>>2]=x[g+8>>2];x[h+12>>2]=c;c=x[g+4>>2];x[h>>2]=x[g>>2];x[h+4>>2]=c;$o(g+16|0);continue}break}BU(b,f);AU(f);e=x[a>>2];c=kh(e,x[a+4>>2]);b=x[f>>2];d=0;while(1){if((c|0)==(d|0)){rn(f);fb=g+32|0}else{a=Xd(b,d);w=Ve(e,d),z=C[a>>3],C[w>>3]=z;d=d+1|0;continue}break}}function roa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-48|0;fb=h;k=c+484344|0;Vf(k,y[b+70|0]|y[b+71|0]<<8);a:{b:{while(1){if((y[b+70|0]|y[b+71|0]<<8)>>>0<=j>>>0){break b}f=x[a+8>>2];e=Pg(a);Vb(a,1);c:{if((y[b+58|0]|y[b+59|0]<<8)==258){c=Zd(a)+1|0;break c}c=ih(a)}d=ih(a);cd(a,e+f|0);e=h+8|0;fe(e,a,d);f=ic(h+28|0,e);ub(e);x[31725]=0;c=U(198,k|0,j&65535,(c?c>>>0>=1024?1024:c:64)|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Wb(x[k>>2],j);m=h,n=wb(x[c>>2]),x[m+8>>2]=n;l=wb(x[c+4>>2]);while(1){c=x[h+8>>2];if(!Ib(c,l)){break d}x[31725]=0;d=R(199,f|0)|0;e=x[31725];x[31725]=0;e:{f:{g:{if((e|0)!=1){e=d<<24>>24;if((e|0)>=0){break g}if(e&1){x[31725]=0;d=R(199,f|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}v[c|0]=d}d=e&255;if(e&2){break f}break e}break a}v[c|0]=e;d=255}x[31725]=0;e=R(199,f|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break a}v[c+1|0]=e}i=0;e=0;if(d&4){x[31725]=0;e=R(199,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}}if(d&8){x[31725]=0;i=R(199,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}}if(d&16){x[31725]=0;d=R(199,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}v[c+5|0]=d}h:{i:{d=y[c|0];if(!d){break i}g=255;if((d|0)==97){break h}if(d>>>0>96){break i}g=d+12|0;break h}g=0}v[c|0]=g;d=y[c+5|0];j:{if((d|i)&255){Bf(c,i,d);break j}v[c+3|0]=0}if(y[c+1|0]==255){v[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){v[c+4|0]=d;v[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;v[c+4|0]=d;e=e-96>>>4|0;v[c+2|0]=y[e+25502|0];if((e|0)!=6){break k}v[c+4|0]=d<<2}vg(h+8|0);continue}}ub(f);j=j+1|0;continue}break}break a}fb=h+48|0;return}a=N()|0;ub(f);Q(a|0);p()}function Gma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=fb-48|0;fb=f;t=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}u=x[a+24>>2];y=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;z=b+24|0;A=x[a+72>>2];r=x[a+68>>2];B=r>>31;s=x[a+64>>2];C=s>>31;m=x[a+60>>2];E=m>>31;j=x[a+8>>2];F=x[a+12>>2];while(1){if(d){b=x[f+16>>2];G=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=(((b>>>16|0)+4&131064)<<1)+z|0;l=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=n+G|0;x[(f+8|0)+(n<<2)>>2]=((((D(v[i+4|0],p)+D(v[i+2|0],q)|0)+D(o,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)<<8>>1)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){p=(f+8|0)+(g<<2)|0;e=x[p>>2];b=(f+28|0)+(g<<3)|0;q=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;o=e<<8;e=o;e=ova(m,E,e,e>>31);k=hb;i=e;e=Yb(h,-16777216,16776704);e=ova(s,C,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(q,-16777216,16776704);k=ova(r,B,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(o&A);x[p>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],y);x[c+4>>2]=x[c+4>>2]+D(u,x[f+12>>2]);Pb(f+16|0,j,F);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function U4(a){a=a|0;var b=0,c=0,d=0;a=a+12|0;d=a+508|0;c=Cb(x[a+512>>2],y[a+519|0]);while(1){a:{if((b|0)==(c|0)){b=c;break a}if(x[Wd(d,b)>>2]==37){break a}b=b+1|0;continue}break}b:{c:{d:{e:{f:{a=x[Wd(d,b+1|0)>>2];if((a|0)!=121){if((a|0)==100){break f}if((a|0)==109){break e}if((a|0)!=89){break c}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){g:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break g}a=b}if((a|0)==(c|0)){break c}b=x[Wd(d,a+1|0)>>2];if((b|0)==100){break d}if((b|0)!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){h:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break h}a=b}if((a|0)==(c|0)){break c}b=3;if(x[Wd(d,a+1|0)>>2]!=100){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){i:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break i}a=b}if((a|0)==(c|0)){break c}if(x[Wd(d,a+1|0)>>2]!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){j:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break j}a=b}if((a|0)==(c|0)){break c}b=1;a=a+1|0;if(x[Wd(d,a)>>2]==121){break b}if(x[Wd(d,a)>>2]==89){break b}break c}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){k:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break k}a=b}if((a|0)==(c|0)){break c}if(x[Wd(d,a+1|0)>>2]!=100){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){l:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break l}a=b}if((a|0)==(c|0)){break c}b=2;a=a+1|0;if(x[Wd(d,a)>>2]==121){break b}if(x[Wd(d,a)>>2]!=89){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){m:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break m}a=b}if((a|0)==(c|0)){break c}b=4;if(x[Wd(d,a+1|0)>>2]!=109){break c}break b}b=b+1|0;continue}}b=0}return b|0}function gna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+28|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;o=x[a+8>>2];C=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=b>>>21&2040;h=w[b+38150>>1];i=w[b+38148>>1];e=w[b+38146>>1];g=w[b+38144>>1];b=0;j=0;while(1){if((j|0)!=2){k=p+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(h,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=ova(s,B,e,e>>31);i=hb;l=e;e=Yb(h,-16777216,16776704);e=ova(r,A,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(p,-16777216,16776704);i=ova(q,z,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(j&y);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Pb(f+16|0,o,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=fb-192|0;fb=c;e=Qm(c+80|0,a);x[31725]=0;d=P(463,c+68|0,42271)|0;a=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){x[31725]=0;x[c+56>>2]=19989250;x[c+60>>2]=0;S(464,e|0,d|0,c+56|0);a=x[31725];x[31725]=0;if((a|0)==1){break n}Eb(d);if(wl(y[e|0])){break e}x[31725]=0;d=P(463,c+56|0,13434)|0;a=x[31725];x[31725]=0;if((a|0)==1){break m}x[31725]=0;V(495,e|0,b|0,d|0,918);a=x[31725];x[31725]=0;if((a|0)==1){break l}Eb(d);x[c+52>>2]=0;x[c+48>>2]=0;x[31725]=0;d=P(463,c+36|0,16760)|0;a=x[31725];x[31725]=0;if((a|0)==1){break k}x[31725]=0;S(919,e|0,c+52|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break j}Eb(d);x[31725]=0;d=P(463,c+24|0,16750)|0;a=x[31725];x[31725]=0;if((a|0)==1){break i}x[31725]=0;S(919,e|0,c+48|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}Eb(d);a=x[c+52>>2];d=x[c+48>>2];o:{if(!a|d>>>0<a>>>0){break o}f=x[x[x[x[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}x[b+20>>2]=d;x[b+16>>2]=a}d=Nb(c+12|0);x[31725]=0;f=P(463,c|0,14133)|0;a=x[31725];x[31725]=0;if((a|0)==1){break d}x[31725]=0;S(920,e|0,d|0,f|0);a=x[31725];x[31725]=0;if((a|0)==1){break g}Eb(f);if(lc(x[d>>2],x[d+4>>2])){break f}a=x[b+16>>2];x[31725]=0;O(870,d|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break f}break c}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;Eb(f);break b}x[31725]=0;O(921,b|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}uc(d)}Ch(e);fb=c+192|0;return}a=N()|0;break b}a=N()|0}uc(d)}Ch(e);Q(a|0);p()}function z4(a){a=a|0;var b=0,c=0,d=0;a=a+12|0;d=a+508|0;c=Cb(x[a+512>>2],y[a+519|0]);while(1){a:{if((b|0)==(c|0)){b=c;break a}if(y[cc(d,b)|0]==37){break a}b=b+1|0;continue}break}b:{c:{d:{e:{f:{a=v[cc(d,b+1|0)|0];if((a|0)!=121){if((a|0)==100){break f}if((a|0)==109){break e}if((a|0)!=89){break c}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){g:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break g}a=b}if((a|0)==(c|0)){break c}b=v[cc(d,a+1|0)|0];if((b|0)==100){break d}if((b|0)!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){h:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break h}a=b}if((a|0)==(c|0)){break c}b=3;if(y[cc(d,a+1|0)|0]!=100){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){i:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break i}a=b}if((a|0)==(c|0)){break c}if(y[cc(d,a+1|0)|0]!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){j:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break j}a=b}if((a|0)==(c|0)){break c}b=1;a=a+1|0;if(y[cc(d,a)|0]==121){break b}if(y[cc(d,a)|0]==89){break b}break c}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){k:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break k}a=b}if((a|0)==(c|0)){break c}if(y[cc(d,a+1|0)|0]!=100){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){l:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break l}a=b}if((a|0)==(c|0)){break c}b=2;a=a+1|0;if(y[cc(d,a)|0]==121){break b}if(y[cc(d,a)|0]!=89){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){m:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break m}a=b}if((a|0)==(c|0)){break c}b=4;if(y[cc(d,a+1|0)|0]!=109){break c}break b}b=b+1|0;continue}}b=0}return b|0}function esa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-16|0;fb=g;i=Hf(a,c);$d(g,x[a+36>>2]);j=a;a:{if(!i){Pc(g,a+32|0,5);c=0;if(Hb(x[x[g>>2]>>2],x[g+4>>2])){break a}}e=fb-192|0;fb=e;f=Qm(e+80|0,x[a+36>>2]);x[31725]=0;a=P(463,e+68|0,26175)|0;c=x[31725];x[31725]=0;b:{c:{d:{e:{if((c|0)!=1){x[31725]=0;x[e+8>>2]=19989250;x[e+12>>2]=0;S(464,f|0,a|0,e+8|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}Eb(a);if(!wl(y[f|0])){break d}break b}c=N()|0;break c}c=N()|0;Eb(a);break c}v[e+67|0]=0;v[e+66|0]=0;x[31725]=0;a=P(463,e+52|0,10094)|0;c=x[31725];x[31725]=0;f:{g:{h:{i:{if((c|0)!=1){x[31725]=0;S(505,f|0,e+67|0,a|0);c=x[31725];x[31725]=0;if((c|0)==1){break i}Eb(a);if(!y[e+67|0]){break b}Qf(e+67|0,50);x[31725]=0;a=P(463,e+40|0,13288)|0;c=x[31725];x[31725]=0;if((c|0)==1){break f}x[31725]=0;S(505,f|0,e+66|0,a|0);c=x[31725];x[31725]=0;if((c|0)==1){break g}Eb(a);a=x[b>>2];c=Qj(a,x[b+4>>2]);h=y[e+67|0];if(c>>>0<h>>>0){a=$B(e+8|0,x[b+12>>2]);x[31725]=0;S(506,b|0,h|0,a|0);c=x[31725];x[31725]=0;if((c|0)==1){break h}Ik(a);a=x[b>>2]}k=z[Xj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=y[e+66|0];n=b,o=Qj(x[b>>2],x[b+4>>2])>>>0>a>>>0?a:0,v[n+16|0]=o;break b}bf(Xj(x[b>>2],a),k);l=x[b>>2];x[31725]=0;O(507,e+8|0,c|0);m=x[31725];x[31725]=0;if((m|0)!=1){x[31725]=0;V(508,f|0,Xj(l,a)|0,e+8|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break j}c=c+1|0;Eb(e+8|0);continue}break}c=N()|0;break c}c=N()|0;Eb(e+8|0);break c}c=N()|0;break c}c=N()|0;Eb(a);break c}c=N()|0;Ik(a);break c}c=N()|0;Eb(a);break c}c=N()|0}Ch(f);Q(c|0);p()}Ch(f);fb=e+192|0;c=i}gf(j,c);fb=g+16|0}function hna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+28|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];q=x[a+68>>2];A=q>>31;r=x[a+64>>2];B=r>>31;s=x[a+60>>2];C=s>>31;o=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=b>>>21&2040;h=w[b+38150>>1];i=w[b+38148>>1];e=w[b+38146>>1];g=w[b+38144>>1];b=0;j=0;while(1){if((j|0)!=2){k=j+p|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(h,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=ova(s,C,e,e>>31);i=hb;l=e;e=Yb(h,-16777216,16776704);e=ova(r,B,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(p,-16777216,16776704);i=ova(q,A,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(j&z);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Pb(f+16|0,o,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function qw(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+15|0]=c;a:{b:{c:{d:{e:{switch(b-2|0){case 11:v[e+14|0]=64;de(a,1,Rb(e+15|0,e+14|0));break a;case 0:if(!(c&3|c>>>0>223?d:1)){break b}v[e+14|0]=c>>>2;de(a,12,e+14|0);break a;case 1:if(!(c&3|c>>>0>223?d:1)){break b}v[e+14|0]=c>>>2;de(a,13,e+14|0);break a;case 2:if(c>>>0>=240){v[e+14|0]=9;de(a,11,e+14|0);break a}b=0;while(1){if((b|0)==10){break b}f=y[b+42208|0];f:{if(d){if(c>>>0>f>>>0){break f}break d}if((c|0)==(f|0)){break d}}b=b+1|0;continue};case 3:g:{if(d){v[e+14|0]=c&15;v[e+13|0]=9;c=y[Rb(e+14|0,e+13|0)|0];break g}if(c>>>0>15|(c&14)>>>0>9){break b}}v[e+14|0]=c&15;de(a,8,e+14|0);break a;case 24:h:{if(d){v[e+15|0]=0;break h}if(c){break b}}de(a,8,e+15|0);break a;case 7:v[e+15|0]=(c|0)==255?64:c>>>2|0;de(a,2,e+15|0);break a;case 9:if(!c){break b}b=c&15;if(!b){v[e+14|0]=c>>>4;de(a,3,e+14|0);break a}d=c&240;if(!d){de(a,4,e+15|0);break a}if((b|0)==15){v[e+14|0]=c>>>4;de(a,5,e+14|0);break a}if((d|0)!=240){break b}v[e+14|0]=c&15;de(a,6,e+14|0);break a;case 18:if((c&240)!=128){break b}v[e+14|0]=c<<2&60|2;de(a,2,e+14|0);break a;case 17:i:{switch((c>>>4|0)-8|0){case 0:v[e+14|0]=c<<2&60|2;de(a,2,e+14|0);break a;case 2:v[e+14|0]=c&15;de(a,5,e+14|0);break a;case 3:break i;default:break b}}v[e+14|0]=c&15;de(a,6,e+14|0);break a;case 4:case 5:case 6:case 8:case 10:case 12:case 13:case 14:case 15:case 16:case 19:case 20:case 21:case 22:case 23:break b;default:break e}}if((b|0)==46){break c}break b}v[e+14|0]=b;de(a,11,e+14|0);break a}if(d?0:c&3){break b}v[e+14|0]=c+3>>>2;de(a,1,e+14|0);break a}v[e+14|0]=0;de(a,0,e+14|0)}fb=e+16|0}function rV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=x[b>>2];if(e){if(!x[b+4>>2]){break b}g=x[b+4>>2];c:{if(!g){while(1){g=Uh(d);d=x[d+8>>2];if(!g){continue}break}break c}d=h_(g)}e=x[d>>2];if(e){break b}}e=x[d+4>>2];if(e){break b}e=0;g=1;break a}x[e+8>>2]=x[d+8>>2];g=0}d:{e:{if(Uh(d)){c=x[d+8>>2];x[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=x[d+8>>2];x[c+4>>2]=e}c=x[c>>2]}h=!y[d+12|0];if((b|0)!=(d|0)){f=x[b+8>>2];x[d+8>>2]=f;i=f+(Uh(b)?0:4)|0,j=d,x[i>>2]=j;f=x[b>>2];x[d>>2]=f;Dn(f,d);f=x[b+4>>2];x[d+4>>2]=f;if(f){Dn(f,d)}v[d+12|0]=y[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=y[c+12|0];f:{g:{if(!Uh(c)){if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;vr(b);b=x[c>>2];a=(b|0)==(a|0)?c:a;c=x[b+4>>2]}b=x[c>>2];h:{if(!(y[b+12|0]?0:b)){b=x[c+4>>2];if(y[b+12|0]?0:b){break h}v[c+12|0]=0;i:{b=x[c+8>>2];if((b|0)!=(a|0)){if(y[b+12|0]){break i}a=b}v[a+12|0]=1;return}if(!Uh(b)){break g}b=x[b+8>>2]+4|0;break f}a=x[c+4>>2];if(y[a+12|0]?0:a){break h}v[b+12|0]=1;v[c+12|0]=0;ur(c);c=x[c+8>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[x[c+4>>2]+12|0]=1;vr(a);return}if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;ur(b);b=x[c+4>>2];a=(b|0)==(a|0)?c:a;c=x[b>>2]}d=x[c>>2];j:{if(y[d+12|0]?0:d){break j}b=x[c+4>>2];if(!(y[b+12|0]?0:b)){v[c+12|0]=0;b=x[c+8>>2];if(!((a|0)!=(b|0)?y[b+12|0]:0)){v[b+12|0]=1;return}if(Uh(b)){b=x[b+8>>2]+4|0;break f}b=x[b+8>>2];break f}if(y[d+12|0]?0:d){break j}v[b+12|0]=1;v[c+12|0]=0;vr(c);c=x[c+8>>2];d=x[c>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[d+12|0]=1;ur(a);return}b=x[b+8>>2]}c=x[b>>2];continue}}v[e+12|0]=1}}function S7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-624|0;fb=a;x[a+616>>2]=c;x[a+620>>2]=b;x[a+16>>2]=1238;h=Be(a+200|0,a+208|0,a+16|0);bd(a+192|0,x[e+28>>2]);x[31725]=0;i=R(1217,x[a+192>>2])|0;b=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+191|0]=0;b=x[e+4>>2];x[31725]=0;b=na(1247,a+620|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}if(!b){break e}b=y[14638]|y[14639]<<8|(y[14640]<<16|y[14641]<<24);v[a+183|0]=b;v[a+184|0]=b>>>8;v[a+185|0]=b>>>16;v[a+186|0]=b>>>24;b=y[14635]|y[14636]<<8|(y[14637]<<16|y[14638]<<24);x[a+176>>2]=y[14631]|y[14632]<<8|(y[14633]<<16|y[14634]<<24);x[a+180>>2]=b;x[31725]=0;V(1228,i|0,a+176|0,a+186|0,a+128|0);b=x[31725];x[31725]=0;if((b|0)==1){break g}x[a+4>>2]=1205;d=Be(a+8|0,0,a+4|0);e=a+16|0;b=x[a+196>>2];c=b-x[h>>2]|0;if((c|0)<393){break f}Te(d,Fd((c>>2)+2|0));e=x[d>>2];if(e){break f}x[31725]=0;X(1206);b=x[31725];x[31725]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+191|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((LK(a+16|0,a)|0)!=1){x[31725]=0;W(1240,8e3);b=x[31725];x[31725]=0;if((b|0)!=1){break a}break c}Lc(d)}else{b=a+128|0;j=e,k=y[(a+176|0)+(ty(b,b+40|0,x[c>>2])-b>>2)|0],v[j|0]=k;e=e+1|0;c=c+4|0;b=x[a+196>>2];continue}break}}x[31725]=0;b=P(1222,a+620|0,a+616|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+620>>2];Zb(a+192|0);Lc(h);fb=a+624|0;return b|0}c=N()|0;break b}c=N()|0;Lc(d)}Zb(a+192|0);Lc(h);Q(c|0);p()}p()}function NQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;m=fb-16|0;fb=m;a:{if((b|0)==(c|0)){break a}x[m+12>>2]=-1953789045;Yz(b,c,m+12|0);k=c-b|0;c=k>>2;x[m+8>>2]=c;e=oc(x[a>>2],x[a+4>>2]);d=11;b:{if(k>>>0>2488){break b}d=7;if(k>>>0>268){break b}d=5;if(k>>>0>152){break b}d=3;if(k>>>0>24){break b}d=c-1>>>1|0}i=e+1|0;x[m+4>>2]=i;k=x[ad(m+4|0,m+8|0)>>2];h=c-d>>>1|0;f=(h<<2)+b|0;l=x[f>>2];g=c-1|0;j=D(ou(l^(x[b>>2]^x[(g<<2)+b>>2])),1664525);x[f>>2]=j+l;f=d+h|0;d=(f<<2)+b|0;l=d;n=x[d>>2];d=e+j|0;x[l>>2]=n+d;x[b>>2]=d;l=i>>>0<=1?1:i;d=(h>>>0)%(c>>>0)|0;e=(f>>>0)%(c>>>0)|0;f=x[a>>2];h=1;a=0;while(1)if((h|0)==(l|0)){while(1)if(k>>>0<=i>>>0){i=c+k|0;h=k>>>0>i>>>0?k:i;while(1){if((h|0)==(k|0)){break a}g=g+1|0;g=(c|0)!=(g|0)?g:0;d=d+1|0;d=(c|0)!=(d|0)?d:0;f=(d<<2)+b|0;l=x[f>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;j=(a<<2)+b|0;i=D(ou(x[(g<<2)+b>>2]+(l+x[j>>2]|0)|0),1566083941);x[f>>2]=i^l;e=e+1|0;e=(c|0)!=(e|0)?e:0;f=(e<<2)+b|0;i=i-a|0;x[f>>2]=i^x[f>>2];x[j>>2]=i;k=k+1|0;continue}}else{d=d+1|0;d=(c|0)!=(d|0)?d:0;f=(d<<2)+b|0;l=x[f>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;j=(a<<2)+b|0;g=g+1|0;g=(c|0)!=(g|0)?g:0;h=D(ou(l^(x[j>>2]^x[(g<<2)+b>>2])),1664525);x[f>>2]=h+l;e=e+1|0;e=(c|0)!=(e|0)?e:0;f=(e<<2)+b|0;h=a+h|0;x[f>>2]=h+x[f>>2];x[j>>2]=h;i=i+1|0;continue}}else{d=d+1|0;d=(c|0)!=(d|0)?d:0;n=(d<<2)+b|0;o=x[n>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;p=(a<<2)+b|0;g=g+1|0;g=(c|0)!=(g|0)?g:0;j=D(ou(o^(x[p>>2]^x[(g<<2)+b>>2])),1664525);x[n>>2]=j+o;j=x[yb(f,h-1|0)>>2]+(a+j|0)|0;e=e+1|0;e=(c|0)!=(e|0)?e:0;n=(e<<2)+b|0;x[n>>2]=j+x[n>>2];x[p>>2]=j;h=h+1|0;continue}}fb=m+16|0}function Z7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-272|0;fb=a;x[a+264>>2]=c;x[a+268>>2]=b;x[a+16>>2]=1238;h=Be(a+152|0,a+160|0,a+16|0);bd(a+144|0,x[e+28>>2]);x[31725]=0;i=R(28,x[a+144>>2])|0;b=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+143|0]=0;b=x[e+4>>2];x[31725]=0;b=na(1239,a+268|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}if(!b){break e}b=y[14638]|y[14639]<<8|(y[14640]<<16|y[14641]<<24);v[a+135|0]=b;v[a+136|0]=b>>>8;v[a+137|0]=b>>>16;v[a+138|0]=b>>>24;b=y[14635]|y[14636]<<8|(y[14637]<<16|y[14638]<<24);x[a+128>>2]=y[14631]|y[14632]<<8|(y[14633]<<16|y[14634]<<24);x[a+132>>2]=b;x[31725]=0;V(1215,i|0,a+128|0,a+138|0,a+118|0);b=x[31725];x[31725]=0;if((b|0)==1){break g}x[a+4>>2]=1205;d=Be(a+8|0,0,a+4|0);e=a+16|0;b=x[a+148>>2];c=b-x[h>>2]|0;if((c|0)<99){break f}Te(d,Fd(c+2|0));e=x[d>>2];if(e){break f}x[31725]=0;X(1206);b=x[31725];x[31725]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+143|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((LK(a+16|0,a)|0)!=1){x[31725]=0;W(1240,8e3);b=x[31725];x[31725]=0;if((b|0)!=1){break a}break c}Lc(d)}else{b=a+118|0;i=r_(b);j=e,k=y[((Mi(b,i,y[c|0])-a|0)+a|0)+10|0],v[j|0]=k;e=e+1|0;c=c+1|0;b=x[a+148>>2];continue}break}}x[31725]=0;b=P(1207,a+268|0,a+264|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+268>>2];Zb(a+144|0);Lc(h);fb=a+272|0;return b|0}c=N()|0;break b}c=N()|0;Lc(d)}Zb(a+144|0);Lc(h);Q(c|0);p()}p()}function Lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=x[a>>2];d=qm(e,x[a+4>>2]);if(d>>>0<b>>>0){i=fb-32|0;fb=i;a:{b:{g=b-d|0;b=x[zb(a)>>2];e=x[a+4>>2];c:{if(g>>>0<=(b-e|0)/52>>>0){pA(a,g,c);break c}f=zb(a);d=uR(a,qm(x[a>>2],e)+g|0);j=qm(x[a>>2],x[a+4>>2]);h=fb-16|0;fb=h;b=i+12|0;Kg(b+12|0,f);d:{if(!d){e=0;d=0;break d}rR(h+8|0,d);e=x[h+12>>2];d=x[h+8>>2]}x[b>>2]=d;f=d+D(j,52)|0;x[b+8>>2]=f;x[b+4>>2]=f;l=nc(b),m=d+D(e,52)|0,x[l>>2]=m;fb=h+16|0;x[31725]=0;S(928,b|0,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}h=fb-16|0;fb=h;c=zb(a);d=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);e=x[d>>2];g=x[g>>2];d=fb+-64|0;fb=d;f=x[f>>2];x[d+56>>2]=f;x[d+60>>2]=e;x[d+52>>2]=f;c=Se(d+24|0,c,d+52|0,d+56|0);x[d+16>>2]=x[c+8>>2];f=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=f;Re(d+36|0,d+8|0);while(1){if(pd(e,g)){c=e-52|0;e=$l(oR(x[d+56>>2]),c);x[e+20>>2]=x[c+20>>2];f=x[c+16>>2];x[e+12>>2]=x[c+12>>2];x[e+16>>2]=f;FW(e+24|0,c+24|0);_c(e+36|0,c+36|0);x[e+48>>2]=x[c+48>>2];c=pR(d+60|0);pR(d+56|0);e=x[c>>2];continue}break}Qe(d+36|0);j=x[d+56>>2];if(!y[d+48|0]){g=fb-16|0;fb=g;c=vb(g+12|0,x[x[d+44>>2]>>2]);k=x[vb(g+8|0,x[x[d+40>>2]>>2])>>2];f=fb-16|0;fb=f;c=x[c>>2];x[f+12>>2]=c;while(1){if(di(c,k)){e=fb-16|0;fb=e;x[e+12>>2]=c;x[e+12>>2]=x[e+12>>2]+52;fb=e+16|0;Ek(oR(x[e+12>>2]));c=x[bm(f+12|0)>>2];continue}break}fb=f+16|0;fb=g+16|0}fb=d- -64|0;x[b+4>>2]=j;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0;qR(b)}fb=i+32|0;break a}a=N()|0;qR(b);Q(a|0);p()}return}if(b>>>0<d>>>0){vR(a,e+D(b,52)|0)}}function G7(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;w=d&512;z=h<<2;while(1){if((u|0)==4){if(Cb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=IJ(Mk(zd(n),1),ul(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];h=Bt(g,32);p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 3:if(Ad(x[n+4>>2],y[n+11|0])){break a}h=x[Wd(n,0)>>2];p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 2:if(Ad(x[m+4>>2],y[m+11|0])|!w){break a}B=c,C=IJ(zd(m),ul(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}A=x[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!zj(g,64,x[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=x[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){q=q-1|0;h=h-4|0;s=x[h>>2];r=p+4|0;x[c>>2]=r;x[p>>2]=s;p=r;continue}break}d:{if(!q){s=0;break d}s=Bt(g,48);p=x[c>>2]}while(1){r=p+4|0;if((q|0)>0){x[p>>2]=s;q=q-1|0;p=r;continue}break}x[c>>2]=r;x[p>>2]=j}e:{if((e|0)==(h|0)){p=Bt(g,48);q=x[c>>2];h=q+4|0;x[c>>2]=h;x[q>>2]=p;break e}s=-1;if(!Ad(x[l+4>>2],y[l+11|0])){s=v[cc(l,0)|0]}q=0;t=0;while(1){if((e|0)!=(h|0)){r=x[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;x[c>>2]=p;x[r>>2]=k;r=0;t=t+1|0;if(Cb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){s=q;break f}s=-1;if(y[cc(l,t)|0]==127){break f}s=v[cc(l,t)|0]}h=h-4|0;q=x[h>>2];x[c>>2]=p+4;x[p>>2]=q;q=r+1|0;continue}break}h=x[c>>2]}jt(A,h)}u=u+1|0;continue}break}}function pe(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{b:{c:{switch(b|0){case 1:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31725]=0;O(53,b|0,Yc(e,d)|0);d=x[31725];x[31725]=0;d:{if((d|0)!=1){e:{while(1){if(Yc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=v[cc(c,a)|0];x[31725]=0;O(35,b|0,((d|0)<0?65533:d&255)|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31725]=0;O(53,b|0,Yc(e,d)|0);d=x[31725];x[31725]=0;f:{if((d|0)!=1){while(1){if(Yc(x[c+4>>2],y[c+11|0])>>>0<=a>>>0){break f}d=y[cc(c,a)|0];x[31725]=0;O(35,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){a=a+1|0;continue}break}}break a}return;case 3:jf(a,c,48928);return;case 4:jf(a,c,49952);return;case 5:jf(a,c,50976);return;case 6:jf(a,c,52e3);return;case 7:jf(a,c,53024);return;case 8:jf(a,c,54048);return;case 9:jf(a,c,55072);return;case 10:jf(a,c,56096);return;case 11:jf(a,c,57120);return;case 12:jf(a,c,58144);return;case 13:jf(a,c,59168);return;case 14:jf(a,c,60192);return;case 15:jf(a,c,61216);return;case 16:jf(a,c,62240);return;case 17:jf(a,c,63264);return;case 18:jf(a,c,64288);return;case 19:jf(a,c,65312);return;case 20:jf(a,c,66336);return;case 21:jf(a,c,67360);return;case 22:jf(a,c,68384);return;case 23:jf(a,c,69408);return;case 24:hB(a,c,70432);return;case 25:hB(a,c,48928);return;case 26:hB(a,c,67360);return;default:a=ac(8);x[31725]=0;b=P(16,a|0,11106)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}b=N()|0;jc(a);Q(b|0);p();case 0:break c}}G_(a,c);return}da(b|0,125132,17);p()}a=N()|0;Qb(b);Q(a|0);p()}function Jka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-32|0;fb=c;a:{b:{c:{d:{e:{f:{if(Dd(x[a+24>>2])){break f}i=Yc(x[a+8>>2],y[a+15|0]);f=fb-16|0;fb=f;h=f+8|0;x[h>>2]=-1;x[h+4>>2]=-1;x[31725]=0;g=iI(66);d=x[31725];x[31725]=0;b=hb;if((d|0)==1){T(0)|0;Sb();p()}e=fb-16|0;fb=e;d=we(e+8|0,ova(g,b,1e3,0),hb);b=x[d>>2];fb=e+16|0;j=f,k=sA(b,x[d+4>>2]),x[j>>2]=k;x[f+4>>2]=hb;e=wR(h,f,zb(f));x[31725]=0;g=iI(67);d=x[31725];x[31725]=0;b=hb;if((d|0)==1){T(0)|0;Sb();p()}h=a+24|0;j=f,k=sA(sR(g,b),hb),x[j>>2]=k;x[f+4>>2]=hb;b=wR(e,f,zb(f));d=x[b>>2];b=x[b+4>>2];fb=f+16|0;if(i){e=Nb(c+20|0);x[31725]=0;x[c+8>>2]=b;O(60,e|0,c+8|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}x[31725]=0;x[c+8>>2]=d;O(60,e|0,c+8|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}d=a+4|0;g=0;g:{while(1){if(Yc(x[a+8>>2],y[a+15|0])>>>0<=g>>>0){b=wb(x[e>>2]);a=wb(x[e+4>>2]);x[31725]=0;d=U(61,c+8|0,b|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break g}a=N()|0;break b}b=y[cc(d,g)|0];x[31725]=0;x[c+8>>2]=b;O(60,e|0,c+8|0);b=x[31725];x[31725]=0;if((b|0)!=1){g=g+1|0;continue}break}a=N()|0;break b}x[31725]=0;b=R(62,d|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){x[c+4>>2]=b;a=c+4|0;wA(h,a);Hj(a);cn(d);uc(e);break f}a=N()|0;cn(d);break b}hb=d;x[c+8>>2]=b;x[c+12>>2]=hb;b=Nb(c+20|0);x[31725]=0;S(65,b|0,c+8|0,c+16|0);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;uc(b);Q(a|0);p()}x[31725]=0;d=R(62,b|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break e}x[c+4>>2]=d;a=c+4|0;wA(h,a);Hj(a);cn(b)}fb=c+32|0;return}a=N()|0;cn(b);break a}a=N()|0;break b}a=N()|0}uc(e)}Q(a|0);p()}function Au(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-128|0;fb=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}d=x[c+4>>2];if(!d&A[c>>2]>=A[b+4>>2]|d){break h}a=ac(8);x[31725]=0;b=P(51,a|0,22255)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break g}b=N()|0;jc(a);break a}if(!x[b>>2]){a=ac(8);x[31725]=0;b=R(859,a|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break f}b=N()|0;jc(a);break a}d=x[b>>2];j=x[b+4>>2];b=fb-16|0;fb=b;mf(b+8|0,d,j);h=x[b+8>>2];g=f+108|0;DG(g,h,x[b+12>>2]);x[g+12>>2]=0;fb=b+16|0;i:{j:{if(a&2){b=Sn(f+88|0,g);x[31725]=0;b=R(860,b|0)|0;e=x[31725];x[31725]=0;d=1;if((e|0)==1){break i}if((b|0)==1){break j}d=Sn(f+68|0,g);x[31725]=0;e=R(861,d|0)|0;h=x[31725];x[31725]=0;d=1;if((h|0)==1){break e}k=(e|0)==1;if(k){break j}d=Sn(f+48|0,g);x[31725]=0;h=P(862,d|0,c|0)|0;i=x[31725];x[31725]=0;d=1;if((i|0)==1){break d}l=(h|0)==1;if(l){break j}d=Sn(f+28|0,g);x[31725]=0;i=P(863,d|0,c|0)|0;m=x[31725];x[31725]=0;d=1;if((m|0)==1){break c}if((i|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(e|0)==-1?-1:b;e=(i|0)==-1?-1:l?b:(h|0)==-1?-1:b}k:{if(!(a&1)){break k}b=29920;while(1){if((b|0)==30496){break k}a=x[b>>2];if(a){d=Sn(f+8|0,g);x[31725]=0;a=P(a|0,d|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}d=1;if((a|0)==1){break j}e=(a|0)==-1?-1:e}b=b+12|0;continue}}a=j;if(c){d=0;if((e|0)!=-1){break j}d=Bc(x[c>>2],x[c+4>>2])>>>0>a>>>0?-1:0;break j}d=0;if((e|0)!=-1){break j}d=a>>>0>2047?1:-1}fb=f+128|0;return d}b=N()|0;break a}da(b|0,125292,17);p()}da(b|0,125188,17);p()}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0}Q(b|0);p()}function X4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-576|0;fb=c;Tb(c+532|0,0,44);x[c+24>>2]=0;x[c+28>>2]=0;while(1){a:{if((d|0)==7){d=0;while(1){b:{if((d|0)==12){x[c+540>>2]=1;d=c+432|0;fa(d|0,100,9262,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+20>>2]=d;e=Hi(c+32|0,c+20|0,100,c+24|0,x[a>>2]);if((e|0)!=-1){break b}break a}x[c+548>>2]=d;e=c+432|0;fa(e|0,100,14278,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;f=Hi(c+32|0,c+8|0,100,c+24|0,x[a>>2]);if(f+1>>>0<=1){break a}g=D(d,12)+a|0;e=c+32|0;Hm(g+172|0,e,e+(f<<2)|0);f=c+432|0;fa(f|0,100,13333,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=f;e=Hi(e,c+8|0,100,c+24|0,x[a>>2]);if(e+1>>>0<=1){break a}f=c+32|0;Hm(g+316|0,f,f+(e<<2)|0);d=d+1|0;continue}break}d=c+32|0;Hm(a+460|0,d,d+(e<<2)|0);x[c+540>>2]=13;e=c+432|0;fa(e|0,100,9262,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+20>>2]=e;d=Hi(d,c+20|0,100,c+24|0,x[a>>2]);if((d|0)!=-1){e=c+32|0;Hm(a+472|0,e,e+(d<<2)|0);d=c+8|0;Ws(d,a,99,b);qh(a+484|0,d);Qb(d);Ws(d,a,114,b);qh(a+496|0,d);Qb(d);Ws(d,a,120,b);qh(a+508|0,d);Qb(c+8|0);Ws(d,a,88,b);qh(a+520|0,d);Qb(c+8|0);fb=c+576|0;return}break a}x[c+556>>2]=d;e=c+432|0;fa(e|0,100,14291,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;f=Hi(c+32|0,c+8|0,100,c+24|0,x[a>>2]);if(f+1>>>0>1){g=D(d,12)+a|0;e=c+32|0;Hm(g+4|0,e,e+(f<<2)|0);f=c+432|0;fa(f|0,100,13540,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=f;e=Hi(e,c+8|0,100,c+24|0,x[a>>2]);if(e+1>>>0<=1){break a}f=c+32|0;Hm(g+88|0,f,f+(e<<2)|0);d=d+1|0;continue}}break}ko(12661);p()}function GH(a,b,c){var d=0,e=0,f=0,g=0;d=fb-432|0;fb=d;a:{f=Ts(d+428|0,b);e=x[f>>2];b:{if(!Dd(e)){x[31725]=0;b=P(36,d+416|0,b|0)|0;a=x[31725];x[31725]=0;c:{d:{e:{if((a|0)!=1){x[31725]=0;S(1017,d+16|0,17691,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}x[31725]=0;W(1345,d+16|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d+16|0)}tb(b);break b}kq(e);if(!gq(a+8|0,22255,x[f>>2])){x[a+8>>2]=2147483647}if(!gq(a+12|0,22255,x[f>>2])){x[a+12>>2]=2147483647}x[31725]=0;O(274,a+16|0,22255);b=x[31725];x[31725]=0;f:{g:{if((b|0)!=1){x[d+8>>2]=0;x[d+12>>2]=0;x[d+4>>2]=22255;b=Hi(d+16|0,d+4|0,100,d+8|0,x[f>>2]);if((b|0)==-1){x[31725]=0;W(1240,12661);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;break b}x[31725]=0;e=d+16|0;b=U(1352,a+28|0,e|0,e+(b<<2)|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break f}x[a+64>>2]=0;x[d+4>>2]=22255;x[d+8>>2]=0;x[d+12>>2]=0;h:{e=Hi(d+16|0,d+4|0,100,d+8|0,x[f>>2]);if((e|0)!=-1){x[31725]=0;g=d+16|0;U(1352,a+40|0,g|0,g+(e<<2)|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break f}x[d+4>>2]=22255;x[d+8>>2]=0;x[d+12>>2]=0;e=Hi(d+16|0,d+4|0,100,d+8|0,x[f>>2]);if((e|0)!=-1){break h}}x[31725]=0;W(1240,12661);a=x[31725];x[31725]=0;if((a|0)!=1){break a}break f}x[31725]=0;g=d+16|0;U(1352,a+52|0,g|0,g+(e<<2)|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break f}x[31725]=0;b=P(1353,d+416|0,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){break g}a=N()|0;break b}a=N()|0;break b}ii(a+68|0,c);ii(a+72|0,c);Qb(b);pl(f);fb=d+432|0;return}a=N()|0}pl(f);Q(a|0);p()}p()}function xna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+28|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;n=x[a+8>>2];C=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+t|0;b=0;j=0;while(1){if((j|0)!=2){g=e+(j<<1)|0;h=w[g>>1];x[(f+8|0)+(j<<2)>>2]=h+((D(i,w[g+4>>1]-h|0)|0)/16384|0);j=j+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=ova(q,B,e,e>>31);i=hb;k=e;e=Yb(h,-16777216,16776704);e=ova(p,A,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(j,-16777216,16776704);i=ova(o,z,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(s&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}m=m+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],m>>12);l=l+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],l>>12);Pb(f+16|0,n,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function lQ(a){var b=E(0),c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,k=0,l=E(0),m=0,n=E(0);c=fb-16|0;fb=c;e=a+4208|0;b=Uz(B[yb(e,2)>>2]);f=x[a+16>>2]+24620|0;B[c+12>>2]=b/E(A[f>>2]);x[c+8>>2]=1056964608;b=Cq(E(B[Zm(c+12|0,c+8|0)>>2]*E(6.2831854820251465)));b=E(M(E(E(E(b+b)+E(3))/E(5))));B[a+4236>>2]=b;B[a+4240>>2]=M(E(E(1)-E(b*b)));b=E(E(B[yb(e,1)>>2]*E(29))+E(2));a:{if(b<E(4294967296)&b>=E(0)){i=~~b>>>0;break a}i=0}v[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}v[a+4273|0]=k;l=De(E(10),E(E(E(B[a+4208>>2]*E(60))+E(-60))/E(20)));m=c,n=E(Uz(B[yb(e,3)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;g=B[Zm(c+12|0,c+8|0)>>2];m=c,n=E(Uz(B[yb(e,4)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;b=E(E(B[Zm(c+12|0,c+8|0)>>2]*E(6.2831854820251465))*E(.5));f=fb-16|0;fb=f;e=(q(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=ro(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=ro(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=ro(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=ro(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=ro(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=E(b-b);break b}d=Yy(b,f+8|0);b=ro(C[f+8>>3],d&1)}fb=f+16|0;b=E(E(E(1)-b)/E(b+E(1)));B[a+4268>>2]=b;g=Cq(E(g*E(6.2831854820251465)));B[a+4264>>2]=-g;B[a+4260>>2]=E(E(l*E(M(E(E(1)-E(g*g)))))*E(M(E(E(1)-E(b*b)))))*B[(i<<2)+44064>>2];fb=c+16|0}function Nna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];n=mg(1,2);b=hb;u=b;Pb(a,n,b);b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;v=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];o=x[a+68>>2];A=o>>31;p=x[a+64>>2];B=p>>31;q=x[a+60>>2];C=q>>31;m=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;F=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=ova(q,C,e,e>>31);i=hb;j=e;e=Yb(h,-16777216,16776704);e=ova(p,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(F,-16777216,16776704);i=ova(o,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(s&z);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+v|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,m,E);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Hg(a,n,u);fb=f+48|0}function yna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+28|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];w=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;n=x[a+8>>2];C=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+t|0;b=0;j=0;while(1){if((j|0)!=2){g=e+j|0;h=v[g|0];x[(f+8|0)+(j<<2)>>2]=((D(i,v[g+2|0]-h|0)|0)/16384|0)+(h<<8);j=j+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=ova(q,B,e,e>>31);i=hb;k=e;e=Yb(h,-16777216,16776704);e=ova(p,A,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(j,-16777216,16776704);i=ova(o,z,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(s&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}m=m+w|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],m>>12);l=l+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],l>>12);Pb(f+16|0,n,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Pq(a,b,c,d){var e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),p=0;h=fb-16|0;fb=h;x[h+12>>2]=w[b+780>>1]+y[b+837|0];x[h+8>>2]=w[b+782>>1]+(y[b+838|0]&127);Fe(h+12|0,0,127);Fe(h+8|0,0,127);k=a+1074312|0;j=Ob(k,1);i=x[h+8>>2];l=x[h+12>>2];if(!j){v[b+838|0]=i;v[b+837|0]=l;x[b+780>>2]=0}m=D(d+256|0,l);j=(m|0)/256|0;a:{if(!(i|!Ob(k,36)|(m|0)<65024)){j=-1;if(!(y[b+851|0]&2)){break a}x[b+88>>2]=x[b+88>>2]&-32769;break a}x[b+88>>2]=x[b+88>>2]|32768;e=De(E(10),E(E(0-i|0)*E(.00937500037252903)));i=fb-16|0;fb=i;g=E(D(d+256|0,l)>>>0);b:{if(x[a+480180>>2]!=33554432){f=E(110);g=E(E(g/(y[a+480209|0]&128?E(10240):E(12288)))+E(.25));break b}f=E(125);g=E(E(g*E(6))/E(65024))}n=i,o=E(De(E(2),g)*f),B[n+12>>2]=o;d=i+12|0;QT(d,E(120),E(2e4));AB(d,E(E(A[a+24620>>2])*E(.5)));fb=i+16|0;g=E(B[i+12>>2]*E(6.2831854820251465));c:{if(!(!Ob(k,36)|y[a+480209|0]&128)){f=E(E(A[a+24620>>2])/g);g=E(E(E(e*f)+e)+E(-1));e=E(f*f);break c}f=E(e+e);e=E(g/E(A[a+24620>>2]));B[h+4>>2]=E(E(1)-f)*e;AB(h+4|0,E(2));g=E(E(f-B[h+4>>2])/e);e=E(E(1)/E(e*e))}f=E(e+E(g+E(1)));g=E(E(e+E(e+g))/f);e=E(E(-e)/f);f=E(E(1)/f);d:{if(y[b+845|0]==1){n=b,p=Sl(E(E(E(1)-f)*E(16777216))),x[n+60>>2]=p;n=b,p=Sl(E(g*E(16777216))),x[n+64>>2]=p;n=b,p=Sl(E(e*E(16777216))),x[n+68>>2]=p;a=-1;break d}d=Sl(E(f*E(16777216)));x[b+60>>2]=d;n=b,p=Sl(E(g*E(16777216))),x[n+64>>2]=p;n=b,p=Sl(E(e*E(16777216))),x[n+68>>2]=p;a=0;if(d){break d}x[b+60>>2]=1}x[b+72>>2]=a;if(!c){break a}x[b+44>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;x[b+56>>2]=0}fb=h+16|0;return j}function K7(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;z=d&512;while(1){if((u|0)==4){if(Cb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=mp(Pe(zd(n),1),Df(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];p=rm(g,32);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 3:if(Ad(x[n+4>>2],y[n+11|0])){break a}p=y[cc(n,0)|0];q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 2:if(Ad(x[m+4>>2],y[m+11|0])|!z){break a}B=c,C=mp(zd(m),Df(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}p=x[g+8>>2];A=x[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!Kf(p,64,v[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){p=p-1|0;r=r-1|0;q=y[r|0];s=x[c>>2];x[c>>2]=s+1;v[s|0]=q;continue}break}if(p){q=rm(g,48)}else{q=0}while(1){s=x[c>>2];x[c>>2]=s+1;if((p|0)>0){v[s|0]=q;p=p-1|0;continue}break}v[s|0]=j}d:{if((e|0)==(r|0)){p=rm(g,48);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break d}q=-1;if(!Ad(x[l+4>>2],y[l+11|0])){q=v[cc(l,0)|0]}p=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=x[c>>2];x[c>>2]=q+1;v[q|0]=k;s=0;t=t+1|0;if(Cb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){q=p;break e}q=-1;if(y[cc(l,t)|0]==127){break e}q=v[cc(l,t)|0]}r=r-1|0;p=y[r|0];w=x[c>>2];x[c>>2]=w+1;v[w|0]=p;p=s+1|0;continue}}Im(A,x[c>>2])}u=u+1|0;continue}break}}function Voa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;k=f,l=$j(b),x[k+4>>2]=l;e=fb-16|0;fb=e;h=a;c=ce(a);a:{if(c){g=ec(h);while(1){a=c;c=a+14|0;if(kv(b,c)){g=a;c=x[a>>2];if(c){continue}break a}if(!kv(c,b)){break a}g=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(h);g=a}x[e+12>>2]=a;b=x[g>>2];if(!b){i=fb-16|0;fb=i;a=ec(h);j=Dh(e,Ec(48),Mg(i+8|0,a));a=x[j>>2];b=x[f+4>>2];c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+14|0]=d;v[a+15|0]=d>>>8;v[a+16|0]=d>>>16;v[a+17|0]=d>>>24;v[a+18|0]=c;v[a+19|0]=c>>>8;v[a+20|0]=c>>>16;v[a+21|0]=c>>>24;c=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);d=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[a+38|0]=d;v[a+39|0]=d>>>8;v[a+40|0]=d>>>16;v[a+41|0]=d>>>24;v[a+42|0]=c;v[a+43|0]=c>>>8;v[a+44|0]=c>>>16;v[a+45|0]=c>>>24;c=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);d=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[a+30|0]=d;v[a+31|0]=d>>>8;v[a+32|0]=d>>>16;v[a+33|0]=d>>>24;v[a+34|0]=c;v[a+35|0]=c>>>8;v[a+36|0]=c>>>16;v[a+37|0]=c>>>24;c=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a+22|0]=b;v[a+23|0]=b>>>8;v[a+24|0]=b>>>16;v[a+25|0]=b>>>24;v[a+26|0]=c;v[a+27|0]=c>>>8;v[a+28|0]=c>>>16;v[a+29|0]=c>>>24;w[a+46>>1]=0;k=ec(j),l=1,v[k+4|0]=l;fb=i+16|0;$g(h,x[e+12>>2],g,x[e>>2]);b=le(e);em(e);d=1}_g(f+8|0,x[vb(e,b)>>2],d);fb=e+16|0;a=jp(x[f+8>>2]);fb=f+16|0;return a+32|0}function V1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;g=Si(b)^-1;a:{if(oc(x[d>>2],x[d+4>>2])>>>0<=g>>>0){yu(a);break a}Si(b);if((y[c+4|0]|y[c+5|0]<<8)>>>0>=60){Vb(b,4)}j=f,k=Si(b),x[j+44>>2]=k;Vb(b,4);h=Si(b);i=Si(b);if(!((h|0)>0&(i|0)>36)){yu(a);break a}if(!Ld(Hd(x[e>>2],x[yb(x[d>>2],g)>>2]),13165)){yu(a);break a}e=f+4|0;vF(e,b,i,h);d=ic(f+24|0,e);ub(e);b=x[d>>2];x[31725]=0;b=R(174,b|0)|0;e=x[31725];x[31725]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){x[31725]=0;R(184,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break d}break b}b=y[c+4|0]|y[c+5|0]<<8;if(b>>>0<=39){x[31725]=0;P(185,d|0,8)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}b=y[c+4|0]|y[c+5|0]<<8}if((b&65535)>>>0<=59){x[31725]=0;P(185,d|0,16)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}}x[31725]=0;R(186,d|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}e:{f:{b=y[c+4|0]|y[c+5|0]<<8;g:{if(b>>>0>=120){x[31725]=0;R(186,d|0)|0;c=x[31725];x[31725]=0;b=8;break g}h:{if(b>>>0>=100){x[31725]=0;P(185,d|0,4)|0;b=x[31725];x[31725]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}x[31725]=0;R(186,d|0)|0;c=x[31725];x[31725]=0;b=4}if((c|0)==1){break b}x[31725]=0;P(185,d|0,b|0)|0;break e}x[31725]=0;R(186,d|0)|0}b=x[31725];x[31725]=0;if((b|0)==1){break b}x[31725]=0;b=R(186,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}x[31725]=0;S(187,f+4|0,d|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=a;a=f+4|0;j=ic(b,a),k=x[f+44>>2],x[j+20>>2]=k;ub(a)}ub(d);break a}}a=N()|0;ub(d);Q(a|0);p()}fb=f+48|0}function kna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;m=x[a+8>>2];A=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=b>>>21&2040;h=w[b+38150>>1];i=w[b+38148>>1];e=w[b+38146>>1];g=w[b+38144>>1];b=0;j=0;while(1){if((j|0)!=2){k=n+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(h,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;n=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=ova(q,z,e,e>>31);i=hb;l=e;e=Yb(h,-16777216,16776704);e=ova(p,y,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(n,-16777216,16776704);i=ova(o,v,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(j&u);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Pb(f+16|0,m,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Ona(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];n=mg(1,2);b=hb;u=b;Pb(a,n,b);b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;w=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];o=x[a+68>>2];A=o>>31;p=x[a+64>>2];B=p>>31;q=x[a+60>>2];C=q>>31;m=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;F=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=ova(q,C,e,e>>31);i=hb;j=e;e=Yb(h,-16777216,16776704);e=ova(p,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(F,-16777216,16776704);i=ova(o,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(s&z);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+w|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,m,E);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Hg(a,n,u);fb=f+48|0}function Ah(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=fb-16|0;fb=c;a:{if((d|0)==189){v[a+3843|0]=e>>>7;v[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=D(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){Uo(f,g);break b}Uo(f,0)}v[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=D(d&256?b+9|0:b,44)+a|0;x[c+8>>2]=a+16;b=x[a+52>>2];x[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];UU(x[a>>2],d);UU(x[a+4>>2],d);w[a+22>>1]=h;UB(a);WU(a);v[a+21|0]=f;UB(a);WU(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];w[a+20>>1]=z[a+20>>1]&768|e&255;UB(a);b=b+1|0;continue}}v[a+58|0]=(e&32)>>>5;v[a+57|0]=(e&16)>>>4;b=e>>>1&7;w[a+46>>1]=b?9-b|0:0;w[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=v[(d&31)+27360|0];a=(f+D(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:v[a+79|0]=e>>>7;v[a+80|0]=(e&64)>>>6;v[a+78|0]=(e&32)>>>5;v[a+77|0]=(e&16)>>>4;Vo(a);w[a+14>>1]=z[((e&15)<<1)+27392>>1];break a;case 1:w[a+68>>1]=y[(e>>>6|0)+22240|0];VU(a);w[a+22>>1]=(e&63)<<2;break a;case 2:w[a+24>>1]=e>>>4;Vo(a);w[a+26>>1]=e&15;Vo(a);break a;case 3:b=e>>>4|0;w[a+28>>1]=b>>>0>=15?496:b<<4;w[a+30>>1]=e&15;Vo(a);break a;case 6:break d;default:break a}}w[a+12>>1]=e&7}fb=c+16|0;return}ib[x[x[b>>2]>>2]](b,c,d,e)}function Uma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0;g=fb-16|0;fb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=x[a+16>>2];e=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+44>>2];l=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=l;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;while(1){l=b;if(d){b=Yb(l,-16777216,16776704);m=ova(r,A,b,b>>31);n=hb;b=x[g+8>>2];f=(x[g+12>>2]<<1)+t|0;b=(b>>>16&65520)+p|0;f=(((((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+4>>1],w[b+10>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/32768<<8;b=f;b=ova(b,b>>31,s,B);m=b+m|0;o=hb+n|0;o=b>>>0>m>>>0?o+1|0:o;b=Yb(e,-16777216,16776704);e=ova(q,z,b,b>>31);n=e+m|0;b=hb+o|0;b=e>>>0>n>>>0?b+1|0:b;e=n+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;k=k+v|0;x[c>>2]=D(b,k>>12)+x[c>>2];j=j+u|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Pb(g+8|0,i,h);b=e-(f&y)|0;c=c+8|0;d=d-1|0;e=l;continue}break}b=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=e;x[a+44>>2]=l;x[a+24>>2]=j>>12;fb=g+16|0}function lna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];y=o>>31;p=x[a+64>>2];z=p>>31;q=x[a+60>>2];A=q>>31;m=x[a+8>>2];B=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=b>>>21&2040;h=w[b+38150>>1];i=w[b+38148>>1];e=w[b+38146>>1];g=w[b+38144>>1];b=0;j=0;while(1){if((j|0)!=2){k=j+n|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(h,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;n=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=ova(q,A,e,e>>31);i=hb;l=e;e=Yb(h,-16777216,16776704);e=ova(p,z,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(n,-16777216,16776704);i=ova(o,y,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(j&u);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Pb(f+16|0,m,B);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;g=fb-16|0;fb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}s=x[a+16>>2];b=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+44>>2];l=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=l;t=x[a+32>>2];u=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;while(1){l=e;if(d){e=Yb(l,-16777216,16776704);f=ova(p,A,e,e>>31);e=hb;b=Yb(b,-16777216,16776704);b=ova(o,z,b,b>>31);f=b+f|0;e=hb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[g+8>>2];m=f;f=x[g+12>>2]+s|0;b=(b>>>16&65520)+n|0;r=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=r;f=ova(b,b>>31,q,B);m=m+f|0;b=hb+e|0;b=f>>>0>m>>>0?b+1|0:b;e=m+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;k=k+u|0;x[c>>2]=D(b,k>>12)+x[c>>2];j=j+t|0;x[c+4>>2]=x[c+4>>2]+D(j>>12,b);Pb(g+8|0,i,h);e=e-(y&r)|0;c=c+8|0;d=d-1|0;b=l;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=b;x[a+44>>2]=l;x[a+24>>2]=j>>12;fb=g+16|0}function Iz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);e=fb-48|0;fb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=x[a+24>>2];if((b|0)==x[d+24604>>2]){break d}a=e+8|0;yc(a,d+24604|0,40);x[e+8>>2]=b;MA(d,a);break d;case 2:f=x[a+24>>2];d=f+24664|0;b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;d=f+24656|0;b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;b=x[f+24652>>2];x[e+8>>2]=x[f+24648>>2];x[e+12>>2]=b;d=fb-16|0;fb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=ac(8);x[31725]=0;b=P(36,d+4|0,10830)|0;a=x[31725];x[31725]=0;i:{if((a|0)!=1){pc(c,b);x[31725]=0;S(99,c|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break g}a=N()|0;tb(b);break i}a=N()|0;jc(c)}Q(a|0);p()}fb=d+16|0;break f}p()}v[e+8|0]=b;a=x[a+24>>2];if(!yz(e+8|0,a+24648|0)){break d}KA(a,e+8|0);break d;case 3:f=e+8|0;d=x[a+24>>2];yc(f,d+24604|0,40);b=fb-48|0;fb=b;j:{if((c|0)==-1){au(f,x[_q(b+8|0)+32>>2]);Uo(f,x[_q(b+8|0)+36>>2]);break j}if((c|0)<=0){au(f,0);Uo(f,0);break j}a=D(c,1e3);au(f,a);Uo(f,a)}fb=b+48|0;if(x[d+24636>>2]==x[e+40>>2]&x[d+24640>>2]==x[e+44>>2]){break d}MA(d,e+8|0);break d;default:d=ac(8);x[31725]=0;c=P(36,e+8|0,10385)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(d,c);x[31725]=0;S(99,d|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b;case 0:break e}}g=a,h=De(E(10),E(E(E(c|0)*E(.0010000000474974513))*E(.5))),B[g+48>>2]=h}fb=e+48|0;return}b=N()|0;jc(d)}Q(b|0)}p()}function Fk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=fb-16|0;fb=i;a:{if(!d){break a}g=x[c>>2];if(!g){break a}b:{c:{d:{e:{f=x[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=D(d,20)+g|0;break d}f=((D(d,36318)|0)/1024|0)+g|0;break d}f:{g:{if(y[a+480208|0]&16){if((f|0)==4){break g}f=d>>31;x[i+12>>2]=(f^d)-f;wc(i+12|0,1020);h=x[i+12>>2];f=c;h:{if((d|0)>0){if(h>>>0<=15){h=x[(h<<2)+(Ob(a+1074312|0,7)?35440:35504)>>2];break h}h=x[(h&-4)+(Ob(a+1074312|0,7)?35568:36592)>>2];break h}if(h>>>0<=15){h=x[(h<<2)+(Ob(a+1074312|0,7)?35504:35440)>>2];break h}h=x[(h&-4)+(Ob(a+1074312|0,7)?36592:35568)>>2]}j=ova(h,h>>31,g,g>>31);h=hb;j=j+32768|0;h=j>>>0<32768?h+1|0:h;k=f;f=Gc(pva(j,h,65536,0),hb);x[k>>2]=f;if((g|0)!=(f|0)){break c}f=Ob(a+1074312|0,7);g=x[c>>2];if(!(f^(d|0)>0)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}f=Ob(a+1074312|0,7);g=x[c>>2];if(!f){break g}if((d|0)<0){f=ova(g,0,14317456,0);h=hb;g=ova(g,0,0-d|0,0);d=hb;g=g+14317456|0;d=g>>>0<14317456?d+1|0:d;f=cT(qva(f,h,g,d),hb);break d}d=ova(g,g>>31,d,0);f=hb;if((f|0)>=0&d>>>0>=14317456|(f|0)>0){if(e){x[c>>2]=2147483647;break a}x[c>>2]=0;x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248;break a}d=cT(qva(ova(g,0,14317456,0),hb,14317456-d|0,0-(f+(d>>>0>14317456)|0)|0),hb);x[c>>2]=d;if((d|0)<=0){break b}break a}f=g-d|0;break d}f=d+g|0}x[c>>2]=f}if((f|0)>0){break a}}x[c>>2]=1;if(x[a+480180>>2]!=2|e){break a}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}fb=i+16|0}function _0(){var a=0,b=0,c=0;if(!y[500080]){a=fb-16|0;fb=a;Kt(499728);x[124944]=-1;x[124942]=499784;x[124940]=126088;x[124932]=94636;v[499780]=0;b=a+12|0;bd(b,x[124933]);c=x[x[124932]+8>>2];x[31725]=0;O(c|0,499728,b|0);b=x[31725];x[31725]=0;a:{if((b|0)!=1){Zb(a+12|0);fb=a+16|0;break a}b=N()|0;Zb(a+12|0);mo(499728);Q(b|0);p()}Ot(499056);x[124764]=94768;x[124762]=94748;x[124763]=0;to(499056,499728);$K(499792,126232,499840);Jy(499224,499792);$K(499848,125936,499896);Jy(499392,499848);Jy(499560,x[x[x[124848]-12>>2]+499416>>2]);_K(x[x[124762]-12>>2]+499048|0);XK(x[x[124848]-12>>2]+499392|0);_K(x[x[124848]-12>>2]+499392|0);a=fb-16|0;fb=a;mL(499904);x[124988]=-1;x[124986]=499960;x[124984]=126088;x[124976]=95028;v[499956]=0;b=a+12|0;bd(b,x[124977]);c=x[x[124976]+8>>2];x[31725]=0;O(c|0,499904,b|0);b=x[31725];x[31725]=0;b:{if((b|0)!=1){Zb(a+12|0);fb=a+16|0;break b}b=N()|0;Zb(a+12|0);Et(499904);Q(b|0);p()}WK(499144);x[124786]=95160;x[124784]=95140;x[124785]=0;to(499144,499904);ZK(499968,126232,500016);Iy(499308,499968);ZK(500024,125936,500072);Iy(499476,500024);Iy(499644,x[x[x[124869]-12>>2]+499500>>2]);YK(x[x[124784]-12>>2]+499136|0);XK(x[x[124869]-12>>2]+499476|0);YK(x[x[124869]-12>>2]+499476|0);v[500080]=1}a=fb-16|0;fb=a;c:{if(bb(a+12|0,a+8|0)|0){break c}b=Fd((x[a+12>>2]<<2)+4|0);x[125022]=b;if(!b){break c}b=Fd(x[a+8>>2]);if(b){c=x[125022];x[c+(x[a+12>>2]<<2)>>2]=0;if(!(ab(c|0,b|0)|0)){break c}}x[125022]=0}fb=a+16|0;x[124213]=42;x[124231]=500180}function QO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;f=Nb(a);a:{b:{c:{a=x[b+36>>2];d=x[b+40>>2];d:{if(Ib(a,d)){sc(c+28|0);break d}x[31725]=0;O(1078,c+16|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}x[31725]=0;a=R(1062,c+16|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}x[c+28>>2]=a;of(c+16|0);d=x[b+40>>2];a=x[b+36>>2]}e:{if(Ib(a,d)){d=b+36|0;break e}d=x[c+28>>2];a=x[d>>2]}g=x[d+4>>2];x[31725]=0;O(178,f|0,pj(a,g)|0);a=x[31725];x[31725]=0;f:{if((a|0)!=1){i=c,j=wb(x[d>>2]),x[i+12>>2]=j;g=wb(x[d+4>>2]);g:{h:{i:{j:{k:{while(1){a=x[c+12>>2];if(!Ib(a,g)){Gl(c+28|0);fb=c+32|0;return}d=y[a+16|0];e=x[x[b+24>>2]+484360>>2];x[31725]=0;d=Xj(e,d);O(1079,c|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break g}x[31725]=0;O(1065,c+16|0,c|0);e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;O(180,f|0,c+16|0);e=x[31725];x[31725]=0;if((e|0)==1){break k}tb(c+16|0);tb(c);e=kl(x[f+4>>2]);l:{if(!Ad(x[e+4>>2],y[e+11|0])){break l}a=x[a+12>>2];if(!cj(d,a&255)){break l}e=x[b+24>>2];h=x[e+1298404>>2];a=z[_b(x[d>>2],a)>>1];d=x[e+484344>>2];x[31725]=0;O(1072,c|0,Wb(d,a)|0);a=x[31725];x[31725]=0;if((a|0)==1){break i}x[31725]=0;S(1080,c+16|0,h|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}a=c+16|0;Ab(kl(x[f+4>>2]),a);tb(a);tb(c)}fA(c+12|0);continue}break}a=N()|0;break j}a=N()|0;tb(c+16|0)}tb(c);break f}a=N()|0;break f}a=N()|0;tb(c);break f}a=N()|0;break f}a=N()|0}Gl(c+28|0);break a}a=N()|0;of(c+16|0);break a}a=N()|0}Td(f);Q(a|0);p()}function Dla(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0;f=fb-48|0;fb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}t=l-4|0;o=D(b,e);u=o-8|0;h:while(1){b=x[c+8>>2];h=x[c>>2];x[31725]=0;b=U(152,h|0,b|0,l|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}if(!(b&n>>>0<o>>>0)){break g}x[31725]=0;S(187,f+8|0,c|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=f+8|0;h=ic(f+28|0,b);ub(b);x[31725]=0;O(576,b|0,h|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}z=$e(f+8|0);q=x[f+8>>2];A=q-4|0;k=0;while(1){if((e|0)==(k|0)){Kc(f+8|0);ub(h);n=(q-l<<1)+n|0;continue h}x[31725]=0;g=R(569,h|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){x[31725]=0;b=R(199,h|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break f}x[f>>2]=b;Fe(f,0,89);x[31725]=0;P(185,h|0,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}j=k+n|0;b=e+k<<2;i:while(1){j:{if(j>>>0>u>>>0){break j}m=0;if(b>>>0>A>>>0){break j}while(1)if((m|0)==8){b=b+t|0;continue i}else{r=x[f>>2];i=y[b+z|0];s=m&1;i=s?i>>>4|0:i&15;x[f>>2]=r+v[(i&7)+28632|0];B=g;g=w[(r<<1)+28640>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;x[f+4>>2]=B+(i>>>0<8?g:0-g|0);Fe(f,0,88);Fe(f+4|0,-32768,32767);g=x[f+4>>2];w[(j<<1)+a>>1]=g;m=m+1|0;j=e+j|0;b=b+s|0;continue}}break}k=k+1|0;continue}break}break}break f}ub(c);fb=f+48|0;return}b=N()|0;Kc(f+8|0);break d}b=N()|0}ub(h);break a}b=N()|0;break a}b=N()|0}ub(c);Q(b|0);p()}function uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-96|0;fb=c;ck(c+76|0,b,1413829443);x[31725]=0;b=R(174,x[c+76>>2])|0;d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){x[31725]=0;S(812,c+56|0,a+140|0,1413894985);a=x[31725];x[31725]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){x[31725]=0;a=P(895,c+56|0,13691)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}b=28591;if(a){b=Fb(c+44|0);x[31725]=0;a=R(204,c+56|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break m}x[31725]=0;S(272,c+56|0,b|0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break m}x[31725]=0;d=P(72,c+20|0,b|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break l}x[31725]=0;W(896,c+8|0);a=x[31725];x[31725]=0;if((a|0)==1){break k}x[31725]=0;S(897,c+32|0,d|0,c+8|0);a=x[31725];x[31725]=0;if((a|0)==1){break j}a=c+32|0;e=Ab(b,a);tb(a);tb(c+8|0);tb(d);x[31725]=0;S(260,a|0,2,e|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}x[31725]=0;a=R(775,c+32|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}tb(c+32|0);tb(e);b=a-1>>>0<19398657?1252:28591}ub(c+56|0);break a}a=N()|0;break b}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;tb(c+8|0)}tb(d);break f}a=N()|0;break f}a=N()|0;tb(c+32|0)}tb(b);break d}a=N()|0}ub(c+56|0);break b}x[31725]=0;a=U(152,x[c+76>>2],x[c+84>>2],2)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}b=28591;if(!a){break a}x[31725]=0;b=R(191,c+76|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0}ub(c+76|0);Q(a|0);p()}ub(c+76|0);fb=c+96|0;return b|0}function H8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=fb-384|0;fb=a;x[a+376>>2]=c;x[a+380>>2]=b;ry(a+220|0,d,a+240|0,a+236|0,a+232|0);d=Fb(a+208|0);b=Mc(d);x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+204>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=x[a+232>>2];i=x[a+236>>2];while(1){d:{x[31725]=0;b=P(1222,a+380|0,a+376|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(b){break c}g=x[a+204>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31725]=0;O(46,d|0,b<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+204>>2]=b+c}x[31725]=0;b=R(1223,x[a+380>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(qy(b,a+23|0,a+22|0,c,a+204|0,i,h,a+220|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[31725]=0;R(1225,a+380|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+224>>2],y[a+231|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}oK(a,c,x[a+204>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Xf(a+220|0,a+32|0,x[a+28>>2],e);x[31725]=0;b=P(1222,a+380|0,a+376|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+380>>2];tb(d);tb(a+220|0);fb=a+384|0;break a}}b=N()|0;tb(d);tb(a+220|0);Q(b|0);p()}return b|0}function hoa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-32|0;fb=e;w[e+30>>1]=254;d=Rj(a);c=fb-16|0;fb=c;f=e+16|0;x[f>>2]=0;x[f+4>>2]=0;sc(f+8|0);Rd(c+8|0,x[vb(c+4|0,f)>>2]);a:{b:{if(d){x[31725]=0;O(642,f|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break b}QE(f,d)}g=c+8|0;Qd(g);ak(g);fb=c+16|0;break a}a=N()|0;ak(c+8|0);Q(a|0);p()}c=x[a>>2];g=x[f>>2];while(1){if((b|0)==(d|0)){c:{if(!(h&65535)){break c}b=wb(c);d=wb(x[a+4>>2]);c=fb-16|0;fb=c;b=LC(b,d,z[e+30>>1]);x[c+12>>2]=b;if(Ib(b,d)){x[c+8>>2]=b;while(1){b=x[Md(c+8|0)>>2];if(Ib(b,d)){b=z[b>>1];if((b|0)==z[e+30>>1]){continue}w[x[c+12>>2]>>1]=b;Md(c+12|0);continue}break}b=x[c+12>>2]}fb=c+16|0;b=vb(e+12|0,b);c=x[vb(e+8|0,wb(x[a+4>>2]))>>2];d=x[b>>2];b=x[a>>2];b=(sp(d,wb(b))<<1)+b|0;if(Ib(d,c)){Kn(a,Wg(b+(sp(c,d)<<1)|0,x[a+4>>2],b))}wb(b);k=e,l=wb(x[a>>2]),x[k+4>>2]=l;d=wb(x[a+4>>2]);while(1){b=x[e+4>>2];if(Ib(b,d)){d:{c=x[a+24>>2];h=x[c+484344>>2];b=z[b>>1];if(!He(h,x[c+484348>>2],b)){break d}b=Wb(h,b);k=e,l=wb(x[b>>2]),x[k>>2]=l;h=wb(x[b+4>>2]);g=x[f+4>>2];c=x[f>>2];while(1){b=x[e>>2];if(!Ib(b,h)){break d}e:{if(y[b+3|0]!=12){break e}j=Zc(c,g);i=y[b+5|0];if(j>>>0<=i>>>0){break e}k=b,l=y[_b(c,i)|0],v[k+5|0]=l}vg(e);continue}}Md(e+4|0);continue}else{b=x[f>>2];d=Zc(b,x[f+4>>2]);c=z[a+28>>1];if(d>>>0<=c>>>0){break c}k=a,l=z[_b(b,c)>>1],w[k+28>>1]=l}break}}}else{k=_b(g,b),l=b-h|0,w[k>>1]=l;h=(z[_b(c,b)>>1]==254)+h|0;b=b+1|0;continue}break}md(f);fb=e+32|0}function Q8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=fb-272|0;fb=a;x[a+264>>2]=c;x[a+268>>2]=b;wy(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Fb(a+196|0);b=Mc(d);x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+192>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=v[a+222|0];i=v[a+223|0];while(1){d:{x[31725]=0;b=P(1207,a+268|0,a+264|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(b){break c}g=x[a+192>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31725]=0;O(46,d|0,b<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+192>>2]=b+c}x[31725]=0;b=R(1208,x[a+268>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(vy(b,a+23|0,a+22|0,c,a+192|0,i,h,a+208|0,a+32|0,a+28|0,a+24|0,a+224|0)){break c}x[31725]=0;R(1210,a+268|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+212>>2],y[a+219|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}oK(a,c,x[a+192>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Xf(a+208|0,a+32|0,x[a+28>>2],e);x[31725]=0;b=P(1207,a+268|0,a+264|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+268>>2];tb(d);tb(a+208|0);fb=a+272|0;break a}}b=N()|0;tb(d);tb(a+208|0);Q(b|0);p()}return b|0}function kpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[a>>2];d=Ud(c,x[a+4>>2]);if(d>>>0<b>>>0){i=fb-32|0;fb=i;b=b-d|0;d=x[zb(a)>>2];c=x[a+4>>2];a:{if(b>>>0<=(d-c|0)/12>>>0){d=fb-16|0;fb=d;b=uv(d+4|0,a,b);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=d+16|0}else{IW(a);a=a+12|0;x[b+4>>2]=a;continue}break}break a}d=zb(a);d=Em(i+12|0,Yp(a,Ud(x[a>>2],c)+b|0),Ud(x[a>>2],x[a+4>>2]),d);f=fb-16|0;fb=f;b=GW(f+4|0,d+8|0,b);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){IW(c);c=x[b>>2]+12|0;x[b>>2]=c;continue}break}he(b);fb=f+16|0;f=fb-16|0;fb=f;e=zb(a);b=vb(f+12|0,x[a+4>>2]);g=vb(f+8|0,x[a>>2]);h=vb(f+4|0,x[d+4>>2]);c=x[b>>2];g=x[g>>2];b=fb+-64|0;fb=b;h=x[h>>2];x[b+56>>2]=h;x[b+60>>2]=c;x[b+52>>2]=h;e=Se(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];h=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=h;Re(b+36|0,b+8|0);while(1){if(pd(c,g)){FW(Xp(x[b+56>>2]),kl(c));c=uk(b+60|0);uk(b+56|0);c=x[c>>2];continue}break}Qe(b+36|0);h=x[b+56>>2];if(!y[b+48|0]){e=fb-16|0;fb=e;c=vb(e+12|0,x[x[b+44>>2]>>2]);j=x[vb(e+8|0,x[x[b+40>>2]>>2])>>2];g=fb-16|0;fb=g;c=x[c>>2];x[g+12>>2]=c;while(1){if(di(c,j)){vC(ux(c));c=x[jl(g+12|0)>>2];continue}break}fb=g+16|0;fb=e+16|0}fb=b- -64|0;x[d+4>>2]=h;Ub(a,d+4|0);Ub(a+4|0,d+8|0);Ub(zb(a),nc(d));x[d>>2]=x[d+4>>2];fb=f+16|0;a=x[d+4>>2];while(1){b=x[d+8>>2];if((b|0)!=(a|0)){b=b-12|0;x[d+8>>2]=b;vC(b);continue}break}a=x[d>>2];if(a){ys(d);Db(a)}}fb=i+32|0;return}if(b>>>0<d>>>0){JW(a,c+D(b,12)|0)}}function nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;t=x[a+16>>2];u=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];o=x[a+128>>2];if(o){p=Gg(m,n,o);q=hb;b=x[a+76>>2];hg(h,e,vf(m,n,d),hb);r=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{s=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;r=r-1|0;b=r;p=b?p:0;q=b?q:0;h=(e<<1)+t|0;b=o;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);ae(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,u);v=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=ova(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(s,-16777216,16776704);j=ova(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=ova(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Pb(g,m,n);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue a}else{be(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);ae(i,4);Pb(g+8|0,p,q);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;fb=g+16|0}function RB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{e=255;b:{c:{g=a+62|0;d=y[xb(g,b)|0];if((d|0)==255){break c}if(v[xb(g,b)|0]>=0){break b}f=a+26|0;d=d&127;if(z[_b(f,d)>>1]!=65535){if(z[_b(f,d)>>1]!=(b|0)){break c}}j=_b(f,d),k=b,w[j>>1]=k;j=xb(g,b),k=d,v[j|0]=k;break b}i=a+8|0;f=a+26|0;d=0;h=255;d:{while(1){if((d|0)==18){break d}if(z[_b(f,d)>>1]!=65535){if(!(y[xb(i,d)|0]&32)){h=v[xb(g,z[_b(f,d)>>1])|0]<0?d:h;e=d}d=d+1|0;continue}break}j=_b(f,d),k=b,w[j>>1]=k;j=xb(g,b),k=d,v[j|0]=k;break b}if((e&255)!=255){d=(h&255)==255?e:h;e=d&255;j=xb(g,z[_b(f,e)>>1]),k=255,v[j|0]=k;j=_b(f,e),k=b,w[j>>1]=k;j=xb(g,b),k=d,v[j|0]=k}d=Yl(a,b)}g=d&255;if((g|0)==255){break a}if(Pj(x[a>>2])){break a}e=Hd(a+318|0,g);d=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[e+8|0]=d;v[e+9|0]=d>>>8;v[e+10|0]=d>>>16;v[e+11|0]=d>>>24;d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=f;v[e+1|0]=f>>>8;v[e+2|0]=f>>>16;v[e+3|0]=f>>>24;v[e+4|0]=d;v[e+5|0]=d>>>8;v[e+6|0]=d>>>16;v[e+7|0]=d>>>24;f=PU(g);h=f+3|0;d=0;while(1){if((d|0)==2){Ah(x[a>>2],x[a+4>>2],b,cv(g)|192,y[xb(c,10)|0])}else{e=d?h:f;Ah(x[a>>2],x[a+4>>2],b,e|32,y[xb(c,d)|0]);Ah(x[a>>2],x[a+4>>2],b,e|64,y[xb(c,d+2|0)|0]);Ah(x[a>>2],x[a+4>>2],b,e|96,y[xb(c,d+4|0)|0]);Ah(x[a>>2],x[a+4>>2],b,e|128,y[xb(c,d+6|0)|0]);Ah(x[a>>2],x[a+4>>2],b,e|224,y[xb(c,d+8|0)|0]);d=d+1|0;continue}break}}}function G8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-320|0;fb=a;x[a+312>>2]=c;x[a+316>>2]=b;h=Fb(a+196|0);bd(a+16|0,x[d+28>>2]);x[31725]=0;b=R(1217,x[a+16>>2])|0;c=x[31725];x[31725]=0;a:{b:{if((c|0)==1){break b}x[31725]=0;V(1228,b|0,111728,111754,a+208|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}Zb(a+16|0);c=Fb(a+184|0);b=Mc(c);x[31725]=0;O(46,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){c:{b=cc(c,0);x[a+180>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1222,a+316|0,a+312|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}d=x[a+180>>2];e:{if(!g){g=d;d=Cb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[31725]=0;O(46,c|0,d<<1);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=Mc(c);x[31725]=0;O(46,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=cc(c,0);x[a+180>>2]=d+b}x[31725]=0;d=R(1223,x[a+316>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(!ho(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break e}d=x[a+180>>2]}x[31725]=0;O(46,c|0,d-b|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}b=Kb(c);d=Od();x[a>>2]=f;if((nK(b,d,a)|0)!=1){x[e>>2]=4}x[31725]=0;b=P(1222,a+316|0,a+312|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}if(b){x[e>>2]=x[e>>2]|2}b=x[a+316>>2];tb(c);tb(h);fb=a+320|0;return b|0}x[31725]=0;R(1225,a+316|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){continue}}break}}}b=N()|0;tb(c);break a}b=N()|0;Zb(a+16|0)}tb(h);Q(b|0);p()}function n8(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=fb-416|0;fb=i;x[i+408>>2]=37;x[i+412>>2]=0;l=gt(i+408|1,13905,x[c+4>>2]);x[i+364>>2]=i+368;a=Od();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=rh(i+368|0,30,a,i+408|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=rh(i+368|0,30,a,i+408|0,i+80|0)}x[i+128>>2]=1205;k=Be(i+356|0,0,i+128|0);b=i+368|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Od();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=sj(i+364|0,a,i+408|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=sj(i+364|0,a,i+408|0,i+32|0)}if((j|0)==-1){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)==1){break d}break e}a=x[i+364>>2];Te(k,a)}f=a+j|0;g=tj(a,f,x[c+4>>2]);x[i+116>>2]=1205;e=Be(i+120|0,0,i+116|0);g:{h:{if((i+368|0)==(a|0)){j=i+128|0;break h}j=Fd(j<<3);if(!j){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break e}a=N()|0;break g}Te(e,j);b=a}a=i+108|0;bd(a,x[c+28>>2]);x[31725]=0;ga(1236,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[31725];x[31725]=0;i:{if((a|0)!=1){Zb(i+108|0);x[31725]=0;a=ea(1237,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}Lc(e);Lc(k);fb=i+416|0;break b}a=N()|0;Zb(i+108|0);break g}a=N()|0}Lc(e);break c}p()}a=N()|0}Lc(k);Q(a|0);p()}return a|0}function P8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;h=Fb(a+196|0);bd(a+16|0,x[d+28>>2]);x[31725]=0;b=R(28,x[a+16>>2])|0;c=x[31725];x[31725]=0;a:{b:{if((c|0)==1){break b}x[31725]=0;V(1215,b|0,111728,111754,a+208|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}Zb(a+16|0);c=Fb(a+184|0);b=Mc(c);x[31725]=0;O(46,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){c:{b=cc(c,0);x[a+180>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1207,a+252|0,a+248|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}d=x[a+180>>2];e:{if(!g){g=d;d=Cb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[31725]=0;O(46,c|0,d<<1);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=Mc(c);x[31725]=0;O(46,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=cc(c,0);x[a+180>>2]=d+b}x[31725]=0;d=R(1208,x[a+252>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(!io(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break e}d=x[a+180>>2]}x[31725]=0;O(46,c|0,d-b|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}b=Kb(c);d=Od();x[a>>2]=f;if((nK(b,d,a)|0)!=1){x[e>>2]=4}x[31725]=0;b=P(1207,a+252|0,a+248|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break d}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(c);tb(h);fb=a+256|0;return b|0}x[31725]=0;R(1210,a+252|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){continue}}break}}}b=N()|0;tb(c);break a}b=N()|0;Zb(a+16|0)}tb(h);Q(b|0);p()}function x8(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=fb-256|0;fb=i;x[i+248>>2]=37;x[i+252>>2]=0;l=gt(i+248|1,13905,x[c+4>>2]);x[i+204>>2]=i+208;a=Od();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=rh(i+208|0,30,a,i+248|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=rh(i+208|0,30,a,i+248|0,i+80|0)}x[i+128>>2]=1205;k=Be(i+196|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Od();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=sj(i+204|0,a,i+248|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=sj(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)==1){break d}break e}a=x[i+204>>2];Te(k,a)}f=a+j|0;g=tj(a,f,x[c+4>>2]);x[i+116>>2]=1205;e=Be(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Fd(j<<1);if(!j){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break e}a=N()|0;break g}Te(e,j);b=a}a=i+108|0;bd(a,x[c+28>>2]);x[31725]=0;ga(1231,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[31725];x[31725]=0;i:{if((a|0)!=1){Zb(i+108|0);x[31725]=0;a=ea(23,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}Lc(e);Lc(k);fb=i+256|0;break b}a=N()|0;Zb(i+108|0);break g}a=N()|0}Lc(e);break c}p()}a=N()|0}Lc(k);Q(a|0);p()}return a|0}function Bna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+28|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;b=0;j=0;while(1){if((j|0)!=2){g=e+(j<<1)|0;h=w[g>>1];x[(f+8|0)+(j<<2)>>2]=h+((D(i,w[g+4>>1]-h|0)|0)/16384|0);j=j+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=ova(o,z,e,e>>31);i=hb;k=e;e=Yb(h,-16777216,16776704);e=ova(n,y,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(j,-16777216,16776704);i=ova(m,v,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(q&u);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+12>>2]);Pb(f+16|0,l,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;t=x[a+16>>2];u=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];o=x[a+128>>2];if(o){p=Gg(m,n,o);q=hb;b=x[a+76>>2];hg(h,e,vf(m,n,d),hb);r=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{s=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;r=r-1|0;b=r;p=b?p:0;q=b?q:0;h=e+t|0;b=o;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(i,v[h+x[g+12>>2]|0]<<6);ae(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,u);w=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=ova(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(s,-16777216,16776704);j=ova(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=ova(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Pb(g,m,n);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue a}else{be(i,v[h+x[g+12>>2]|0]<<6);ae(i,4);Pb(g+8|0,p,q);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;fb=g+16|0}function Rna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;r=x[a+16>>2];l=mg(1,2);b=hb;s=b;Pb(a,l,b);b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+28|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}t=x[a+24>>2];u=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;v=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;k=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=ova(o,A,e,e>>31);i=hb;j=e;e=Yb(h,-16777216,16776704);e=ova(n,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(C,-16777216,16776704);i=ova(m,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(q&v);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],u);x[c+4>>2]=x[c+4>>2]+D(t,x[f+12>>2]);Pb(f+16|0,k,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Hg(a,l,s);fb=f+48|0}function Cna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+28|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];m=x[a+68>>2];w=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+r|0;b=0;j=0;while(1){if((j|0)!=2){g=e+j|0;h=v[g|0];x[(f+8|0)+(j<<2)>>2]=((D(i,v[g+2|0]-h|0)|0)/16384|0)+(h<<8);j=j+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=ova(o,z,e,e>>31);i=hb;k=e;e=Yb(h,-16777216,16776704);e=ova(n,y,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(j,-16777216,16776704);i=ova(m,w,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(q&u);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+12>>2]);Pb(f+16|0,l,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function AD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=fb-16|0;fb=i;a:{if(b&4){break a}d=y[a+14|0];b:{if(d>>>0>=y[a+15|0]){break b}c=y[a+12|0];if(!(c&2)){break b}v[a+12|0]=c&251}if(!(y[a+12|0]&2)|d>>>0<=y[a+13|0]){break a}f=x[a>>2];c=x[a+4>>2];if(Sd(f,c)>>>0<=d>>>0){break a}f=z[Oc(f,c,d)>>1];c=Oc(x[a>>2],x[a+4>>2],y[a+14|0]-1|0);d=y[a+14|0];if(z[c>>1]<(f-1|0)){d=z[Oc(x[a>>2],x[a+4>>2],d)>>1]-1&65535;f=Xq(a,d,64,64);c=vb(i+12|0,Mk(wb(x[a>>2]),y[a+14|0]));j=fm(i+8|0,d,f&255);m=fb-32|0;fb=m;g=x[c>>2];c=x[a>>2];g=(Iv(g,wb(c))<<2)+c|0;c=x[a+4>>2];c:{d:{if(c>>>0<A[zb(a)>>2]){if((c|0)!=(g|0)){break d}eZ(a,j);break c}f=zb(a);e=$f(m+12|0,Mf(a,oc(x[a>>2],c)+1|0),g-x[a>>2]>>2,f);x[31725]=0;O(782,e|0,j|0);c=x[31725];x[31725]=0;if((c|0)!=1){h=fb-16|0;fb=h;c=x[e+4>>2];k=vb(h+12|0,g);d=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[e+4>>2]);n=e,o=NF(x[k>>2],x[d>>2],x[f>>2]),x[n+4>>2]=o;n=e,o=Cr(g,x[a+4>>2],x[e+8>>2]),x[n+8>>2]=o;Ub(a,e+4|0);Ub(a+4|0,e+8|0);Ub(zb(a),nc(e));x[e>>2]=x[e+4>>2];fb=h+16|0;g=c;_f(e);break c}a=N()|0;_f(e);Q(a|0);p()}e=fb-16|0;fb=e;k=x[a+4>>2];f=(k-(g+4|0)|0)+g|0;h=Tg(e+4|0,a,c-f>>2);l=x[h+4>>2];d=f;while(1){if(c>>>0<=d>>>0){hc(h);Dr(g,f,k);fb=e+16|0}else{ip(l,z[d>>1]|z[d+2>>1]<<16);l=l+4|0;x[h+4>>2]=l;d=d+4|0;continue}break}v[g+2|0]=y[j+2|0];w[g>>1]=z[j>>1]}wb(g);fb=m+32|0;break a}v[a+14|0]=d-1}if((b|0)!=16777216){v[a+17|0]=255}fb=i+16|0}function RA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=92;j=91;k=85;l=84;m=83;n=5;o=118;p=113;q=111;r=107;s=106;t=96;c=88;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;a=hs(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!c&(b|0)!=32){break c}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1),119,1),120,1);if(!c){break a}d=111;e=105;f=99;break b;case 3:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1);o=112;p=98;q=93;r=90;s=89;t=88;c=86;u=76;v=75;w=74;x=73;y=72;z=71;A=70;d=69;e=68;g=67;case 1:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1),v,1);n=u;m=c;l=t;k=s;j=r;i=q;c=p;h=o;break;case 2:break c;case 0:break d}}Lb(Lb(Lb(Lb(a,n,1),m,1),l,1),k,1);g=j;f=i;e=c;d=h}Lb(a,g,1)}Lb(Lb(Lb(a,f,1),e,1),d,1)}}function w3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-2096|0;fb=d;uu(d+48|0);a:{b:{c:{if(Lp(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){a=ac(8);x[31725]=0;c=P(36,d+36|0,10453)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}g=wM(c);if(g){b=uM(c)}else{b=0}x[d+24>>2]=b;x[d+28>>2]=0;h=c+16|0;b=2048;d:{while(1){e:{if(!b){break e}if(!vM(x[x[x[c>>2]-12>>2]+h>>2])){break e}e=x[x[x[Ej(c,(d+48|0)+f|0,b)>>2]-12>>2]+h>>2];if(Lp(e)){a=ac(8);x[31725]=0;c=P(36,d+36|0,10453)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}f:{if(VF(e)){break f}if(!xk(e)){break f}a=ac(8);x[31725]=0;c=P(36,d+36|0,10453)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}e=x[c+4>>2];b=b-e|0;f=e+f|0;continue}break}b=gc(d+16|0,d+48|0,f);c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;a=Au(a,d+8|0,g?d+24|0:0);if(a+1>>>0>=3){a=ac(8);x[31725]=0;c=P(36,d+36|0,8057)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}fb=d+2096|0;break a}b=N()|0;jc(a)}Q(b|0)}p()}return a|0}function XO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb+-64|0;fb=e;f=Nb(a);a=0;c=x[b+24>>2];g=Rj(Xb(x[c+484360>>2],y[c+484376|0]));x[31725]=0;O(178,f|0,g|0);c=x[31725];x[31725]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(g|0)){c=x[b+24>>2];d=x[c+484344>>2];h=x[c+484348>>2];c=z[_b(x[Xb(x[c+484360>>2],y[c+484376|0])>>2],a)>>1];if(yp(d,h,c)){x[31725]=0;O(1072,e+40|0,Wb(d,c)|0);c=x[31725];x[31725]=0;c:{d:{e:{if((c|0)!=1){c=x[b+24>>2];x[31725]=0;S(1059,e+52|0,c|0,e+40|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}x[31725]=0;O(180,f|0,e+52|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}tb(e+52|0);tb(e+40|0);break b}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+52|0)}tb(e+40|0);break a}f:{switch(c-65534|0){case 0:x[31725]=0;c=P(36,e+28|0,9240)|0;d=x[31725];x[31725]=0;g:{if((d|0)!=1){x[31725]=0;O(180,f|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break g}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;case 1:x[31725]=0;c=P(36,e+16|0,9202)|0;d=x[31725];x[31725]=0;h:{if((d|0)!=1){x[31725]=0;O(180,f|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break h}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;default:break f}}x[31725]=0;c=P(36,e+4|0,14600)|0;d=x[31725];x[31725]=0;i:{if((d|0)!=1){x[31725]=0;O(180,f|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break i}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a}fb=e- -64|0;return}a=a+1|0;continue}}a=N()|0}Td(f);Q(a|0);p()}function n1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;xc(c);while(1){a:{if(!Mb(x[c>>2],x[c+8>>2],3)){break a}d=f+13|0;Xr(d,c);i=Jc(d);h=af(d);d=y[f+13|0];if(d>>>0>=A[a+12>>2]){break a}g=jd(x[a>>2],x[x[a+48>>2]+12>>2],d,b);d=y[i|0];if(d>>>0<=126){if(!(d|y[h|0])){v[g|0]=254;continue}v[g|0]=d+1;if(y[h|0]==255){continue}v[g+2|0]=1;v[g+4|0]=y[h|0];continue}b:{switch(d-127|0){case 1:v[g+1|0]=y[h|0]+1;continue;case 0:continue;default:break b}}e=v[h|0];v[f+12|0]=e;h=0;j=y[i|0];d=j&127;if(d>>>0<=23){h=y[d+24576|0]}c:{d:{e:{f:{g:{switch(d-2|0){case 0:case 8:case 9:if((e|0)>=0){break f}d=0-e&15;break e;case 1:v[f+8|0]=64;e=y[Rb(f+12|0,f+8|0)|0];if(y[g+2|0]>1){break d}v[g+4|0]=e;v[g+2|0]=1;continue;case 2:d=3;if((e|0)>=0){break c}d=0-e&127;break e;case 15:if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e;case 16:case 20:if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;v[f+12|0]=e;j=y[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;v[f+12|0]=e;break c;case 17:d=e&15|-48;break e;case 18:d=e&15|-64;break e;case 21:break g;default:break d}}d=164;if((e|0)==100){break e}x[f+8>>2]=e- -64;x[f+4>>2]=0;x[f>>2]=128;e=x[hk(f+8|0,f+4|0,f)>>2];if(!y[g+3|0]){break d}h:{switch(y[g+2|0]){case 0:case 2:break h;default:continue}}v[g+2|0]=2;v[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;v[f+12|0]=e}d=h;if(!d){continue}}v[g+5|0]=e;v[g+3|0]=d;continue}break}fb=f+16|0}function PS(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;f=fb-48|0;fb=f;b=Gw(f+30|0,x[a>>2]);c=rq(f+29|0,x[a+4>>2]);MY(f+32|0,z[b>>1],c);c=rq(f+28|0,x[a+8>>2]);d=z[f+32>>1];b=fb-16|0;fb=b;v[b+15|0]=y[f+34|0];JS(f+36|0,d,b+15|0,c);fb=b+16|0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;h=z[f+36>>1]<<16>>16;g=y[f+38|0];b=Pf(g);e=Pf(2);g=Pf(g);b=h-(((b|0)!=(e|0)?b>>>0<e>>>0?-1:1:0)<<24>>24<=0)|0;e=(((b|0)<0?b-399|0:b)|0)/400|0;b=D(e,-400)+b|0;b=x[vb(d+12|0,((((Pf(y[f+39|0])+D(e,146097)|0)+((D(g+(g>>>0>2?-3:9)|0,153)+2>>>0)/5|0)+(b>>>2)|0)+D(b,365)|0)-((b>>>0)/100|0)|0)-719469|0)>>2];fb=d+16|0;e=x[vb(c+12|0,b)>>2];fb=c+16|0;g=vb(f+24|0,x[a+12>>2]);c=fb-16|0;fb=c;b=fb-16|0;fb=b;d=fb-16|0;fb=d;e=x[vb(d+12|0,D(e,24))>>2];fb=d+16|0;x[b+8>>2]=e;d=x[vb(b+12|0,x[g>>2]+x[b+8>>2]|0)>>2];fb=b+16|0;e=x[vb(c+12|0,d)>>2];fb=c+16|0;g=vb(f+20|0,x[a+16>>2]);c=fb-16|0;fb=c;b=fb-16|0;fb=b;d=fb-16|0;fb=d;e=x[vb(d+12|0,D(e,60))>>2];fb=d+16|0;x[b+8>>2]=e;d=x[vb(b+12|0,x[g>>2]+x[b+8>>2]|0)>>2];fb=b+16|0;b=x[vb(c+12|0,d)>>2];fb=c+16|0;c=we(f+8|0,x[a+24>>2],x[a+28>>2]);d=fb-16|0;fb=d;a=fb-16|0;fb=a;e=fb-16|0;fb=e;b=we(e+8|0,ova(b,b>>31,60,0),hb);g=x[b>>2];b=x[b+4>>2];fb=e+16|0;x[a>>2]=g;x[a+4>>2]=b;b=x[a>>2];e=b+x[c>>2]|0;c=x[c+4>>2]+x[a+4>>2]|0;b=we(a+8|0,e,b>>>0>e>>>0?c+1|0:c);c=x[b>>2];fb=a+16|0;a=we(d+8|0,c,x[b+4>>2]);b=x[a>>2];fb=d+16|0;a=Eu(f+40|0,b,x[a+4>>2]);b=x[a>>2];fb=f+48|0;hb=x[a+4>>2];return b}function Sna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;r=x[a+16>>2];l=mg(1,2);b=hb;s=b;Pb(a,l,b);b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+28|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}t=x[a+24>>2];u=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;w=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;k=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=ova(o,A,e,e>>31);i=hb;j=e;e=Yb(h,-16777216,16776704);e=ova(n,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(C,-16777216,16776704);i=ova(m,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(q&w);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],u);x[c+4>>2]=x[c+4>>2]+D(t,x[f+12>>2]);Pb(f+16|0,k,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Hg(a,l,s);fb=f+48|0}function Wja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;m=fb-32|0;fb=m;e=b;b=x[a>>2];g=D(xu(e,wb(b)),6)+b|0;a:{if(!c){break a}b=x[zb(a)>>2];i=x[a+4>>2];if((b-i|0)/6>>>0>=c>>>0){b=c;e=(i-g|0)/6|0;if(e>>>0<c>>>0){tD(a,c-e|0,d);b=e;if((g|0)==(i|0)){break a}}n=fb-16|0;fb=n;o=x[a+4>>2];h=D((o-(D(c,6)+g|0)|0)/6|0,6)+g|0;f=Kr(n+4|0,a,(i-h|0)/6|0);k=x[f+4>>2];e=h;while(1){if(e>>>0>=i>>>0){hc(f);i=fb-16|0;fb=i;j=fb-32|0;fb=j;Id(j+24|0,g,h);l=fb-16|0;fb=l;k=x[j+28>>2];f=x[j+24>>2];h=k-f|0;e=D((h|0)/-6|0,6)+o|0;x[l+12>>2]=e;nl(e,f,h);Ac(j+16|0,k,l+12|0);fb=l+16|0;e=CR(g,x[j+16>>2]);p=j,q=tA(o,x[j+20>>2]),x[p+12>>2]=q;Ac(i+8|0,e,j+12|0);fb=j+32|0;fb=i+16|0;fb=n+16|0}else{Pv(k,e);k=k+6|0;x[f+4>>2]=k;e=e+6|0;continue}break}e=g;c=D(e>>>0<=d>>>0?A[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=a;v[e+1|0]=a>>>8;v[e+2|0]=a>>>16;v[e+3|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[e+4|0]=a;v[e+5|0]=a>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=zb(a);f=AZ(m+12|0,oD(a,Pk(x[a>>2],i)+c|0),(g-x[a>>2]|0)/6|0,b);zZ(f,c,d);h=fb-16|0;fb=h;b=x[f+4>>2];e=vb(h+12|0,g);d=vb(h+8|0,x[a>>2]);c=vb(h+4|0,x[f+4>>2]);p=f,q=wZ(x[e>>2],x[d>>2],x[c>>2]),x[p+4>>2]=q;p=f,q=uA(g,x[a+4>>2],x[f+8>>2]),x[p+8>>2]=q;Ub(a,f+4|0);Ub(a+4|0,f+8|0);Ub(zb(a),nc(f));x[f>>2]=x[f+4>>2];fb=h+16|0;g=b;yZ(f)}wb(g);fb=m+32|0}function Yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=fb-16|0;fb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}r=x[a+16>>2];e=x[a+48>>2];s=x[a+24>>2];t=x[a+20>>2];b=x[a+44>>2];j=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=j;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;while(1){j=b;if(d){b=Yb(j,-16777216,16776704);k=ova(p,y,b,b>>31);l=hb;b=x[g+8>>2];f=(x[g+12>>2]<<1)+r|0;b=(b>>>16&65520)+n|0;f=(((((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+4>>1],w[b+10>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/32768<<8;b=f;b=ova(b,b>>31,q,z);k=b+k|0;m=hb+l|0;m=b>>>0>k>>>0?m+1|0:m;b=Yb(e,-16777216,16776704);e=ova(o,v,b,b>>31);l=e+k|0;b=hb+m|0;b=e>>>0>l>>>0?b+1|0:b;e=l+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,t)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,s);Pb(g+8|0,i,h);b=e-(f&u)|0;c=c+8|0;d=d-1|0;e=j;continue}break}b=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=b;x[a+48>>2]=e;x[a+44>>2]=j;fb=g+16|0}function J8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=fb-368|0;fb=a;x[a+360>>2]=c;x[a+364>>2]=b;ry(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Fb(a+192|0);b=Mc(d);x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[31725]=0;b=P(1222,a+364|0,a+360|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31725]=0;O(46,d|0,b<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+188>>2]=b+c}x[31725]=0;b=R(1223,x[a+364>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(qy(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[31725]=0;R(1225,a+364|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=sK(c,x[a+188>>2],e),B[j>>2]=k;Xf(a+204|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+364|0,a+360|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);fb=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function S8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;wy(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Fb(a+180|0);b=Mc(d);x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+206|0];i=v[a+207|0];while(1){d:{x[31725]=0;b=P(1207,a+252|0,a+248|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31725]=0;O(46,d|0,b<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+176>>2]=b+c}x[31725]=0;b=R(1208,x[a+252>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(vy(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[31725]=0;R(1210,a+252|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=sK(c,x[a+176>>2],e),B[j>>2]=k;Xf(a+192|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+252|0,a+248|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);fb=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function I8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=fb-368|0;fb=a;x[a+360>>2]=c;x[a+364>>2]=b;ry(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Fb(a+192|0);b=Mc(d);x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[31725]=0;b=P(1222,a+364|0,a+360|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31725]=0;O(46,d|0,b<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+188>>2]=b+c}x[31725]=0;b=R(1223,x[a+364>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(qy(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[31725]=0;R(1225,a+364|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=pK(c,x[a+188>>2],e),C[j>>3]=k;Xf(a+204|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+364|0,a+360|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);fb=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function R8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;wy(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Fb(a+180|0);b=Mc(d);x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+206|0];i=v[a+207|0];while(1){d:{x[31725]=0;b=P(1207,a+252|0,a+248|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31725]=0;O(46,d|0,b<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+176>>2]=b+c}x[31725]=0;b=R(1208,x[a+252>>2])|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}if(vy(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[31725]=0;R(1210,a+252|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=pK(c,x[a+176>>2],e),C[j>>3]=k;Xf(a+192|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+252|0,a+248|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);fb=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function wG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=x[a>>2];e=kh(c,x[a+4>>2]);if(e>>>0<b>>>0){j=fb-32|0;fb=j;c=b-e|0;b=x[zb(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=b-d>>3>>>0){e=fb-16|0;fb=e;b=ks(e+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=e+16|0}else{gl(a);a=a+8|0;x[b+4>>2]=a;continue}break}break a}b=zb(a);e=ms(j+12|0,ns(a,kh(x[a>>2],d)+c|0),kh(x[a>>2],x[a+4>>2]),b);d=fb-16|0;fb=d;b=d+4|0;x[b>>2]=x[e+8>>2];f=x[e+8>>2];x[b+8>>2]=e+8;x[b+4>>2]=f+(c<<3);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){gl(c);c=x[b>>2]+8|0;x[b>>2]=c;continue}break}he(b);fb=d+16|0;h=fb-16|0;fb=h;b=vb(h+12|0,x[a+4>>2]);d=vb(h+8|0,x[a>>2]);g=x[vb(h+4|0,x[e+4>>2])>>2];i=fb-16|0;fb=i;c=fb-32|0;fb=c;Id(c+24|0,x[b>>2],x[d>>2]);k=c+16|0;b=x[c+24>>2];l=x[c+28>>2];f=fb-16|0;fb=f;x[f+8>>2]=g;x[f+12>>2]=b;while(1){if(pd(b,l)){d=Qp(b);g=Qp(x[f+8>>2]);b=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[g|0]=d;v[g+1|0]=d>>>8;v[g+2|0]=d>>>16;v[g+3|0]=d>>>24;v[g+4|0]=b;v[g+5|0]=b>>>8;v[g+6|0]=b>>>16;v[g+7|0]=b>>>24;b=Pp(f+12|0);Pp(f+8|0);b=x[b>>2];continue}break}Ac(k,b,f+8|0);fb=f+16|0;b=x[c+16>>2];x[c+12>>2]=x[c+20>>2];Ac(i+8|0,b,c+12|0);fb=c+32|0;fb=i+16|0;x[e+4>>2]=x[i+12>>2];Ub(a,e+4|0);Ub(a+4|0,e+8|0);Ub(zb(a),nc(e));x[e>>2]=x[e+4>>2];fb=h+16|0;ls(e)}fb=j+32|0;return}if(b>>>0<e>>>0){uG(a,c+(b<<3)|0)}}function Zma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;g=fb-16|0;fb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}p=b;q=x[a+16>>2];b=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];j=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=j;t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];y=m>>31;n=x[a+60>>2];z=n>>31;while(1){j=e;if(d){e=Yb(j,-16777216,16776704);f=ova(m,y,e,e>>31);e=hb;b=Yb(b,-16777216,16776704);b=ova(l,u,b,b>>31);f=b+f|0;e=hb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[g+8>>2];k=f;f=x[g+12>>2]+q|0;b=(b>>>16&65520)+p|0;o=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=o;f=ova(b,b>>31,n,z);k=k+f|0;b=hb+e|0;b=f>>>0>k>>>0?b+1|0:b;e=k+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,r);Pb(g+8|0,i,h);e=e-(t&o)|0;c=c+8|0;d=d-1|0;b=j;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=b;x[a+44>>2]=j;fb=g+16|0}function F7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-480|0;fb=a;bd(a+476|0,x[d+28>>2]);x[31725]=0;n=R(1217,x[a+476>>2])|0;g=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Cb(x[f+4>>2],y[f+11|0])){g=x[Wd(f,0)>>2];x[31725]=0;h=P(1234,n|0,45)|0;j=x[31725];x[31725]=0;if((j|0)==1){break e}o=(g|0)==(h|0)}j=Fb(a+452|0);g=Fb(a+440|0);h=Fb(a+428|0);x[31725]=0;ka(1256,c|0,o|0,x[a+476>>2],a+472|0,a+468|0,a+464|0,j|0,g|0,h|0,a+424|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}x[a+4>>2]=1205;c=Be(a+8|0,0,a+4|0);k=a+16|0;l=Cb(x[f+4>>2],y[f+11|0]);m=x[a+424>>2];f:{if((l|0)>(m|0)){i=((Cb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Cb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Cb(x[h+4>>2],y[h+11|0])+Cb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Te(c,Fd(i<<2));k=x[c>>2];if(!k){break g}l=Cb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Kb(f);x[31725]=0;ma(1257,k|0,a+4|0,a|0,i|0,f|0,f+(l<<2)|0,n|0,o|0,a+472|0,x[a+468>>2],x[a+464>>2],j|0,g|0,h|0,m|0);f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;b=ea(1237,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}Lc(c);Qb(h);Qb(g);tb(j);Zb(a+476|0);fb=a+480|0;return b|0}x[31725]=0;X(1206);b=x[31725];x[31725]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Lc(c)}Qb(h);Qb(g);tb(j)}Zb(a+476|0);Q(f|0);p()}function B7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=fb-16|0;fb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!x[b>>2]){break a}b=b+4|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=fb-16|0;fb=r;s=Nh(r+12|0,x[a+8>>2]);i=f;j=g-f|0;m=0;o=fb-16|0;fb=o;k=x[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=Xy(j>>>0<4?o+12|0:i,x[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}yc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!x[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){x[e>>2]=k}fb=o+16|0;Mh(s);fb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:x[h>>2]=f;while(1){i:{if(x[e>>2]==(c|0)){break i}b=fy(f,x[c>>2],x[a+8>>2]);if((b|0)==-1){break i}f=b+x[h>>2]|0;x[h>>2]=f;c=c+4|0;continue}break};x[e>>2]=c;break g;case 1:break c;default:break h}}f=x[h>>2]+m|0;x[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=x[e>>2];b=d;continue}b=fy(n+12|0,0,x[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-x[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=y[c|0];i=x[h>>2];x[h>>2]=i+1;v[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=x[e>>2]+4|0;x[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!x[b>>2]){break b}b=b+4|0;continue}}c=x[e>>2]}q=(c|0)!=(d|0)}fb=n+16|0;return q|0}f=x[h>>2];continue}}function gra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=y[f+4|0];j=xb(h,d),k=i+1|0,v[j|0]=k;f=y[f+6|0]|y[f+7|0]<<8;j=_b(g,d),k=f+1|0,w[j>>1]=k;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;g=y[g+6|0]|y[g+7|0]<<8;j=_b(f,d+12|0),k=g+1|0,w[j>>1]=k;d=d+1|0;continue}}XC(a+484|0,b+48|0,0,c);XC(a+590|0,b+68|0,0,c);XC(a+696|0,b+88|0,5,c);x[b>>2]=y[a+806|0]|y[a+807|0]<<8;d=v[a+808|0];b:{if((d|0)<0){v[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(v[a|0]&1){v[b+31|0]=d+1;break b}if(!d){break b}v[b+31|0]=d+1}if(y[b+31|0]){c:{d:{if((c|0)==4){d=y[a+810|0];break d}d=v[a+809|0];if((d|0)>=0){w[b+28>>1]=(d&255)+1}d=v[a+810|0];if((d|0)<0){break c}}v[b+30|0]=d+1}v[b+33|0]=y[a+811|0]}if((c|0)==32){v[e+15|0]=y[a+812|0];v[e+14|0]=128;j=b,k=y[Rb(e+15|0,e+14|0)|0]>>>1|0,x[j+4>>2]=k}c=y[a+813|0]|y[a+814|0]<<8;if(c>>>0<=256){x[b+8>>2]=c;v[b+15|0]=y[b+15|0]|1}v[b+16|0]=y[a+815|0];v[b+26|0]=y[a+816|0];v[b+27|0]=y[a+817|0];v[b+17|0]=y[a+818|0];v[b+18|0]=y[a+819|0];w[e+12>>1]=y[a+820|0]|y[a+821|0]<<8;w[e+10>>1]=100;j=b,k=y[Nc(e+12|0,e+10|0)|0],v[j+20|0]=k;w[e+8>>1]=y[a+822|0]|y[a+823|0]<<8;w[e+6>>1]=256;j=b,k=z[Nc(e+8|0,e+6|0)>>1]>>>2|0,v[j+19|0]=k;c=y[a+824|0];mk(b,c&127,c>>>7|0);a=y[a+825|0];lk(b,a&127,a>>>7|0);fb=e+16|0}function M8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=xj(x[d+4>>2]);i=nq(x[d+28>>2],a+208|0);mq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1222,a+332|0,a+328|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31725]=0;g=R(1223,x[a+332>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(ho(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31725]=0;R(1225,a+332|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=xK(c,x[a+180>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+332|0,a+328|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function K8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=xj(x[d+4>>2]);i=nq(x[d+28>>2],a+208|0);mq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1222,a+332|0,a+328|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31725]=0;g=R(1223,x[a+332>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(ho(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31725]=0;R(1225,a+332|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=tK(c,x[a+180>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+332|0,a+328|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function J7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-176|0;fb=a;bd(a+172|0,x[d+28>>2]);x[31725]=0;n=R(28,x[a+172>>2])|0;g=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Cb(x[f+4>>2],y[f+11|0])){g=y[cc(f,0)|0];x[31725]=0;h=P(29,n|0,45)|0;j=x[31725];x[31725]=0;if((j|0)==1){break e}o=(g|0)==(h&255)}j=Fb(a+152|0);g=Fb(a+140|0);h=Fb(a+128|0);x[31725]=0;ka(1254,c|0,o|0,x[a+172>>2],a+168|0,a+167|0,a+166|0,j|0,g|0,h|0,a+124|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}x[a+4>>2]=1205;c=Be(a+8|0,0,a+4|0);k=a+16|0;l=Cb(x[f+4>>2],y[f+11|0]);m=x[a+124>>2];f:{if((l|0)>(m|0)){i=((Cb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Cb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Cb(x[h+4>>2],y[h+11|0])+Cb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Te(c,Fd(i));k=x[c>>2];if(!k){break g}l=Cb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Kb(f);x[31725]=0;ma(1255,k|0,a+4|0,a|0,i|0,f|0,f+l|0,n|0,o|0,a+168|0,v[a+167|0],v[a+166|0],j|0,g|0,h|0,m|0);f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;b=ea(23,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}Lc(c);tb(h);tb(g);tb(j);Zb(a+172|0);fb=a+176|0;return b|0}x[31725]=0;X(1206);b=x[31725];x[31725]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Lc(c)}tb(h);tb(g);tb(j)}Zb(a+172|0);Q(f|0);p()}function sY(a,b){var c=0;a:{b:{c:{if(ne(a,16755)){break c}if(ne(a,17522)){break c}if(ne(a,13681)){break c}if(ne(a,13761)){break c}if(!ne(a,14243)){break b}}w[b+10>>1]=4;x[b>>2]=12036;break a}d:{e:{if(ne(a,17517)){break e}if(ne(a,13686)){break e}if(!ne(a,16745)){break d}}v[b+15|0]=1;v[b+12|0]=1;x[b>>2]=8391;w[b+10>>1]=4;break a}f:{if(!ne(a,14281)){if(!ne(a,14286)){break f}}w[b+10>>1]=8;x[b>>2]=8169;break a}g:{if(!ne(a,15375)){if(!ne(a,15380)){break g}}x[b>>2]=17109;w[b+10>>1]=v[a+2|0]-48;break a}h:{if(!ne(a,25242)){if(!ne(a,25247)){break h}}x[b+4>>2]=1;x[b>>2]=16915;w[b+10>>1]=y[a|0]==56?8:4;break a}if(!(kd(a,15535,3)|(y[a+3|0]-52&255)>>>0>4)){x[b>>2]=8509;a=v[a+3|0];w[b+8>>1]=1088;w[b+10>>1]=a-48;break a}i:{j:{if(kd(a,13699,3)){if(kd(a,13818,3)){break j}}if((y[a+3|0]-52&255)>>>0>5){break j}v[b+15|0]=1;v[b+13|0]=1;x[b>>2]=8268;break i}k:{if((y[a|0]-49&255)>>>0>8){break k}if(!kd(a+1|0,13839,3)){v[b+14|0]=1;x[b>>2]=8573;w[b+10>>1]=v[a|0]-48;break a}c=y[a+2|0]|y[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(y[a+1|0]-48&255)>>>0>9){break k}v[b+14|0]=1;x[b>>2]=8573;w[b+10>>1]=(v[a+1|0]+D(v[a|0],10)|0)-528;break a}if(!(kd(a,13572,3)|(y[a+3|0]-49&255)>>>0>8)){x[b>>2]=8418;break i}if(ne(a,13911)){v[b+16|0]=1;w[b+10>>1]=4;break a}if(ne(a,14238)){v[b+14|0]=1;x[b>>2]=8573;w[b+10>>1]=8;a=1}else{a=0}return a}w[b+10>>1]=v[a+3|0]-48}return 1}function Yoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=fb-16|0;fb=i;ld(d,32);h=i+8|0;tW(h,y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24),y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24),x[b>>2]);h=ec(h);tW(i,y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24),y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24),x[c>>2]);a=0;a:{h=x[h>>2];if(h-838861>>>0<4294128436){break a}e=x[ec(i)>>2];x[d>>2]=D(h,320);w[d+34>>1]=1;if(!Fh(d)){break a}k=h<<2;f=+(k>>>0);o=+(e>>>0)/f;p=+(h>>>0)/f;q=1/+A[d>>2];r=+A[i>>2];s=+A[i+8>>2];h=0;b:while(1){if((h|0)==(k|0)){a=1;break a}l=+(h>>>0);m=0;n=0;a=x[b+20>>2];if(je(x[b>>2],a)){f=l*p+s;c:{if(f<4294967296&f>=0){g=~~f>>>0;break c}g=0}e=g;f=f-+(e>>>0);e=z[b+34>>1];j=_d(e);g=D(g,j);d:{if(e&1){e=w[a+(g<<1)>>1];a=z[a+(g+j<<1)>>1];break d}e=y[a+g|0]<<8;a=y[a+(g+j|0)|0]<<8}n=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}a=x[c+20>>2];if(je(x[c>>2],a)){f=l*o+r;e:{if(f<4294967296&f>=0){g=~~f>>>0;break e}g=0}e=g;f=f-+(e>>>0);e=z[c+34>>1];j=_d(e);g=D(g,j);f:{if(e&1){e=w[a+(g<<1)>>1];a=z[a+(g+j<<1)>>1];break f}e=y[a+g|0]<<8;a=y[a+(g+j|0)|0]<<8}m=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}e=0;a=h;while(1)if((e|0)==80){h=h+1|0;continue b}else{f=q*+(a>>>0);t=x[d+20>>2]+(a<<1)|0,u=qC(n*(1-f)+m*f),w[t>>1]=u;a=a+k|0;e=e+1|0;continue}}}fb=i+16|0;return a|0}function Fua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=Fb(a);a=y[b+11|0];g=x[b+4>>2];x[31725]=0;k=zh(g,a);O(112,i|0,k|0);a=x[31725];x[31725]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=v[cc(b,a)|0];h=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(h-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(h-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}x[31725]=0;O(304,i|0,Hd(c,g)|0);h=x[31725];x[31725]=0;g=e;if((h|0)!=1){break d}a=N()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(h-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}x[31725]=0;O(304,i|0,Hd(c,j)|0);e=x[31725];x[31725]=0;if((e|0)!=1){break d}a=N()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(D(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}h=(e|0)!=125;f=-1;e=125;if(h){break d}}f=0;x[31725]=0;O(113,i|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){break d}a=N()|0;break b}f=-1}a=a+1|0;continue}break}b=ac(8);x[31725]=0;a=R(98,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){x[31725]=0;S(99,a|0,40244,17);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;jc(b);break b}a=N()|0}tb(i);Q(a|0)}p()}function vpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;ld(b,2);f=e+24|0;Rk(f,2,a+1|0);d=e+36|0;Cc(d,f);ze(b+43|0,d);tb(d);a:{b:{c:{d:{switch(y[a|0]){case 0:f=x[b+4>>2];d=x[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b>>2]=d;x[e+36>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[e+24>>2]=d-1;d=e+36|0;f=x[Gb(d,e+24|0)>>2];x[b+4>>2]=f;x[e+36>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);d=x[Gb(d,b)>>2];x[b+8>>2]=d;w[b+34>>1]=z[b+34>>1]&65533|y[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}w[b+34>>1]=0;x[b+4>>2]=0;x[b+8>>2]=0;break a}f=e+24|0;ph(f,a+16|0);d=x[e+24>>2];x[e+36>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);ph(f,a+20|0);d=x[e+24>>2];x[e+40>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);ph(f,a+24|0);d=x[e+24>>2];d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+44>>2]=d;x[e+16>>2]=d;d=x[e+40>>2];x[e+8>>2]=x[e+36>>2];x[e+12>>2]=d;_k(b,1,e+8|0)}v[e+36|0]=y[a+28|0];v[e+24|0]=64;g=b,h=y[Rb(e+36|0,e+24|0)|0]<<2,w[g+30>>1]=h;d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);x[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(y[a|0]==2){d=d&65535;x[b>>2]=d;break e}if(A[b>>2]>=65536){x[b>>2]=65535}d=x[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}x[b>>2]=a}fb=e+48|0}function lK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=xj(x[d+4>>2]);i=nq(x[d+28>>2],a+208|0);mq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1222,a+332|0,a+328|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31725]=0;g=R(1223,x[a+332>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(ho(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31725]=0;R(1225,a+332|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=uK(c,x[a+180>>2],e,b),x[j>>2]=k;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+332|0,a+328|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function N8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=xj(x[d+4>>2]);i=nq(x[d+28>>2],a+208|0);mq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1222,a+332|0,a+328|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31725]=0;g=R(1223,x[a+332>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(ho(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31725]=0;R(1225,a+332|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=zK(c,x[a+180>>2],e,b),x[j>>2]=k;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+332|0,a+328|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function L8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=xj(x[d+4>>2]);i=nq(x[d+28>>2],a+208|0);mq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1222,a+332|0,a+328|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31725]=0;g=R(1223,x[a+332>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(ho(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31725]=0;R(1225,a+332|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=wK(c,x[a+180>>2],e,b),w[j>>1]=k;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1222,a+332|0,a+328|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function $I(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{c:{while(1){c=x[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[c|0];j=i&255;d:{if((i|0)>=0){w[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=y[c+1|0];if((i&192)!=128){break a}w[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=y[c+2|0];i=y[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}w[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=y[c+3|0];i=y[c+2|0];c=y[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;w[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;x[a+8>>2]=f+2;w[f+2>>1]=i<<6&960|k&63|56320;b=x[a+12>>2]+4|0}x[a+12>>2]=b;f=x[a+8>>2]+2|0;x[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return b|0}function V8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=xj(g);oq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1207,a+220|0,a+216|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31725]=0;g=R(1208,x[a+220>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(io(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111728)){break c}x[31725]=0;R(1210,a+220|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=xK(c,x[a+184>>2],e,b),x[i>>2]=j;x[f+4>>2]=hb;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+220|0,a+216|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function T8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=xj(g);oq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1207,a+220|0,a+216|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31725]=0;g=R(1208,x[a+220>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(io(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111728)){break c}x[31725]=0;R(1210,a+220|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=tK(c,x[a+184>>2],e,b),x[i>>2]=j;x[f+4>>2]=hb;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+220|0,a+216|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function B4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Fb(a);a=y[b+11|0];g=x[b+4>>2];x[31725]=0;k=zh(g,a);O(95,h|0,k|0);a=x[31725];x[31725]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=y[cc(b,a)|0];d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(e-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(e-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}x[31725]=0;O(96,h|0,Hd(c,g)|0);j=x[31725];x[31725]=0;g=e;if((j|0)!=1){break d}a=N()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;i=e;break d;case 3:f=-1;j:{switch(e-123|0){case 2:f=0;if(d>>>0<=i>>>0){break d}x[31725]=0;O(96,h|0,Hd(c,i)|0);e=x[31725];x[31725]=0;if((e|0)!=1){break d}a=N()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}i=(D(i,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}j=(e|0)!=125;f=-1;e=125;if(j){break d}}f=0;x[31725]=0;O(97,h|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){break d}a=N()|0;break b}f=-1}a=a+1|0;continue}break}b=ac(8);x[31725]=0;a=R(98,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){x[31725]=0;S(99,a|0,40244,17);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;jc(b);break b}a=N()|0}tb(h);Q(a|0)}p()}function AN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=fb-16|0;fb=h;g=x[a+32>>2];f=Aq(g);if(!f){f=zq(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=ac(8);x[31725]=0;c=P(36,h+4|0,6e3)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}if(c>>>0>=120){b=ac(8);x[31725]=0;c=P(36,h+4|0,11318)|0;a=x[31725];x[31725]=0;if((a|0)!=1){pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;jc(b);break b}f=dB(g,65535);j=(f|0)==65535?255:f;w[h+4>>1]=j;f=g+D(j,872)|0;i=f+1074992|0;Wo(i,g,65535,1024);c=c+1|0;v[f+1075794|0]=c;v[f+1075791|0]=c;w[f+1075778>>1]=0;en(i);Ro(x[a+32>>2],i,b+1|0,0,1,1);x[f+1075688>>2]=65536;Su(x[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=_i(Uv(e*128,-128,128)+128),x[l>>2]=m;l=f+1075680|0,m=_i(Uv(d*256,0,256)),x[l>>2]=m;c=x[a+32>>2];i=c+1074478|0;b=i;c=b+(z[c+480212>>1]<<1)|0;g=z[h+4>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=z[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=z[f>>1];if((k|0)==(g|0)){continue}w[b>>1]=k;b=b+2|0;g=z[h+4>>1];continue}}l=x[a+32>>2],m=IB(i,c),w[l+480212>>1]=m;fb=h+16|0;return j|0}a=N()|0;jc(b)}Q(a|0)}p()}function VI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){tc(a,9750);break j}d=b>>>24|0;if(!(b&65535)){e=fb-16|0;fb=e;f=tc(e+4|0,4399);_c(c+68|0,f);tb(f);fb=e+16|0;x[31725]=0;x[c+24>>2]=d;O(89,c+56|0,c+24|0);d=x[31725];x[31725]=0;k:{l:{m:{n:{if((d|0)!=1){x[31725]=0;x[c+8>>2]=b>>>16&255;O(90,c+44|0,c+8|0);b=x[31725];x[31725]=0;if((b|0)==1){break n}x[31725]=0;V(91,a|0,c+68|0,c+56|0,c+44|0);a=x[31725];x[31725]=0;if((a|0)==1){break m}tb(c+44|0);tb(c+56|0);Eb(c+68|0);break j}b=N()|0;break k}b=N()|0;break l}b=N()|0;tb(c+44|0)}tb(c+56|0)}break a}e=fb-16|0;fb=e;f=tc(e+4|0,4123);_c(c+68|0,f);tb(f);fb=e+16|0;x[31725]=0;x[c+40>>2]=d;O(89,c+56|0,c+40|0);d=x[31725];x[31725]=0;if((d|0)==1){break i}x[31725]=0;x[c+36>>2]=b>>>16&255;O(90,c+44|0,c+36|0);d=x[31725];x[31725]=0;if((d|0)==1){break h}x[31725]=0;x[c+20>>2]=b>>>8&255;O(90,c+24|0,c+20|0);d=x[31725];x[31725]=0;if((d|0)==1){break g}x[31725]=0;x[c+4>>2]=b&255;O(90,c+8|0,c+4|0);b=x[31725];x[31725]=0;if((b|0)==1){break f}x[31725]=0;ja(92,a|0,c+68|0,c+56|0,c+44|0,c+24|0,c+8|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}tb(c+8|0);tb(c+24|0);tb(c+44|0);tb(c+56|0);Eb(c+68|0)}fb=c+80|0;return}b=N()|0;break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;tb(c+8|0)}tb(c+24|0)}tb(c+44|0)}tb(c+56|0)}Eb(c+68|0);Q(b|0);p()}function Gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;m=fb-16|0;fb=m;e=x[vb(m+12|0,wb(x[a+4>>2]))>>2];k=fb-32|0;fb=k;f=e;e=x[a>>2];j=(sp(f,wb(e))<<1)+e|0;g=IB(b,c);a:{if((g|0)<=0){break a}e=x[zb(a)>>2];l=x[a+4>>2];if((g|0)<=e-l>>1){p=l-j|0;d=p>>1;b:{if((d|0)>=(g|0)){e=c;break b}x[k+12>>2]=b;$T(k+12|0,d);e=x[k+12>>2];f=e;n=fb-16|0;fb=n;o=$h(n+4|0,a,g-d|0);h=zb(a);d=fb-48|0;fb=d;i=x[o+4>>2];x[d+44>>2]=i;x[d+40>>2]=i;h=Se(d+12|0,h,d+40|0,d+44|0);x[d+8>>2]=x[h+8>>2];i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;Re(d+24|0,d);while(1){if((c|0)!=(f|0)){gj(x[d+44>>2],z[f>>1]);x[d+44>>2]=x[d+44>>2]+2;f=f+2|0;continue}break}Qe(d+24|0);q=x[d+44>>2];if(!y[d+36|0]){f=fb-16|0;fb=f;c=vb(f+12|0,x[x[d+32>>2]>>2]);r=x[vb(f+8|0,x[x[d+28>>2]>>2])>>2];h=fb-16|0;fb=h;c=x[c>>2];x[h+12>>2]=c;while(1){if(pd(c,r)){i=fb-16|0;fb=i;x[i+12>>2]=c;$T(i+12|0,-1);fb=i+16|0;c=x[jj(h+12|0)>>2];continue}break}fb=h+16|0;fb=f+16|0}fb=d+48|0;x[o+4>>2]=q;hc(o);fb=n+16|0;if((p|0)<=0){break a}}hV(a,j,l,(g<<1)+j|0);Nk(b,e,j);break a}e=zb(a);d=ok(k+12|0,pk(a,Zc(x[a>>2],l)+g|0),j-x[a>>2]>>1,e);g=fb-16|0;fb=g;c=Ip(g+4|0,d+8|0,IB(b,c));e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){gj(e,z[b>>1]);e=x[c>>2]+2|0;x[c>>2]=e;b=b+2|0;continue}break}he(c);fb=g+16|0;j=gV(a,d,j);kj(d)}wb(j);fb=k+32|0;fb=m+16|0;return a|0}function t8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=Oy(x[g>>2]);g=uy(x[g>>2]);th(k+4|0,g);a:{b:{if(Ad(x[k+8>>2],y[k+15|0])){x[31725]=0;V(1228,l|0,a|0,c|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[31725]=0;j=P(1234,l|0,h<<24>>24)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[31725]=0;h=P(1234,l|0,48)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;h=v[j+1|0];x[31725]=0;h=P(1234,l|0,h|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;j=j+2|0}Im(j,c);i=0;x[31725]=0;o=R(1226,g|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){jt((j-a<<2)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[cc(k+4|0,h)|0]){break e}if(v[cc(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=o;h=(Cb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[31725]=0;n=P(1234,l|0,n|0)|0;m=x[31725];x[31725]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+4;x[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;tb(k+4|0);fb=k+16|0}function rma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=fb-16|0;fb=g;r=x[a+16>>2];s=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];m=x[a+128>>2];if(m){n=Gg(k,l,m);o=hb;b=x[a+76>>2];hg(h,e,vf(k,l,d),hb);p=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{q=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;p=p-1|0;b=p;n=b?n:0;o=b?o:0;h=(e<<1)+r|0;b=m;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);ae(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,s);v=x[a+72>>2];h=b<<8;b=h;e=x[a+60>>2];b=ova(e,e>>31,b,b>>31);y=hb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Yb(q,-16777216,16776704);j=ova(j,z,b,b>>31);e=e+j|0;b=hb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=ova(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,t);Pb(g,k,l);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue a}else{be(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);ae(i,4);Pb(g+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;fb=g+16|0}function bM(a){var b=0,c=0,d=0,e=0;Ie(x[a+80>>2],x[a+20>>2]);while(1){c=x[a+28>>2];if((b|0)<x[a+24>>2]){Ie(x[a+80>>2],x[c+(b<<2)>>2]);b=b+1|0;continue}break}Ie(x[a+80>>2],c);a:{if(!x[a+396>>2]){break a}c=0;while(1){if(x[a+264>>2]<=(c|0)){break a}e=x[a+396>>2]+D(c,24)|0;d=x[e+16>>2];if(d){b=0;while(1){if((b|0)<x[(x[a+124>>2]+D(y[e+13|0],2096)|0)+4>>2]){Ie(x[a+80>>2],x[(b<<2)+d>>2]);b=b+1|0;d=x[e+16>>2];continue}break}Ie(x[a+80>>2],d)}Ie(x[a+80>>2],x[e+20>>2]);c=c+1|0;continue}}d=x[a+124>>2];if(d){c=0;while(1){if((c|0)<x[a+120>>2]){b=D(c,2096)+d|0;Ie(x[a+80>>2],x[b+8>>2]);Ie(x[a+80>>2],x[b+28>>2]);Ie(x[a+80>>2],x[b+32>>2]);Ie(x[a+80>>2],x[b+2084>>2]);b=x[b+2088>>2];Ie(x[a+80>>2],b?b-4|0:0);c=c+1|0;d=x[a+124>>2];continue}break}Ie(x[a+80>>2],d)}Ie(x[a+80>>2],x[a+260>>2]);Ie(x[a+80>>2],x[a+396>>2]);c=x[a+404>>2];if(c){b=0;while(1){if((b|0)<x[a+400>>2]){Ie(x[a+80>>2],x[(D(b,40)+c|0)+4>>2]);b=b+1|0;c=x[a+404>>2];continue}break}Ie(x[a+80>>2],c)}c=0;b=0;while(1){if(!(x[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;Ie(x[a+80>>2],x[d+800>>2]);Ie(x[a+80>>2],x[d+928>>2]);Ie(x[a+80>>2],x[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;Ie(x[a+80>>2],x[b+1068>>2]);Ie(x[a+80>>2],x[b+1076>>2]);Ie(x[a+80>>2],x[b+1084>>2]);Ie(x[a+80>>2],x[b+1092>>2]);Ie(x[a+80>>2],x[b+1100>>2]);c=c+1|0;continue}break}}function SU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;c=x[a>>2];a:{if(Pj(c)){i=fb-16|0;fb=i;e=Ec(3848);d=e+808|0;c=e+16|0;while(1){x[c+16>>2]=0;x[c+20>>2]=0;x[c+36>>2]=0;v[c+42|0]=1;w[c+40>>1]=257;x[c+24>>2]=0;x[c+28>>2]=0;w[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){x[d>>2]=0;x[d+4>>2]=0;x[d+68>>2]=0;x[d+72>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;w[d+20>>1]=511;x[d+16>>2]=-1;w[d+14>>1]=1;w[d+6>>1]=0;w[d+8>>1]=0;w[d+10>>1]=0;w[d+12>>1]=0;v[d+73|0]=0;v[d+74|0]=0;v[d+75|0]=0;v[d+76|0]=0;v[d+77|0]=0;v[d+78|0]=0;v[d+79|0]=0;v[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}x[e+3832>>2]=0;x[e+3836>>2]=0;c=e+3837|0;v[c|0]=0;v[c+1|0]=0;v[c+2|0]=0;v[c+3|0]=0;v[c+4|0]=0;v[c+5|0]=0;v[c+6|0]=0;v[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}Vo((e+D(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+D(f,44)|0)+16|0;c=x[(f<<2)+27280>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+D(c,84)|0;YU(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+D(c,84)|0;YU(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{x[(e+D(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}XU(e,b)}else{yd((e+D(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=x[yf(i+12|0,e)>>2];fb=i+16|0;x[h+12>>2]=b;b=h+12|0;wA(a,b);Hj(b);break a}XU(c,b)}RU(a);fb=h+16|0}function YE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=fb-16|0;fb=h;d=x[b>>2];e=Zc(d,x[b+4>>2]);a:{if(e>>>0<c>>>0){l=fb-32|0;fb=l;d=c-e|0;e=x[zb(b)>>2];f=x[b+4>>2];b:{if(d>>>0<=e-f>>1>>>0){f=fb-16|0;fb=f;d=$h(f+4|0,b,d);e=x[d+4>>2];g=x[d+8>>2];while(1){if((e|0)==(g|0)){hc(d);fb=f+16|0}else{zp(e);e=e+2|0;x[d+4>>2]=e;continue}break}break b}e=zb(b);e=ok(l+12|0,pk(b,Zc(x[b>>2],f)+d|0),Zc(x[b>>2],x[b+4>>2]),e);g=fb-16|0;fb=g;d=Ip(g+4|0,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){zp(f);f=x[d>>2]+2|0;x[d>>2]=f;continue}break}he(d);fb=g+16|0;i=fb-16|0;fb=i;f=vb(i+12|0,x[b+4>>2]);g=vb(i+8|0,x[b>>2]);j=x[vb(i+4|0,x[e+4>>2])>>2];k=fb-16|0;fb=k;m=k+8|0;d=fb-32|0;fb=d;Id(d+24|0,x[f>>2],x[g>>2]);n=d+16|0;g=x[d+24>>2];o=x[d+28>>2];f=fb-16|0;fb=f;x[f+8>>2]=j;x[f+12>>2]=g;while(1){if(pd(g,o)){g=On(g);j=On(x[f+8>>2]);g=y[g|0]|y[g+1|0]<<8;v[j|0]=g;v[j+1|0]=g>>>8;g=jj(f+12|0);jj(f+8|0);g=x[g>>2];continue}break}Ac(n,g,f+8|0);fb=f+16|0;f=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(m,f,d+12|0);fb=d+32|0;fb=k+16|0;x[e+4>>2]=x[k+12>>2];Ub(b,e+4|0);Ub(b+4|0,e+8|0);Ub(zb(b),nc(e));x[e>>2]=x[e+4>>2];fb=i+16|0;kj(e)}fb=l+32|0;break a}if(c>>>0<e>>>0){Kn(b,d+(c<<1)|0)}}c=Mb(x[a>>2],x[a+8>>2],c<<1);if(c){e=x[b>>2];bc(h+8|0,e,Zc(e,x[b+4>>2])<<1);rd(h,a,x[h+8>>2],x[h+12>>2])}fb=h+16|0;return c|0}function vK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=xj(g);oq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1207,a+220|0,a+216|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31725]=0;g=R(1208,x[a+220>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(io(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111728)){break c}x[31725]=0;R(1210,a+220|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=uK(c,x[a+184>>2],e,b),x[i>>2]=j;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+220|0,a+216|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function W8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=xj(g);oq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1207,a+220|0,a+216|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31725]=0;g=R(1208,x[a+220>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(io(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111728)){break c}x[31725]=0;R(1210,a+220|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=zK(c,x[a+184>>2],e,b),x[i>>2]=j;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+220|0,a+216|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function U8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=xj(g);oq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31725]=0;g=P(1207,a+220|0,a+216|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31725]=0;O(46,d|0,g<<1);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=Mc(d);x[31725]=0;O(46,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31725]=0;g=R(1208,x[a+220>>2])|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}if(io(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111728)){break c}x[31725]=0;R(1210,a+220|0)|0;g=x[31725];x[31725]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=wK(c,x[a+184>>2],e,b),w[i>>1]=j;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31725]=0;b=P(1207,a+220|0,a+216|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function WP(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-240|0;fb=e;if(!y[127064]){if(!y[126936]){b=fb-16|0;fb=b;Fb(126912);x[31731]=0;v[126928]=0;x[31733]=0;x[31725]=0;a=ca(56)|0;c=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){x[b+12>>2]=a;a=b+12|0;OA(126924,le(a));Hj(a);v[126928]=0;break f}a=ta(125e3,125584)|0;c=gb;if(($(125e3)|0)==(c|0)){Y(a|0)|0;x[31725]=0;X(57);b=x[31725];x[31725]=0;if((b|0)==1){break d}p()}if(($(125584)|0)!=(c|0)){break c}Y(a|0)|0;x[31725]=0;v[126928]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;break c}if(y[126928]){break e}}x[31725]=0;W(58,126908);a=x[31725];x[31725]=0;if((a|0)!=1){break e}a=N()|0;break c}fb=b+16|0;break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}}Hj(126932);Hj(126924);tb(126912);Q(a|0);p()}T(0)|0;Sb();p()}v[126936]=1}c=fb+-64|0;fb=c;b=c+16|0;g=fb-16|0;fb=g;h=CP(g+8|0);j=e+120|0;l=c+4|0;while(1){if((i|0)==12){fb=g+16|0}else{f=fb-48|0;fb=f;a=x[h+4>>2];d=x[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=uP(wP(f+12|0,32));break g}d=G(a);d=wP(f+12|0,(a<<d&2147483647?32:31)-d|0);while(1){k=uP(d);if(a>>>0<=k>>>0){continue}break}a=x[h>>2]+k|0}fb=f+48|0;m=yb(b,i),n=a,x[m>>2]=n;i=i+1|0;continue}break}b=LP(l,b,OP(b));FP(j,b);cn(b);fb=c- -64|0;yc(126944,yc(e,j,120),116);v[127064]=1}fb=e+240|0}function QU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{b:{switch(e<<31|e-2>>>1){case 4:HB(a,b,c,d);return;case 0:e=32-G(d|1)|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<17){while(1){b=b-1|0;v[b|0]=y[(d&1)+15477|0];e=d>>>0>1;d=d>>>1|0;if(e){continue}break}}else{b=b-4|0;jn((d<<2&60)+78800|0,4,b);d=d>>>4|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 3:e=(34-G(d|1)>>>0)/3|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<65){while(1){b=b-1|0;v[b|0]=y[(d&7)+14762|0];e=d>>>0>7;d=d>>>3|0;if(e){continue}break}}else{b=b-2|0;jn((d<<1&126)+78864|0,2,b);d=d>>>6|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 7:e=35-G(d|1)>>>2|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<257){while(1){b=b-1|0;v[b|0]=y[(d&15)+11165|0];e=d>>>0>15;d=d>>>4|0;if(e){continue}break}}else{b=b-2|0;jn((d<<1&510)+78992|0,2,b);d=d>>>8|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;default:break b}}g=d;i=D(e,e);k=D(i,e);j=D(i,i);c:{while(1){h=f|1;if(e>>>0>g>>>0){break c}h=f|2;if(g>>>0<i>>>0){break c}h=f|3;if(g>>>0<k>>>0){break c}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){x[a+4>>2]=61;break a}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;v[c|0]=y[(d-D(b,e)|0)+4895|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}x[a+4>>2]=0;x[a>>2]=f;return}x[a>>2]=c}function Fsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-48|0;fb=d;l=b+484344|0;m=b+480280|0;n=b+906300|0;while(1){a:{b:{c:{if(Mb(x[c>>2],x[c+8>>2],9)){rr(c,d+43|0);e=Pg(c);d:{f=y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24);e:{if((f|0)==1229999433|(f|0)==1397771593){break e}f=y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24);if((f|0)==1297110104|(f|0)==1297110099){break e}if(Mb(x[c>>2],x[c+8>>2],e)){break d}}v[d+47|0]=j;Gh(c,8);break c}fe(d,c,e);f=ic(d+20|0,d);ub(d);e=m;f:{if((y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24))==1481001027){while(1){if((e|0)==(l|0)){h=1;break a}x[31725]=0;h=R(153,f|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break f}v[e+8|0]=h;e=e+32|0;continue}}if(y[d+43|0]!=70){break b}g=y[d+44|0];k=(g|0)==88;g:{if(!k){if((g-48&255)>>>0>9){break b}e=v[d+45|0];if((e|0)>47){break g}break b}e=v[d+45|0];if((e|0)<48){break b}}if(e>>>0>57){break b}i=v[d+46|0];if((i|0)<48|(i|0)>57){break b}h=1;e=((i&255)+(k?-528:D(g,100)-5328|0)|0)+D(e&255,10)&65535;if(e>>>0>249){break a}e=vd(n,e);x[31725]=0;O(452,f|0,e|0);e=x[31725];x[31725]=0;if((e|0)!=1){break a}}a=N()|0;ub(f);Q(a|0);p()}v[d+47|0]=j}vD(a,h,d+47|0);fb=d+48|0;return}if((y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24))!=1430540109){break a}x[b+1074308>>2]=0;j=1}ub(f);continue}}function Usa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb+-64|0;fb=d;b=b&4095;w[d+62>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=fb-16|0;fb=e;f=tc(e+4|0,4451);_c(d+48|0,f);tb(f);fb=e+16|0;x[31725]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=ova(e,e>>31,1e4,0);b=hb;c=c+14780|0;b=c>>>0<14780?b+1|0:b;b=pva(c,b,3652425,0);c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(D(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;x[d+32>>2]=g+f;O(75,d+36|0,d+32|0);g=x[31725];x[31725]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){x[31725]=0;x[d+16>>2]=(e+D(f,-12)|0)+1;O(78,d+20|0,d+16|0);e=x[31725];x[31725]=0;if((e|0)==1){break j}x[31725]=0;x[d>>2]=(((D(b,306)+5|0)/-10|0)+c|0)+1;O(78,d+4|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break i}x[31725]=0;aa(415,a|0,d+48|0,d+36|0,d+20|0,d+4|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}tb(d+4|0);tb(d+20|0);break d}b=N()|0;break e}b=N()|0;break f}b=N()|0;break g}b=N()|0;tb(d+4|0)}tb(d+20|0)}tb(d+36|0)}break a}ig(d+48|0,4431);x[31725]=0;O(416,d+36|0,d+62|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}x[31725]=0;S(141,a|0,d+48|0,d+36|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}}tb(d+36|0);Eb(d+48|0);fb=d- -64|0;return}b=N()|0;break a}b=N()|0;tb(d+36|0)}Eb(d+48|0);Q(b|0);p()}function D8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=Aw(x[g>>2]);g=By(x[g>>2]);th(k+4|0,g);a:{b:{if(Ad(x[k+8>>2],y[k+15|0])){x[31725]=0;V(1215,l|0,a|0,c|0,d|0);g=x[31725];x[31725]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[31725]=0;j=P(29,l|0,h<<24>>24)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+1;v[h|0]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[31725]=0;h=P(29,l|0,48)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[j+1|0];x[31725]=0;h=P(29,l|0,h|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;j=j+2|0}Im(j,c);i=0;x[31725]=0;o=R(1213,g|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Im((j-a|0)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[cc(k+4|0,h)|0]){break e}if(v[cc(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+1;v[i|0]=o;h=(Cb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[31725]=0;n=P(29,l|0,n|0)|0;m=x[31725];x[31725]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+1;v[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;tb(k+4|0);fb=k+16|0}function wB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;f=x[c+656>>2];a:{if(!Uj(f)){i=x[c+704>>2];f=fb-16|0;fb=f;x[f+12>>2]=d;g=0;b:{if(!d){break b}j=x[b+480180>>2];if(j&20){e=b+1074312|0;d=Ob(e,73)?d&65535:d;if(y[b+480208|0]&16){e=Ob(e,73)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=x[((d>>>0)%768<<2)+32368>>2]<<6>>>e|0;break b}g=229079296/((d>>>0<=1?1:d)>>>0)|0;break b}g=227001280/(d>>>0)|0;if(En(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}wc(f+12|0,16777215);if(j&17408){g=Bc(qva(ova(i?i:8363,0,3506176,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}if(Jj(b)){d=x[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(y[b+480208|0]&16){g=Bc(qva(ova(i?i:8363,0,7012352,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}g=Bc(qva(-1485242368,13,(x[f+12>>2]<<8)+e|0,0),hb)}e=g;fb=f+16|0;f=x[c+656>>2];break a}e=x[c+700>>2]}x[h+12>>2]=e;c=w[c+774>>1];c:{if(!c){break c}c=f?D(v[f+33|0],c):c;if(!c){break c}e=_e(Di(+(c|0)/393216)*+(e>>>0));x[h+12>>2]=e}d:{if(!f){break d}c=x[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=x[b+1074420>>2];e=ova(f,f>>31,e,e>>31);f=d+e|0;d=hb+(d>>31)|0;k=h,l=Gc(pva(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),hb),x[k+12>>2]=l}wc(h+12|0,2147483647);c=x[h+12>>2];b=mg(c,x[b+24620>>2]<<4);x[a+8>>2]=c;x[a>>2]=b;x[a+4>>2]=hb;fb=h+16|0}function ac(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=OY(a+24|0);a=h;i=a>>>0<=1?1:a;a=i;b=a+15&-16;d=a>>>0<b>>>0?b:a;b=0;f=fb-16|0;fb=f;if(!(d&15)){if(d>>>0>4294967216){a=48}else{a:{if(d>>>0>=4294967216){x[31600]=48;a=0;break a}d=d>>>0<11?16:d+11&-8;c=Fd(d+28|0);a=0;if(!c){break a}b=c-8|0;b:{if(!(c&15)){a=b;break b}g=c-4|0;j=x[g>>2];a=(c+15&-16)-8|0;a=(a-b>>>0<=15?16:0)+a|0;c=a-b|0;e=(j&-8)-c|0;if(!(j&3)){b=x[b>>2];x[a+4>>2]=e;x[a>>2]=b+c;break b}x[a+4>>2]=e|x[a+4>>2]&1|2;e=a+e|0;x[e+4>>2]=x[e+4>>2]|1;x[g>>2]=c|x[g>>2]&1|2;e=b+c|0;x[e+4>>2]=x[e+4>>2]|1;Cv(b,c)}b=x[a+4>>2];c:{if(!(b&3)){break c}c=b&-8;if(c>>>0<=d+16>>>0){break c}x[a+4>>2]=d|b&1|2;b=a+d|0;d=c-d|0;x[b+4>>2]=d|3;c=a+c|0;x[c+4>>2]=x[c+4>>2]|1;Cv(b,d)}a=a+8|0}if(a){x[f+12>>2]=a;a=0}else{a=48}}b=a?0:x[f+12>>2]}fb=f+16|0;a=b;if(!a){d:{b=0;a=x[125550];if(!a){x[125550]=502220;w[251111]=125;k=502220,l=Qx(502720),w[k>>1]=l;a=x[125550]}d=(i+3>>>2|0)+1|0;while(1){e:{if(!a|(a|0)==502720){a=0}else{c=z[a+2>>1];f=d+(d>>>0<c>>>0?c-d&3:0)|0;if(c>>>0>f>>>0){b=c-f|0;w[a+2>>1]=b;a=((b&65535)<<2)+a|0;w[a+2>>1]=f;w[a>>1]=0;a=a+4|0;break d}if(d>>>0>c>>>0){break e}d=z[a>>1];f:{if(!b){k=502200,l=Rx(d),x[k>>2]=l;break f}w[b>>1]=d}w[a>>1]=0;a=a+4|0}break d}b=a;a=Rx(z[a>>1]);continue}}}if(!a){Sb();p()}return cS(Tb(a,0,h))}function IA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=ZR(b,c);a:{if(!x[b+656>>2]|!(v[h+6|0]&1)){break a}e=x[h>>2];i=a+1074312|0;f=Ob(i,31);d=Jw(x[b+656>>2],c);if(lc(x[d>>2],x[d+4>>2])){break a}f=e+(f^1)|0;g=Ob(i,31);e=y[d+12|0];b:{c:{if(!g){d:{if(!(e&2)){break d}j=y[d+14|0];k=!(x[a+480180>>2]&1048580)+z[yb(x[d>>2],j)>>1]|0;g=0;if(!(!(y[b+89|0]&8)|(!(e&4)|(j|0)!=y[d+16|0]))){g=Ob(i,70)}if(g|(f|0)!=(k|0)){break d}f=z[yb(x[d>>2],y[d+13|0])>>1]}if(!(!(y[d+12|0]&4)|y[b+89|0]&8)){a=x[d>>2];if((z[yb(a,y[d+16|0])>>1]+1|0)!=(f|0)){break b}f=z[yb(a,y[d+15|0])>>1];if(!Ob(i,93)|(c|0)!=1|y[b+89|0]&8){break b}v[h+6|0]=y[h+6|0]&254;break b}j=1;e=z[xf(x[d+4>>2])>>1];if(f>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|y[b+669|0]&8)){if(z[h+4>>1]==65535){break f}if(Ob(i,97)){break f}e=y[d+12|0]}if(e&2){g=x[d>>2];e=z[yb(g,y[d+13|0])>>1];g=z[yb(g,y[d+14|0])>>1]+1|0;break e}e=z[xf(x[d+4>>2])>>1];j=f>>>0>e>>>0;g=e;break e}g=x[d>>2];e=z[yb(g,y[d+15|0])>>1];g=z[yb(g,y[d+16|0])>>1]+1|0}e=f>>>0<g>>>0?f:e}g:{if(!j|c){break g}f=x[a+480180>>2];c=x[b+88>>2];if(!(!(f&16777248)&(!(c&2048)|(f|0)==16384))){c=c|4096;x[b+88>>2]=c}if(y[xf(x[d+4>>2])+2|0]|!(z[b+786>>1]|x[a+480180>>2]&16777248)){break g}x[b+696>>2]=0;x[b+720>>2]=0;x[b+680>>2]=0;x[b+88>>2]=c|4096}f=e}l=h,m=Ob(i,31)+f|0,x[l>>2]=m}}
function sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;g=fb-16|0;fb=g;r=x[a+16>>2];s=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];m=x[a+128>>2];if(m){n=Gg(k,l,m);o=hb;b=x[a+76>>2];hg(h,e,vf(k,l,d),hb);p=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{q=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;p=p-1|0;b=p;n=b?n:0;o=b?o:0;h=e+r|0;b=m;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(i,v[h+x[g+12>>2]|0]<<6);ae(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,s);w=x[a+72>>2];h=b<<8;b=h;e=x[a+60>>2];b=ova(e,e>>31,b,b>>31);y=hb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Yb(q,-16777216,16776704);j=ova(j,z,b,b>>31);e=e+j|0;b=hb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=ova(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,t);Pb(g,k,l);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue a}else{be(i,v[h+x[g+12>>2]|0]<<6);ae(i,4);Pb(g+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;fb=g+16|0}function F4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;k=fb-128|0;fb=k;j=lt(c,d);x[k+4>>2]=1205;n=kt(k+8|0,k+4|0);i=k+16|0;a:{b:{c:{if(j>>>0>=101){i=Fd(j);if(!i){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}Te(n,i)}h=i;g=c;while(1)if((d|0)==(g|0)){d:while(1){g=x[a>>2];h=(g|0)==(b|0);if(j?h:1){if(h){x[f>>2]=x[f>>2]|2}break b}g=x[g>>2];x[31725]=0;s=P(1224,e|0,g|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}l=o+1|0;r=0;h=i;g=c;while(1){if((d|0)==(g|0)){o=l;if(!r){continue d}x[a>>2]=x[a>>2]+4;h=i;g=c;if(j+m>>>0<2){continue d}while(1){if((d|0)==(g|0)){continue d}e:{if(y[h|0]!=2){break e}if((Cb(x[g+4>>2],y[g+11|0])|0)==(o|0)){break e}v[h|0]=0;m=m-1|0}h=h+1|0;g=g+12|0;continue}}f:{if(y[h|0]!=1){break f}q=x[Wd(g,o)>>2];x[31725]=0;q=P(1224,e|0,q|0)|0;t=x[31725];x[31725]=0;if((t|0)==1){break a}g:{if((q|0)==(s|0)){r=1;if((Cb(x[g+4>>2],y[g+11|0])|0)!=(l|0)){break f}v[h|0]=2;m=m+1|0;break g}v[h|0]=0}j=j-1|0}h=h+1|0;g=g+12|0;continue}}}else{l=Ad(x[g+4>>2],y[g+11|0]);v[h|0]=l?2:1;m=m+l|0;j=j-l|0;h=h+1|0;g=g+12|0;continue}}p()}h:{i:{while(1){if((c|0)==(d|0)){break i}if(y[i|0]!=2){i=i+1|0;c=c+12|0;continue}break}d=c;break h}x[f>>2]=x[f>>2]|4}Lc(n);fb=k+128|0;return d|0}a=N()|0;Lc(n);Q(a|0);p()}function u4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;k=fb-128|0;fb=k;j=lt(c,d);x[k+4>>2]=1205;n=kt(k+8|0,k+4|0);i=k+16|0;a:{b:{c:{if(j>>>0>=101){i=Fd(j);if(!i){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}Te(n,i)}h=i;g=c;while(1)if((d|0)==(g|0)){d:while(1){g=x[a>>2];h=(g|0)==(b|0);if(j?h:1){if(h){x[f>>2]=x[f>>2]|2}break b}g=v[g|0];x[31725]=0;s=P(1209,e|0,g|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}l=o+1|0;r=0;h=i;g=c;while(1){if((d|0)==(g|0)){o=l;if(!r){continue d}x[a>>2]=x[a>>2]+1;h=i;g=c;if(j+m>>>0<2){continue d}while(1){if((d|0)==(g|0)){continue d}e:{if(y[h|0]!=2){break e}if((Cb(x[g+4>>2],y[g+11|0])|0)==(o|0)){break e}v[h|0]=0;m=m-1|0}h=h+1|0;g=g+12|0;continue}}f:{if(y[h|0]!=1){break f}q=v[cc(g,o)|0];x[31725]=0;q=P(1209,e|0,q|0)|0;t=x[31725];x[31725]=0;if((t|0)==1){break a}g:{if((q|0)==(s|0)){r=1;if((Cb(x[g+4>>2],y[g+11|0])|0)!=(l|0)){break f}v[h|0]=2;m=m+1|0;break g}v[h|0]=0}j=j-1|0}h=h+1|0;g=g+12|0;continue}}}else{l=Ad(x[g+4>>2],y[g+11|0]);v[h|0]=l?2:1;m=m+l|0;j=j-l|0;h=h+1|0;g=g+12|0;continue}}p()}h:{i:{while(1){if((c|0)==(d|0)){break i}if(y[i|0]!=2){i=i+1|0;c=c+12|0;continue}break}d=c;break h}x[f>>2]=x[f>>2]|4}Lc(n);fb=k+128|0;return d|0}a=N()|0;Lc(n);Q(a|0);p()}function $O(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-160|0;fb=e;d=Dc(e+4|0,11600);x[31725]=0;b=d+12|0;P(36,b|0,11005)|0;c=x[31725];x[31725]=0;a:{if((c|0)==1){break a}x[31725]=0;b=d+24|0;P(36,b|0,11430)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+36|0;P(36,b|0,10997)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+48|0;P(36,b|0,8243)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+60|0;P(36,b|0,10982)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+72|0;P(36,b|0,8309)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+84|0;P(36,b|0,5620)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+96|0;P(36,b|0,12004)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+108|0;P(36,b|0,11373)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+120|0;P(36,b|0,12273)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+132|0;P(36,b|0,5472)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;b=d+144|0;P(36,b|0,7335)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;U(1069,a|0,d|0,13)|0;a=x[31725];x[31725]=0;if((a|0)!=1){b=d+156|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}fb=e+160|0;return}b=d+156|0}a=N()|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}Q(a|0);p()}function goa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-32|0;fb=d;c=z[a+480190>>1];v[d+20|0]=0;pU(b,c+1|0,d+20|0);if(z[a+480192>>1]){h=Nb(d+20|0);m=d,n=wb(x[a+484344>>2]),x[m+16>>2]=n;l=wb(x[a+484348>>2]);while(1){i=x[d+16>>2];if(Ib(i,l)){a:{if(!Ib(x[i>>2],x[i+4>>2])){break a}c=z[a+480188>>1];x[31725]=0;v[d+4|0]=0;S(781,h|0,c|0,d+4|0);c=x[31725];x[31725]=0;if((c|0)!=1){m=d,n=wb(x[i>>2]),x[m+12>>2]=n;j=0;b:while(1){f=0;if(A[i+12>>2]<=j>>>0){break a}while(1)if(z[a+480188>>1]<=f>>>0){j=j+1|0;continue b}else{c:{c=x[d+12>>2];if(!Tc(y[c|0])){break c}d:{e:{c=y[c+1|0];if(c){g=z[a+480192>>1];break e}g=z[a+480192>>1];c=y[xb(x[h>>2],f)|0];if(c){break e}c=1;break d}m=xb(x[h>>2],f),n=c,v[m|0]=n;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break c}e=x[((e<<2)+a|0)+900380>>2];f:{if(!e){break f}e=z[_b(e+236|0,y[x[d+12>>2]]-1|0)>>1];if(e>>>0>z[a+480190>>1]){break f}k=d+4|0;Jb(k,x[b>>2],e);Jf(k,1)}c=c+1|0;continue}}f=f+1|0;JC(d+12|0);continue}}}a=N()|0;dc(h);Q(a|0);p()}bm(d+16|0);continue}else{c=z[a+480190>>1];while(1){if(c){Jb(d+4|0,x[b>>2],c);if(!Hb(x[x[d+4>>2]>>2],x[d+8>>2])){e=f;f=D(c,104)+a|0;f=e+je(x[f+484380>>2],x[f+484400>>2])|0}c=c-1|0;continue}else{dc(h)}break}}break}}fb=d+32|0;return f&65535}function aJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;c=x[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=z[c>>1];c:{if(b>>>0<=127){f=1;c=x[a+8>>2];if((g-c|0)<=0){break a}x[a+8>>2]=c+1;v[c|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if(b>>>0<=55295){c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=z[c+2>>1];if((i&64512)!=56320){break e}if((g-x[a+8>>2]|0)<4){break a}x[a+12>>2]=c+2;c=x[a+8>>2];x[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;v[f|0]=c>>>2|240;f=x[a+8>>2];x[a+8>>2]=f+1;v[f|0]=c<<4&48|b>>>2&15|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=i>>>6&15|b<<4&48|128;b=x[a+8>>2];x[a+8>>2]=b+1;v[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}c=x[a+12>>2]+2|0;x[a+12>>2]=c;continue}break}f=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return f|0}function fsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=Hf(a,c);$d(e,x[a+36>>2]);i=a;a:{if(!h){Pc(e,a+32|0,5);c=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}d=fb-160|0;fb=d;f=Qm(d+48|0,x[a+36>>2]);x[31725]=0;a=P(463,d+36|0,42276)|0;c=x[31725];x[31725]=0;b:{c:{d:{e:{if((c|0)!=1){x[31725]=0;x[d+16>>2]=19989250;x[d+20>>2]=0;S(464,f|0,a|0,d+16|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}Eb(a);if(!wl(y[f|0])){break d}break b}c=N()|0;break c}c=N()|0;Eb(a);break c}k=d,l=gk(x[b>>2],x[b+4>>2]),w[k+34>>1]=l;w[d+32>>1]=65535;x[31725]=0;a=P(463,d+16|0,10105)|0;c=x[31725];x[31725]=0;f:{if((c|0)!=1){x[31725]=0;c=U(493,f|0,d+32|0,a|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break f}Eb(a);if(c){w[d+34>>1]=z[d+32>>1]}Gf(d+34|0,4e3);a=z[d+34>>1];g:{if(gk(x[b>>2],x[b+4>>2])>>>0>=a>>>0){break g}x[31725]=0;O(225,b|0,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){break g}c=N()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}g=x[b>>2];x[31725]=0;O(494,d+4|0,c|0);j=x[31725];x[31725]=0;if((j|0)!=1){x[31725]=0;V(495,f|0,Wb(g,c)|0,d+4|0,496);g=x[31725];x[31725]=0;if((g|0)==1){break h}c=c+1|0;Eb(d+4|0);continue}break}c=N()|0;break c}c=N()|0;Eb(d+4|0);break c}c=N()|0;break c}c=N()|0;Eb(a)}Ch(f);Q(c|0);p()}Ch(f);fb=d+160|0;c=h}gf(i,c);fb=e+16|0}function Dma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=ova(n,y,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=ova(m,v,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=p;g=ova(e,e>>31,o,z);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,l,A);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function De(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,k=0;d=(q(b),j(2));c=oI(d);a:{b:{c:{d:{e=(q(a),j(2));e:{if(e-2139095040>>>0>=2164260864){if(c){break e}break c}if(!c){break d}}h=E(1);if((e|0)==1065353216){break b}c=d<<1;if(!c){break b}i=c>>>0<4278190081;c=e<<1;a=E(a+b);if(!(i&c>>>0<=4278190080)){break a}if((c|0)==2130706432){break b}a=c>>>0>2130706431^(d|0)>=0?E(0):E(b*b);break a}if(oI(e)){h=E(a*a);if((e|0)<0){h=(nI(d)|0)==1?E(-h):h}if((d|0)>=0){break b}a=zx(E(E(1)/h));break a}if((e|0)<0){c=nI(d);if(!c){a=UI(a);break a}e=e&2147483647;i=((c|0)==1)<<16}if(e>>>0>8388607){break c}e=((q(E(a*E(8388608))),j(2))&2147483647)-192937984|0}d=e-1060306944|0;c=d>>>15&240;f=+(l(2,e-(d&-8388608)|0),r())*C[c+125624>>3]+-1;g=f*f;f=((f*.288457581109214+-.36092606229713164)*(g*g)+((f*.480898481472577+-.7213474675006291)*g+(f*1.4426950408774342+(C[c+125632>>3]+ +(d>>23)))))*+b;o(+f);c=j(1)|0;j(0)|0;f:{c=c&2147450880;if((c|0)==1079967744|c>>>0<1079967744){break f}if(f>127.99999995700433){a=cG(i);break a}if(!(f<=-150)){break f}a=MF(i);break a}k=f;g=C[160];f=g+f;g=k-(f-g);g=(C[161]*g+C[162])*(g*g)+(C[163]*g+1);o(+f);j(1)|0;e=j(0)|0;d=i+e|0;i=d<<15;d=((e&31)<<3)+1024|0;c=x[d>>2];d=x[d+4>>2]+i|0;l(0,c|0);l(1,(c>>>0>c>>>0?d+1|0:d)|0);h=E(g*+n())}a=h}return a}function TL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=te(a,k),x[p>>2]=q;g=d+1076|0;p=g,q=te(a,k),x[p>>2]=q;i=te(a,c&-4);x[d+1084>>2]=i;a:{h=x[h>>2];if(!h){break a}g=x[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=E(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+E(E(E(g<<1)*E(3.1415927410125732))/j);p=i+(e<<2)|0,r=E(kf(f)),B[p>>2]=r;p=i+(g<<2)|0,r=E(-E(Xi(f))),B[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+E(E(E(e<<2)*E(3.1415927410125732))/j);p=h+l|0,r=E(kf(f)),B[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=E(-E(Xi(f))),B[p>>2]=r;f=+E(E(E(E(m|0)*E(3.1415927410125732))/j)*E(.5));p=g+l|0,r=E(E(kf(f))*E(.5)),B[p>>2]=r;p=g+n|0,r=E(E(Xi(f))*E(.5)),B[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=te(a,k);x[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=E(Xi((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=E(Xi(+E(j*j)*1.5707963705062866)),B[p>>2]=r;b=b+1|0;continue}break}b=te(a,c>>2&-2);x[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-Pm(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=Nm(a)>>>c<<2,w[p>>1]=q;a=a+1|0;continue}break}return 1}fc(a,3);return 0}function O1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-1088|0;fb=g;e=bi(a);Tb(e+20|0,0,1040);x[e+1064>>2]=0;x[e+1068>>2]=0;x[e+1060>>2]=c;v[e+1084|0]=d;a=e+1072|0;x[a>>2]=0;x[a+4>>2]=0;x[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(_d(z[a+34>>1])>>>0<=d>>>0){break a}x[e+1064>>2]=0;x[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(A[c>>2]<=a>>>0){break j}a=x[b+8>>2];f=x[b>>2];x[31725]=0;a=U(152,f|0,a|0,2)|0;f=x[31725];x[31725]=0;if((f|0)==1){break i}if(!a){break j}x[31725]=0;a=R(191,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break h}if(!a){break e}x[31725]=0;S(187,g+8|0,b|0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break g}h=g+8|0;a=qs(g+28|0,h);f=hd(e,a);yc(f+20|0,a+20|0,1040);ub(a);ub(h);x[e+1076>>2]=0;x[e+1080>>2]=0;h=x[e+1060>>2];a=x[h+20>>2];if(Qn(z[h+34>>1])>>>0>=2){x[31725]=0;O(192,f|0,a+(d<<1)|0);a=x[31725];x[31725]=0;if((a|0)!=1){break e}break f}x[31725]=0;O(193,f|0,a+d|0);a=x[31725];x[31725]=0;if((a|0)==1){break f}break e}d=d+1|0;a=x[e+1060>>2];continue c}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=T(28848)|0;if((gb|0)!=($(28848)|0)){break b}Y(a|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break d}}a=x[i>>2];continue}break}break}a=N()|0}ub(e);Q(a|0);p()}fb=g+1088|0;return e|0}function Kla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;k=fb-32|0;fb=k;h=k+28|0;f=k+24|0;g=fb-16|0;fb=g;a:{b:{if(!lc(b,x[vb(g+12|0,rg(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=td(b);m=z[j>>1];j=x[j+4>>2];if(!Wl(e,i,m,j)){break b}}x[g+12>>2]=b;e=vb(g+8|0,wb(x[a>>2]));c:{f=x[g+12>>2];if(!lc(f,x[e>>2])){f=x[MB(g+12|0)>>2];e=td(f);j=z[e>>1];m=x[e+4>>2];e=z[c>>1];i=x[c+4>>2];if(!Wl(j,m,e,i)){break c}}if(!x[b>>2]){x[h>>2]=b;break a}x[h>>2]=f;b=f+4|0;break a}b=LB(a,h,e,i);break a}if(Wl(m,j,e,i)){d:{f=KB(b);if(!lc(f,x[vb(g+12|0,rg(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=td(f);if(!Wl(e,i,z[j>>1],x[j+4>>2])){break d}}if(!x[b+4>>2]){x[h>>2]=b;b=b+4|0;break a}x[h>>2]=f;b=f;break a}b=LB(a,h,e,i);break a}x[h>>2]=b;x[f>>2]=b;b=f}fb=g+16|0;f=b;b=x[b>>2];if(!b){b=fb-16|0;fb=b;g=ec(a);h=k+12|0;e=Dh(h,Ec(36),Mg(b+8|0,g));g=x[e>>2]+16|0;i=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=i;$l(g+8|0,d);o=ec(e),p=1,v[o+4|0]=p;fb=b+16|0;$g(a,x[k+28>>2],f,x[k+12>>2]);b=le(h);jU(h);n=1}a=l+4|0;_g(a,x[vb(k+12|0,b)>>2],n);fb=k+32|0;if(!y[ec(a)|0]){a=td(x[l+4>>2])+8|0;iU(a);x[a>>2]=x[d>>2];x[a+4>>2]=x[d+4>>2];b=zb(d);o=zb(a),p=x[b>>2],x[o>>2]=p;x[b>>2]=0;x[d>>2]=0;x[d+4>>2]=0}a=x[vb(l+12|0,x[l+4>>2])>>2];fb=l+16|0;return a|0}function uma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=fb-16|0;fb=e;s=x[a+16>>2];t=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];m=x[a+128>>2];if(m){n=Gg(k,l,m);o=hb;h=x[a+76>>2];hg(b,f,vf(k,l,d),hb);p=hb>>>0>h>>>0?d:0}h=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;p=p-1|0;g=p;n=g?n:0;o=g?o:0;r=(((f&2147483647)<<1|b>>>31)&-2)+s|0;f=m;a:{b:while(1){c:{if((f|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);f=x[a+116>>2];if(!f){break a}g=x[e+8>>2];q=((x[e+12>>2]&2147483647)<<1|g>>>31)&-2;g=0;b=0;break c}g=x[e+8>>2];q=((x[e+12>>2]&2147483647)<<1|g>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){be(h,g>>>3<<16>>16);ae(h,4);Pb(e+8|0,n,o);f=f-1|0;continue b}else{g=(v[(b+q|0)+r|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[(b+q|0)+r|0]<<8)+g|0;b=b+1|0;continue}break}be(h,g>>>3<<16>>16);ae(h,f);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=Eg(h,t);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(e,k,l);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function JM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Zf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){l=x[c+20>>2];if(l>>>0<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}m=x[c+28>>2];if(f>>>0>x[c+24>>2]-m>>>0){break b}n=b+12|0;o=x[c+16>>2];q=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}r=D(h,k);s=D(h+m|0,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=yb(x[b>>2],d);i=Ee(Ig(C[(d+r<<3)+q>>3])*134217728);j=e;e=(x[e>>2]>>1)+Cn(i)|0;t=e;e=Yt(n)+e&-4096;x[j>>2]=t-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=(d+s<<1)+o|0;i=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}u=j,v=ed(e),w[u>>1]=v;d=d+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=c- -64|0}function Sj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!je(x[a>>2],x[a+20>>2])){break a}al(a);b:{switch(Qn(z[a+34>>1])-1|0){case 1:h=fb-48|0;fb=h;g=x[a+20>>2];c=x[a>>2];d=_d(z[a+34>>1]);e=g+(D(c,d)<<1)|0;while(1){c:{d:{if((f|0)!=16){i=D(d,f);j=D(d,f^-1);c=0;break d}f=e+(d<<5)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;qV(h+28|0,f,g+(D(d,e)<<1)|0,i,d,(c&4)>>>2|0,Ob(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;qV(h+8|0,f+(d<<7)|0,g+(D(a,d)<<1)|0,e,d,(c&16)>>>4|0,Ob(b+1074312|0,33))}fb=h+48|0;break c}while(1){if((c|0)!=(d|0)){w[e+(c+i<<1)>>1]=z[e+(c-d<<1)>>1];w[g+(c+j<<1)>>1]=z[g+(c<<1)>>1];c=c+1|0;continue}break}f=f+1|0;continue}break};return;case 0:break b;default:break a}}h=fb-48|0;fb=h;g=x[a+20>>2];c=x[a>>2];d=_d(z[a+34>>1]);e=g+D(c,d)|0;while(1){e:{f:{if((f|0)!=16){i=D(d,f);j=D(d,f^-1);c=0;break f}f=e+(d<<4)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;pV(h+28|0,f,g+D(d,e)|0,i,d,(c&4)>>>2|0,Ob(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;pV(h+8|0,f+(d<<6)|0,g+D(a,d)|0,e,d,(c&16)>>>4|0,Ob(b+1074312|0,33))}fb=h+48|0;break e}while(1){if((c|0)!=(d|0)){v[e+(c+i|0)|0]=y[e+(c-d|0)|0];v[g+(c+j|0)|0]=y[c+g|0];c=c+1|0;continue}break}f=f+1|0;continue}break}}}function PM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Zf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){if(A[c+20>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}l=x[c+28>>2];if(f>>>0>x[c+24>>2]-l>>>0){break b}m=b+12|0;n=x[c+16>>2];o=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}q=h+l|0;r=D(h,k);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=yb(x[b>>2],d);i=Ee(Ig(C[(d+r<<3)+o>>3])*134217728);j=e;e=(x[e>>2]>>1)+Cn(i)|0;s=e;e=Yt(m)+e&-4096;x[j>>2]=s-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=(d<<2)+n|0;i=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}t=x[j>>2]+(q<<1)|0,u=ed(e),w[t>>1]=u;d=d+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=c- -64|0}function Sba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=hv(c+4|0,a,1);zz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+16;hc(a);fb=c+16|0;return}i=fb-32|0;fb=i;c=zb(a);c=$V(i+12|0,aW(a,Lk(x[a>>2],x[a+4>>2])+1|0),Lk(x[a>>2],x[a+4>>2]),c);zz(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+16;h=fb-16|0;fb=h;f=zb(a);b=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);e=vb(h+4|0,x[c+4>>2]);d=x[b>>2];g=x[g>>2];b=fb+-64|0;fb=b;e=x[e>>2];x[b+56>>2]=e;x[b+60>>2]=d;x[b+52>>2]=e;f=Se(b+24|0,f,b+52|0,b+56|0);x[b+16>>2]=x[f+8>>2];e=x[f+4>>2];x[b+8>>2]=x[f>>2];x[b+12>>2]=e;Re(b+36|0,b+8|0);while(1){if(pd(d,g)){zz(Az(x[b+56>>2]),kC(d));d=br(b+60|0);br(b+56|0);d=x[d>>2];continue}break}Qe(b+36|0);j=x[b+56>>2];if(!y[b+48|0]){f=fb-16|0;fb=f;d=vb(f+12|0,x[x[b+44>>2]>>2]);k=x[vb(f+8|0,x[x[b+40>>2]>>2])>>2];g=fb-16|0;fb=g;e=x[d>>2];x[g+12>>2]=e;while(1){if(di(e,k)){d=fb-16|0;fb=d;x[d+12>>2]=e;x[d+12>>2]=x[d+12>>2]+16;fb=d+16|0;Zj(Az(x[d+12>>2]));e=x[$o(g+12|0)>>2];continue}break}fb=g+16|0;fb=f+16|0}fb=b- -64|0;x[c+4>>2]=j;Ub(a,c+4|0);Ub(a+4|0,c+8|0);Ub(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=h+16|0;a=x[c+4>>2];while(1){b=x[c+8>>2];if((b|0)!=(a|0)){b=b-16|0;x[c+8>>2]=b;Zj(b);continue}break}a=x[c>>2];if(a){ys(c);Db(a)}fb=i+32|0}function Ema(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;l=x[a+8>>2];B=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=ova(n,z,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=ova(m,y,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=p;g=ova(e,e>>31,o,A);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,l,B);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function yh(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=x[a+480180>>2];if(!En(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=z[((D(a,-12)+e&255)<<1)+31680>>1]<<4>>>a|0;break a}if(!d){x[f+12>>2]=8363;d=8363}if(Jj(a)){a=((e&255)>>>0)/12|0;b=ova(x[(D(a,-12)+e<<6&960)+35568>>2]<<a,0,d,0);a=hb;c=a>>>21|0;h=f,i=Bc((a&2097151)<<11|b>>>21,c),x[h+8>>2]=i;wc(f+8|0,2147483647);e=x[f+8>>2];break a}if(y[a+480208|0]&16){a=e&255;e=z[((a>>>0)%12<<1)+31680>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;wc(f+12|0,-1>>>a|0);e=Bc(qva(ova(z[((D(a,-12)+e&255)<<1)+31680>>1],0,267616,0),hb,x[f+12>>2]<<a,0),hb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{b=Ob(a+1074312|0,76)?c&-8:c}c=d?e:12;if(y[a+480208|0]&16){a=((b|0)/-2|0)-(c<<6)|0;e=((a|0)<=-8447?-8447:a)+8448|0;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(D(c,-12)+a<<3&248)|0;x[f+4>>2]=d+8;Fe(f+4|0,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)<=-8?-8:a;e=D(b,z[(((a|0)>=95?95:a)<<1)+32176>>1])+D(z[(x[f+4>>2]<<1)+32160>>1],16-b|0)<<1>>>c|0;break a}if(!(!(c&240)&b-25>>>0<84)){a=((e&255)>>>0)/12|0;e=z[(D(c>>>4&15,12)+(D(a,-12)+e&255)<<1)+31280>>1]<<5>>>a|0;break a}e=z[(b<<1)+31054>>1]<<2}fb=f+16|0;return e}function pQ(a){var b=0,c=E(0),d=0,e=0,f=0,g=E(0),h=0,i=0,k=E(0),m=0,n=0,o=E(0);d=fb-16|0;fb=d;b=x[x[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=De(E(10),E(E(E(B[yb(e,0)>>2]*E(120))+E(-60))/E(20))),B[n+4232>>2]=o;k=E(E(b>>>0)/E(1e3));n=a,o=De(E(10),E(E(-1)/E(k*E(E(B[yb(e,1)>>2]*E(499.989990234375))+E(.009999999776482582))))),B[n+4236>>2]=o;n=a,o=De(E(10),E(E(-1)/E(k*E(E(B[yb(e,2)>>2]*E(2950))+E(50))))),B[n+4240>>2]=o;x[d+12>>2]=1325400064;c=E(De(E(10),E(E(E(B[yb(e,3)>>2]*E(60))+E(-60))/E(20)))*E(2147483648));b=(q(c),j(2));g=E(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){g=E(zx(E(-1))/E(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=UI(c);break a}b=(q(E(c*E(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),r())*C[h+3568>>3]+-1;m=i*i;c=E((C[479]*m+(C[480]*i+C[481]))*m+(+(f>>23)*C[478]+C[h+3576>>3]+i))}g=c}B[d+8>>2]=E(E(g*E(67108864))/E(.6931471824645996))+E(67108864);n=a,o=E(B[Zm(d+12|0,d+8|0)>>2]*E(4.656612873077393e-10)),B[n+4244>>2]=o;n=a,o=E(E(E(-1)/E(E(B[yb(e,4)>>2]*E(99))+E(1)))+E(1)),B[n+4248>>2]=o;c=E(E(E(B[yb(e,5)>>2]*E(4))*k)+E(2));c:{if(E(F(c))<E(2147483648)){h=~~c;break c}h=-2147483648}x[a+4252>>2]=h;fb=d+16|0}function AO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=fb+-64|0;fb=d;a:{b:{c:{d:{e=x[a+36>>2];c=x[a+40>>2];e:{if(Ib(e,c)){sc(d+60|0);break e}c=d+24|0;Bo(c,a);x[31725]=0;c=R(1062,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}x[d+60>>2]=c;of(d+24|0);c=x[a+40>>2];e=x[a+36>>2]}c=(k=a+36|0,l=x[d+60>>2],m=Ib(e,c),m?k:l);f=x[a+8>>2];if((f|0)==-1){e=x[c+4>>2];f=ql(e);g=x[c>>2];i=pj(g,e);j=C[f>>3];e=0;while(1){if((e|0)==(i|0)){c=f;break c}c=wf(g,e);if(h+C[c>>3]>b){break c}e=e+1|0;h=h+j;continue}}c=wf(x[c>>2],f);break b}e=N()|0;of(d+24|0);break a}b=b-h}f=z[c+12>>1];e=x[a+24>>2];x[31725]=0;O(1096,e|0,f|0);f=x[31725];x[31725]=0;if((f|0)!=1){f:{f=x[a+24>>2];e=y[a+64|0];c=dS(mY(d+24|0,b),y[c+16|0],z[c+12>>1],x[c+8>>2]);x[31725]=0;g=x[c+12>>2];x[d+8>>2]=x[c+8>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d+16>>2]=x[c+16>>2];x[d+20>>2]=g;g=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=g;V(1097,d+48|0,f|0,(e?7:1)|0,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break f}c=nn(x[d+52>>2]);f=v[c+26|0]&1;e=x[(f?c+8|0:c+12|0)>>2];f=z[(f?c+20|0:c+22|0)>>1];b=C[c>>3];Yi(d+48|0);c=x[a+24>>2];w[c+1074450>>1]=f;w[c+1074448>>1]=f;x[c+1074428>>2]=e;x[c+1074392>>2]=-2;b=h+b;C[a+16>>3]=b;Gl(d+60|0);fb=d- -64|0;return+b}}e=N()|0;Gl(d+60|0)}Q(e|0);p()}function pja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=hC(c+4|0,a);eA(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}i=fb-32|0;fb=i;c=zb(a);c=$f(i+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);eA(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+4;h=fb-16|0;fb=h;f=zb(a);b=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);e=vb(h+4|0,x[c+4>>2]);d=x[b>>2];g=x[g>>2];b=fb+-64|0;fb=b;e=x[e>>2];x[b+56>>2]=e;x[b+60>>2]=d;x[b+52>>2]=e;f=Se(b+24|0,f,b+52|0,b+56|0);x[b+16>>2]=x[f+8>>2];e=x[f+4>>2];x[b+8>>2]=x[f>>2];x[b+12>>2]=e;Re(b+36|0,b+8|0);while(1){if(pd(d,g)){eA(rA(x[b+56>>2]),xf(d));d=Ni(b+60|0);Ni(b+56|0);d=x[d>>2];continue}break}Qe(b+36|0);j=x[b+56>>2];if(!y[b+48|0]){f=fb-16|0;fb=f;d=vb(f+12|0,x[x[b+44>>2]>>2]);k=x[vb(f+8|0,x[x[b+40>>2]>>2])>>2];g=fb-16|0;fb=g;e=x[d>>2];x[g+12>>2]=e;while(1){if(di(e,k)){d=fb-16|0;fb=d;x[d+12>>2]=e;x[d+12>>2]=x[d+12>>2]+4;fb=d+16|0;og(rA(x[d+12>>2]));e=x[Je(g+12|0)>>2];continue}break}fb=g+16|0;fb=f+16|0}fb=b- -64|0;x[c+4>>2]=j;Ub(a,c+4|0);Ub(a+4|0,c+8|0);Ub(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=h+16|0;a=x[c+4>>2];while(1){b=x[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;x[c+8>>2]=b;og(b);continue}break}a=x[c>>2];if(a){Tz(c);Db(a)}fb=i+32|0}function OK(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=x[a+4>>2];h:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break h}c=sd(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=x[a+4>>2];i:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break i}c=sd(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(D(e,10)+c|0)-48|0;d=(e|0)<214748364;c=x[a+4>>2];j:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break j}c=sd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=ova(e,d,10,0);d=b+c|0;c=hb;e=d-48|0;d=(b>>>0>d>>>0?c+1|0:c)-(d>>>0<48)|0;b=x[a+4>>2];l:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;c=y[b|0];break l}c=sd(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=x[a+4>>2];m:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;b=y[b|0];break m}b=sd(a)}if(b-48>>>0<10){continue}break}}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){x[a+4>>2]=x[a+4>>2]-1}hb=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}x[a+4>>2]=x[a+4>>2]-1;break b}if(x[a+116>>2]<0){break a}}x[a+4>>2]=x[a+4>>2]-1}hb=-2147483648;return 0}function Bd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-80|0;fb=e;x[a+480180>>2]=b;c=zr(a);yr(e+12|0,c);f=x[e+24>>2];d=a+1074320|0;x[d>>2]=x[e+20>>2];x[d+4>>2]=f;d=x[e+16>>2];x[a+1074312>>2]=x[e+12>>2];x[a+1074316>>2]=d;if(!((b|0)==32|(c|0)!=32)){dg(a+1074312|0,120)}Bu(a+8|0,c);b=1;while(1){c=b&65535;if(c>>>0>z[a+480192>>1]){x[a+480184>>2]=0;x[a+480188>>2]=0;x[a+480236>>2]=65536;x[a+480228>>2]=48;x[a+480232>>2]=48;v[a+480268|0]=5;x[a+480260>>2]=16;x[a+480264>>2]=32767;x[a+480204>>2]=125e4;x[a+480208>>2]=0;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+1074304>>2]=0;x[a+1074308>>2]=0;w[a+480192>>1]=0;SA(a,4);d=fb+-64|0;fb=d;b=a+484344|0;Du(b);f=qm(x[b>>2],x[b+4>>2]);c=qA(d+12|0,b);x[31725]=0;S(858,b|0,f|0,c|0);b=x[31725];x[31725]=0;a:{if((b|0)!=1){Ek(c);fb=d- -64|0;break a}a=N()|0;Ek(c);Q(a|0);p()}fV(a+484360|0);tf(a+1298308|0);tf(a+1298320|0);tf(a+1298332|0);b=e+12|0;Tb(b,0,68);b=GS(b);c=Ab(a+1298344|0,b);Ab(c+12|0,b+12|0);Ab(c+24|0,b+24|0);Ab(c+36|0,b+36|0);Ab(c+48|0,b+48|0);d=x[b+64>>2];x[c+60>>2]=x[b+60>>2];x[c+64>>2]=d;YA(b);fw(a+1298412|0);Nf(a+480248|0);if(x[a+480180>>2]&738230281){x[a+480208>>2]=x[a+480208>>2]|8388608}fb=e+80|0;return}c=((c<<2)+a|0)+900380|0;d=x[c>>2];if(d){Db(Jv(d))}x[c>>2]=0;b=b+1|0;continue}}function I1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1397771593){ld(b,32);Ep(b);c=d+8|0;nk(c,1,a+4|0);e=d+20|0;Cc(e,c);ze(b+43|0,e);tb(e);w[b+30>>1]=y[a+19|0]<<2;Gf(b+30|0,256);w[b+32>>1]=y[a+17|0];Gf(b+32|0,64);w[b+28>>1]=(y[a+47|0]&127)<<2;Gf(b+28|0,256);if(v[a+47|0]<0){w[b+34>>1]=z[b+34>>1]|32}c=y[a+18|0];if(c&16){w[b+34>>1]=z[b+34>>1]|2;c=y[a+18|0]}if(c&32){w[b+34>>1]=z[b+34>>1]|8;c=y[a+18|0]}if(c&64){w[b+34>>1]=z[b+34>>1]|4;c=y[a+18|0]}if(c<<24>>24<0){w[b+34>>1]=z[b+34>>1]|16}c=y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24);x[b+24>>2]=c?c>>>0<=256?256:c:8363;x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+12>>2]=y[a+64|0]|y[a+65|0]<<8|(y[a+66|0]<<16|y[a+67|0]<<24);x[b+16>>2]=y[a+68|0]|y[a+69|0]<<8|(y[a+70|0]<<16|y[a+71|0]<<24);al(b);v[b+38|0]=y[(y[a+79|0]&7)+38128|0];v[b+41|0]=y[a+76|0];v[b+40|0]=y[a+77|0]&127;v[b+39|0]=y[a+78|0];c=y[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}w[b+34>>1]=c|z[b+34>>1]}c=y[a+72|0]|y[a+73|0]<<8|(y[a+74|0]<<16|y[a+75|0]<<24)}fb=d+32|0;return c|0}function _ma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;b=(b>>>16&65520)+g|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];v=w[b+2>>1];y=w[b>>1];k=0;while(1){if((k|0)!=2){b=(k<<1)+o|0;x[(k<<2)+e>>2]=(((((((D(w[b-8>>1],v)+D(w[b-12>>1],y)|0)+D(w[b-4>>1],u)|0)+D(w[b>>1],t)|0)+D(w[b+4>>1],s)|0)+D(w[b+8>>1],r)|0)+D(w[b+12>>1],q)|0)+D(w[b+16>>1],p)|0)/32768;k=k+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i>>12);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function p8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=fb-368|0;fb=f;x[f+360>>2]=37;x[f+364>>2]=0;h=gt(f+360|1,22255,x[c+4>>2]);x[f+316>>2]=f+320;a=Od();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=rh(f+320|0,30,a,f+360|0,f+32|0);break a}C[f+48>>3]=e;g=rh(f+320|0,30,a,f+360|0,f+48|0)}x[f+80>>2]=1205;i=Be(f+308|0,0,f+80|0);b=f+320|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Od();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=sj(f+316|0,a,f+360|0,f);break f}C[f+16>>3]=e;g=sj(f+316|0,a,f+360|0,f+16|0)}if((g|0)==-1){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)==1){break d}break e}a=x[f+316>>2];Te(i,a)}j=a+g|0;l=tj(a,j,x[c+4>>2]);x[f+68>>2]=1205;h=Be(f+72|0,0,f+68|0);g:{h:{if((f+320|0)==(a|0)){g=f+80|0;break h}g=Fd(g<<3);if(!g){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break e}a=N()|0;break g}Te(h,g);b=a}a=f+60|0;bd(a,x[c+28>>2]);x[31725]=0;ga(1236,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[31725];x[31725]=0;i:{if((a|0)!=1){Zb(f+60|0);x[31725]=0;a=ea(1237,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}Lc(h);Lc(i);fb=f+368|0;break b}a=N()|0;Zb(f+60|0);break g}a=N()|0}Lc(h);break c}p()}a=N()|0}Lc(i);Q(a|0);p()}return a|0}function Lka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-16|0;fb=i;d=x[b+1298304>>2];if(!Dd(d)){e=fb-16|0;fb=e;c=Ec(12);x[31725]=0;d=R(957,c|0)|0;f=x[31725];x[31725]=0;a:{if((f|0)!=1){c=x[yf(e+12|0,d)>>2];fb=e+16|0;break a}a=N()|0;Db(c);Q(a|0);p()}x[i+12>>2]=c;c=b+1298304|0;e=i+12|0;yS(c,le(e));XA(e);d=x[c>>2]}f=fb-32|0;fb=f;c=f+8|0;nS(c,a);x[31725]=0;O(958,f+20|0,c|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){tb(f+8|0);m=f,n=wb(x[d>>2]),x[m+4>>2]=n;l=wb(x[d+4>>2]);c=0;d=0;while(1){d:{h=x[f+4>>2];if(!Ib(h,l)){e:{if(!d){break e}c=x[d+4>>2];if(!c){break e}x[31725]=0;b=U(c|0,d|0,b|0,a|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}if(b){c=x[d>>2];x[b+4>>2]=c;if(c){x[c+8>>2]=b}x[d>>2]=b}x[a>>2]=b}tb(f+20|0);fb=f+32|0;break b}j=0;e=x[h>>2];if(x[e+32>>2]==x[a+16>>2]){j=x[e+36>>2]==x[a+20>>2]}x[31725]=0;O(959,f+8|0,e+8|0);e=x[31725];x[31725]=0;if((e|0)!=1){g=fb-16|0;fb=g;k=f+8|0;ee(g+8|0,k);ee(g,f+20|0);e=SR(x[g+8>>2],x[g+12>>2],x[g>>2],x[g+4>>2]);fb=g+16|0;tb(k);f:{if(!(!j|(e|0)!=0)){d=x[h>>2];c=3;break f}if((c|0)<2&j){d=x[h>>2];c=2;break f}e=!e&(c|0)<=0;d=e?x[h>>2]:d;c=e?1:c}Je(f+4|0);continue}}break}d=N()|0;tb(f+20|0);break c}d=N()|0;tb(f+8|0)}Q(d|0);p()}fb=i+16|0}
function z8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=fb-208|0;fb=f;x[f+200>>2]=37;x[f+204>>2]=0;h=gt(f+200|1,22255,x[c+4>>2]);x[f+156>>2]=f+160;a=Od();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=rh(f+160|0,30,a,f+200|0,f+32|0);break a}C[f+48>>3]=e;g=rh(f+160|0,30,a,f+200|0,f+48|0)}x[f+80>>2]=1205;i=Be(f+148|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Od();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=sj(f+156|0,a,f+200|0,f);break f}C[f+16>>3]=e;g=sj(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)==1){break d}break e}a=x[f+156>>2];Te(i,a)}j=a+g|0;l=tj(a,j,x[c+4>>2]);x[f+68>>2]=1205;h=Be(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Fd(g<<1);if(!g){x[31725]=0;X(1206);a=x[31725];x[31725]=0;if((a|0)!=1){break e}a=N()|0;break g}Te(h,g);b=a}a=f+60|0;bd(a,x[c+28>>2]);x[31725]=0;ga(1231,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[31725];x[31725]=0;i:{if((a|0)!=1){Zb(f+60|0);x[31725]=0;a=ea(23,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break i}Lc(h);Lc(i);fb=f+208|0;break b}a=N()|0;Zb(f+60|0);break g}a=N()|0}Lc(h);break c}p()}a=N()|0}Lc(i);Q(a|0);p()}return a|0}function N3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(oh(a,x[b+8>>2],e)){Ox(b,c,d);return}a:{if(oh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;if(x[b+44>>2]!=4){f=a+16|0;h=f+(x[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}w[b+52>>1]=0;Lx(x[f>>2],x[f+4>>2],b,c,c,1,e);if(y[b+54|0]){break d}e:{if(!y[b+53|0]){break e}if(y[b+52|0]){d=1;if(x[b+24>>2]==1){break c}g=1;if(y[a+8|0]&2){break e}break c}g=1;if(!(v[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}x[b+44>>2]=a;if(d&1){break a}}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}g=x[a+12>>2];Rs(x[a+16>>2],x[a+20>>2],b,c,d,e);f=a+24|0;g=(a+16|0)+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=x[a+8>>2];if(!(!(a&2)&x[b+36>>2]!=1)){while(1){if(y[b+54|0]){break a}Rs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(y[b+54|0]|x[b+36>>2]==1){break a}Rs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(y[b+54|0]|x[b+36>>2]==1&x[b+24>>2]==1){break a}Rs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function Zka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=fb-16|0;fb=l;x[l+12>>2]=b;q=Rf(a);while(1){if(Zg(b,c)){b=x[vb(l+8|0,q)>>2];k=td(x[l+12>>2]);o=fb-16|0;fb=o;p=0;m=fb-16|0;fb=m;i=fb-32|0;fb=i;g=i+28|0;d=i+24|0;e=fb-16|0;fb=e;a:{b:{if(!lc(b,x[vb(e+12|0,rg(a))>>2])){f=y[k|0];j=x[k+4>>2];h=td(b);n=y[h|0];h=x[h+4>>2];if(!Ho(f,j,n,h)){break b}}x[e+12>>2]=b;f=vb(e+8|0,wb(x[a>>2]));c:{d=x[e+12>>2];if(!lc(d,x[f>>2])){d=x[MB(e+12|0)>>2];f=td(d);h=y[f|0];n=x[f+4>>2];f=y[k|0];j=x[k+4>>2];if(!Ho(h,n,f,j)){break c}}if(!x[b>>2]){x[g>>2]=b;break a}x[g>>2]=d;b=d+4|0;break a}b=eB(a,g,f,j);break a}if(Ho(n,h,f,j)){d:{d=KB(b);if(!lc(d,x[vb(e+12|0,rg(a))>>2])){f=y[k|0];j=x[k+4>>2];h=td(d);if(!Ho(f,j,y[h|0],x[h+4>>2])){break d}}if(!x[b+4>>2]){x[g>>2]=b;b=b+4|0;break a}x[g>>2]=d;b=d;break a}b=eB(a,g,f,j);break a}x[g>>2]=b;x[d>>2]=b;b=d}fb=e+16|0;d=b;b=x[b>>2];if(!b){b=fb-16|0;fb=b;e=ec(a);g=i+12|0;e=Dh(g,Ec(28),Mg(b+8|0,e));uC(x[e>>2]+16|0,k);r=ec(e),s=1,v[r+4|0]=s;fb=b+16|0;$g(a,x[i+28>>2],d,x[i+12>>2]);b=le(g);em(g);p=1}_g(m+8|0,x[vb(i+12|0,b)>>2],p);fb=i+32|0;fb=m+16|0;vb(o+12|0,x[m+8>>2]);fb=o+16|0;b=x[ah(l+12|0)>>2];continue}else{fb=l+16|0}break}}function Hja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0);g=w[d>>1];h=w[d+2>>1];a:{if((g|0)>(h|0)){break a}k=x[b>>2];i=oc(k,x[b+4>>2]);if(!i){break a}j=w[e>>1];if((j|0)<(g|0)|(h|0)<(j|0)|(i-1&65535)>>>0>(h-j&65535)>>>0|A[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(i|0)){break b}j=yb(k,f);f=f+1|0;if(!(B[j>>2]<E(0))){continue}break}return 0}f=0;l=B[c>>2];if(l<=E(0)){break a}w[a+28>>1]=g;w[a>>1]=1;m=a,n=mR(i),w[m+30>>1]=n;B[a+32>>2]=F(l);Ll(a+4|0,(h-g|0)+1|0);c=wb(x[b>>2]);h=wb(x[b+4>>2]);f=Mk(wb(x[a+4>>2]),w[e>>1]-w[d>>1]|0);g=fb-16|0;fb=g;b=fb-32|0;fb=b;Id(b+24|0,c,h);yn(b+16|0,x[b+24>>2],x[b+28>>2],f);c=kA(c,x[b+16>>2]);m=b,n=lR(f,x[b+20>>2]),x[m+12>>2]=n;Ac(g+8|0,c,b+12|0);fb=b+32|0;fb=g+16|0;c=x[a+4>>2];g=w[a+30>>1];h=w[a+28>>1];b=w[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;i=yb(c,b+g|0);m=yb(c,b),o=E(B[i>>2]/B[a+32>>2]),B[m>>2]=o;b=w[e>>1];continue}else{c=w[a+30>>1];e=w[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=x[a+4>>2];d=w[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=yb(b,f-h|0);m=yb(b,f-e|0),o=E(B[a+32>>2]*B[g>>2]),B[m>>2]=o;f=f+1|0;continue}else{Eq(a)}break}}break}f=1}return f|0}function $ma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+l|0;b=(b>>>16&65520)+g|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];y=w[b+2>>1];z=w[b>>1];k=0;while(1){if((k|0)!=2){b=k+o|0;x[(k<<2)+e>>2]=(((((((D(v[b-4|0],y)+D(v[b-6|0],z)|0)+D(v[b-2|0],u)|0)+D(v[b|0],t)|0)+D(v[b+2|0],s)|0)+D(v[b+4|0],r)|0)+D(v[b+6|0],q)|0)+D(v[b+8|0],p)<<8)/32768;k=k+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i>>12);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function kba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Zf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[c+4>>2];if(f>>>0<=g>>>0){h=x[c+20>>2];if(f>>>0>h>>>0){break d}if(A[c+8>>2]<e>>>0){break c}i=x[c+28>>2];if(x[c+24>>2]-i>>>0<e>>>0){break b}l=b+12|0;m=x[c+16>>2];n=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}o=D(b,g);q=D(b+i|0,h);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{s=a,t=+(Cn(Ee(Ig(C[(d+o<<3)+n>>3])*134217728))+qd(Xt(l),21)|0)*7.450580596923828e-9,C[s+24>>3]=t;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;r=(d+q<<1)+m|0;j=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}s=r,u=ed(k),w[s>>1]=u;d=d+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=c- -64|0}function Aoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-48|0;fb=g;c=wb(x[a>>2]);x[g+44>>2]=c;k=wb(x[a+4>>2]);while(1){if(Ib(c,k)){i=g+24|0;a=wb(x[c>>2]);l=wb(x[c+4>>2]);c=wX(g+4|0,b);v[c+16|0]=y[b+16|0];x[c+12>>2]=x[b+12>>2];h=fb-16|0;fb=h;x[h+12>>2]=a;while(1){if(Ib(a,l)){f=fb-16|0;fb=f;if(!(y[a+5|0]|y[a+3|0]!=4)){e=f+8|0;Jb(e,x[c>>2],z[c+14>>1]);Jf(e,0);v[a+3|0]=0}e=y[a+2|0];if(!(y[a+4|0]|(e|0)!=11)){d=f+8|0;Jb(d,x[c>>2],z[c+14>>1]);Jf(d,0);v[a+2|0]=0;e=0}a:{b:{if(!y[a|0]){Jb(f+8|0,x[c>>2],z[c+14>>1]);e=y[a+2|0];d=y[a+3|0];if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break b}if(!((e|0)==11|d)){v[a+5|0]=0;d=4;v[a+3|0]=4;break a}if((d|0)==4|e){break a}v[a+4|0]=0;v[a+2|0]=11;break a}d=y[a+3|0]}j=f+8|0;Jb(j,x[c>>2],z[c+14>>1]);Jf(j,(d|0)==4|(e|0)==11);d=y[a+3|0]}c:{d:{e:{if(!(!y[c+16|0]|d)){v[a+3|0]=17;d=125;e=0;break e}e=0;f:{switch(d-16|0){case 1:break d;case 0:break f;default:break c}}if(y[a+5|0]){break c}d=6;e=1}v[a+5|0]=d}v[c+16|0]=e}a=z[c+14>>1]+1|0;w[c+14>>1]=z[c+12>>1]>(a&65535)>>>0?a:0;fb=f+16|0;a=x[vg(h+12|0)>>2];continue}break}a=AC(i,c);v[a+16|0]=y[c+16|0];x[a+12>>2]=x[c+12>>2];fb=h+16|0;uf(i);uf(c);c=x[bm(g+44|0)>>2];continue}else{fb=g+48|0}break}}function tba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Zf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[c+4>>2];if(f>>>0<=g>>>0){if(f>>>0>A[c+20>>2]){break d}if(A[c+8>>2]<e>>>0){break c}h=x[c+28>>2];if(x[c+24>>2]-h>>>0<e>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}n=b+h|0;o=D(b,g);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{r=a,s=+(Cn(Ee(Ig(C[(d+o<<3)+m>>3])*134217728))+qd(Xt(k),21)|0)*7.450580596923828e-9,C[r+24>>3]=s;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;q=(d<<2)+l|0;i=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}r=x[q>>2]+(n<<1)|0,t=ed(j),w[r>>1]=t;d=d+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=c- -64|0}function cJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{while(1){j=x[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=y[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=y[j+2|0];i=y[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=y[j+3|0];m=y[j+2|0];k=y[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}x[f>>2]=c;x[a+12>>2]=i+j;f=x[a+8>>2]+4|0;x[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return b|0}function dra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;ld(b,0);Ep(b);f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{if(c&34){if(d){x[b+24>>2]=f;break a}g=b,h=_e(Di(+(f+1408|0)/1536)*8363),x[g+24>>2]=h;break a}v[b+37|0]=(c|0)==16?f:f^128;v[b+36|0]=y[a+4|0]}v[e+15|0]=y[a+5|0];v[e+14|0]=64;g=b,h=y[Rb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;d=y[a+6|0]|y[a+7|0]<<8;if(d>>>0<=256){w[b+28>>1]=d;w[b+34>>1]=z[b+34>>1]|32}x[b>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+4>>2]=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);x[b+8>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);d=y[a+20|0]|y[a+21|0]<<8;if(d&16){w[b+34>>1]=z[b+34>>1]|2;d=y[a+20|0]|y[a+21|0]<<8}if(d&32){w[b+34>>1]=z[b+34>>1]|4;d=y[a+20|0]|y[a+21|0]<<8}if(d&256){w[b+34>>1]=z[b+34>>1]|8;d=y[a+20|0]|y[a+21|0]<<8}if(d&512){w[b+34>>1]=z[b+34>>1]|16}v[b+38|0]=y[(y[a+22|0]&7)+38128|0];v[b+39|0]=y[a+23|0];v[b+40|0]=y[a+24|0];v[b+41|0]=y[a+25|0];if((c|0)==32){v[e+13|0]=y[a+26|0];v[e+12|0]=64;g=b,h=y[Rb(e+13|0,e+12|0)|0],w[g+32>>1]=h}x[b+12>>2]=y[a+27|0]|y[a+28|0]<<8|(y[a+29|0]<<16|y[a+30|0]<<24);x[b+16>>2]=y[a+31|0]|y[a+32|0]<<8|(y[a+33|0]<<16|y[a+34|0]<<24);fb=e+16|0}function wM(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+8|0;tz(d,a);b=fb-96|0;fb=b;a=x[d+4>>2];kg(x[x[a>>2]-12>>2]+a|0,0);$d(b+80|0,x[d+4>>2]);a:{b:{c=x[d+4>>2];if(!xk(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){a=hi(b- -64|0,-1,-1);if(!go(x[b+88>>2],x[b+92>>2],x[a+8>>2],x[a+12>>2])){break b}}kg(c+x[x[c>>2]-12>>2]|0,0);break a}Ii(c,0,0,0);c=x[d+4>>2];a=x[x[c>>2]-12>>2]+c|0;if(xk(x[a+16>>2])){kg(a,0);c=x[d+4>>2];a=x[b+92>>2];x[b+8>>2]=x[b+88>>2];x[b+12>>2]=a;a=x[b+84>>2];x[b>>2]=x[b+80>>2];x[b+4>>2]=a;$m(c,b);a=x[d+4>>2];kg(x[x[a>>2]-12>>2]+a|0,0);break a}Ii(c,0,0,2);c=x[d+4>>2];a=x[x[c>>2]-12>>2]+c|0;if(xk(x[a+16>>2])){kg(a,0);c=x[d+4>>2];a=x[b+92>>2];x[b+24>>2]=x[b+88>>2];x[b+28>>2]=a;a=x[b+84>>2];x[b+16>>2]=x[b+80>>2];x[b+20>>2]=a;$m(c,b+16|0);a=x[d+4>>2];kg(x[x[a>>2]-12>>2]+a|0,0);break a}$d(b- -64|0,c);c=x[d+4>>2];c:{if(!xk(x[(c+x[x[c>>2]-12>>2]|0)+16>>2])){a=hi(b+48|0,-1,-1);f=1;if(!go(x[b+72>>2],x[b+76>>2],x[a+8>>2],x[a+12>>2])){break c}}kg(x[x[c>>2]-12>>2]+c|0,0);c=x[d+4>>2];f=0}a=x[b+92>>2];x[b+40>>2]=x[b+88>>2];x[b+44>>2]=a;a=x[b+84>>2];x[b+32>>2]=x[b+80>>2];x[b+36>>2]=a;$m(c,b+32|0);a=x[d+4>>2];kg(x[x[a>>2]-12>>2]+a|0,0)}fb=b+96|0;fb=e+16|0;return f|0}function pha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=0;i=fb-16|0;fb=i;if(Ai(a+44|0)){n=x[a+44>>2];j=Hc(n,0);k=Hc(n,1);n=x[a+56>>2];t=Hc(n,0);n=Hc(n,1);u=B[yb(a+4208|0,1)>>2];x[i+12>>2]=d;s=x[a+4220>>2];q=E(E(1)/E(s>>>0));v=x[a+4216>>2];o=d;f=n;g=t;while(1){if(o){h=x[a+4224>>2];a:{if(s>>>0>h>>>0){x[i+8>>2]=s-h;r=x[Gb(i+12|0,i+8|0)>>2];m=0;b:{if(u<E(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break b}p=E(h>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){B[g>>2]=B[j>>2];B[f>>2]=B[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;x[i+12>>2]=o;break a}m=v-h|0;x[i+4>>2]=m;l=x[Gb(i+12|0,i+4|0)>>2];e=0;c:{if(u<E(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break c}p=E(m>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){x[g>>2]=0;x[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;x[i+12>>2]=o;e=h+l|0;l=e>>>0<v>>>0?e:0}x[a+4224>>2]=l;continue}else{Qi(a,b,c,t,n,d)}break}}fb=i+16|0}function kS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=Xb(x[a+484360>>2],y[a+484376|0]);f=Zc(x[c>>2],x[c+4>>2]);a:{while(1){e=b&65535;if(e>>>0>=f>>>0){break a}if(!cj(c,e)){b=b+1|0;continue}break}f=a+1074312|0;e=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(e|0)){jS(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){So(a+1298264|0,1);x[a+1074456>>2]=x[a+480200>>2];x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+480208>>2]=x[a+480208>>2]&-769;sB(a+1074376|0);w[a+1074450>>1]=0;x[a+1074392>>2]=-2;b=a+1074428|0;x[b>>2]=0;x[b+4>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074376>>2]=0;x[a+1074380>>2]=0}else{Wo((D(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}v[c+797|0]=0;x[c+700>>2]=0;v[c+841|0]=0;v[c+805|0]=0;x[c+708>>2]=0;v[c+821|0]=0;x[c+764>>2]=0;v[c+819|0]=0;v[c+820|0]=0;Jb(d+8|0,f,23);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){v[c+807|0]=1;v[c+808|0]=0}v[c+839|0]=0;c=c+872|0;continue}break}w[a+1074450>>1]=b;w[a+1074446>>1]=0;b=a+1074424|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074392>>2]=-2;x[a+1074432>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074380>>2]=0}x[a+480208>>2]=x[a+480208>>2]&-769}fb=d+16|0}function Zqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;x[g+44>>2]=0;d=g+44|0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],4)){lD(d);break a}ph(c+8|0,d);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0;b:{if(!BV(d)){break b}e=y[g+46|0];f=y[g+47|0];d=y[g+45|0];v[a+4|0]=1;h=d>>>3&3;c=(h|0)!=3;d=(d^-1)>>>1&3;f=f>>>0<192;w[a+2>>1]=z[(D(c,6)+(d<<1)|0)+25736>>1]<<f;i=D(D(y[(d+D(c,3)|0)+25512|0],z[((D(c,90)+D(d,30)|0)+(e>>>3&30)|0)+25520>>1]),1e3);e=e>>>1|0;e=((i>>>0)/z[(D(h,6)+(e&6)|0)+25712>>1]|0)+(e&1)<<(!d<<1);w[a>>1]=e;d=y[(f|c<<1)+25748|0];if(d+8>>>0>(e&65535)>>>0){break b}e=Tb(g,0,36);c=fb-32|0;fb=c;x[c+28>>2]=d+4;x[c+8>>2]=36;h=x[b>>2];i=x[b+8>>2];f=x[Gb(c+28|0,c+8|0)>>2];if(!Mb(h,i,f)){f=lf(b)}h=c+8|0;fs(h,e);i=gc(c+16|0,x[c+8>>2],f);kc(c,x[b>>2],x[b+8>>2],x[i>>2],x[i+4>>2]);fs(h,e);Tb(x[c+8>>2]+f|0,0,36-f|0);Vb(b,x[c+28>>2]);fb=c+32|0;b=2;c=d>>>0<=2?2:d;while(1){if((b|0)!=(c|0)){f=b+e|0;b=b+1|0;if(!y[f|0]){continue}break b}break}b=d+e|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1868983881){b=1}else{b=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1735289176}v[a+5|0]=b}fb=g+48|0;return a|0}function yea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=fb-2160|0;fb=b;uu(b+112|0);a:{b:{c:{f=x[c+4>>2];if(!f){a=ac(8);x[31725]=0;b=P(36,b+100|0,10453)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}g=x[c>>2];d=x[c+12>>2];e=x[c+8>>2];x[b+92>>2]=e;x[b+96>>2]=d;c=x[b+96>>2];x[b+40>>2]=x[b+92>>2];x[b+44>>2]=c;x[b+88>>2]=f;x[b+84>>2]=g;c=x[b+88>>2];x[b+32>>2]=x[b+84>>2];x[b+36>>2]=c;h=FM(b+32|0);if(h){c=b- -64|0;x[c>>2]=e;x[b+68>>2]=d;d=x[c+4>>2];x[b+24>>2]=x[c>>2];x[b+28>>2]=d;x[b+60>>2]=f;x[b+56>>2]=g;c=x[b+60>>2];x[b+16>>2]=x[b+56>>2];x[b+20>>2]=c;c=yM(b+16|0)}else{c=0}x[b+72>>2]=c;x[b+76>>2]=0;d=0;c=2048;while(1){if(c){e=ib[f|0](g,(b+112|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=gc(b+48|0,b+112|0,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a=Au(a,b+8|0,h?b+72|0:0);if(a+1>>>0>=3){a=ac(8);x[31725]=0;b=P(36,b+100|0,8057)|0;c=x[31725];x[31725]=0;if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a);break b}fb=b+2160|0;return a|0}c=N()|0;jc(a)}Q(c|0)}p()}function yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=fb-16|0;fb=e;q=x[a+16>>2];r=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=Gg(i,j,k);m=hb;h=x[a+76>>2];hg(b,g,vf(i,j,d),hb);n=hb>>>0>h>>>0?d:0}h=a+112|0;s=x[a+24>>2];t=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;while(1){if(d){g=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;n=n-1|0;f=n;l=f?l:0;m=f?m:0;d=d-1|0;p=(((g&2147483647)<<1|b>>>31)&-2)+q|0;g=k;a:{b:while(1){c:{if((g|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);g=x[a+116>>2];if(!g){break a}f=x[e+8>>2];o=((x[e+12>>2]&2147483647)<<1|f>>>31)&-2;f=0;b=0;break c}f=x[e+8>>2];o=((x[e+12>>2]&2147483647)<<1|f>>>31)&-2;b=0;f=0;while(1)if((b|0)==2){be(h,f>>>3<<16>>16);ae(h,4);Pb(e+8|0,l,m);g=g-1|0;continue b}else{f=(v[(b+o|0)+p|0]<<8)+f|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){f=(v[(b+o|0)+p|0]<<8)+f|0;b=b+1|0;continue}break}be(h,f>>>3<<16>>16);ae(h,g);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=Eg(h,r);x[c>>2]=x[c>>2]+D(b,t);x[c+4>>2]=x[c+4>>2]+D(b,s);Pb(e,i,j);c=c+8|0;continue}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function tma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;q=x[a+16>>2];r=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];n=x[a+128>>2];if(n){o=Gg(l,m,n);p=hb;g=x[a+76>>2];hg(b,f,vf(l,m,d),hb);k=hb>>>0>g>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;k=k-1|0;o=k?o:0;p=k?p:0;f=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+q|0;b=n;while(1)if((b|0)<=0){Pb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;be(g,(w[(h<<1|2)+f>>1]+w[f+((h&2147483646)<<1)>>1]|0)/8<<16>>16);ae(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=Eg(g,r);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(e,l,m);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue a}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;be(g,(w[(h<<1|2)+f>>1]+w[f+((h&2147483646)<<1)>>1]|0)/8<<16>>16);ae(g,4);Pb(e+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function Hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;h=fb-16|0;fb=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];v=m>>31;j=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=ova(l,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=ova(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=n;g=ova(e,e>>31,m,v);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Pb(h+8|0,j,y);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function ila(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(x[a+4>>2]!=x[zb(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+32;YS(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+32;hc(c);fb=d+16|0;return}j=fb-32|0;fb=j;c=zb(a);c=gv(j+12|0,ar(a,Lg(x[a>>2],x[a+4>>2])+1|0),Lg(x[a>>2],x[a+4>>2]),c);YS(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;h=fb-16|0;fb=h;b=vb(h+12|0,x[a+4>>2]);e=vb(h+8|0,x[a>>2]);f=x[vb(h+4|0,x[c+4>>2])>>2];i=fb-16|0;fb=i;d=fb-32|0;fb=d;Id(d+24|0,x[b>>2],x[e>>2]);k=d+16|0;b=x[d+24>>2];l=x[d+28>>2];g=fb-16|0;fb=g;x[g+8>>2]=f;x[g+12>>2]=b;while(1){if(pd(b,l)){b=nn(b);e=nn(x[g+8>>2]);f=y[b+23|0]|y[b+24|0]<<8|(y[b+25|0]<<16|y[b+26|0]<<24);v[e+23|0]=f;v[e+24|0]=f>>>8;v[e+25|0]=f>>>16;v[e+26|0]=f>>>24;f=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=f;f=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;b=_o(g+12|0);_o(g+8|0);b=x[b>>2];continue}break}Ac(k,b,g+8|0);fb=g+16|0;b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(i+8|0,b,d+12|0);fb=d+32|0;fb=i+16|0;x[c+4>>2]=x[i+12>>2];Ub(a,c+4|0);Ub(a+4|0,c+8|0);Ub(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=h+16|0;YV(c);fb=j+32|0}function ita(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ld(b,32);np(b);f=b,g=xe((y[a+50|0]|y[a+51|0]<<8)<<16>>16)>>>2|0,w[f+32>>1]=g;if((xe((y[a+32|0]|y[a+33|0]<<8)<<16>>16)|0)>0){w[b+34>>1]=z[b+34>>1]|32;c=xe((y[a+32|0]|y[a+33|0]<<8)<<16>>16);e=c>>>24|0;d=(c<<8&-256)+2047|0;c=e&255;f=b,g=Bc(qva(d,d>>>0<2047?c+1|0:c,4095,0),hb),w[f+28>>1]=g}c=$b(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24));x[b>>2]=c;d=$b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24));x[b+4>>2]=d;e=$b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))+$b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))|0;x[b+8>>2]=e;if((Bb(y[a+34|0]|y[a+35|0]<<8)|0)==16){x[b+8>>2]=e>>>1;x[b+4>>2]=d>>>1;x[b>>2]=c>>>1}a:{b:{if($b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))){c=z[b+34>>1];break b}c=z[b+34>>1];if($b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))>>>0>=3){break b}c=c&-3;break a}c=c|2}w[b+34>>1]=c;f=b,g=c&65531|Bb(y[a+30|0]|y[a+31|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=Bb(y[a+36|0]|y[a+37|0]<<8)<<1,x[f+24>>2]=g;c=xe((y[a+52|0]|y[a+53|0]<<8)<<16>>16);if(c){hm(b,+(c|0)/96);c=xe((y[a+52|0]|y[a+53|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function Ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;if(!y[a+4242|0]){Zz(a);a:{if(!y[a+4240|0]){break a}e=PA(x[a+16>>2]);if(e==C[a+4288>>3]){break a}C[a+4288>>3]=e;pu(a)}f=a+4256|0;b:{if(y[a+4244|0]){if(C[f>>3]>1){x[f>>2]=0;x[f+4>>2]=1072693248}break b}i=(x[a+4232>>2]&-2)!=4;e=C[f>>3];c:{if(F(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Xz(a);e=C[a+4256>>3]}C[f>>3]=e-+(g|0)}e=0;d:{e:{switch(x[a+4232>>2]){case 0:e=Xi(C[f>>3]*6.283185307179586);break d;case 1:e=F(C[f>>3]+-.5)*-4+1;break d;case 2:e=C[f>>3];e=e+e+-1;break d;case 3:e=C[f>>3]<.5?-1:1;break d;case 4:e=C[a+4272>>3];break d;case 5:break e;default:break d}}e=C[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=C[a+4280>>3]*e+C[a+4272>>3]*(1-e)}C[h+8>>3]=(y[a+4241|0]?-e:e)*+B[a+4220>>2]+ +B[a+4224>>2];RT(h+8|0,1);g=Fj(a);f:{if(!g){break f}f=x[a+4236>>2];if(y[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|gm(C[h+8>>3]*127)<<16,j=x[x[g>>2]+68>>2],ib[j](k|0,l|0)|0;break f}ib[x[x[g>>2]+44>>2]](g,f,E(C[h+8>>3]))}C[a+4256>>3]=C[a+4264>>3]*+(d>>>0)+C[a+4256>>3]}g=a;a=x[a+44>>2];Qi(g,b,c,Hc(a,0),Hc(a,1),d);fb=h+16|0}function hZ(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+15|0]=c;a:{if(b>>>0>=22){v[d+14|0]=0;de(a,0,d+14|0);break a}e=y[b+25040|0];b:{c:{switch(b-8|0){case 0:v[d+15|0]=c<<1;break b;case 4:v[d+15|0]=c+1>>>1;break b;case 5:v[d+15|0]=D(c>>>4|0,10)+(c&15);break b;case 6:d:{switch((c>>>4|0)-1|0){default:e=0;break b;case 0:v[d+13|0]=c&15;v[d+12|0]=14;f=d,g=y[Rb(d+13|0,d+12|0)|0]<<4|15,v[f+15|0]=g;e=29;break b;case 1:v[d+11|0]=c&15;v[d+10|0]=14;f=d,g=y[Rb(d+11|0,d+10|0)|0]|240,v[f+15|0]=g;e=29;break b;case 3:v[d+15|0]=c&15|48;break b;case 4:v[d+15|0]=c<<4^128;e=35;break b;case 5:v[d+15|0]=c&15|176;break b;case 6:v[d+15|0]=c&15|64;break b;case 8:e=15;v[d+15|0]=c&15;break b;case 9:v[d+15|0]=(c<<3&120)+8&240;e=24;break b;case 10:v[d+15|0]=(c&15)+1>>>1;e=24;break b;case 14:break d;case 11:case 12:case 13:break b}}e=10;break b;case 8:if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=(b>>>0>=15?15:b)<<4;break b}if(c>>>0<=239){v[d+15|0]=c<<2&48|15;break b}v[d+15|0]=c<<4|15;break b;case 9:break c;default:break b}}if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=b>>>0>=15?15:b;break b}if(c>>>0>239){break b}v[d+15|0]=c>>>2&3|240}de(a,e,d+15|0)}fb=d+16|0}function Ima(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];y=m>>31;j=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=ova(l,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=ova(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=n;g=ova(e,e>>31,m,y);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Pb(h+8|0,j,z);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function ina(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];n=x[a+68>>2];u=n>>31;o=x[a+64>>2];v=o>>31;p=x[a+60>>2];y=p>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);k=ova(o,v,e,e>>31);l=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+38146>>1])+D(w[h-2>>1],w[e+38144>>1])|0)+D(w[h+2>>1],w[e+38148>>1])|0)+D(w[h+4>>1],w[e+38150>>1])|0)/16384<<8;e=h;e=ova(e,e>>31,p,y);k=e+k|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;f=Yb(f,-16777216,16776704);e=ova(n,u,f,f>>31);l=e+k|0;f=hb+m|0;f=e>>>0>l>>>0?f+1|0:f;e=l+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;j=j+s|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(f,i>>12);Pb(g+8|0,z,A);e=e-(h&t)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=g+16|0}function _ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=fb-16|0;fb=i;x[i+12>>2]=b;o=Rf(a);while(1){if(Zg(b,c)){b=x[vb(i+8|0,o)>>2];j=td(x[i+12>>2]);m=fb-16|0;fb=m;n=0;k=fb-16|0;fb=k;h=fb-32|0;fb=h;f=h+28|0;d=h+24|0;e=fb-16|0;fb=e;a:{b:{if(!lc(b,x[vb(e+12|0,rg(a))>>2])){g=y[j|0];l=y[td(b)|0];if(!Io(g,l)){break b}}x[e+12>>2]=b;g=vb(e+8|0,wb(x[a>>2]));c:{d=x[e+12>>2];if(!lc(d,x[g>>2])){d=x[MB(e+12|0)>>2];l=y[td(d)|0];g=y[j|0];if(!Io(l,g)){break c}}if(!x[b>>2]){x[f>>2]=b;break a}x[f>>2]=d;b=d+4|0;break a}b=fB(a,f,g);break a}if(Io(l,g)){d:{d=KB(b);if(!lc(d,x[vb(e+12|0,rg(a))>>2])){g=y[j|0];if(!Io(g,y[td(d)|0])){break d}}if(!x[b+4>>2]){x[f>>2]=b;b=b+4|0;break a}x[f>>2]=d;b=d;break a}b=fB(a,f,g);break a}x[f>>2]=b;x[d>>2]=b;b=d}fb=e+16|0;d=b;b=x[b>>2];if(!b){b=fb-16|0;fb=b;e=ec(a);f=h+12|0;e=Dh(f,Ec(24),Mg(b+8|0,e));ZS(x[e>>2]+16|0,x[j>>2],x[j+4>>2]);p=ec(e),q=1,v[p+4|0]=q;fb=b+16|0;$g(a,x[h+28>>2],d,x[h+12>>2]);b=le(f);em(f);n=1}_g(k+8|0,x[vb(h+12|0,b)>>2],n);fb=h+32|0;fb=k+16|0;vb(m+12|0,x[k+8>>2]);fb=m+16|0;b=x[ah(i+12|0)>>2];continue}else{fb=i+16|0}break}}function O7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=fb-448|0;fb=a;x[a+440>>2]=c;x[a+444>>2]=b;x[a+20>>2]=1238;b=Be(a+24|0,a+32|0,a+20|0);bd(a+16|0,x[e+28>>2]);x[31725]=0;h=R(1217,x[a+16>>2])|0;i=x[31725];x[31725]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[31725]=0;c=na(1247,a+444|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(Cd(y[g+11|0])){yd(x[g>>2],0);Yd(g,0);break d}yd(g,0);Me(g,0)}if(y[a+15|0]){x[31725]=0;c=P(1234,h|0,45)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[31725]=0;O(35,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}}x[31725]=0;d=P(1234,h|0,48)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-4|0;c=x[b>>2];while(1){if(!((d|0)!=x[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}x[31725]=0;U(1252,g|0,c|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break c}break a}x[31725]=0;c=P(1222,a+444|0,a+440|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+444>>2];Zb(a+16|0);Lc(b);fb=a+448|0;return c|0}}}c=N()|0;Zb(a+16|0);Lc(b);Q(c|0);p()}function jna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];l=x[a+68>>2];t=l>>31;m=x[a+64>>2];u=m>>31;n=x[a+60>>2];y=n>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=ova(m,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=ova(l,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;o=(((D(v[g|0],w[e+38146>>1])+D(v[g-1|0],w[e+38144>>1])|0)+D(v[g+1|0],w[e+38148>>1])|0)+D(v[g+2|0],w[e+38150>>1])<<8)/16384<<8;e=o;g=ova(e,e>>31,n,y);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,z,A);f=f-(s&o)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function CT(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=x[b+64>>2];a:{b:{g=x[b+60>>2];f=z[b+68>>1];if(!((g|0)==-1&(f|0)==65535)){c:{d:{if((e|0)==-1){break d}e=a+1074312|0;if(Ob(e,68)){break d}if(h=Ob(e,103),i=0,j=(f|0)!=65535,j?h:i){break c}if(h=Ob(e,49),i=0,j=(f|0)!=65535,j?h:i){break c}e=x[b+64>>2];break b}if((f|0)!=65535){break c}w[b+68>>1]=z[b+72>>1]+1}if((g|0)==-1){x[b+60>>2]=0}f=Zc(x[c>>2],x[c+4>>2]);e=z[b+68>>1];if(f>>>0<=e>>>0){e=z[c+28>>1];w[b+68>>1]=e}e:{if(z[b+72>>1]==(e&65535)){break e}c=a+1074312|0;if(Ob(c,26)){break e}if(Ob(c,68)|x[a+480180>>2]==1){break e}c=z[a+480188>>1];e=0;while(1){if((c|0)==(e|0)){break e}v[(D(e,872)+b|0)+1457|0]=0;e=e+1|0;continue}}x[b+52>>2]=x[b+60>>2];if(d){e=1;if(y[a+480208|0]&32){break a}}w[b+74>>1]=z[b+68>>1];return 1}if((e|0)!=-1){break b}e=0;break a}x[b+52>>2]=e;w[b+74>>1]=z[b+72>>1];f:{if(!x[b+20>>2]){break f}c=x[a+480180>>2];if((c|0)==32){if(Ob(a+1074312|0,103)){break f}c=x[a+480180>>2]}if((c|0)==2){break f}x[b+52>>2]=x[b+52>>2]+1}e=0;if(A[b+64>>2]<A[Wb(x[a+484344>>2],z[b+70>>1])+12>>2]){break a}x[b+52>>2]=0;w[b+74>>1]=z[b+74>>1]+1;return 0}return e}function cna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+j|0;b=(b>>>16&65520)+g|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];i=0;while(1){if((i|0)!=2){b=(i<<1)+m|0;x[(i<<2)+e>>2]=(((((((D(w[b-8>>1],t)+D(w[b-12>>1],u)|0)+D(w[b-4>>1],s)|0)+D(w[b>>1],r)|0)+D(w[b+4>>1],q)|0)+D(w[b+8>>1],p)|0)+D(w[b+12>>1],o)|0)+D(w[b+16>>1],n)|0)/32768;i=i+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function CK(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;g=y[a|0];a:{if(!g){f=a;break a}f=a;b:{while(1){if(!zl(g<<24>>24)){break b}g=y[f+1|0];f=f+1|0;if(g){continue}break}break a}c:{g=g&255;switch(g-43|0){case 0:case 2:break c;default:break a}}j=(g|0)==45?-1:0;f=f+1|0}d:{if(!((c|16)!=16|y[f|0]!=48)){n=1;if((y[f+1|0]&223)==88){f=f+2|0;m=16;break d}f=f+1|0;m=c?c:8;break d}m=c?c:10}c=0;while(1){e:{g=-48;i=v[f|0];f:{if((i-48&255)>>>0<10){break f}g=-87;if((i-97&255)>>>0<26){break f}g=-55;if((i-65&255)>>>0>25){break e}}i=g+i|0;if((i|0)>=(m|0)){break e}Of(l,m,0,0,0,k,h,0,0);g=1;g:{if(x[l+8>>2]|x[l+12>>2]){break g}o=ova(k,h,m,0);p=hb;if((p|0)==-1&(i^-1)>>>0<o>>>0){break g}h=p;k=i+o|0;h=k>>>0<i>>>0?h+1|0:h;n=1;g=c}f=f+1|0;c=g;continue}break}if(b){x[b>>2]=n?f:a}h:{i:{j:{if(c){x[31600]=68;a=d&1;j=a?0:j;k=d;h=e;break j}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|j)){x[31600]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break i}x[31600]=68;break h}a=j^k;d=a-j|0;b=j>>31;e=(b^h)-((a>>>0<j>>>0)+b|0)|0}fb=l+16|0;hb=e;return d}function lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;b=fb+-64|0;fb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Zf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){h=x[b+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}i=x[b+28>>2];if(d>>>0>x[b+24>>2]-i>>>0){break b}l=x[b+16>>2];m=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}n=D(f,g);o=D(f+i|0,h);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c+n<<3)+m>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;q=(c+o<<1)+l|0;j=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}r=q,s=ed(k),w[r>>1]=s;c=c+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=b- -64|0}function uba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;b=fb+-64|0;fb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Zf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){if(A[b+20>>2]<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}h=x[b+28>>2];if(d>>>0>x[b+24>>2]-h>>>0){break b}k=x[b+16>>2];l=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}m=f+h|0;n=D(f,g);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c+n<<3)+l>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;o=(c<<2)+k|0;i=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}q=x[o>>2]+(m<<1)|0,r=ed(j),w[q>>1]=r;c=c+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=a+32|0;fb=b- -64|0}function Qo(a,b,c){var d=0,e=0,f=0,g=0;f=a+1074312|0;d=Ob(f,96);x[b+660>>2]=(d?0:x[b+660>>2])+c;e=x[a+480180>>2];d=x[b+84>>2];if(!(!(e&18)|d>>>0>c>>>0|(!(y[b+88|0]&2)|!d))){g=c;c=x[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(x[b+88>>2]&1&(e|0)==16384)|0;a:{b:{if(!Tc(y[b+788|0])){if(!Ob(f,114)){break b}}d=x[b+656>>2];c:{if(!d){break c}e=y[b+788|0];if(!Tc(e)){break c}if((z[_b(d+236|0,e-1|0)>>1]-1&65535)>>>0>=z[a+480190>>1]){break a}}if(y[a+480210|0]&32){d=c;c=x[b+660>>2];x[b+660>>2]=d+c}x[b>>2]=0;x[b+4>>2]=c;if((!(y[b+88|0]&2)|A[b+84>>2]>c>>>0)&A[b+76>>2]>c>>>0){break a}d:{if(!Ob(f,57)){c=x[a+480180>>2];if((c|0)!=16){break d}}x[b+700>>2]=0;x[b+88>>2]=x[b+88>>2]|2097152;return}if(!(c&1048581)){if(Ob(f,27)){if(y[a+480208|0]&4){c=x[b+76>>2];x[b>>2]=0;x[b+4>>2]=c;return}x[b>>2]=0;x[b+4>>2]=0;return}c=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=c;if(!(y[a+480208|0]&4)){break a}a=x[b+76>>2];if(a>>>0<5){break a}x[b>>2]=0;x[b+4>>2]=a-2;return}if(!(y[b+88|0]&2)|(c|0)!=1){break a}a=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=a;return}if(!(x[a+480180>>2]&268582928)|A[b+76>>2]<=c>>>0){break a}x[b>>2]=0;x[b+4>>2]=c}}function Daa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=fb-32|0;fb=f;m=x[d>>2];g=x[d+4>>2];x[f+28>>2]=g;k=b+36|0;d=m;while(1){a:{if(!g){break a}h=0;j=fb-32|0;fb=j;i=b+36|0;e=b+228|0;l=c&-4096;b:{c:{while(1){if((h|0)==16){break c}d:{g=x[yb(e,h)>>2];if(y[Hd(i,g)+8|0]){if(x[Hd(i,g)>>2]==(l|0)){break d}}h=h+1|0;continue}break}i=x[yb(e,h)>>2];h=e+(h<<2)|0;Dr(e,h,h+4|0);o=yb(e,0),p=i,x[o>>2]=p;break b}h=x[yb(e,15)>>2];Dr(e,b+288|0,b+292|0);o=yb(e,0),p=h,x[o>>2]=p;g=x[yb(e,0)>>2];e=Hd(i,g);x[e>>2]=l;mz(j+16|0,x[b+24>>2],g);i=x[x[b>>2]+44>>2];h=x[j+20>>2];x[j+8>>2]=x[j+16>>2];x[j+12>>2]=h;ib[i|0](j+24|0,b,l,j+8|0);x[e+4>>2]=x[j+28>>2];v[e+8|0]=1}fb=j+32|0;i=c-x[Hd(k,g)>>2]|0;x[f+12>>2]=4096-i;o=f,p=x[Gb(f+12|0,f+28|0)>>2],x[o+24>>2]=p;if(i>>>0<A[Hd(k,g)+4>>2]){e=x[Hd(k,g)+4>>2]-i|0}else{e=0}x[f+20>>2]=e;e=x[Gb(f+24|0,f+20|0)>>2];mz(f+12|0,x[b+24>>2],g);h=x[f+12>>2];mz(f+4|0,x[b+24>>2],g);Wg(h+i|0,e+(i+x[f+4>>2]|0)|0,d);g=x[f+28>>2]-e|0;x[f+28>>2]=g;n=e+n|0;if(e>>>0<A[f+24>>2]){break a}c=c+e|0;d=d+e|0;continue}break}bc(a,m,n);fb=f+32|0}function $ua(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=fb-32|0;fb=g;v[g+16|0]=0;m=H0(g+20|0,d,g+16|0);f=x[m>>2];x[g+16>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=y[a|0];if(!(!i|(k|0)!=(e&255))){x[g+12>>2]=y[a+1|0];i=a+2|0;j=Gb(g+12|0,g+16|0);b:{k=b-2|0;if(!k){break b}j=x[j>>2];if(!(j&255)){break b}i=y[i|0];while(1){if(!(j&255)){break a}v[f|0]=i;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;j=j-1|0;continue}}v[f|0]=e;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;v[f|0]=k;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=x[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=v[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;v[c|0]=k;e=e-1|0;c=c+1|0;continue}break}dc(m);fb=g+32|0;return}n=y[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;v[l|0]=y[l|0]|D(f&n,257)>>>(h-j&7);b=b+1|0;l=b>>>0>=d>>>0;b=l?0:b;j=j+1|0;h=h+l|0;f=(f<<8|f)>>>1&255;continue}}}function $ta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-1072|0;fb=d;x[d+1068>>2]=c;o=d,q=Zd(b),v[o+8|0]=q;v[d+4|0]=1;c=d+8|0;g=y[ef(c,d+4|0)|0];f=aE(c,b);l=Ir(f);x[31725]=0;c=R(204,b|0)|0;e=x[31725];x[31725]=0;a:{if((e|0)!=1){x[d+4>>2]=c;x[d>>2]=536870911;wc(d+1068|0,x[Gb(d+4|0,d)>>2]<<3);x[31725]=0;m=x[d+1068>>2];k=P(343,a|0,m|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;c=8;h=P(160,f|0,8)|0;a=x[31725];x[31725]=0;b:{if((a|0)!=1){c:{o=xb(x[k>>2],0),q=h,v[o|0]=q;i=1;a=g;while(1){c=c&255;n=c>>>0<=9?9:c;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}x[31725]=0;j=P(160,f|0,c|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=xb(x[k>>2],i),q=h,v[o|0]=q;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=Ir(f);x[31725]=0;P(151,b|0,((a-l|0)+3&-4)+l|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break b}}}c=N()|0;dc(k);break a}ub(f);fb=d+1072|0;return}c=N()|0;break a}c=N()|0}ub(f);Q(c|0);p()}function yY(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;g=z[c>>1];a:{if((d&255)>>>0<=4){while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Af(a,f+15|0)){break a}d=y[f+15|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Af(a,f+14|0)){break a}d=y[f+14|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!Af(a,f+13|0)){break a}d=y[f+13|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break a}}while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Af(a,f+12|0)){break a}d=y[f+12|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!Af(a,f+11|0)){break a}d=y[f+11|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break}}fb=f+16|0}function dna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+j|0;b=(b>>>16&65520)+g|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];i=0;while(1){if((i|0)!=2){b=i+m|0;x[(i<<2)+e>>2]=(((((((D(v[b-4|0],t)+D(v[b-6|0],u)|0)+D(v[b-2|0],s)|0)+D(v[b|0],r)|0)+D(v[b+2|0],q)|0)+D(v[b+4|0],p)|0)+D(v[b+6|0],o)|0)+D(v[b+8|0],n)<<8)/32768;i=i+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function R1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;xc(b);Tp(a);a:{if(!_w(b,d+60|0)){break a}if(!_F(d+60|0)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],$b(y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24))-28|0)){break a}px(a);g=d,h=ox(),x[g+40>>2]=h;e=d+40|0;nx(mj(x[a+4>>2])+32|0,e);rs(e);c=x[mj(x[a+4>>2])+32>>2];f=y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24);x[31725]=0;S(188,e|0,b|0,$b(f)-28|0);b=x[31725];x[31725]=0;c:{d:{if((b|0)!=1){Tn(d+32|0,d+40|0);b=y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24);x[31725]=0;b=ba(189,x[d+32>>2],x[d+36>>2],c|0,$b(b)|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}Kc(d+40|0);e=0;if(!b){break a}oe(d+16|0,x[c>>2],x[c+4>>2]);mf(d+24|0,x[d+16>>2],x[d+20>>2]);b=Nd(d+8|0);c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;b=lx(d+40|0,x[d+24>>2],x[d+28>>2],d);hd(mj(x[a+4>>2])+12|0,b);ub(b);break b}a=ta(125e3,24440)|0;b=gb;break c}a=ta(125e3,24440)|0;b=gb;Kc(d+40|0)}e:{if(($(125e3)|0)==(b|0)){break e}if(($(24440)|0)==(b|0)){break e}Q(a|0);p()}Y(a|0)|0;Z();e=0;break a}e=1}fb=d+96|0;return e|0}function IQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);c=fb-80|0;fb=c;d=x[b>>2];b=x[b+4>>2];e=Nd(c+52|0);f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;b=lx(c+60|0,d,b,c+8|0);x[31725]=0;d=R(204,b|0)|0;e=x[31725];x[31725]=0;a:{if((e|0)==1){break a}x[31725]=0;d=U(955,b|0,c+19|0,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break a}if(!(!d|(y[c+23|0]|y[c+24|0]<<8|(y[c+25|0]<<16|y[c+26|0]<<24)|(y[c+19|0]|y[c+20|0]<<8|(y[c+21|0]<<16|y[c+22|0]<<24))!=542066252))){g=a,h=Pd((l(2,y[c+27|0]|y[c+28|0]<<8|(y[c+29|0]<<16|y[c+30|0]<<24)),r()),E(0)),B[g+4220>>2]=h;g=a,h=Pd((l(2,y[c+31|0]|y[c+32|0]<<8|(y[c+33|0]<<16|y[c+34|0]<<24)),r()),E(0)),B[g+4224>>2]=h;g=a,h=Pd((l(2,y[c+35|0]|y[c+36|0]<<8|(y[c+37|0]<<16|y[c+38|0]<<24)),r()),E(0)),B[g+4228>>2]=h;d=y[c+39|0]|y[c+40|0]<<8|(y[c+41|0]<<16|y[c+42|0]<<24);if(d>>>0<=5){x[a+4232>>2]=d}x[a+4236>>2]=y[c+43|0]|y[c+44|0]<<8|(y[c+45|0]<<16|y[c+46|0]<<24);v[a+4240|0]=y[c+47|0]!=0;v[a+4241|0]=y[c+48|0]!=0;v[a+4242|0]=y[c+49|0]!=0;v[a+4243|0]=y[c+50|0]!=0;v[a+4244|0]=y[c+51|0]!=0;qu(a)}ub(b);fb=c+80|0;return}a=N()|0;ub(b);Q(a|0);p()}function mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=0,v=0,w=0,z=E(0);h=x[a+44>>2];g=Hc(h,0);h=Hc(h,1);j=x[a+56>>2];n=Hc(j,0);j=Hc(j,1);e=oc(x[a+4208>>2],x[a+4212>>2]);o=D(x[x[a+16>>2]+1074404>>2],y[a+4233|0]);k=o<<1;if(e>>>0<k>>>0){Ll(a+4208|0,k)}l=y[a+4232|0];a:{if(l){e=x[a+4220>>2];k=x[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=B[h>>2];e=e>>>0<o>>>0?e:0;i=e-o|0;i=((i|0)<0?e:i)<<1;v=yb(k,i);f=B[yb(k,i|1)>>2];s=B[g>>2];t=B[v>>2];p=E(s+t);B[n>>2]=p;q=E(r+f);B[j>>2]=q;f=E(0);m=E(0);b:{c:{switch(u|0){case 0:f=B[a+4224>>2];m=E(q*f);f=E(p*f);break b;case 1:case 2:f=B[a+4224>>2];m=E(p*f);f=E(q*f);break b;case 3:break c;default:break b}}f=E(E(E(E(s+r)*E(.5))+t)*B[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;h=h+4|0;g=g+4|0;i=e<<1;w=yb(k,i),z=E(F(f))<E(10000000195414814e-40)?E(0):f,B[w>>2]=z;w=yb(k,i|1),z=E(F(m))<E(10000000195414814e-40)?E(0):m,B[w>>2]=z;e=e+1|0;x[a+4220>>2]=e;l=l+1|0;continue}}e=g;g=d<<2;Nk(e,e+g|0,n);Nk(h,h+g|0,j)}g=a;a=x[a+56>>2];Qi(g,b,c,Hc(a,0),Hc(a,1),d)}function xD(a,b,c,d){v[a+5|0]=c;a:{b:{switch((b|64)+-64|0){case 0:v[a+3|0]=c?37:0;return;case 1:v[a+3|0]=16;return;case 2:v[a+3|0]=12;return;case 3:v[a+3|0]=14;if(d){break a}v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 4:v[a+3|0]=11;return;case 5:v[a+3|0]=3;return;case 6:v[a+3|0]=2;return;case 7:v[a+3|0]=4;return;case 8:v[a+3|0]=5;return;case 9:v[a+3|0]=18;return;case 10:v[a+3|0]=1;return;case 11:v[a+3|0]=7;return;case 12:v[a+3|0]=6;return;case 13:v[a+3|0]=21;return;case 14:v[a+3|0]=22;return;case 15:v[a+3|0]=10;return;case 16:v[a+3|0]=29;return;case 17:v[a+3|0]=15;return;case 18:v[a+3|0]=8;return;case 19:v[a+3|0]=20;return;case 20:v[a+3|0]=17;return;case 21:v[a+3|0]=26;return;case 22:v[a+3|0]=23;return;case 23:v[a+3|0]=24;return;case 24:v[a+3|0]=9;return;case 25:v[a+3|0]=27;return;case 26:v[a+3|0]=31;return;case 28:v[a+3|0]=d?32:31;return;case 29:v[a+3|0]=d?33:0;return;case 27:v[a+3|0]=d?34:0;return;case 30:v[a+3|0]=d?35:0;return;case 31:v[a+3|0]=d?36:0;return;case 50:v[a+3|0]=d?25:0;return;case 51:v[a+3|0]=d?30:0;return;default:break b}}v[a+3|0]=0}}function Tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=E(0),t=0,u=0,v=0,w=0,y=0,z=E(0);a:{j=x[a+4272>>2];if(!j){break a}if(!Ai(a+44|0)){break a}f=x[a+44>>2];l=Hc(f,0);m=Hc(f,1);u=x[a+4252>>2]-1|0;i=x[a+4268>>2];k=x[a+4256>>2];n=d;f=x[a+56>>2];q=Hc(f,0);o=q;r=Hc(f,1);p=r;while(1){if(n){e=B[m>>2];f=i<<1;h=yb(k,f);g=B[l>>2];B[h>>2]=g;y=yb(k,f|1),z=e,B[y>>2]=z;s=B[a+4276>>2];e=E(E(F(oQ(E(E(E(F(g))+E(F(e)))*E(536870912)),31,5)))*E(4.656612873077393e-10));e=E(E(E(s-e)*B[(e>=s?4236:4240)+a>>2])+e);B[a+4276>>2]=e;g=B[a+4244>>2];e=E(E(E(E(g-(e<g?g:e))*B[a+4248>>2])+E(.9999998807907104))*E(2147483648));b:{if(e<E(4294967296)&e>=E(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=B[yb(k,t)>>2];h=f<<5;v=h;w=h|-2147483648;h=f>>>0<67108864;e=E(B[a+4232>>2]*E(E((h?v:w)>>>(h?31:32-(f>>>26|0)|0)>>>0)*E(4.656612873077393e-10)));B[o>>2]=g*e;y=p,z=E(B[yb(k,t|1)>>2]*e),B[y>>2]=z;i=((i?0:j)+i|0)-1|0;x[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{Qi(a,b,c,q,r,d)}break}}}function Bo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-80|0;fb=c;g=Nb(a);a=x[b+24>>2];a:{b:{if(Qj(x[a+484360>>2],x[a+484364>>2])){c:{d:{e:while(1){if(Qj(x[a+484360>>2],x[a+484364>>2])>>>0<=f>>>0){break d}d=dS(nY(c+40|0,1),f&255,0,0);x[31725]=0;e=x[d+12>>2];x[c+16>>2]=x[d+8>>2];x[c+20>>2]=e;e=x[d+20>>2];x[c+24>>2]=x[d+16>>2];x[c+28>>2]=e;e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;V(1097,c+68|0,a|0,0,c+8|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}j=c,k=wb(x[c+68>>2]),x[j+36>>2]=k;d=wb(x[c+72>>2]);while(1){a=x[c+36>>2];if(!Ib(a,d)){f=f+1|0;Yi(c+68|0);a=x[b+24>>2];continue e}h=C[a>>3];e=x[a+16>>2];i=z[a+24>>1];a=c+40|0;x[a+16>>2]=f;x[a+12>>2]=i;x[a+8>>2]=e;C[a>>3]=h;x[31725]=0;O(1132,g|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){er(c+36|0);continue}break}break}a=N()|0;Yi(c+68|0);break b}fb=c+80|0;return}a=N()|0;break b}b=ac(8);x[31725]=0;d=P(36,c+40|0,7310)|0;a=x[31725];x[31725]=0;if((a|0)!=1){pc(b,d);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=N()|0;jc(b)}of(g);Q(a|0)}p()}function xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;o=x[a+16>>2];p=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=Gg(j,k,l);n=hb;f=x[a+76>>2];hg(b,g,vf(j,k,d),hb);i=hb>>>0>f>>>0?d:0}f=a+112|0;q=x[a+24>>2];r=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;g=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=l;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;be(f,(w[(h<<1|2)+g>>1]+w[((h&2147483646)<<1)+g>>1]|0)/8<<16>>16);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,p);x[c>>2]=x[c>>2]+D(b,r);x[c+4>>2]=x[c+4>>2]+D(b,q);Pb(e,j,k);c=c+8|0;continue a}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;be(f,(w[(h<<1|2)+g>>1]+w[((h&2147483646)<<1)+g>>1]|0)/8<<16>>16);ae(f,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function bC(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;if(b&5){if((b|0)==1){e=ova(x[a+24>>2],0,8363,0);c=hb;e=e+4143|0;c=e>>>0<4143?c+1|0:c;f=a,g=Bc(qva(e,c,8287,0),hb),x[f+24>>2]=g}GV(a)}if(b&3){w[a+38>>1]=0;w[a+40>>1]=0;v[a+36|0]=0;w[a+34>>1]=z[a+34>>1]&65499}if(b&7){w[a+32>>1]=64;c=z[a+34>>1];if(c&8){e=x[a+16>>2];x[a+4>>2]=x[a+12>>2];x[a+8>>2]=e;c=c&16?c|6:c&65529|2}x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=c&65511}a:{if(!(b&4)){break a}c=z[a+34>>1];if(!(c&32)){w[a+28>>1]=128;w[a+34>>1]=c|32}Qf(a+40|0,15);Qf(a+41|0,63);if(!y[a+41|0]){break a}e=y[a+40|0];if(!e){break a}c=y[a+39|0];if(c){c=zi(Bc(((e<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}v[a+39|0]=c}b:{c:{if((b|0)!=4){if((b|0)==16777216){break b}if((b|0)!=32|y[a+38|0]!=2){break c}v[a+38|0]=3;break c}if(y[a+38|0]!=4){break c}v[a+38|0]=0}w[a+34>>1]=z[a+34>>1]&49151}d:{if(!(!(y[a+35|0]&2)|b&16777218)){x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;_k(a,0,d);break d}if(!(y[a+35|0]&2)|(b|0)!=2){break d}a=a+68|0;b=xb(a,8);v[b|0]=y[b|0]&3;a=xb(a,9);v[a|0]=y[a|0]&3}fb=d+32|0}function Wo(a,b,c,d){var e=0,f=0;e=b+1074312|0;f=Ob(e,120);v[a+797|0]=f;v[a+802|0]=f;w[a+800>>1]=0;v[a+803|0]=0;v[a+804|0]=0;v[a+841|0]=0;v[a+805|0]=0;x[a+708>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+764>>2]=0;x[a+696>>2]=0;x[a+668>>2]=0;x[a+88>>2]=x[a+88>>2]|6144;if(Ob(e,23)){v[a+807|0]=1;v[a+808|0]=0}v[a+846|0]=0;v[a+839|0]=0;w[a+774>>1]=0;v[a+850|0]=255;x[a+660>>2]=0;v[a+851|0]=y[a+851|0]&224;ap(a+788|0);x[a+84>>2]=0;x[a+76>>2]=0;x[a+80>>2]=0;x[a+700>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;v[a+845|0]=0;v[a+838|0]=0;v[a+821|0]=0;x[a+688>>2]=0;x[a+672>>2]=0;x[a+676>>2]=0;w[a+836>>1]=32512;v[a+819|0]=0;v[a+820|0]=0;w[a+842>>1]=0;x[a+28>>2]=0;x[a+32>>2]=0;x[a+20>>2]=0;x[a+24>>2]=0;x[a+852>>2]=0;x[a+856>>2]=0;v[a+851|0]=y[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=x[b+480280>>2];x[a+88>>2]=c;x[a+692>>2]=z[b+480284>>1];x[a+748>>2]=z[b+480286>>1];if(!(c&1024)){break a}x[a+88>>2]=c&-1025|d;break a}x[a+748>>2]=64;x[a+692>>2]=128;x[a+88>>2]=0}w[a+784>>1]=0;v[a+795|0]=0;v[a+796|0]=0}function G0(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;a:{if((y[a|0]-16&255)>>>0<241){break a}c=a+1954|0;d=a+1698|0;while(1){if((d|0)==(c|0)){d=0;c=0;while(1){if((d|0)==32){g=c;break a}g=0;e=D(d,13)+a|0;if(y[nc(e+2|0)|0]){break a}b=(d<<4)+a|0;if(y[b+418|0]|y[b+419|0]<<8|(y[b+420|0]<<16|y[b+421|0]<<24)){break a}h=y[b+422|0]|y[b+423|0]<<8|(y[b+424|0]<<16|y[b+425|0]<<24);if(h>>>0>1048575){break a}if(y[nc(e+930|0)|0]){break a}e=(D(d,11)+a|0)+1346|0;if(y[xb(e,0)|0]>15){break a}if(y[xb(e,5)|0]>3){break a}if(y[xb(e,10)|0]>3){break a}b:{c:{d:{if(h){i=y[b+430|0]|y[b+431|0]<<8|(y[b+432|0]<<16|y[b+433|0]<<24);if(i>>>0<=1048574&(h>>>0<i>>>0|(y[b+426|0]|y[b+427|0]<<8|(y[b+428|0]<<16|y[b+429|0]<<24))>>>0>i>>>0)){break a}if(c|h){break c}break d}if(c){break c}}v[f+7|0]=0;v[f+8|0]=0;v[f+9|0]=0;v[f+10|0]=0;x[f>>2]=0;x[f+4>>2]=0;g=e+11|0;c=f;while(1){e:{b=(e|0)==(g|0);if(b){break e}if(!F0(y[e|0],y[c|0])){break e}c=c+1|0;e=e+1|0;continue}break}c=0;if(b){break b}}c=1}d=d+1|0;continue}}b=v[d|0];d=d+1|0;if((b|0)>-2){continue}break}}fb=f+16|0;return g&1}function JT(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{switch(y[a+480224|0]-1|0){default:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2]<<1;c=ova(c,c>>31,5e4,0);e=hb;b=x[ad(d+12|0,d+8|0)>>2];c=Gc(pva(c,e,b,b>>31),hb);break a;case 0:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2];c=ova(c,c>>31,1e4,0);e=hb;b=x[ad(d+12|0,d+8|0)>>2];c=Gc(pva(c,e,b,b>>31),hb);break a;case 1:break b}}f=60/(+A[b+44>>2]/1e4*(+(ova(x[b+32>>2],0,x[b+40>>2],0)>>>0)+ +(hb>>>0)*4294967296))*+A[a+24620>>2];c:{d:{c=x[a+484344>>2];e=z[b+70>>1];if(!He(c,x[a+484348>>2],e)){break d}c=Wb(c,e);if(!Ib(x[c+24>>2],x[c+28>>2])){break d}c=cS(c);break c}c=a+480248|0}e=x[c>>2];c=x[c+4>>2];if(!lc(e,c)){f=f*+A[yb(e,A[b+48>>2]%(oc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(F(f)<2147483648){c=~~f;break e}c=-2147483648}f=C[b+8>>3]+(f-+(c>>>0));C[b+8>>3]=f;if(f>=1){C[b+8>>3]=f+-1;c=c+1|0;break a}if(!(C[a+1074384>>3]<=-1)){break a}C[b+8>>3]=f+1;c=c-1|0}b=ova(x[a+480244>>2],0,c,0);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Bc((a&65535)<<16|b>>>16,a>>>16|0);fb=d+16|0;return a>>>0<=1?1:a}function Aia(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb+-64|0;fb=b;g=Nb(a);x[31725]=0;W(960,g|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){a=43040;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==43352){fb=b- -64|0;return g|0}k:{h=zu(44);if(h){x[31725]=0;d=P(36,b+36|0,x[a+4>>2])|0;c=x[31725];x[31725]=0;if((c|0)==1){break k}c=x[a>>2];x[31725]=0;O(961,b+48|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break j}x[31725]=0;e=P(36,b+12|0,x[a+8>>2])|0;f=x[31725];x[31725]=0;if((f|0)==1){break i}x[31725]=0;O(961,b+24|0,e|0);f=x[31725];x[31725]=0;if((f|0)==1){break h}x[31725]=0;c=ba(962,h|0,c|0,b+48|0,b+24|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break g}Eb(b+24|0);tb(e);Eb(b+48|0);tb(d);x[b+60>>2]=c;x[31725]=0;O(963,g|0,b+60|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}v[c+40|0]=y[a+20|0];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;v[c+41|0]=y[c+41|0]&253|y[a+21|0]<<1}a=a+24|0;continue}break}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;Eb(b+24|0)}tb(e)}Eb(b+48|0)}tb(d)}Db(h);break a}a=N()|0;break a}a=N()|0}uc(g);Q(a|0);p()}function ZL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),q=0;a:{if(y[b+21|0]){q=D(d,g);j=x[e>>2];l=x[f>>2];m=x[b>>2];b:{while(1){if((h|0)>0){if(x[a+1396>>2]<=9){El(a)}g=x[a+1392>>2];k=w[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=y[k+x[b+8>>2]|0];x[a+1392>>2]=i>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;k=(g|0)<0?-1:k;break c}k=Om(a,b)}if((k|0)>=x[b+2092>>2]?y[b+23|0]:0){break a}if((k|0)<0){if(!y[a+1376|0]){b=0;if(x[a+1384>>2]){break b}}fc(a,21);return 0}else{g=0;n=D(d,l);m=((m+n|0)+j|0)>(q|0)?(q-n|0)+j|0:m;n=(m|0)>0?m:0;k=D(k,x[b>>2]);o=E(0);d:{if(y[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=E(o+B[x[b+28>>2]+(g+k<<2)>>2]);i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=o+B[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+E(B[x[b+28>>2]+(g+k<<2)>>2]+E(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}}break}x[e>>2]=j;x[f>>2]=l;b=1}return b}fc(a,21);return 0}_(7552,13258,1887,6586);p()}function U7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=fb-144|0;fb=a;x[a+136>>2]=c;x[a+140>>2]=b;x[a+20>>2]=1238;b=Be(a+24|0,a+32|0,a+20|0);bd(a+16|0,x[e+28>>2]);x[31725]=0;h=R(28,x[a+16>>2])|0;i=x[31725];x[31725]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[31725]=0;c=na(1239,a+140|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}tf(g);if(y[a+15|0]){x[31725]=0;c=P(29,h|0,45)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[31725]=0;O(117,g|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}}x[31725]=0;d=P(29,h|0,48)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-1|0;c=x[b>>2];d=d&255;while(1){if(!((d|0)!=y[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}x[31725]=0;U(1245,g|0,c|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break c}break a}x[31725]=0;c=P(1207,a+140|0,a+136|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+140>>2];Zb(a+16|0);Lc(b);fb=a+144|0;return c|0}}}c=N()|0;Zb(a+16|0);Lc(b);Q(c|0);p()}function zS(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=fb-32|0;fb=g;b=dv(g);d=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);c=(f<<5)+a|0;e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=e;v[c+1|0]=e>>>8;v[c+2|0]=e>>>16;v[c+3|0]=e>>>24;v[c+4|0]=d;v[c+5|0]=d>>>8;v[c+6|0]=d>>>16;v[c+7|0]=d>>>24;d=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);e=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[c+24|0]=e;v[c+25|0]=e>>>8;v[c+26|0]=e>>>16;v[c+27|0]=e>>>24;v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);e=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[c+16|0]=e;v[c+17|0]=e>>>8;v[c+18|0]=e>>>16;v[c+19|0]=e>>>24;v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[c+8|0]=b;v[c+9|0]=b>>>8;v[c+10|0]=b>>>16;v[c+11|0]=b>>>24;v[c+12|0]=d;v[c+13|0]=d>>>8;v[c+14|0]=d>>>16;v[c+15|0]=d>>>24;fb=g+32|0;f=f+1|0;continue}break}}function UL(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=a;d=fb-208|0;fb=d;x[d+8>>2]=1;x[d+12>>2]=0;h=b<<2;a:{if(!h){break a}x[d+16>>2]=4;x[d+20>>2]=4;a=4;b=4;e=2;while(1){f=a;a=(a+b|0)+4|0;x[(d+16|0)+(e<<2)>>2]=a;e=e+1|0;b=f;if(a>>>0<h>>>0){continue}break}f=(g+h|0)-4|0;b:{if(f>>>0<=g>>>0){b=0;e=1;h=0;a=1;f=0;break b}e=1;a=1;while(1){c:{if((e&3)==3){$y(g,c,a,d+16|0);Nt(d+8|0,2);a=a+2|0;break c}b=a-1|0;d:{if(A[(d+16|0)+(b<<2)>>2]>=f-g>>>0){Mt(g,c,e,x[d+12>>2],a,0,d+16|0);break d}$y(g,c,a,d+16|0)}if((a|0)==1){Lt(d+8|0,1);a=0;break c}Lt(d+8|0,b);a=1}b=x[d+8>>2];e=b|1;x[d+8>>2]=e;g=g+4|0;if(f>>>0>g>>>0){continue}break}h=b>>>0>1;b=x[d+12>>2];f=(b|0)!=0}Mt(g,c,e,b,a,0,d+16|0);if(!(f|((a|0)!=1|h))){break a}while(1){e:{if((a|0)<=1){f=ML(e,b);Nt(d+8|0,f);b=x[d+12>>2];e=x[d+8>>2];a=a+f|0;break e}e=d+8|0;Lt(e,2);x[d+8>>2]=x[d+8>>2]^7;Nt(e,1);b=g-4|0;h=d+16|0;f=a-2|0;Mt(b-x[h+(f<<2)>>2]|0,c,x[d+8>>2],x[d+12>>2],a-1|0,1,h);Lt(e,1);e=x[d+8>>2]|1;x[d+8>>2]=e;a=b;b=x[d+12>>2];Mt(a,c,e,b,f,1,h);a=f}g=g-4|0;if((a|0)!=1|(e|0)!=1|b){continue}break}}fb=d+208|0}function dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31725]=0;W(1027,a|0);e=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}x[31725]=0;W(1003,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break e}e=0;x[31725]=0;W(1028,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break e}a=Tb(c,0,d);if(!y[b|0]){break b}if(oi(b,47360)|(d|0)!=8){break d}x[a+4>>2]=1029;x[a>>2]=1030;break c}Y(T(0)|0)|0;x[31725]=0;V(989,12344,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();return 0}if(!(oi(b,47372)|(d|0)!=64)){x[a+60>>2]=1031;x[a+56>>2]=1032;x[a+52>>2]=1033;x[a+48>>2]=1034;x[a+44>>2]=1035;x[a+40>>2]=1036;x[a+36>>2]=1037;x[a+32>>2]=1038;x[a+28>>2]=1039;x[a+24>>2]=1040;x[a+20>>2]=1041;x[a+16>>2]=1042;x[a+12>>2]=1043;x[a+8>>2]=1044;x[a+4>>2]=1045;x[a>>2]=1046;break c}if(!(oi(b,47384)|(d|0)!=24)){x[a+20>>2]=1047;x[a+16>>2]=1048;x[a+12>>2]=1049;x[a+8>>2]=1050;x[a+4>>2]=1051;x[a>>2]=1052;break c}if(oi(b,47397)|(d|0)!=4){break b}x[a>>2]=1053}e=1}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Ana(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];w=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=ova(n,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=ova(m,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=x[h+12>>2]+p|0;k=v[g|0];k=((D(v[g+1|0]-k|0,x[h+8>>2]>>>10&4194048)|0)/16384<<8)+(k<<16)|0;e=k;g=ova(e,e>>31,o,w);l=g+l|0;e=hb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function Eia(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=E(0),h=0,i=0;c=fb-32|0;fb=c;a:{d=x[a+20>>2];b:{if(!d){break b}x[d+148>>2]=-1;h=c,i=ib[x[x[a>>2]+40>>2]](a)|0,x[h+16>>2]=i;x[c+8>>2]=1073741822;f=x[Gb(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}e=x[a+20>>2];d=0;x[31725]=0;O(289,e+4|0,b+4|0);b=x[31725];x[31725]=0;c:{d:{if((b|0)!=1){b=x[a+20>>2];oe(c+8|0,x[b+4>>2],x[b+8>>2]);x[c>>2]=0;x[c+4>>2]=0;e=x[c+12>>2];b=c+16|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=e;e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;e=fb-16|0;fb=e;x[e+12>>2]=0;FQ(b,e+12|0);fb=e+16|0;b=x[x[a>>2]+184>>2];x[31725]=0;O(b|0,a|0,-1);b=x[31725];x[31725]=0;if((b|0)==1){break d}while(1){if((d|0)==(f|0)){d=x[x[a>>2]+188>>2];x[31725]=0;W(d|0,a|0);d=x[31725];x[31725]=0;if((d|0)!=1){break b}break d}b=x[x[a>>2]+48>>2];x[31725]=0;g=E(_a(b|0,a|0,d|0));b=x[31725];x[31725]=0;if((b|0)!=1){B[c+8>>2]=g;d=d+1|0;FQ(c+16|0,c+8|0);continue}break}d=T(125e3)|0;break c}d=T(125e3)|0;break c}d=T(125e3)|0}if((gb|0)!=($(125e3)|0)){break a}Y(d|0)|0;gp(x[a+20>>2]+4|0);Z()}fb=c+32|0;return}Q(d|0);p()}function zna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];v=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=ova(n,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=ova(m,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=(x[h+12>>2]<<1)+p|0;k=w[g>>1];k=k+((D(w[g+2>>1]-k|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=k;g=ova(e,e>>31,o,v);l=g+l|0;e=hb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function kX(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-80|0;fb=c;x[c+72>>2]=0;x[c+76>>2]=0;b=c- -64|0;x[b>>2]=0;x[b+4>>2]=0;x[c+56>>2]=0;x[c+60>>2]=0;x[c+48>>2]=0;x[c+52>>2]=0;gC(a,EV(a),c+48|0);b=qc(c+40|0,14192);sf(Oe(a,0),x[b>>2],x[b+4>>2]);b=qc(c+32|0,14275);sf(Oe(a,1),x[b>>2],x[b+4>>2]);b=qc(c+24|0,5496);sf(Oe(a,3),x[b>>2],x[b+4>>2]);b=qc(c+16|0,15744);sf(Oe(a,4),x[b>>2],x[b+4>>2]);b=qc(c+8|0,9265);sf(Oe(a,8),x[b>>2],x[b+4>>2]);e=Oe(a+288|0,0);b=fb-16|0;fb=b;d=e;e=qc(b+8|0,4932);sf(d,x[e>>2],x[e+4>>2]);fb=b+16|0;e=a+800|0;b=0;a=fb+-64|0;fb=a;a:{b:{while(1){if((b|0)==128){break a}x[a+60>>2]=b<<3;c:{d:{if(b>>>0<=15){lw(a+28|0,4084);x[31725]=0;O(291,a+16|0,a+60|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}x[31725]=0;S(292,a+40|0,a+28|0,a+16|0);d=x[31725];x[31725]=0;if((d|0)!=1){d=a+40|0;ee(a+52|0,d);sf(Oe(e,b),x[a+52>>2],x[a+56>>2]);tb(d);tb(a+16|0);Eb(a+28|0);break d}b=N()|0;tb(a+16|0);break b}d=qc(a+8|0,22255);sf(Oe(e,b),x[d>>2],x[a+12>>2])}b=b+1|0;continue}break}b=N()|0}Eb(a+28|0);Q(b|0);p()}fb=a- -64|0;fb=c+80|0}function ana(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Pb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=e+16|0}function qva(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(b){if(!c){break k}if(!d){break j}e=G(d)-G(b)|0;if(e>>>0<=31){break i}break c}if((d|0)==1|d>>>0>1){break c}hb=0;a=(a>>>0)/(c>>>0)|0;break a}if(!a){break h}if(!d|d-1&d){break g}a=b>>>nva(d)|0;hb=0;break a}if(!(c-1&c)){break f}h=(G(c)+33|0)-G(b)|0;g=0-h|0;break d}h=e+1|0;g=63-e|0;break d}hb=0;a=(b>>>0)/(d>>>0)|0;break a}e=G(d)-G(b)|0;if(e>>>0<31){break e}break c}if((c|0)==1){break b}d=nva(c);c=d&31;if((d&63)>>>0>=32){a=b>>>c|0}else{e=b>>>c|0;a=((1<<c)-1&b)<<32-c|a>>>c}hb=e;break a}h=e+1|0;g=63-e|0}e=h&63;f=e&31;if(e>>>0>=32){e=0;i=b>>>f|0}else{e=b>>>f|0;i=((1<<f)-1&b)<<32-f|a>>>f}g=g&63;f=g&31;if(g>>>0>=32){b=a<<f;a=0}else{b=(1<<f)-1&a>>>32-f|b<<f;a=a<<f}if(h){f=d-1|0;g=c-1|0;m=(g|0)!=-1?f+1|0:f;while(1){j=e<<1|i>>>31;e=i<<1|b>>>31;f=m-(j+(e>>>0>g>>>0)|0)>>31;k=c&f;i=e-k|0;e=j-((d&f)+(e>>>0<k>>>0)|0)|0;b=b<<1|a>>>31;a=l|a<<1;l=f&1;h=h-1|0;if(h){continue}break}}hb=b<<1|a>>>31;a=l|a<<1;break a}a=0;b=0}hb=b}return a}function $ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;ld(c,0);w[d+14>>1]=y[a+36|0]|y[a+37|0]<<8;w[d+12>>1]=32767;g=c,h=(z[Nc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,w[g+28>>1]=h;w[d+10>>1]=y[a+38|0]|y[a+39|0]<<8;w[d+8>>1]=32767;g=c,h=(z[Nc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,w[g+30>>1]=h;w[c+32>>1]=64;x[c>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+4>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+8>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[c+24>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);e=y[b+166|0];if(e>>>0<=4){v[c+38|0]=y[e+41178|0]}e=y[b+167|0]|y[b+168|0]<<8;v[c+39|0]=e;f=(y[b+171|0]|y[b+172|0]<<8)>>>4|0;v[c+41|0]=f;b=(y[b+169|0]|y[b+170|0]<<8)>>>2|0;v[c+40|0]=b;if((b|f)&255){v[c+39|0]=e^-1}b=y[a+40|0]|y[a+41|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+40|0]|y[a+41|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+40|0]|y[a+41|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+40|0]|y[a+41|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}fb=d+16|0}function Pna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;r=x[a+16>>2];l=mg(1,2);b=hb;s=b;Pb(a,l,b);f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+32>>2];u=x[a+28>>2];v=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){p=w[(x[g+12>>2]<<1)+r>>1]<<8;e=p;e=ova(e,e>>31,o,A);k=hb;h=e;e=Yb(b,-16777216,16776704);e=ova(n,z,e,e>>31);q=h+e|0;h=hb+k|0;h=e>>>0>q>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=ova(m,y,f,f>>31);k=e+q|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;j=j+u|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Pb(g+8|0,B,C);e=e-(v&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;Hg(a,l,s);fb=g+16|0}function OM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=e;x[c+8>>2]=x[a+8>>2];e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a:{b:{c:{d:{e=x[c+4>>2];if(g>>>0<=e>>>0){if(g>>>0>A[c+20>>2]){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=h+j|0;o=D(e,h);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=yb(x[b>>2],a);i=d;d=x[(a+o<<2)+m>>2]+(x[d>>2]>>1)|0;q=d;d=Yt(k)+d&-4096;x[i>>2]=q-d;i=x[(a<<2)+l>>2]+(n<<1)|0;d=qd(d|2048,12);d=(d|0)>=32767?32767:d;w[i>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function IM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=e;x[c+8>>2]=x[a+8>>2];e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a:{b:{c:{d:{e=x[c+4>>2];if(g>>>0<=e>>>0){i=x[c+20>>2];if(g>>>0>i>>>0){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=D(e,h);o=D(h+j|0,i);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=yb(x[b>>2],a);q=d;d=x[(a+n<<2)+m>>2]+(x[d>>2]>>1)|0;r=d;d=Yt(k)+d&-4096;x[q>>2]=r-d;d=qd(d|2048,12);d=(d|0)>=32767?32767:d;w[(a+o<<1)+l>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function YL(a,b,c,d,e){var f=E(0),g=0,h=E(0),i=0,j=E(0),k=E(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=B[b>>2];j=B[c>>2];k=B[d>>2];B[c>>2]=j+k;g=c-4|0;f=B[g>>2];B[g>>2]=f+B[b>>2];j=E(j-k);f=E(f-h);B[d>>2]=E(j*B[e>>2])-E(B[e+4>>2]*f);B[b>>2]=E(f*B[e>>2])+E(j*B[e+4>>2]);b=d-12|0;j=B[b>>2];g=c-8|0;f=B[g>>2];i=g;g=d-8|0;k=B[g>>2];B[i>>2]=f+k;i=c-12|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+32>>2])-E(B[e+36>>2]*h);B[b>>2]=E(h*B[e+32>>2])+E(f*B[e+36>>2]);b=d-20|0;j=B[b>>2];g=c-16|0;f=B[g>>2];i=g;g=d-16|0;k=B[g>>2];B[i>>2]=f+k;i=c-20|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+64>>2])-E(B[e+68>>2]*h);B[b>>2]=E(h*B[e+64>>2])+E(f*B[e+68>>2]);b=d-28|0;j=B[b>>2];g=c-24|0;f=B[g>>2];i=g;g=d-24|0;k=B[g>>2];B[i>>2]=f+k;i=c-28|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+96>>2])-E(B[e+100>>2]*h);B[b>>2]=E(h*B[e+96>>2])+E(f*B[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}_(15833,13258,2423,9211);p()}function Qna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;r=x[a+16>>2];l=mg(1,2);b=hb;s=b;Pb(a,l,b);f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+32>>2];u=x[a+28>>2];w=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){p=v[x[g+12>>2]+r|0]<<16;e=p;e=ova(e,e>>31,o,A);k=hb;h=e;e=Yb(b,-16777216,16776704);e=ova(n,z,e,e>>31);q=h+e|0;h=hb+k|0;h=e>>>0>q>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=ova(m,y,f,f>>31);k=e+q|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;j=j+u|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Pb(g+8|0,B,C);e=e-(w&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;Hg(a,l,s);fb=g+16|0}function bna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Pb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=e+16|0}function bta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;d=_h(b,c);n=e,o=Bb(y[a|0]|y[a+1|0]<<8),w[n+14>>1]=o;w[e+12>>1]=64;hh(d,z[Nc(e+14|0,e+12|0)>>1]);n=d,o=Bb(y[a+14|0]|y[a+15|0]<<8),v[n+13|0]=o;n=d,o=Bb(y[a+16|0]|y[a+17|0]<<8),v[n+14|0]=o;n=d,o=Bb(y[a+20|0]|y[a+21|0]<<8),v[n+15|0]=o;n=d,o=Bb(y[a+22|0]|y[a+23|0]<<8),v[n+16|0]=o;i=x[d>>2];f=x[d+4>>2];b=y[d+12|0]&-2|lc(i,f)^1;v[d+12|0]=b;b=Bb(y[a+12|0]|y[a+13|0]<<8)>>>3&2|b&-3;v[d+12|0]=b;n=d,o=Bb(y[a+12|0]|y[a+13|0]<<8)>>>3&4|b&251,v[n+12|0]=o;b=4096;a:{b:{switch(c-1|0){case 0:j=-128;b=127;break a;case 1:break b;default:break a}}j=-1616;b=1616}d=b-j|0;k=d>>>1|0;m=Sd(i,f);b=0;while(1){if(b>>>0>=m>>>0){fb=e+16|0}else{f=yb(i,b);w[f>>1]=l;g=(b<<2)+a|0;c=xe((y[g+28|0]|y[g+29|0]<<8)<<16>>16)+j|0;h=c;c=c>>31<<6|c>>>26;h=k+(h<<6)|0;c=h>>>0<k>>>0?c+1|0:c;n=f,o=bh(Gc(pva(h,c,d,0),hb)),v[n+2|0]=o;n=e,o=Bb(y[g+26|0]|y[g+27|0]<<8),w[n+10>>1]=o;w[e+8>>1]=1;b=b+1|0;l=z[qe(e+10|0,e+8|0)>>1]+l|0;continue}break}}function gC(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a|0]=e;v[a+1|0]=e>>>8;v[a+2|0]=e>>>16;v[a+3|0]=e>>>24;v[a+4|0]=d;v[a+5|0]=d>>>8;v[a+6|0]=d>>>16;v[a+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[a+24|0]=e;v[a+25|0]=e>>>8;v[a+26|0]=e>>>16;v[a+27|0]=e>>>24;v[a+28|0]=d;v[a+29|0]=d>>>8;v[a+30|0]=d>>>16;v[a+31|0]=d>>>24;d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[a+16|0]=e;v[a+17|0]=e>>>8;v[a+18|0]=e>>>16;v[a+19|0]=e>>>24;v[a+20|0]=d;v[a+21|0]=d>>>8;v[a+22|0]=d>>>16;v[a+23|0]=d>>>24;d=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+8|0]=e;v[a+9|0]=e>>>8;v[a+10|0]=e>>>16;v[a+11|0]=e>>>24;v[a+12|0]=d;v[a+13|0]=d>>>8;v[a+14|0]=d>>>16;v[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function Hua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-32|0;fb=g;i=a+8|0;c=x[a+8>>2];h=nc(a);a:{if((c|0)!=x[h>>2]){break a}k=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){f=fb-16|0;fb=f;l=f+8|0;a=fb-32|0;fb=a;Id(a+24|0,d,c);m=a+16|0;c=x[a+24>>2];h=x[a+28>>2];j=((d-e>>1)+1|0)/-2<<1;d=d+j|0;e=fb-16|0;fb=e;while(1){if((c|0)!=(h|0)){d=h0(d,c)+2|0;c=c+2|0;continue}break}x[e+12>>2]=d;Ac(m,h,e+12|0);fb=e+16|0;c=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Ac(l,c,a+12|0);fb=a+32|0;fb=f+16|0;c=x[f+12>>2];x[i>>2]=c;x[k>>2]=x[k>>2]+j;break a}x[g+8>>2]=c-e;x[g+28>>2]=1;d=g+8|0;c=x[ad(d,g+28|0)>>2];c=ok(d,c,c>>>2|0,x[a+16>>2]);d=vb(g+4|0,x[a+4>>2]);e=x[vb(g,x[a+8>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;e=Ip(f,c+8|0,mE(d,e));d=x[e>>2];while(1){if(x[e+4>>2]!=(d|0)){j=d;d=x[f+12>>2];ij(j,y[d|0]|y[d+1|0]<<8);d=x[e>>2]+2|0;x[e>>2]=d;Md(f+12|0);continue}break}he(e);fb=f+16|0;Ub(a,c);Ub(k,c+4|0);Ub(i,c+8|0);Ub(h,nc(c));kj(c);c=x[a+8>>2]}ij(c,y[b|0]|y[b+1|0]<<8);x[i>>2]=x[i>>2]+2;fb=g+32|0}function Nta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-288|0;fb=e;tf(b);a:{if(!Mb(x[a>>2],x[a+8>>2],1)){break a}while(1){d=e+32|0;yo(e+8|0,d,Ar(d));kc(e+20|0,x[a>>2],x[a+8>>2],x[e+8>>2],x[e+12>>2]);x[e+28>>2]=x[e+24>>2];o=e,q=c-Yc(x[b+4>>2],y[b+11|0])|0,x[o+4>>2]=q;d=x[Gb(e+28|0,e+4|0)>>2];if(!d){break a}k=e+32|0;m=d+k|0;j=Mi(k,m,0);d=x[vb(e,Df(b))>>2];l=fb-16|0;fb=l;h=Hk(d,zd(b));b:{c:{d=k;f=Yj(d,j);d:{if(!f){zd(b);break d}if(!Lz(b,d)){i=Cb(x[b+4>>2],y[b+11|0]);g=Mc(b);e:{if(f>>>0<=g-i>>>0){g=Kb(b);if((h|0)==(i|0)){break e}n=h+g|0;Vi(f+n|0,n,i-h|0);break e}Xm(b,g,(f+i|0)-g|0,i,h,0,f);g=x[b>>2]}f=f+i|0;ng(b,f);fd(f+g|0,0);f=h+g|0;while(1){if((d|0)!=(j|0)){fd(f,y[d|0]);d=d+1|0;f=f+1|0;continue}break}Pe(zd(b),h);break d}d=ti(l+4|0,d,j);i=zd(d);g=Df(d);x[31725]=0;ha(366,b|0,f|0,h|0,i|0,g|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break c}tb(d)}fb=l+16|0;break b}a=N()|0;tb(d);Q(a|0);p()}Vb(a,j-k|0);if(j>>>0>=m>>>0){continue}break}Vb(a,1)}fb=e+288|0}function mna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=fb-16|0;fb=g;f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+72>>2];l=x[a+68>>2];s=l>>31;m=x[a+64>>2];t=m>>31;n=x[a+60>>2];u=n>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);i=ova(m,t,e,e>>31);j=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+38146>>1])+D(w[h-2>>1],w[e+38144>>1])|0)+D(w[h+2>>1],w[e+38148>>1])|0)+D(w[h+4>>1],w[e+38150>>1])|0)/16384<<8;e=h;e=ova(e,e>>31,n,u);i=e+i|0;k=hb+j|0;k=e>>>0>i>>>0?k+1|0:k;f=Yb(f,-16777216,16776704);e=ova(l,s,f,f>>31);j=e+i|0;f=hb+k|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,o);Pb(g+8|0,v,y);e=e-(h&r)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;fb=g+16|0}function cL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;q=a;i=fb-1040|0;fb=i;r=x[31600];a:{b:{a=i+16|0;l=z[((b>>>0<=153?b:0)<<1)+123456>>1]+121532|0;c=x[x[124231]+20>>2];if(c){j=x[c+4>>2];c=x[c>>2];e=x[c>>2]+1794895138|0;h=Jm(x[c+8>>2],e);f=Jm(x[c+12>>2],e);d=Jm(x[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}s=d>>>2|0;t=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+t<<2)|0;o=Jm(x[d>>2],e);d=Jm(x[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|y[c+(d+o|0)|0]){break c}d=oi(l,c+d|0);if(!d){f=c+(s+n<<2)|0;h=Jm(x[f>>2],e);e=Jm(x[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=y[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=Cf(g);d:{if(c>>>0>=1024){yc(a,g,1023);v[a+1023|0]=0;g=68;break d}yc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=22255}break a}va();p()}if(!y[a|0]){x[i>>2]=b;a=i+16|0;Hy(a,1024,13075,i)}x[31600]=r;Dc(q,a);fb=i+1040|0}function CD(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+15|0]=c;e=a;a:{b:{c:{switch(b-14|0){case 0:b=14;if(!c){break b}d:{if((c|0)!=15){if((c|0)!=240){break d}v[d+15|0]=239;break b}v[d+15|0]=254;break b}if(c>>>0>=16){v[d+15|0]=c|15;break b}v[d+15|0]=c|240;break b;case 1:v[d+15|0]=c^128;b=15;break b;case 6:case 7:if(c>>>0>=16){v[d+15|0]=c>>>4|240;break b}v[d+15|0]=c|224;break b;case 8:v[d+15|0]=((c^-1)&254)>>>1;b=22;break b;case 9:v[d+15|0]=c&15|128;b=23;break b;case 17:f=d,g=bh(c<<1),v[f+15|0]=g;b=31;break b;case 19:a=32;b=33;e:{f:{switch(c>>>4|0){default:b=0;break b;case 8:a=64;break e;case 10:a=176;break e;case 11:a=224;break e;case 12:case 13:b=c?33:0;break b;case 14:g:{switch(c&15){case 0:v[d+15|0]=119;break b;case 1:v[d+15|0]=119;break b;case 2:v[d+15|0]=121;break b;case 3:break g;default:break b}}v[d+15|0]=123;break b;case 3:break e;case 5:break f;case 0:break b}}a=48}v[d+15|0]=c&15|a;break b;default:break c}}a=0;if(b>>>0>35){break a}}a=y[b+24976|0]}de(e,a,d+15|0);fb=d+16|0}function Ak(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;x[i+8>>2]=c;x[i+12>>2]=b;bd(i+4|0,x[d+28>>2]);c=0;x[31725]=0;j=R(28,x[i+4>>2])|0;b=x[31725];x[31725]=0;if((b|0)!=1){Zb(i+4|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(uh(i+12|0,i+8|0)){break b}c:{if((tl(j,v[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=tl(j,v[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=tl(j,v[g+2|0])}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,b,k)|0,x[l+12>>2]=m;g=c+2|0;break c}b=x[j+8>>2];if(Kf(b,1,v[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(Kf(b,1,v[g|0])){continue}}break}while(1){if(uh(i+12|0,i+8|0)){break c}b=Cl(x[i+12>>2]);if(!Kf(x[j+8>>2],1,b)){break c}Lm(i+12|0);continue}}if((zy(j,Cl(x[i+12>>2]))|0)==(zy(j,v[g|0])|0)){g=g+1|0;Lm(i+12|0);break c}x[e>>2]=4}c=x[e>>2];continue}break}x[e>>2]=4}if(uh(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}fb=i+16|0;return x[i+12>>2]}a=N()|0;Zb(i+4|0);Q(a|0);p()}function Oua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-144|0;fb=f;x[31725]=0;l=R(275,a|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){while(1){a:{if((j&65535)>>>0>=l>>>0){ub(a);fb=f+144|0;return}x[31725]=0;O(294,a|0,f+8|0);e=x[31725];x[31725]=0;if((e|0)!=1){b:{e=Bb(z[f+8>>1]);if((e-1&65535)>>>0>=z[c+480192>>1]){break b}e=x[((e<<2)+c|0)+900380>>2];if(!e){break b}e=_h(e,b);g=y[f+11|0];c:{if(!g){break c}h=y[f+10|0];if(h&1){v[e+12|0]=y[e+12|0]|1}if(h&2){v[e+12|0]=y[e+12|0]|4}if(!(h&4)){break c}v[e+12|0]=y[e+12|0]|2}v[f+4|0]=g;v[f+7|0]=31;h=y[Rb(f+4|0,f+7|0)|0];x[31725]=0;h=h+1&255;O(295,e|0,h|0);g=x[31725];x[31725]=0;if((g|0)==1){break a}v[e+13|0]=y[f+13|0];v[e+14|0]=y[f+14|0];g=y[f+12|0];v[e+15|0]=g;v[e+16|0]=g;g=x[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;m=Bb(z[i+8>>1]);k=yb(g,e);w[k>>1]=m;i=Bb(z[i+10>>1]);w[f+4>>1]=d?i+128>>>2|0:i;Gf(f+4|0,64);v[k+2|0]=y[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=N()|0;ub(a);Q(b|0);p()}function nna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];j=x[a+68>>2];r=j>>31;k=x[a+64>>2];s=k>>31;l=x[a+60>>2];t=l>>31;u=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=ova(k,s,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=ova(j,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;m=(((D(v[g|0],w[e+38146>>1])+D(v[g-1|0],w[e+38144>>1])|0)+D(v[g+1|0],w[e+38148>>1])|0)+D(v[g+2|0],w[e+38150>>1])<<8)/16384<<8;e=m;g=ova(e,e>>31,l,t);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,y);f=f-(q&m)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function Oba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(A[a+4>>2]<A[zb(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+24;lN(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+24;hc(c);fb=d+16|0;return}i=fb-32|0;fb=i;c=zb(a);c=LJ(i+12|0,OJ(a,pj(x[a>>2],x[a+4>>2])+1|0),pj(x[a>>2],x[a+4>>2]),c);lN(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+24;g=fb-16|0;fb=g;d=vb(g+12|0,x[a+4>>2]);e=vb(g+8|0,x[a>>2]);f=x[vb(g+4|0,x[c+4>>2])>>2];h=fb-16|0;fb=h;b=fb-32|0;fb=b;Id(b+24|0,x[d>>2],x[e>>2]);k=b+16|0;e=x[b+24>>2];l=x[b+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=f;x[d+12>>2]=e;while(1){if(pd(e,l)){e=ql(e);f=ql(x[d+8>>2]);x[f+16>>2]=x[e+16>>2];j=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=j;j=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=j;e=$s(d+12|0);$s(d+8|0);e=x[e>>2];continue}break}Ac(k,e,d+8|0);fb=d+16|0;d=x[b+16>>2];x[b+12>>2]=x[b+20>>2];Ac(h+8|0,d,b+12|0);fb=b+32|0;fb=h+16|0;x[c+4>>2]=x[h+12>>2];Ub(a,c+4|0);Ub(a+4|0,c+8|0);Ub(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;JJ(c);fb=i+32|0}function Jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];v=w[b+4>>1];y=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=(i<<1)+p|0;x[(i<<2)+e>>2]=(((((D(w[f+8>>1],s)+D(w[f+4>>1],t)|0)+D(w[f+12>>1],r)|0)+D(w[f+16>>1],q)|0)/2|0)+((((D(w[f-8>>1],y)+D(w[f-12>>1],b)|0)+D(w[f-4>>1],v)|0)+D(w[f>>1],u)|0)/2|0)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Pb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function O8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}bd(g,x[d+28>>2]);x[31725]=0;b=R(1217,x[g>>2])|0;a=x[31725];x[31725]=0;d:{e:{f:{g:{if((a|0)!=1){Zb(g);bd(g,x[d+28>>2]);x[31725]=0;a=R(1218,x[g>>2])|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}Zb(g);x[31725]=0;O(1219,g|0,a|0);d=x[31725];x[31725]=0;if((d|0)==1){b=N()|0;break d}x[31725]=0;O(1220,g|12,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break f}x[31725]=0;d=g+24|0;a=sa(1221,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=Qb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Zb(g);break d}b=N()|0;Zb(g);break d}b=N()|0;Qb(g);break d}b=N()|0;while(1){d=Qb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}fb=g+32|0;return b|0}function Di(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=uj(a)&2047;c=uj(5551115123125783e-32);a:{if(e-c>>>0>=uj(512)-c>>>0){if(c>>>0>e>>>0){return a+1}o(+a);c=j(1)|0;d=j(0)|0;b:{if(uj(1024)>>>0>e>>>0){break b}b=0;if(!d&(c|0)==-1048576){break a}if(uj(Infinity)>>>0<=e>>>0){return a+1}if((c|0)>0|(c|0)>=0){return Qs(3105036184601418e216)}if(c>>>0<3230714880){break b}return Qs(12882297539194267e-247)}c=c<<1|d>>>31;e=!(d<<1)&(c|0)==-2129002496|c>>>0<2165964800?e:0}b=C[177];f=b+a;a=a-(f-b);b=a*a;g=b*b*(a*C[182]+C[181]);b=b*(a*C[180]+C[179]);a=a*C[178];o(+f);j(1)|0;i=j(0)|0;d=i<<4&2032;a=g+(b+(a+C[d+1464>>3]));d=d+1472|0;h=x[d>>2];c=x[d+4>>2];d=h;h=0;d=d+h|0;c=(i<<13)+c|0;c=d>>>0<h>>>0?c+1|0:c;if(!e){c:{if(!(i&-2147483648)){l(0,d|0);l(1,c+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){gJ(PJ()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function Z8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}bd(g,x[d+28>>2]);x[31725]=0;b=R(28,x[g>>2])|0;a=x[31725];x[31725]=0;d:{e:{f:{g:{if((a|0)!=1){Zb(g);bd(g,x[d+28>>2]);x[31725]=0;a=R(1201,x[g>>2])|0;d=x[31725];x[31725]=0;if((d|0)==1){break g}Zb(g);x[31725]=0;O(1202,g|0,a|0);d=x[31725];x[31725]=0;if((d|0)==1){b=N()|0;break d}x[31725]=0;O(1203,g|12,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break f}x[31725]=0;d=g+24|0;a=sa(1204,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Zb(g);break d}b=N()|0;Zb(g);break d}b=N()|0;tb(g);break d}b=N()|0;while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}fb=g+32|0;return b|0}function Lra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=Lv(c,d);d=b&63;if(e>>>0>d>>>0){c=iZ(c,d);d=0;g=fb-16|0;fb=g;v[a+12|0]=0;Nf(a);e=fb-32|0;fb=e;a:{b:{if(Ug(a)>>>0<=14){if(Lh(1073741823)>>>0<=14){break b}f=zb(a);f=$f(e+12|0,15,oc(x[a>>2],x[a+4>>2]),f);bs(a,f);_f(f)}fb=e+32|0;break a}dd();p()}h=0-y[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=c+(d<<1)|0;f=y[e+1|0];if(!f){break c}v[g+11|0]=64;h=f+(h<<16>>16)|0;f=fm(g+12|0,h&65535,y[Rb(e+2|0,g+11|0)|0]);d:{if(A[a+4>>2]<A[zb(a)>>2]){eZ(a,f);break d}i=fb-32|0;fb=i;e=zb(a);e=$f(i+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),e);ip(x[e+8>>2],z[f>>1]|z[f+2>>1]<<16);x[e+8>>2]=x[e+8>>2]+4;bs(a,e);_f(e);fb=i+32|0}d=d+1|0;continue}break}d=y[c+32|0];v[a+14|0]=d>>>4;v[a+13|0]=d&15;c=y[c+31|0];d=c&15;v[a+15|0]=d;v[a+16|0]=d;if(c&16){v[a+12|0]=y[a+12|0]|4}if(c&32){v[a+12|0]=y[a+12|0]|2}fb=g+16|0}e:{if(b<<24>>24>=0){c=y[a+12|0]&-2;a=a+12|0;break e}c=y[a+12|0]&-2|lc(x[a>>2],x[a+4>>2])^1;a=a+12|0}v[a|0]=c}function zk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;x[i+8>>2]=c;x[i+12>>2]=b;bd(i+4|0,x[d+28>>2]);b=0;x[31725]=0;j=R(1217,x[i+4>>2])|0;c=x[31725];x[31725]=0;if((c|0)!=1){Zb(i+4|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(mi(i+12|0,i+8|0)){break b}c:{if((yk(j,x[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}d:{e:{c=yk(j,x[b>>2]);if((c|0)==69){break e}k=0;if((c&255)==48){break e}b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=yk(j,x[g+8>>2])}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,c,k)|0,x[l+12>>2]=m;g=b+8|0;break c}if(zj(j,1,x[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(zj(j,1,x[g>>2])){continue}}break}while(1){if(mi(i+12|0,i+8|0)){break c}if(!zj(j,1,Bl(x[i+12>>2]))){break c}oo(i+12|0);continue}}if((rm(j,Bl(x[i+12>>2]))|0)==(rm(j,x[g>>2])|0)){g=g+4|0;oo(i+12|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(mi(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}fb=i+16|0;return x[i+12>>2]}a=N()|0;Zb(i+4|0);Q(a|0);p()}function hma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-16|0;fb=g;x[g+12>>2]=1;a:{if(cp(a)){c=x[a>>2];k=Lg(c,x[a+4>>2]);x[g+8>>2]=k;l=x[Gb(g+12|0,g+8|0)>>2];while(1){if(l){l=l-1|0;if((b|0)!=(c|0)){i=wb(x[b>>2]);e=wb(x[b+4>>2]);f=fb-16|0;fb=f;h=mE(i,e);b:{if(h>>>0<=Pn(c)>>>0){x[f+12>>2]=e;m=x[c>>2];d=Zc(m,x[c+4>>2]);n=d>>>0>=h>>>0;if(n){d=e}else{x[f+12>>2]=i;iV(f+12|0,d);d=x[f+12>>2]}j=fb-16|0;fb=j;kV(j+8|0,i,d,m);d=x[j+12>>2];fb=j+16|0;if(!n){mV(c,x[f+12>>2],e,h-Zc(x[c>>2],x[c+4>>2])|0);break b}Kn(c,d);break b}lV(c);GC(c,pk(c,h));mV(c,i,e,h)}fb=f+16|0;us(c+12|0,b+12|0);w[c+28>>1]=z[b+28>>1]}c=c+32|0;continue}break}if(!k){ZB(a,1-k|0,b);break a}bV(a,x[a>>2]+32|0);break a}if(x[a>>2]){eV(a);e=x[a>>2];cp(a);Db(e);o=zb(a),q=0,x[o>>2]=q;x[a>>2]=0;x[a+4>>2]=0}d=ar(a,1);e=fb-16|0;fb=e;if(Lh(134217727)>>>0<d>>>0){dd();p()}XV(e+8|0,d);d=x[e+8>>2];x[a+4>>2]=d;x[a>>2]=d;o=zb(a),q=d+(x[e+12>>2]<<5)|0,x[o>>2]=q;fb=e+16|0;ZB(a,1,b)}fb=g+16|0}function wx(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=c<<4|b>>>28;c=d<<4|c>>>28;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){f=c+1073741824|0;e=e+1|0;f=e?f:f+1|0;break a}f=c+1073741824|0;if(a|(b|0)!=134217728){break a}a=e&1;e=a+e|0;f=a>>>0>e>>>0?f+1|0:f;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){a=d<<4|c>>>28;e=c<<4|b>>>28;f=a&524287|2146959360;break a}e=0;f=2146435072;if(h>>>0>1140785151){break a}f=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;bg(g+16|0,a,b,c,e,h-15233|0);gn(g,a,b,c,e,15361-h|0);b=x[g+8>>2];e=b<<4;b=x[g+12>>2]<<4|b>>>28;c=x[g>>2];f=x[g+4>>2];h=f;e=f>>>28|e;f=b;a=h&268435455;b=c|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){e=e+1|0;f=e?f:f+1|0;break a}if(b|(a|0)!=134217728){break a}a=e;e=e+(e&1)|0;f=a>>>0>e>>>0?f+1|0:f}fb=g+32|0;l(0,e|0);l(1,d&-2147483648|f);return+n()}function Hf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;c=x[a+36>>2];kg(x[x[c>>2]-12>>2]+c|0,0);c=a+32|0;Pc(d+12|0,c,4);if(!Hb(x[x[d+12>>2]>>2],x[d+16>>2])){oy(a)}a:{if(!x[a+8>>2]){break a}Pc(d+12|0,c,6);if(Hb(x[x[d+12>>2]>>2],x[d+16>>2])){break a}Pc(d+24|0,c,7);if(Hb(x[x[d+24>>2]>>2],x[d+28>>2])){break a}f=x[a+36>>2];e=x[a+92>>2];g=D(x[a+28>>2],x[a+8>>2]);h=g;g=g+x[a+88>>2]|0;e=h>>>0>g>>>0?e+1|0:e;Ii(f,g,e,0)}Pc(d+12|0,c,5);c=0;b:{if(!Hb(x[x[d+12>>2]>>2],x[d+16>>2])){break b}e=pj(x[a+52>>2],x[a+56>>2]);while(1){if((e|0)==(i|0)){break b}g=(x[a+108>>2]+i>>>0)%(e>>>0)|0;h=wf(x[a+52>>2],g);f=x[h>>2];c:{j=x[a+40>>2];if(Sc(j,x[a+44>>2])>>>0<=f>>>0){break c}f=yl(d+12|0,xb(j,f),z[h+20>>1]);h=Fy(b,f);Eb(f);if(!h){break c}b=g+1|0;x[a+108>>2]=(b|0)!=(e|0)?b:0;c=wf(x[a+52>>2],g);b=x[c+8>>2];e=x[c+12>>2];if(!(b|e)){break b}f=x[a+16>>2];c=f+b|0;b=x[a+20>>2]+e|0;Ii(x[a+36>>2],c,c>>>0<f>>>0?b+1|0:b,0);c=wf(x[a+52>>2],g);break b}i=i+1|0;continue}}fb=d+32|0;return c}function qq(a,b,c,d,e,f){var g=E(0),h=0,i=E(0),j=0,k=E(0),l=E(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=B[f>>2];k=B[c>>2];l=B[d>>2];B[c>>2]=k+l;h=c-4|0;g=B[h>>2];B[h>>2]=g+B[f>>2];k=E(k-l);g=E(g-i);B[d>>2]=E(k*B[e>>2])-E(B[e+4>>2]*g);B[f>>2]=E(g*B[e>>2])+E(k*B[e+4>>2]);f=d-12|0;k=B[f>>2];h=c-8|0;g=B[h>>2];j=h;h=d-8|0;l=B[h>>2];B[j>>2]=g+l;j=c-12|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-20|0;k=B[f>>2];h=c-16|0;g=B[h>>2];j=h;h=d-16|0;l=B[h>>2];B[j>>2]=g+l;j=c-20|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-28|0;k=B[f>>2];h=c-24|0;g=B[h>>2];j=h;h=d-24|0;l=B[h>>2];B[j>>2]=g+l;j=c-28|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function rba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Zf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(g>>>0<=d>>>0){if(g>>>0>A[c+20>>2]){break d}if(f>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(f>>>0>x[c+24>>2]-h>>>0){break b}i=b+12|0;j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(f|0)){break a}l=b+h|0;m=D(b,d);a=0;while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{e=x[(a+m<<2)+k>>2];n=Xt(i);o=x[(a<<2)+j>>2]+(l<<1)|0;e=qd((qd(n,21)+e|0)+2048|0,12);e=(e|0)>=32767?32767:e;w[o>>1]=(e|0)<=-32768?-32768:e;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function HH(a,b,c){var d=0,e=0,f=0;e=fb-32|0;fb=e;a:{f=Ts(e+28|0,b);d=x[f>>2];if(!Dd(d)){x[31725]=0;b=P(36,e+4|0,b|0)|0;a=x[31725];x[31725]=0;b:{c:{d:{if((a|0)!=1){x[31725]=0;S(1017,e+16|0,17691,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}x[31725]=0;W(1345,e+16|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}p()}a=N()|0;break a}a=N()|0;break b}a=N()|0;tb(e+16|0)}tb(b);break a}kq(d);if(!Ss(a+8|0,22255,x[f>>2])){v[a+8|0]=127}if(!Ss(a+9|0,22255,x[f>>2])){v[a+9|0]=127}x[31725]=0;O(274,a+12|0,22255);b=x[31725];x[31725]=0;e:{f:{if((b|0)==1){break f}x[31725]=0;b=a+24|0;O(274,b|0,22255);d=x[31725];x[31725]=0;if((d|0)==1){break f}x[a+60>>2]=0;x[31725]=0;O(274,a+36|0,22255);d=x[31725];x[31725]=0;if((d|0)==1){break f}x[31725]=0;O(274,a+48|0,22255);d=x[31725];x[31725]=0;if((d|0)==1){break f}x[31725]=0;b=P(72,e+16|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break e}a=N()|0;break a}a=N()|0;break a}ii(a- -64|0,c);ii(a+68|0,c);tb(b);pl(f);fb=e+32|0;return}pl(f);Q(a|0);p()}function lua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-2608|0;fb=f;d=aE(f+4|0,a);x[d+1060>>2]=0;x[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){v[a+4|0]=0;w[a>>1]=0;w[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}x[31725]=0;W(325,d|0);a=x[31725];x[31725]=0;a:{b:{if((a|0)!=1){if((w[d+1068>>1]|w[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}x[31725]=0;j=P(160,d|0,1)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}a=0;d:{while(1){x[31725]=0;k=P(160,d|0,1)|0;e=x[31725];x[31725]=0;if((e|0)==1){break d}a=w[(d+D(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+D(a,6)|0;h=y[e+1072|0];if(w[e+1068>>1]<0){break e}if(w[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;v[b+g|0]=i;g=g+1|0;continue}break}a=T(28848)|0;break b}a=T(28848)|0;break b}a=T(28848)|0}if((gb|0)==($(28848)|0)){Y(a|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0}ub(d);Q(a|0);p()}a=Ir(d);ub(d);fb=f+2608|0;return a|0}function aA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0);c=fb-48|0;fb=c;a:{b=x[a+20>>2];b:{if(!b){break b}d=x[b+4>>2];b=x[b+8>>2];if(Sc(d,b)>>>0<4){break b}oe(c+16|0,d,b);b=Nd(c+8|0);d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=m$(c+28|0,x[c+16>>2],x[c+20>>2],c);x[31725]=0;b=R(153,d|0)|0;f=x[31725];x[31725]=0;c:{if((f|0)!=1){if(b){break c}b=x[x[a>>2]+40>>2];x[31725]=0;f=R(b|0,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}b=x[a+20>>2];if(Sc(x[b+4>>2],x[b+8>>2])-4>>>0<f<<2>>>0){break c}e=x[x[a>>2]+176>>2];b=0;x[31725]=0;O(e|0,a|0,-1);e=x[31725];x[31725]=0;if((e|0)==1){break a}while(1){if((b|0)==(f|0)){b=x[x[a>>2]+180>>2];x[31725]=0;W(b|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}x[31725]=0;g=E(xa(475,d|0));e=x[31725];x[31725]=0;d:{if((e|0)==1){break d}e=x[x[a>>2]+44>>2];x[31725]=0;wa(e|0,a|0,b|0,E(an(g)?g:E(0)));e=x[31725];x[31725]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}ub(d)}fb=c+48|0;return}a=N()|0;ub(d);Q(a|0);p()}function vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=Gg(j,k,l);n=hb;f=x[a+76>>2];hg(b,g,vf(j,k,d),hb);o=hb>>>0>f>>>0?d:0}f=a+112|0;h=x[a+40>>2];i=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;o=o-1|0;b=o;m=b?m:0;n=b?n:0;g=(g<<1)+p|0;b=l;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(f,w[g+(x[e+12>>2]<<1)>>1]/4<<16>>16);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,q);g=x[a+32>>2];i=x[a+28>>2]+i|0;x[c>>2]=x[c>>2]+D(b,i>>12);h=g+h|0;x[c+4>>2]=x[c+4>>2]+D(b,h>>12);Pb(e,j,k);c=c+8|0;b=x[e>>2];g=x[e+4>>2];continue a}else{be(f,w[g+(x[e+12>>2]<<1)>>1]/4<<16>>16);ae(f,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;fb=e+16|0}function vV(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=E(0),l=0,m=0,n=0;if(Uj(x[a+656>>2])){e=y[a+797|0];e=(l=e,m=y[a+799|0],n=Tc(e),n?l:m);f=Ob(d+1074312|0,34);d=x[a+656>>2];a:{if(!f){break a}f=e&255;if(!f|f>>>0>120){break a}e=y[xb(d+108|0,(e&255)-1|0)|0]}k=E(E(x[a+704>>2])*b);d=x[d+44>>2];g=((e&255)+c|0)-61<<16>>16;b:{c:{c=x[a+852>>2]+w[a+772>>1]|0;if(c){h=x[d+36>>2];if(h){break c}}b=bn(d,c+g<<16>>16);break b}j=h+1|0;i=gA(c,j);e=hA(c,j);b=E(1);f=w[d+28>>1];c=g+i<<16>>16;d:{if((f|0)>(c|0)){break d}g=x[d+4>>2];if((c|0)>(oc(g,x[d+8>>2])+f|0)-1<<16>>16){break d}if(!e){b=B[yb(g,c-f|0)>>2];break b}e:{f:{g:{switch(z[d>>1]-1|0){case 2:h=x[d+16>>2];if(!oc(h,x[d+20>>2])){break f}b=B[yb(h,e-1|0)>>2];break e;case 0:break g;default:break f}}i=x[d+16>>2];if(!oc(i,x[d+20>>2])){break f}b=B[yb(i,(e+D(h,lA(c,z[d+30>>1])<<16>>16)|0)-1|0)>>2];break e}b=De(E(bn(d,c+1<<16>>16)/bn(d,c)),E(E(e|0)/E(j|0)))}b=E(b*B[yb(g,c-f|0)>>2])}}l=a,m=Jk(E(E(k*b)*E(16))),x[l+700>>2]=m}}function Jz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;a:{b:{c:{d:{e:{f:{g:{e=x[a+36>>2];c=x[a+40>>2];h:{if(Ib(e,c)){sc(d+12|0);break h}Bo(d,a);x[31725]=0;c=R(1062,d|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}x[d+12>>2]=c;of(d);c=x[a+40>>2];e=x[a+36>>2]}e=(h=a+36|0,i=x[d+12>>2],j=Ib(e,c),j?h:i);if((b|0)==-1){f=x[e>>2];g=4194304;c=0;break e}if((b|0)>=0){c=b;f=x[e>>2];if((pj(f,x[e+4>>2])|0)>(b|0)){break e}}b=ac(8);x[31725]=0;c=P(36,d|0,10966)|0;a=x[31725];x[31725]=0;if((a|0)==1){break f}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}a=N()|0;tb(c);break d}a=N()|0;of(d);break c}a=N()|0;jc(b);break d}x[a+8>>2]=b;b=x[a+24>>2];x[b+480208>>2]=x[b+480208>>2]&-4194305|g;ek(b+484360|0,y[wf(f,c)+16|0]);b=wf(x[e>>2],c);c=x[b+8>>2];b=x[b+12>>2];x[31725]=0;+oa(1094,a|0,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}a=N()|0}Gl(d+12|0)}Q(a|0)}p()}x[a+16>>2]=0;x[a+20>>2]=0;Gl(d+12|0);fb=d+16|0}function iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb+-64|0;fb=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Zf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(f>>>0<=d>>>0){h=x[c+20>>2];if(f>>>0>h>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(e>>>0>x[c+24>>2]-i>>>0){break b}j=b+12|0;k=x[c+16>>2];l=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}m=D(b,d);n=D(b+i|0,h);a=0;while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=qd((x[(a+m<<2)+l>>2]+qd(Xt(j),21)|0)+2048|0,12);g=(g|0)>=32767?32767:g;w[(a+n<<1)+k>>1]=(g|0)<=-32768?-32768:g;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function Kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];y=w[b+4>>1];z=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=i+p|0;x[(i<<2)+e>>2]=((((D(v[f+4|0],s)+D(v[f+2|0],t)|0)+D(v[f+6|0],r)|0)+D(v[f+8|0],q)<<8>>1)+(((D(v[f-4|0],z)+D(v[f-6|0],b)|0)+D(v[f-2|0],y)|0)+D(v[f|0],u)<<8>>1)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Pb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function dJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;b=x[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=x[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=x[a+8>>2];if((g-f|0)<=0){break a}x[a+8>>2]=f+1;v[f|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}c=x[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if((f|0)<4){break b}x[a+8>>2]=c+1;v[c|0]=b>>>18|240;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>12&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}b=x[a+12>>2]+4|0;x[a+12>>2]=b;continue}break}c=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return c|0}function Rta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;ld(b,32);g=b,h=$b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24)),x[g>>2]=h;f=$b(y[a+10|0]|y[a+11|0]<<8|(y[a+12|0]<<16|y[a+13|0]<<24));x[b+4>>2]=f;g=b,h=$b(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))+f|0,x[g+8>>2]=h;if(!(d?0:c)){c=$b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))}x[b+24>>2]=c;c=y[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Bb(y[a+42|0]|y[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}hm(b,+(c|0)*.0006510416666666666);v[e+15|0]=y[a+9|0];v[e+14|0]=64;g=b,h=y[Rb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;c=x[b+4>>2];d=x[b+8>>2];if(v[a+40|0]&1){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;w[b+34>>1]=z[b+34>>1]|64;x[b>>2]=x[b>>2]>>>1}if(y[a+41|0]>=9){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1}b:{if(c+1>>>0<d>>>0){w[b+34>>1]=z[b+34>>1]|2;break b}x[b+4>>2]=0;x[b+8>>2]=0}fb=e+16|0}function vA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=fb-16|0;fb=d;f=y[a+2|0];if(!(!f|(f|0)==255)){x[d+12>>2]=f+1;x[d+8>>2]=10;hh(b,x[ud(d+12|0,d+8|0)>>2]);i=y[a+3|0];v[b+15|0]=i;v[b+16|0]=i;j=y[a+4|0];v[b+13|0]=j;l=y[a+5|0];v[b+14|0]=l;f=511;a:{b:{switch(c-1|0){case 1:e=4096;f=128;break a;case 0:break b;default:break a}}e=32768;f=1024}o=f>>>1|e;c=x[b>>2];k=Sd(c,x[b+4>>2]);e=0;c:{while(1){if((e|0)==(k|0)){d:{c=y[b+12|0]&-2|v[a|0]&1;v[b+12|0]=c;if(y[a|0]&2){break d}c=c&251;break c}}else{m=yb(c,e);h=(e<<2)+a|0;g=(y[h+6|0]|y[h+7|0]<<8)>>>4|0;w[m>>1]=g;e:{if(e){n=z[yb(c,e-1|0)>>1];if(g>>>0>=n>>>0){break e}g=n+1|0}else{g=0}p=yb(c,e),q=g,w[p>>1]=q}x[d+12>>2]=(((y[h+8|0]|y[h+9|0]<<8)<<16>>16)+o|0)/(f|0);x[d+8>>2]=0;x[d+4>>2]=64;p=m,q=x[hk(d+12|0,d+8|0,d+4|0)>>2],v[p+2|0]=q;e=e+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}v[b+12|0]=c;if(j>>>0<=l>>>0?y[a|0]&4:0){a=c&-3|(k>>>0>=j>>>0)<<1}else{a=c&253}v[b+12|0]=a}fb=d+16|0}function lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];c=qk(d,x[a+4>>2]);if(c>>>0<b>>>0){g=fb-32|0;fb=g;f=b-c|0;b=x[zb(a)>>2];c=x[a+4>>2];a:{if(f>>>0<=b-c>>11>>>0){c=fb-16|0;fb=c;b=c+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(f<<11);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{uu(a);a=a+2048|0;x[b+4>>2]=a;continue}break}break a}h=zb(a);i=g+12|0;b=a;e=qk(x[a>>2],c)+f|0;c=fb-16|0;fb=c;x[c+12>>2]=e;d=fb-16|0;fb=d;x[d+12>>2]=2097151;x[d+8>>2]=2147483647;a=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(a>>>0>=e>>>0){d=cA(b);if(d>>>0<a>>>1>>>0){x[c+8>>2]=d<<1;a=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}dd();p()}d=ZQ(i,a,qk(x[b>>2],x[b+4>>2]),h);c=d;e=fb-16|0;fb=e;a=e+4|0;x[a>>2]=x[c+8>>2];h=x[c+8>>2];x[a+8>>2]=c+8;x[a+4>>2]=h+(f<<11);c=x[a>>2];while(1){if(x[a+4>>2]!=(c|0)){uu(c);c=x[a>>2]+2048|0;x[a>>2]=c;continue}break}he(a);fb=e+16|0;YQ(b,d);XQ(d)}fb=g+32|0;return}if(b>>>0<c>>>0){TQ(a,d+(b<<11)|0)}}function qy(a,b,c,d,e,f,g,h,i,j,k,l){var m=0,n=0;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Cb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Cb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=ty(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=v[(a>>2)+111728|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=x[e>>2];if((a|0)!=(d|0)){f=-1;if((Al(v[a-1|0])|0)!=(Al(v[c|0])|0)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0}v[c|0]=80;break d}d=Al(g);if((d|0)!=v[c|0]){break d}m=c,n=zt(d),v[m|0]=n;if(!y[b|0]){break d}v[b|0]=0;if(!Cb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>84){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function vy(a,b,c,d,e,f,g,h,i,j,k,l){var m=0,n=0;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Cb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Cb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=Mi(l,l+32|0,a)-l|0;if((a|0)>31){break b}g=v[a+111728|0];d:{e:{switch((a&-2)-22|0){case 2:a=x[e>>2];if((a|0)!=(d|0)){if((Al(v[a-1|0])|0)!=(Al(v[c|0])|0)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0;case 0:v[c|0]=80;break d;default:break e}}d=Al(g);if((d|0)!=v[c|0]){break d}m=c,n=zt(d),v[m|0]=n;if(!y[b|0]){break d}v[b|0]=0;if(!Cb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>21){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function Cc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=x[b>>2];e=fb-48|0;fb=e;f=x[b+4>>2];b=y[b+8|0];d=f-(((b|0)==1|(b|0)==4)&(f|0)!=0)|0;f=Fb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){a=Mi(c,c+d|0,0);x[31725]=0;U(71,f|0,c|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break h}a=N()|0;break b}if((b-3&255)>>>0>1){break h}x[31725]=0;b=U(71,f|0,c|0,c+d|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break g}c=zd(b);d=Df(b);g=zd(b);a=fb-16|0;fb=a;x[a+8>>2]=g;x[a+12>>2]=c;while(1){if(Ib(c,d)){c=v[c|0];v[x[a+8>>2]]=c?c:32;c=me(a+12|0);me(a+8|0);c=x[c>>2];continue}break}fb=a+16|0;x[31725]=0;c=P(72,e+24|0,b|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break f}x[31725]=0;d=P(36,e+12|0,18429)|0;a=x[31725];x[31725]=0;if((a|0)==1){break e}x[31725]=0;S(73,e+36|0,c|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}a=e+36|0;Ab(b,a);tb(a);tb(d);tb(c)}fb=e+48|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d)}tb(c)}tb(f);Q(a|0);p()}}function zr(a){var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=x[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(z[a+480192>>1]){break a}c=wb(x[a+484344>>2]);x[e+12>>2]=c;a=wb(x[a+484348>>2]);while(1){if(!Ib(c,a)){d=1;break a}if(!(!Ib(x[c>>2],x[c+4>>2])|x[c+12>>2]==64)){break a}c=x[bm(e+12|0)>>2];continue}}d=16777216;break a}d=32;f=z[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(v[b+480281|0]&1){break a}c=c+1|0;if(z[b+480286>>1]==64){continue}break}break a}d=2}fb=e+16|0;return d}function P2(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-48|0;fb=b;e=Fb(a);x[31725]=0;a=ca(119)|0;c=x[31725];x[31725]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}x[31725]=0;c=P(1,b+24|0,8963)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;a=ca(119)|0;d=x[31725];x[31725]=0;e:{f:{g:{h:{if((d|0)==1){break h}x[31725]=0;x[b+8>>2]=a;O(128,b+12|0,b+8|0);a=x[31725];x[31725]=0;if((a|0)==1){break h}x[31725]=0;S(2,b+36|0,c|0,b+12|0);a=x[31725];x[31725]=0;if((a|0)==1){break g}d=b+36|0;a=Ab(e,d);tb(d);tb(b+12|0);tb(c);x[31725]=0;c=ca(121)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}if(!c){break e}x[31725]=0;P(129,a|0,17525)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break e}break b}a=N()|0;break f}a=N()|0;tb(b+12|0)}tb(c);break a}x[31725]=0;c=ca(120)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}if(!c){break d}x[31725]=0;P(129,a|0,16811)|0;a=x[31725];x[31725]=0;if((a|0)==1){break b}}fb=b+48|0;return}a=N()|0;break a}a=N()|0}tb(e);Q(a|0);p()}function rz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{l=Ee(Ig(C[(a+k<<3)+i>>3])*134217728);m=x[(a<<2)+h>>2]+(j<<2)|0,n=E(+(Cn(l)|0)*7.450580596923828e-9),B[m>>2]=n;a=a+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=c- -64|0}function Hba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;h=g+4|0;e=fb-160|0;fb=e;d=e+24|0;f=d+56|0;c=Ot(f);x[d>>2]=94156;x[c>>2]=94176;x[d+56>>2]=94216;x[d>>2]=94196;i=f;f=d+4|0;to(i,f);x[d>>2]=94156;x[c>>2]=94176;c=Kt(f);x[c>>2]=93640;Fb(c+32|0);x[c+44>>2]=0;x[c+48>>2]=16;c=x[x[d>>2]-12>>2];x[31725]=0;f=ca(106)|0;i=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{if((i|0)==1){break f}x[31725]=0;S(107,e+20|0,c+d|0,f|0);c=x[31725];x[31725]=0;if((c|0)==1){break f}Zb(e+20|0);c=fb-16|0;fb=c;x[c+12>>2]=17;fb=c+16|0;Dn(x[x[d>>2]-12>>2]+d|0,x[c+12>>2]);j=C[b>>3];x[31725]=0;b=Sa(1136,d|0,+j)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}x[31725]=0;O(1137,e+8|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}x[31725]=0;O(305,h|0,e+8|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}tb(e+8|0);pq(b);fb=e+160|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=N()|0;tb(e+8|0)}pq(d);Q(a|0);p()}Sh(a,h);tb(h);fb=g+16|0}function Bf(a,b,c){v[a+5|0]=c;a:{switch(b|0){case 0:v[a+3|0]=(c|0)!=0;return;case 1:v[a+3|0]=2;return;case 2:v[a+3|0]=3;return;case 3:v[a+3|0]=4;return;case 4:v[a+3|0]=5;return;case 5:v[a+3|0]=6;return;case 6:v[a+3|0]=7;return;case 7:v[a+3|0]=8;return;case 8:v[a+3|0]=9;return;case 9:v[a+3|0]=10;return;case 10:v[a+3|0]=11;return;case 11:v[a+3|0]=12;return;case 12:v[a+3|0]=13;return;case 13:v[a+3|0]=14;v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 14:v[a+3|0]=19;return;case 15:if(c>>>0<=31){v[a+3|0]=16;return}v[a+3|0]=17;return;case 16:v[a+3|0]=23;return;case 17:v[a+3|0]=24;return;case 20:v[a+3|0]=25;return;case 21:v[a+3|0]=30;return;case 25:v[a+3|0]=29;return;case 27:v[a+3|0]=15;return;case 29:v[a+3|0]=18;return;case 32:v[a+3|0]=37;return;case 33:v[a+3|0]=28;return;case 34:v[a+3|0]=27;return;case 35:v[a+3|0]=31;return;case 36:v[a+3|0]=32;return;case 37:v[a+3|0]=32;return;case 38:v[a+3|0]=34;return;default:break a}}v[a+3|0]=0}function pz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=(a+l<<2)+i|0,n=E(+(Cn(Ee(Ig(C[(a+k<<3)+j>>3])*134217728))|0)*7.450580596923828e-9),B[m>>2]=n;a=a+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=c- -64|0}function xt(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{d=uj(a)&2047;c=uj(5551115123125783e-32);if(d-c>>>0<uj(512)-c>>>0){i=d;break b}if(c>>>0>d>>>0){return a+1}if(uj(1024)>>>0>d>>>0){break b}o(+a);c=j(1)|0;b=0;if(!(j(0)|0)&(c|0)==-1048576){break a}if(uj(Infinity)>>>0<=d>>>0){return a+1}if((c|0)<0){return Qs(12882297539194267e-247)}return Qs(3105036184601418e216)}b=C[170];e=C[169]*a+b;b=e-b;a=b*C[172]+(b*C[171]+a);b=a*a;f=b*b*(a*C[176]+C[175]);b=b*(a*C[174]+C[173]);o(+e);j(1)|0;h=j(0)|0;c=h<<4&2032;a=f+(b+(C[c+1464>>3]+a));c=c+1472|0;g=x[c>>2];d=x[c+4>>2];c=g;g=0;c=c+g|0;d=(h<<13)+d|0;d=c>>>0<g>>>0?d+1|0:d;if(!i){c:{if(!(h&-2147483648)){l(0,c|0);l(1,d-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,c|0);l(1,d+1071644672|0);b=+n();e=b*a;a=e+b;if(a<1){gJ(PJ()*22250738585072014e-324);f=a+1;a=f+(e+(b-a)+(a+(1-f)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,c|0);l(1,d|0);b=+n();b=b*a+b}return b}function sba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=b+h|0;l=D(b,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=x[(a<<2)+i>>2]+(k<<1)|0;f=qd(x[(a+l<<2)+j>>2]+2048|0,12);f=(f|0)>=32767?32767:f;w[m>>1]=(f|0)<=-32768?-32768:f;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function wma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=Gg(j,k,l);n=hb;f=x[a+76>>2];hg(b,g,vf(j,k,d),hb);o=hb>>>0>f>>>0?d:0}f=a+112|0;h=x[a+40>>2];i=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;o=o-1|0;b=o;m=b?m:0;n=b?n:0;g=g+p|0;b=l;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(f,v[g+x[e+12>>2]|0]<<6);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,q);g=x[a+32>>2];i=x[a+28>>2]+i|0;x[c>>2]=x[c>>2]+D(b,i>>12);h=g+h|0;x[c+4>>2]=x[c+4>>2]+D(b,h>>12);Pb(e,j,k);c=c+8|0;b=x[e>>2];g=x[e+4>>2];continue a}else{be(f,v[g+x[e+12>>2]|0]<<6);ae(f,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;fb=e+16|0}function jba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){h=x[c+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(d>>>0>x[c+24>>2]-i>>>0){break b}j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}l=D(b,g);m=D(b+i|0,h);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=qd(x[(a+l<<2)+k>>2]+2048|0,12);f=(f|0)>=32767?32767:f;w[(a+m<<1)+j>>1]=(f|0)<=-32768?-32768:f;a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function mta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ld(b,32);np(b);f=b,g=Bb(y[a+40|0]|y[a+41|0]<<8)>>>2|0,w[f+32>>1]=g;d=z[b+34>>1];if((xe((y[a+38|0]|y[a+39|0]<<8)<<16>>16)|0)>0){d=d|32;w[b+34>>1]=d;c=xe((y[a+38|0]|y[a+39|0]<<8)<<16>>16);e=(c<<8&-256)+2047|0;c=c>>>24|0;f=b,g=Bc(qva(e,e>>>0<2047?c+1|0:c,4095,0),hb),w[f+28>>1]=g}f=b,g=$b(y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24)),x[f>>2]=g;f=b,g=$b(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24)),x[f+4>>2]=g;f=b,g=$b(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24))+$b(y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24))|0,x[f+8>>2]=g;c=d&-3|((Bb(y[a+44|0]|y[a+45|0]<<8)|0)!=0)<<1;w[b+34>>1]=c;f=b,g=c&65531|Bb(y[a+44|0]|y[a+45|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=$b(y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24))<<1,x[f+24>>2]=g;c=xe((y[a+42|0]|y[a+43|0]<<8)<<16>>16);if(c){hm(b,+(c|0)/96);c=xe((y[a+42|0]|y[a+43|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function _2(){var a=0,b=0,c=0,d=0;c=fb-32|0;fb=c;a:{b=Dc(c+20|0,15559);if(!Yc(x[b+4>>2],y[b+11|0])){break a}b:{if((Rg(b,14629)|0)!=-1){a=Rg(b,14629);x[31725]=0;V(123,c+8|0,b|0,a+1|0,-1);a=x[31725];x[31725]=0;if((a|0)==1){break b}a=c+8|0;Ab(b,a);tb(a)}if((Rg(b,16809)|0)!=-1){a=Rg(b,16809);x[31725]=0;V(123,c+8|0,b|0,a+1|0,-1);a=x[31725];x[31725]=0;if((a|0)==1){break b}a=c+8|0;Ab(b,a);tb(a)}if((Rg(b,13898)|0)!=-1){a=Rg(b,13898);x[31725]=0;V(123,c+8|0,b|0,0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}a=c+8|0;Ab(b,a);tb(a)}if((Rg(b,13773)|0)!=-1){a=Rg(b,13773);x[31725]=0;V(123,c+8|0,b|0,0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}a=c+8|0;Ab(b,a);tb(a)}if((Rg(b,13816)|0)!=-1){a=Rg(b,13816);x[31725]=0;V(123,c+8|0,b|0,0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}a=c+8|0;Ab(b,a);tb(a)}x[31725]=0;a=R(124,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break a}}c=N()|0;tb(b);Q(c|0);p()}tb(b);fb=c+32|0;return a|0}function Eha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=E(0),u=E(0),v=E(0),w=E(0),z=0,A=0,C=0,D=0,G=0,H=E(0);g=fb-16|0;fb=g;m=x[a+4240>>2];a:{if(!m){break a}if(!Ai(a+44|0)){break a}n=B[a+4220>>2];e=x[a+44>>2];D=g,G=Hc(e,0),x[D+8>>2]=G;D=g,G=Hc(e,1),x[D+12>>2]=G;e=x[a+56>>2];o=Hc(e,0);x[g>>2]=o;p=Hc(e,1);x[g+4>>2]=p;w=E(E(1)-n);q=x[a+4208>>2];z=y[a+4264|0];e=d;b:while(1){if(e){k=x[a+4244>>2];A=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;x[a+4244>>2]=(f|0)!=(m|0)?f:0;e=e-1|0;continue b}else{h=(z?1-l|0:f)&255;j=x[((h<<2)+a|0)+4248>>2];C=x[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=x[s>>2];x[s>>2]=i+4;j=k-j|0;t=B[yb(q,h+((j>>31&C)+j<<1)|0)>>2];u=B[i>>2];v=E(E(t*B[a+4224>>2])+E(u*B[a+4260>>2]));D=yb(q,f+A|0),H=E(F(v))<E(10000000195414814e-40)?E(0):v,B[D>>2]=H;h=g+r|0;i=x[h>>2];x[h>>2]=i+4;B[i>>2]=E(u*w)+E(n*t);l=l+1|0;f=f+1|0;continue}}break}Qi(a,b,c,o,p,d)}fb=g+16|0}function Y1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-32|0;fb=h;e=Sn(h+12|0,a);c=fb-48|0;fb=c;i=-1;a:{if(!$F(e,c+12|0)){break a}i=0;if(!eG(c+12|0)){break a}j=Cf(13165);if(j){n=x[e+12>>2];b:{if(!dm(e,y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))){break b}while(1){c:{if((y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24))>>>0>l>>>0){if(mh(e,5)){break c}}d=k&1;break b}d:{if((y[c+16|0]|y[c+17|0]<<8)>>>0>=64){a=Sr(e);d=a&63;g=a<<24>>24;e:{if(!(a&64)){break e}f=6;while(1){a=Sr(e);d=(a&127)<<f|d;if(a<<24>>24>=0){break e}a=f>>>0<25;f=f+7|0;if(a){continue}break}}if((((g|0)<0?(d|0)<0?-2147483648:0-d|0:d)|0)<=0){break d}}d=0;f=1;while(1){g=Sr(e);if(g){m=d>>>0>=j>>>0;a=m&f;if(!((f^1)&1|m)){a=(Rq(g<<24>>24)&255)==y[d+13165|0]}f=a;d=d+1|0;continue}break}gd(e,4);k=(d|0)==(j|0)?f&1?1:k:k}l=l+1|0;continue}}dm(e,n)}if(!d){break a}i=ve(e,b,dG(c+12|0),0)}fb=c+48|0;fb=h+32|0;return i|0}function Eq(a){a=a|0;var b=0,c=0,d=0,e=0,f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=E(0);b=x[a+36>>2];if(!b){Nf(a+16|0);return}a:{b:{switch(z[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Nf(c);return}Ll(c,b);b=x[a+36>>2]+1|0;c=b>>>0<=1?1:b;e=w[a+28>>1];g=De(E(bn(a,e+1<<16>>16)/bn(a,e)),E(E(1)/E(b>>>0)));a=x[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}f=De(g,E(b>>>0));n=yb(a,b-1|0),o=f,B[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;e=z[a+30>>1];if(e>>>0>1e3/(b>>>0)>>>0){Nf(c);return}Ll(c,D(b,e));h=z[a+30>>1];j=lA(w[a+28>>1],h);i=x[a+36>>2];g=E(E(1)/E(i+1>>>0));c=0;c:while(1){if(e>>>0<=(c&65535)>>>0){break a}b=1;d=lA(c+j<<16>>16,h);f=bn(a,d+1<<16>>16);d=d<<16>>16;f=De(E(f/bn(a,d)),g);k=D(d,x[a+36>>2]);l=x[a+16>>2];while(1){d=b&65535;if(d>>>0>i>>>0){c=c+1|0;continue c}else{m=De(f,E(d>>>0));n=yb(l,(d+k|0)-1|0),o=m,B[n>>2]=o;b=b+1|0;continue}}};case 0:Nf(a+16|0);return;default:break b}}Nf(a+16|0);x[a+36>>2]=0}}function Ena(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];w=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=ova(l,s,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=ova(k,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=x[h+12>>2]+p|0;i=v[g|0];i=((D(v[g+1|0]-i|0,x[h+8>>2]>>>10&4194048)|0)/16384<<8)+(i<<16)|0;e=i;g=ova(e,e>>31,m,t);j=g+j|0;e=hb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,w);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function Aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-80|0;fb=e;x[e+76>>2]=c;a=re(a,e+76|0);c=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31725]=0;O(997,a|0,d|0);f=x[31725];x[31725]=0;a:{b:{c:{d:{if((f|0)!=1){f=x[b>>2];k=x[b+4>>2];l=x[b+12>>2];x[e+48>>2]=x[b+8>>2];x[e+52>>2]=l;x[e+40>>2]=f;x[e+44>>2]=k;b=Nd(e+32|0);f=x[e+52>>2];x[e+24>>2]=x[e+48>>2];x[e+28>>2]=f;x[31725]=0;f=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=f;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;S(986,e+56|0,e+16|0,e+8|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;S(998,a|0,e+56|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}ub(e+56|0);x[31725]=0;W(999,a|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}Vc(e+76|0);fb=e+80|0;return a|0}d=N()|0;break a}d=N()|0;break a}d=N()|0;ub(e+56|0);break a}d=N()|0}Td(j);of(i);Jl(h);xh(g);wh(c);Vc(a);Vc(e+76|0);Q(d|0);p()}function Dna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];v=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=ova(l,s,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=ova(k,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=(x[h+12>>2]<<1)+p|0;i=w[g>>1];i=i+((D(w[g+2>>1]-i|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;g=ova(e,e>>31,m,t);j=g+j|0;e=hb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,v);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function bra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;w[e+12>>1]=0;x[e+8>>2]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(l|0)){i=(l<<1)+b|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){w[e+6>>1]=0;yY(a,e+15|0,e+12|0,j,e+6|0);g=z[e+6>>1];f=z[e+12>>1];c=j;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!Af(a,e+5|0)){break c}f=y[e+5|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&65535;e:{if(h>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=c-1|0;if(!(h&1<<m)){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+z[e+8>>1]|0;w[e+6>>1]=f;w[i>>1]=f;x[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);i=(d<<1)+i|0;j=(c+j&254)>>>1|0;c=-32768;k=x[e+8>>2];f:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break f}}x[e+8>>2]=c}k=f;continue}}break}fb=e+16|0}function ena(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+j|0;b=(b>>>16&65520)+h|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Pb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=E(0),w=E(0),y=E(0),z=0,A=0,C=0,D=E(0);r=x[a+4220>>2];if(r){f=x[a+44>>2];k=Hc(f,0);l=Hc(f,1);g=x[a+56>>2];s=Hc(g,0);j=x[a+4208>>2];z=x[a+4228>>2];f=d;t=Hc(g,1);m=t;g=s;while(1){if(f){h=x[a+4224>>2];e=h-z|0;e=(x[a+4220>>2]&e>>31)+e<<1;A=yb(j,e);n=B[yb(j,e|1)>>2];u=B[a+4244>>2];o=B[A>>2];v=B[a+4252>>2];p=B[l>>2];w=B[a+4248>>2];q=B[k>>2];y=B[a+4256>>2];i=E(E(n*u)+E(E(o*v)+E(E(p*w)+E(q*y))));e=h<<1;C=yb(j,e),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;i=E(E(o*u)+E(E(n*v)+E(E(q*w)+E(p*y))));C=yb(j,e|1),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;h=h+1|0;x[a+4224>>2]=(h|0)!=(r|0)?h:0;B[g>>2]=E(q*B[a+4240>>2])+E(o*B[a+4236>>2]);B[m>>2]=E(p*B[a+4240>>2])+E(n*B[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{Qi(a,b,c,s,t,d)}break}}}function cN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;x[e+12>>2]=c;a:{b:{if(!b){a=a+120|0;zo(a);c=x[e+12>>2];b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(b+8|0,x[vb(b+4|0,a)>>2]);c:{if(c){x[31725]=0;O(1143,a|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}_M(a,c)}c=b+8|0;Qd(c);dj(c);fb=b+16|0;break c}v[a+20|0]=0;break b}d=fb-16|0;fb=d;x[d+12>>2]=c;d:{if((b|0)==1){b=a+120|0;zo(b);h=wz(b,a,x[d+12>>2]),i=1,v[h+20|0]=i;break d}f=fb-16|0;fb=f;x[f+12>>2]=c;e:{if((b|0)==2){a=a+120|0;zo(a);c=x[f+12>>2];b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(b+8|0,x[vb(b+4|0,a)>>2]);f:{if(c){x[31725]=0;O(1142,a|0,c|0);g=x[31725];x[31725]=0;if((g|0)==1){break a}_M(a,c)}c=b+8|0;Qd(c);dj(c);fb=b+16|0;break f}Nd(a+12|0);v[a+20|0]=2;break e}b=fb-16|0;fb=b;x[b+12>>2]=c;c=a+120|0;zo(c);h=wz(c,a,x[b+12>>2]),i=3,v[h+20|0]=i;fb=b+16|0}fb=f+16|0}fb=d+16|0}fb=e+16|0;return}a=N()|0;dj(b+8|0);Q(a|0);p()}function TK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Ze(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=sv(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){v[c+23|0]=y[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(fL(x[a+36>>2],f,i,g,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=sv(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}v[c+23|0]=y[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((At(Pf(v[e+(c+24|0)|0]),x[a+32>>2])|0)!=-1){continue}break a}}d=Pf(v[c+23|0]);x[a+48>>2]=d;break a}d=Pf(v[c+23|0]);break a}d=-1}fb=c+32|0;return d}function rw(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;a:{if(y[a+3|0]!=19){break a}v[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=y[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}v[a+3|0]=0;break a}v[a+3|0]=2;v[a+5|0]=b|240;break a}v[a+3|0]=3;v[a+5|0]=b|240;break a}v[a+5|0]=b&15|16;break a}v[a+5|0]=b&3|48;break a}v[a+5|0]=b&223^120;break a}v[a+5|0]=b&15|176;break a}v[a+5|0]=b&3|64;break a}v[a+3|0]=15;v[a+5|0]=b&15;break a}if(b&15){v[a+3|0]=11;v[a+5|0]=b<<4|15;break a}v[a+3|0]=0;break a}b=b&15;if(b){v[a+3|0]=11;x[c+12>>2]=b;x[c+8>>2]=14;d=a,e=y[ud(c+12|0,c+8|0)|0]|240,v[d+5|0]=e;break a}v[a+3|0]=0;break a}if((b|0)!=192){break a}v[a|0]=254;v[a+3|0]=0;break a}if((b|0)!=208){break a}v[a+3|0]=0}fb=c+16|0}function Tna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;p=x[a+16>>2];j=mg(1,2);b=hb;q=b;Pb(a,j,b);f=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+72>>2];k=x[a+68>>2];u=k>>31;l=x[a+64>>2];v=l>>31;m=x[a+60>>2];y=m>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){n=w[(x[g+12>>2]<<1)+p>>1]<<8;e=n;e=ova(e,e>>31,m,y);i=hb;h=e;e=Yb(b,-16777216,16776704);e=ova(l,v,e,e>>31);o=h+e|0;h=hb+i|0;h=e>>>0>o>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=ova(k,u,f,f>>31);i=e+o|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Pb(g+8|0,z,A);e=e-(t&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;Hg(a,j,q);fb=g+16|0}function Gba(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;x[31725]=0;g=P(21,d+8|0,a|0)|0;c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){d:{if(!Ed(y[g|0])){break d}bd(d+4|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31725]=0;c=R(1138,x[d+4>>2])|0;e=x[31725];x[31725]=0;e:{f:{if((e|0)!=1){Zb(d+4|0);e=xp(d,a);f=x[x[a>>2]-12>>2];x[31725]=0;f=a+f|0;h=R(22,f|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break f}e=x[e>>2];x[31725]=0;c=Ra(1139,c|0,e|0,f|0,h|0,+b)|0;e=x[31725];x[31725]=0;if((e|0)==1){break f}if(c){break d}c=x[x[a>>2]-12>>2];x[31725]=0;O(24,a+c|0,5);c=x[31725];x[31725]=0;if((c|0)!=1){break d}c=T(0)|0;break e}c=T(0)|0;Zb(d+4|0);break e}c=T(0)|0}om(g);break c}om(g);break b}c=T(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[31725]=0;W(25,a+c|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31725]=0;X(26);d=x[31725];x[31725]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function uia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=fb-16|0;fb=c;d=Fb(a);while(1){b:{c:{d:{if(Yc(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Wd(f,g)>>2];if(b>>>0>=2097152){x[31725]=0;O(969,d|0,63);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[31725]=0;O(969,d|0,a<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}i=(2<<a)+255<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[31725]=0;O(969,d|0,(a|i)<<24>>24);h=x[31725];x[31725]=0;a=e;break e}x[31725]=0;a=a-1|0;O(969,d|0,v[a+(c+10|0)|0]|-128);h=x[31725];x[31725]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function _I(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=v[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((y[a+1|0]&192)!=128){break a}break b}g=f&255;if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];f=y[a+1|0];c:{d:{if((g|0)!=237){if((g|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)!=128){break a}break c}if((f&192)!=128){break a}}g=3;if((h&192)!=128){break a}break b}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=y[a+3|0];i=y[a+2|0];f=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0>=48){break a}break e;case 4:if((f&240)!=128){break a}break e;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function aM(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[a+32>>2];a:{b:{b=x[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=x[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=y[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(A[a+40>>2]<c>>>0){fc(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=x[a+40>>2];if(e>>>0<=c+26>>>0){fc(a,1);break a}if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=(y[125924]|y[125925]<<8|(y[125926]<<16|y[125927]<<24))){fc(a,21);break a}if(y[c+4|0]){fc(a,21);break a}d:{if(d){if(!x[a+992>>2]|!(v[c+5|0]&1)){break d}fc(a,21);break a}if(v[c+5|0]&1){break d}fc(a,21);break a}b=0;f=c+27|0;d=y[c+26|0];c=f+d|0;if(e>>>0<c>>>0){fc(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=y[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}fc(a,1)}return 0}function Una(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;p=x[a+16>>2];j=mg(1,2);b=hb;q=b;Pb(a,j,b);f=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+72>>2];k=x[a+68>>2];u=k>>31;l=x[a+64>>2];w=l>>31;m=x[a+60>>2];y=m>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){n=v[x[g+12>>2]+p|0]<<16;e=n;e=ova(e,e>>31,m,y);i=hb;h=e;e=Yb(b,-16777216,16776704);e=ova(l,w,e,e>>31);o=h+e|0;h=hb+i|0;h=e>>>0>o>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=ova(k,u,f,f>>31);i=e+o|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Pb(g+8|0,z,A);e=e-(t&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;Hg(a,j,q);fb=g+16|0}function RV(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+15|0]=c;f=b&15;b=y[f+25440|0];a:{b:{switch(f|0){case 0:b=c?d>>>0>=51?b:0:0;break a;case 5:c:{d:{f=c&15;e:{if(!((f|0)!=2&(c&240)!=32)){c=159;v[e+15|0]=159;b=20;break e}if((f|0)==12){break d}}if(d>>>0<51){break a}if((c&240)==192){break c}break a}if(d>>>0<51){break a}}v[e+15|0]=0;b=25;break a;case 7:b=d>>>0>=52?b:0;break a;case 10:c=c&240;if(!c){break a}v[e+15|0]=c;break a;case 11:v[e+15|0]=D(c&15,17);break a;case 13:v[e+15|0]=D(c>>>4|0,10)+(c&15);break a;case 14:f:{switch((c>>>4|0)-1|0){case 0:v[e+15|0]=c|240;b=2;break a;case 1:v[e+15|0]=c|240;b=3;break a;case 7:if(d>>>0<52){break a}v[e+15|0]=c&15|96;case 11:case 12:b=20;break a;case 8:b=15;v[e+15|0]=c&15;break a;case 9:v[e+15|0]=c<<4|15;b=11;break a;case 10:break f;default:break a}}v[e+15|0]=c|240;b=11;break a;case 15:break b;default:break a}}b=c>>>0>47?17:b}de(a,b,e+15|0);fb=e+16|0}function UK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Ze(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=sv(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){x[c+20>>2]=v[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(fL(x[a+36>>2],f,i,g,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=sv(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}x[c+20>>2]=v[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((At(v[e+(c+24|0)|0],x[a+32>>2])|0)!=-1){continue}break a}}d=x[c+20>>2];x[a+48>>2]=d;break a}d=x[c+20>>2];break a}d=-1}fb=c+32|0;return d}function fna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+j|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Pb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function bJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=v[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((y[a+1|0]&192)!=128){break a}break b}g=b&255;if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];b=y[a+1|0];c:{d:{if((g|0)!=237){if((g|0)!=224){break d}if((b&224)==160){break c}break a}if((b&224)!=128){break a}break c}if((b&192)!=128){break a}}f=3;if((h&192)!=128){break a}break b}if((d-a|0)<4|b>>>0>4294967284){break a}f=y[a+3|0];h=y[a+2|0];b=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0>=48){break a}break e;case 4:if((b&240)!=128){break a}break e;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function BE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-560|0;fb=f;w[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=x[e>>2];b:{if(b){c=tV(f,c);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;d=y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24);e=y[c+7|0]|y[c+8|0]<<8|(y[c+9|0]<<16|y[c+10|0]<<24);v[b+7|0]=e;v[b+8|0]=e>>>8;v[b+9|0]=e>>>16;v[b+10|0]=e>>>24;v[b+11|0]=d;v[b+12|0]=d>>>8;v[b+13|0]=d>>>16;v[b+14|0]=d>>>24;v[b+15|0]=y[c+15|0];d=x[c+44>>2];x[b+40>>2]=x[c+40>>2];x[b+44>>2]=d;d=x[c+36>>2];x[b+32>>2]=x[c+32>>2];x[b+36>>2]=d;d=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=d;d=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=d;NA(b+48|0,c+48|0);NA(b+68|0,c+68|0);NA(b+88|0,c+88|0);yc(b+108|0,c+108|0,448);d=b;Jv(c);break b}b=zu(556);if(!b){x[e>>2]=0;break a}d=tV(b,c);x[e>>2]=d}g=a,h=z[qe(a+480192|0,f+558|0)>>1],w[g+480192>>1]=h}fb=f+560|0;return d|0}function Vt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(a+l<<2)+i>>2]=E(x[(a+k<<2)+j>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function J1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=fb-16|0;fb=c;d=Fb(a);while(1){b:{c:{d:{if(Yc(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Wd(f,g)>>2];if(b>>>0>=2097152){x[31725]=0;O(50,d|0,63);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[31725]=0;O(50,d|0,a&255);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}i=(2<<a)+255<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[31725]=0;O(50,d|0,a|i&255);h=x[31725];x[31725]=0;a=e;break e}x[31725]=0;a=a-1|0;O(50,d|0,y[a+(c+10|0)|0]|128);h=x[31725];x[31725]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function Soa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;w[f+12>>1]=c;w[f+14>>1]=b;w[f+10>>1]=d;h=z[x[x[a+24>>2]+8>>2]+12>>1];a:{if(h>>>0<=b>>>0){break a}if(!c|Rj(a)>>>0>=h>>>0){break a}Gf(f+12|0,h-b&65535);k=f,l=mm(x[a>>2],x[a+4>>2]),w[k+8>>1]=l;d=z[f+12>>1];QY(a,d+z[qe(f+14|0,f+8|0)>>1]|0);i=f+4|0;c=x[a>>2];e=a;if(Zc(c,x[a+4>>2])>>>0<b>>>0){xg(e,b);c=x[e>>2]}a=x[vb(i,jV(wb(c),b))>>2];j=f+10|0;i=fb-32|0;fb=i;b=a;a=x[e>>2];g=(sp(b,wb(a))<<1)+a|0;a=d;b:{if(!a){break b}b=x[zb(e)>>2];d=x[e+4>>2];if(a>>>0<=b-d>>1>>>0){b=a;c=d-g>>1;if(c>>>0<a>>>0){Ap(e,a-c|0,j);b=c;if((d|0)==(g|0)){break b}}hV(e,g,d,(a<<1)+g|0);Hv(g,b,((g>>>0<=j>>>0?A[e+4>>2]>j>>>0?a:0:0)<<1)+j|0);break b}b=zb(e);b=ok(i+12|0,pk(e,Zc(x[e>>2],d)+a|0),g-x[e>>2]>>1,b);rF(b,a,j);g=gV(e,b,g);kj(b)}wb(g);fb=i+32|0;if(Zc(x[e>>2],x[e+4>>2])>>>0<=h>>>0){break a}xg(e,h)}fb=f+16|0}function Ara(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-432|0;fb=d;xc(b);dD(b,d+380|0,d+300|0,d+16|0);k=d,l=bh((m=y[d+431|0]+1|0,n=1,o=$b(y[d+412|0]|y[d+413|0]<<8|(y[d+414|0]<<16|y[d+415|0]<<24)),o?m:n)),v[k+12|0]=l;i=y[Rb(25168,d+12|0)|0];v[d+15|0]=i;w[d+12>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Bb(z[d+16>>1])<<16>>16;if(!((e|0)<0|y[d+299|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=$b(x[d+300>>2]);if(e>>>0<g>>>0){if(cd(b,g)){break c}}v[d+15|0]=h+1;break b}}else{d:{if(!cd(b,$b(y[d+396|0]|y[d+397|0]<<8|(y[d+398|0]<<16|y[d+399|0]<<24))+(f<<2)|0)){break d}if(!cd(b,vp(b))){break d}e:{if(!c){j=Zd(b);break e}j=Wk(b)}w[d+10>>1]=j;k=d,l=z[qe(d+12|0,d+10|0)>>1],w[k+12>>1]=l}f=f+1|0;continue}break}g=$b(x[d+300>>2]);dD(b,d+380|0,d+300|0,d+16|0);h=h+1|0;continue}break}Sw(a);break a}MY(a,z[d+12>>1],d+15|0)}fb=d+432|0}function _ra(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;b=fb-16|0;fb=b;x[b+4>>2]=1073741824;w[b+10>>1]=12;c=Ec(64);x[31725]=0;d=R(879,c|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{if((f|0)!=1){c=yf(b,d);d=x[c>>2];x[31725]=0;O(880,d|0,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}a=x[c>>2];x[31725]=0;a=U(881,a|0,b+10|0,b+4|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}d:{if(!a){sc(b+12|0);break d}a=x[c>>2];x[31725]=0;O(882,a|0,15);a=x[31725];x[31725]=0;if((a|0)==1){break c}re(b+12|0,c)}og(c);fb=b+16|0;b=x[b+12>>2];break a}a=N()|0;Db(c);break b}a=N()|0;og(c)}Q(a|0);p()}x[e+12>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}x[31725]=0;c=P(1,e|0,(a<<2)+30576|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;S(501,b|0,a|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break g}tb(c);a=a+1|0;continue}break}a=N()|0;break f}a=N()|0;tb(c)}og(e+12|0);Q(a|0);p()}fb=e+16|0;return b|0}function Wt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[x[(a<<2)+h>>2]+(j<<2)>>2]=E(x[(a+k<<2)+i>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}_(7244,9045,33,8758);p()}_(7209,9045,34,8758);p()}_(5897,9045,35,8758);p()}_(5867,9045,36,8758);p()}fb=c- -64|0}function pB(a,b,c,d,e){var f=0,g=0,h=0;g=D(c,872)+b|0;a:{if(d){if(!Ob(a+1074312|0,90)){v[(D(c,872)+b|0)+1427|0]=d}v[(D(c,872)+b|0)+1428|0]=d;break a}d=y[g+1428|0]}f=x[a+480180>>2];if(!e){h=Ju(f)}g=g+616|0;b:{if((f|0)!=268435456){if((f|0)!=16777216){break b}f=x[(D(c,872)+b|0)+1272>>2];if(!f|!x[f+44>>2]){break b}a=d&255;if(!(a>>>0<240|e)){fT(b,c,240-a|0);return}if(!(a>>>0<224|e)){eT(g,224-a|0);return}dT(g,0-a|0);return}x[(D(c,872)+b|0)+1324>>2]=65535}e=d&255;c:{d:{if(!(e>>>0>223&h)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}mB(a,g,f);return}if(x[a+480180>>2]==524288){break d}lB(a,g,f);return}if(x[a+480180>>2]!=524288){break c}}b=D(c,872)+b|0;f:{if(!(v[b+1467|0]&1)){break f}if(x[a+1074416>>2]==1){if(Ob(a+1074312|0,6)){break f}}c=x[a+480180>>2];if(c&32832){break f}if(!(y[a+480208|0]&2)|(c|0)!=8){break c}}Fk(a,g,b+1316|0,0-(e<<2)|0,0)}}function _qa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;w[e+12>>1]=0;x[e+8>>2]=0;n=D(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){v[e+7|0]=0;xY(a,e+15|0,e+12|0,e+7|0);g=y[e+7|0];f=z[e+12>>1];c=k;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!Af(a,e+6|0)){break c}f=y[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=c-1|0;if(!(h&1<<m)){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+y[e+8|0]|0;v[e+7|0]=f;v[i|0]=f;x[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=x[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}x[e+8>>2]=c}j=f;continue}}break}fb=e+16|0}function TG(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;h=e;c=c&33554431;if(!(!e&(c|0)==16777216?!(a|b):!e&c>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(c^16777216|a|(b|h)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;bg(g+16|0,a,b,c,e,f-16129|0);gn(g,a,b,c,e,16257-f|0);a=x[g+8>>2];e=(x[g+12>>2]&33554431)<<7|a>>>25;c=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;f=x[g+4>>2];b=0;a=a&33554431;if(!(!b&(a|0)==16777216?!(c|f):!b&a>>>0<16777216)){e=e+1|0;break a}if(a^16777216|c|(b|f)){break a}e=(e&1)+e|0}fb=g+32|0;return l(2,d&-2147483648|e),r()}function Nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=(g<<1)+n|0;x[(g<<2)+e>>2]=(((((D(w[f+8>>1],q)+D(w[f+4>>1],r)|0)+D(w[f+12>>1],p)|0)+D(w[f+16>>1],o)|0)/2|0)+((((D(w[f-8>>1],u)+D(w[f-12>>1],b)|0)+D(w[f-4>>1],t)|0)+D(w[f>>1],s)|0)/2|0)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Pb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=E(0),w=E(0);h=fb-16|0;fb=h;if(Ai(a+44|0)){f=x[a+44>>2];g=Hc(f,0);x[h+8>>2]=g;f=Hc(f,1);x[h+12>>2]=f;j=x[a+56>>2];m=Hc(j,0);x[h>>2]=m;j=Hc(j,1);x[h+4>>2]=j;a:{if(B[yb(a+4208|0,2)>>2]!=E(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{k=g<<2;e=k+(h+8|0)|0;i=x[e>>2];x[e>>2]=i+4;e=a+k|0;n=e+4248|0;q=B[n>>2];l=B[i>>2];r=B[a+4236>>2];s=B[a+4232>>2];t=B[a+4228>>2];u=B[a+4220>>2];v=B[a+4224>>2];i=e+4240|0;o=B[i>>2];B[n>>2]=o;B[i>>2]=l;i=e+4264|0;w=B[i>>2];e=e+4256|0;p=B[e>>2];B[i>>2]=p;l=E(E(E(E(t*q)+E(E(u*l)+E(v*o)))-E(s*p))-E(r*w));B[e>>2]=l;k=h+k|0;e=x[k>>2];x[k>>2]=e+4;B[e>>2]=l;g=g+1|0;continue}}}e=g;g=d<<2;yc(m,e,g);yc(j,f,g);f=x[a+56>>2];m=Hc(f,0);j=Hc(f,1)}Qi(a,b,c,m,j,d)}fb=h+16|0}function qB(a,b,c,d,e){var f=0,g=0,h=0;g=D(c,872)+b|0;a:{if(d){if(!Ob(a+1074312|0,90)){v[(D(c,872)+b|0)+1428|0]=d}v[(D(c,872)+b|0)+1427|0]=d;break a}d=y[g+1427|0]}f=x[a+480180>>2];if(!e){h=Ju(f)}g=g+616|0;b:{if((f|0)!=268435456){if((f|0)!=16777216){break b}f=x[(D(c,872)+b|0)+1272>>2];if(!f|!x[f+44>>2]){break b}a=d&255;if(!(a>>>0<240|e)){fT(b,c,a-240|0);return}if(!(a>>>0<224|e)){eT(g,a-224|0);return}dT(g,a);return}x[(D(c,872)+b|0)+1324>>2]=1}e=d&255;c:{d:{if(!(e>>>0>223&h)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}nB(a,g,f);return}if(x[a+480180>>2]==524288){break d}oB(a,g,f);return}if(x[a+480180>>2]!=524288){break c}}b=D(c,872)+b|0;f:{if(!(v[b+1467|0]&1)){break f}if(x[a+1074416>>2]==1){if(Ob(a+1074312|0,6)){break f}}c=x[a+480180>>2];if(c&32832){break f}if(!(y[a+480208|0]&2)|(c|0)!=8){break c}}Fk(a,g,b+1316|0,e<<2,0)}}function zma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=x[a+16>>2];o=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=Gg(i,j,k);m=hb;f=x[a+76>>2];hg(b,g,vf(i,j,d),hb);h=hb>>>0>f>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(g<<1)+n|0;b=k;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(e,i,j);c=c+8|0;continue a}else{be(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);ae(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function UC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=fb-32|0;fb=i;h=fb-16|0;fb=h;ld(b,1);g=Bb(y[a+22|0]|y[a+23|0]<<8)<<1;x[b>>2]=g;v[b+37|0]=y[a+24|0]<<4;v[h+15|0]=y[a+25|0];v[h+14|0]=64;l=b,m=y[Rb(h+15|0,h+14|0)|0]<<2,w[l+30>>1]=m;f=Bb(y[a+26|0]|y[a+27|0]<<8);e=f<<1;k=Bb(y[a+28|0]|y[a+29|0]<<8);j=k<<1;e=k>>>0>=2?e+j>>>0<=g>>>0?e:f+j>>>0>g>>>0?e:f:e;a:{b:{switch(g|0){case 2:x[b>>2]=0;break a;case 0:break a;default:break b}}x[b+4>>2]=e;f=e+j|0;x[b+8>>2]=f;if(e>>>0>=g>>>0){e=g-1|0;x[b+4>>2]=e}if(!(!(f>>>0<4|e>>>0>f>>>0)&f-e>>>0>3)){x[b+4>>2]=0;x[b+8>>2]=0;f=0;e=0}if(!(f>>>0>8|f>>>0>=g>>>0|(!d|e))){x[b+8>>2]=0;break a}if(e>>>0>=f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}fb=h+16|0;d=i+8|0;Zk(d,3,a);b=i+20|0;Cc(b,d);c=zc(c,b);tb(b);d=0;while(1){if((d|0)!=32){b=c+d|0;if((y[b|0]-1&255)>>>0<=30){v[b|0]=32}d=d+1|0;continue}break}a=WC(a);fb=i+32|0;return a}function poa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-32|0;fb=g;e=fb-16|0;fb=e;c=a+33|0;x[b>>2]=y[c+206|0]|y[c+207|0]<<8;KR(c,b+48|0,y[c+192|0],y[c+200|0],y[c+194|0],y[c+195|0],y[c+196|0],0);KR(c,b+68|0,y[c+193|0],y[c+201|0],y[c+197|0],y[c+198|0],y[c+199|0],1);f=b+236|0;while(1){if((d|0)==96){if(y[c+208|0]){v[b+31|0]=y[c+209|0]+1;f=y[b+31|0];a:{b:{if(!f){d=1;break b}d=16;if(f>>>0<17){break a}}v[b+31|0]=d}w[e+14>>1]=y[c+210|0]|y[c+211|0]<<8;w[e+12>>1]=127;j=b,k=y[Nc(e+14|0,e+12|0)|0]+1|0,v[j+30|0]=k}v[b+33|0]=y[c+212|0];fb=e+16|0}else{i=y[c+d|0];j=_b(f,d+12|0),k=i,w[j>>1]=k;d=d+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){d=y[c+h|0];f=y[a+27|0]|y[a+28|0]<<8;j=_b(e,h+12|0),k=d>>>0<f>>>0?d:0,w[j>>1]=k;h=h+1|0;continue}break}d=g+8|0;Zk(d,3,a+4|0);c=g+20|0;Cc(c,d);zc(b+492|0,c);tb(c);if(!y[a+241|0]){v[b+30|0]=y[a+26|0]}fb=g+32|0}function RH(a,b,c,d,e,f,g,h){var i=0,j=0,k=E(0);i=fb-96|0;fb=i;LA(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[i+92>>2]=f;x[i+88>>2]=e;x[i+84>>2]=d;x[i+80>>2]=c;a:{d=i+80|0;c=0;while(1){b:{if((c|0)!=4){if(x[(c<<2)+d>>2]){break b}}else{c=4}break a}c=c+1|0;continue}}x[i+44>>2]=b;x[i+40>>2]=c;x[i+36>>2]=d;e=x[a+32>>2];k=B[a+48>>2];x[i+8>>2]=b;c=x[i+40>>2];x[i>>2]=x[i+36>>2];x[i+4>>2]=c;d=fb-16|0;fb=d;x[d+8>>2]=x[i+8>>2];c=x[i+4>>2];x[d>>2]=x[i>>2];x[d+4>>2]=c;c=SM(i+48|0);x[c+8>>2]=e;x[c+4>>2]=0;x[c>>2]=h;e=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=e;x[c+20>>2]=x[d+8>>2];C[c+24>>3]=k;x[c>>2]=g;fb=d+16|0;while(1){if(b){d=x[a+24>>2];x[i+24>>2]=b;x[i+28>>2]=0;x[i+16>>2]=134217727;x[i+20>>2]=0;d=TM(d,x[_r(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|j)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}fb=i+96|0;return j}function w0(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;v[e+15|0]=c;a:{if(b>>>0>35){break a}b:{c:{d:{e:{f:{g:{h:{d=y[b+24656|0];switch(d-6|0){case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break c;case 13:break d;case 0:case 1:case 5:break f;case 8:break g;default:break h}}if((d|0)==31){break b}if((d|0)==23){break e}if((d|0)!=1){break a}d=(c|0)!=0;break a}v[e+15|0]=D(c>>>4|0,10)+(c&15);d=14;break a}b=c&240;if(!b|(b|0)==240|(c&15)==15){break a}v[e+15|0]=b;break a}if(c>>>0<=64){v[e+15|0]=c<<1;d=23;break a}v[e+15|0]=128;d=23;break a}d=19;i:{switch((c&240)-48>>>4|0){case 0:v[e+15|0]=159;d=20;break a;case 1:v[e+15|0]=192;d=20;break a;case 2:if(c&14){break a}v[e+15|0]=((c|0)!=80)<<6;d=21;break a;case 4:break i;default:break a}}v[e+15|0]=c&15|160;d=20;break a}d=c>>>0<32?16:17;break a}v[e+15|0]=(b<<5|c>>>3)^128;d=31}de(a,d,e+15|0);fb=e+16|0}function fba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(a+l<<2)+i>>2]=C[(a+k<<3)+j>>3];a=a+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=c- -64|0}function Mpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;CX(a,c+11|0);if((y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24))==1414807888){CX(a,c+11|0);v[b|0]=1;b=0}else{b=1}a=fb-176|0;fb=a;d=a+12|0;Rw(d,(c+11|0)+b|0);x[31725]=0;O(126,a+24|0,d|0);b=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((b|0)!=1){x[31725]=0;b=P(105,a+36|0,a+24|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break e}tb(a+24|0);tb(a+12|0);d=x[x[b>>2]-12>>2];x[31725]=0;e=ca(106)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;S(107,a+8|0,b+d|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}Zb(a+8|0);x[31725]=0;w[a+24>>1]=0;d=P(688,b|0,a+24|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}b=xk(x[(d+x[x[d>>2]-12>>2]|0)+16>>2]);e=z[a+24>>1];Ff(d);fb=a+176|0;a=(b?0:e)&65535;break a}c=N()|0;break d}c=N()|0;tb(a+24|0)}tb(a+12|0);break b}c=N()|0;Ff(b)}Q(c|0);p()}fb=c+16|0;return a|0}function oG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;d=zb(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);e=x[c>>2];g=x[g>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=e;x[c+52>>2]=f;d=Se(c+24|0,d,c+52|0,c+56|0);x[c+16>>2]=x[d+8>>2];f=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=f;Re(c+36|0,c+8|0);while(1){if(pd(e,g)){bx(mG(x[c+56>>2]),mj(e));e=nG(c+60|0);nG(c+56|0);e=x[e>>2];continue}break}Qe(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){g=fb-16|0;fb=g;d=vb(g+12|0,x[x[c+44>>2]>>2]);j=x[vb(g+8|0,x[x[c+40>>2]>>2])>>2];e=fb-16|0;fb=e;f=x[d>>2];x[e+12>>2]=f;while(1){if(di(f,j)){d=fb-16|0;fb=d;x[d+12>>2]=f;x[d+12>>2]=x[d+12>>2]+36;fb=d+16|0;Op(mG(x[d+12>>2]));x[e+12>>2]=x[e+12>>2]+36;f=x[e+12>>2];continue}break}fb=e+16|0;fb=g+16|0}fb=c- -64|0;x[b+4>>2]=i;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function Um(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;x[a+4>>2]=0;if(Ed(y[Mm(e+15|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){b=a+24|0;while(1){c=x[b+x[x[a>>2]-12>>2]>>2];x[31725]=0;c=R(85,c|0)|0;d=x[31725];x[31725]=0;d:{if((d|0)!=1){if(!lc(c,-1)){break d}break b}break c}x[a+4>>2]=x[a+4>>2]+1;continue}}if(x[a+4>>2]>=(b|0)){break a}c=a+24|0;e:{while(1){d=x[c+x[x[a>>2]-12>>2]>>2];x[31725]=0;d=R(85,d|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break e}if(lc(d,-1)){break b}d=x[a+4>>2]+1|0;x[a+4>>2]=d;if((b|0)>(d|0)){continue}break}c=0;break a}}Y(T(0)|0)|0;c=1;Km(x[x[a>>2]-12>>2]+a|0,1);f:{g:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break f}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break g}Q(a|0);p()}Z();break a}T(0)|0;Sb()}p()}c=2}fk(x[x[a>>2]-12>>2]+a|0,c)}fb=e+16|0;return a|0}function Om(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;El(a);a:{b:{c:{f=x[b+32>>2];d:{if(!f){e=x[b+2084>>2];if(e){break d}break b}c=x[b+4>>2];if((c|0)<9){break c}e=x[b+2084>>2];if(!e){break c}}h=x[a+1392>>2];j=Nm(h);d=x[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=A[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=x[a+1396>>2];c=y[b+23|0]?c:x[x[b+2088>>2]+(c<<2)>>2];b=y[c+x[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}x[a+1392>>2]=h>>>b;b=d-b|0}x[a+1396>>2]=b;return c}if(y[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=y[x[b+8>>2]+d|0];if((c|0)==255){break f}g=x[a+1392>>2];if(x[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=x[a+1396>>2];if((e|0)>=(c|0)){x[a+1392>>2]=g>>>c;x[a+1396>>2]=e-y[x[b+8>>2]+d|0];return d}x[a+1396>>2]=0;break b}d=d+1|0;continue}break}fc(a,21);x[a+1396>>2]=0}return-1}_(11378,13258,1705,5445);p()}function oba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[x[(a<<2)+h>>2]+(j<<2)>>2]=C[(a+k<<3)+i>>3];a=a+1|0;continue}}}_(7244,9045,77,8725);p()}_(7209,9045,78,8725);p()}_(5897,9045,79,8725);p()}_(5867,9045,80,8725);p()}fb=c- -64|0}function Gy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=y[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=x[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=x[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;e=y[b|0];if((e|0)!=61){b=c+1|0;if(e){continue}}break}b=c}if((a|0)==(b|0)){return 0}g=b-a|0;c:{if(y[g+a|0]){break c}f=x[125022];if(!f){break c}b=x[f>>2];if(!b){break c}while(1){d:{c=a;e=b;i=0;h=g;d=0;e:{if(!g){break e}d=y[c|0];f:{if(!d){break f}while(1){g:{j=y[e|0];if((j|0)!=(d|0)|!j){break g}h=h-1|0;if(!h){break g}e=e+1|0;d=y[c+1|0];c=c+1|0;if(d){continue}break f}break}i=d}d=(i&255)-y[e|0]|0}if(!d){b=b+g|0;if(y[b|0]==61){break d}}b=x[f+4>>2];f=f+4|0;if(b){continue}break c}break}k=b+1|0}return k}function uP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;b=x[a>>2];vb(g+12|0,b);a:{b:{c:{d:{e:{if(Dd(x[b+16>>2])){while(1){if(c>>>0>31){break e}x[31725]=0;d=ca(70)|0;e=x[31725];x[31725]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=T(125584)|0;if((gb|0)!=($(125584)|0)){break c}Y(c|0)|0;v[b+20|0]=0;x[31725]=0;W(58,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}Z();break e}v[b+20|0]=0}if(!y[b+20|0]){d=x[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=x[d+2496>>2];e=d+(b<<2)|0;i=x[d+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=x[d+(h<<2)>>2];b=i^(b&2147483647|x[e>>2]&-2147483648)>>>1^0-(b&1)&-1727483681;x[e>>2]=b;x[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}fb=g+16|0;break a}c=N()|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break b}}Q(c|0);p()}T(0)|0;Sb();p()}return x[a+28>>2]&f}function Iq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;a:{b:{switch(y[a+480224|0]-1|0){default:b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2]<<1;e=ova(b,d,5e4,0);f=hb;b=x[ad(c+8|0,c)>>2];b=Gc(pva(e,f,b,b>>31),hb);x[a+1074404>>2]=b;break a;case 1:b=x[a+24620>>2];x[c+8>>2]=1;x[c+12>>2]=0;g=c,h=ova(x[a+1074420>>2],0,ova(x[a+1074408>>2],0,x[a+1074416>>2],0),hb),x[g>>2]=h;x[c+4>>2]=hb;b=ova(b,0,6e5,0);d=c+8|0;f=b;e=hb;b=Nw(x[d>>2],x[d+4>>2],x[c>>2],x[c+4>>2])?c:d;b=qva(f,e,x[b>>2],x[b+4>>2]);x[a+1074404>>2]=b;break a;case 0:break b}}b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2];e=ova(b,d,1e4,0);f=hb;b=x[ad(c+8|0,c)>>2];b=Gc(pva(e,f,b,b>>31),hb);x[a+1074404>>2]=b}d=a+1074404|0;a=x[a+480244>>2];b=ova(a,a>>31,b,b>>31);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Gc(pva(b,a,65536,0),hb);x[d>>2]=a>>>0<=1?1:a;fb=c+16|0}function X0(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{switch(b|0){case 0:se(a,0,c);break a;case 1:se(a,1,c);break a;case 2:se(a,2,c);break a;case 3:se(a,3,c);break a;case 4:se(a,4,c);break a;case 5:se(a,5,c);break a;case 6:se(a,6,c);break a;case 7:se(a,7,c);break a;case 8:se(a,8,c);break a;case 9:se(a,9,c);break a;case 10:se(a,10,c);break a;case 11:se(a,11,c);break a;case 12:se(a,12,c);break a;case 13:se(a,13,c);break a;case 14:se(a,14,c);break a;case 15:se(a,15,c);break a;case 16:se(a,16,c);break a;case 17:se(a,17,c);break a;case 18:se(a,18,c);break a;case 19:se(a,19,c);break a;case 20:W0(a,71456,c);break a;case 21:W0(a,72480,c);break a;case 22:se(a,20,c);break a;case 23:se(a,21,c);break a;case 24:se(a,22,c);break a;case 25:se(a,23,c);break a;case 26:se(a,24,c);break a;case 27:se(a,25,c);break a;case 28:se(a,26,c);break a;default:break b}}Fb(a)}}function VG(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{switch(b|0){case 0:pe(a,0,c);break a;case 1:pe(a,1,c);break a;case 2:pe(a,2,c);break a;case 3:pe(a,3,c);break a;case 4:pe(a,4,c);break a;case 5:pe(a,5,c);break a;case 6:pe(a,6,c);break a;case 7:pe(a,7,c);break a;case 8:pe(a,8,c);break a;case 9:pe(a,9,c);break a;case 10:pe(a,10,c);break a;case 11:pe(a,11,c);break a;case 12:pe(a,12,c);break a;case 13:pe(a,13,c);break a;case 14:pe(a,14,c);break a;case 15:pe(a,15,c);break a;case 16:pe(a,16,c);break a;case 17:pe(a,17,c);break a;case 18:pe(a,18,c);break a;case 19:pe(a,19,c);break a;case 20:UG(a,71456,c);break a;case 21:UG(a,72480,c);break a;case 22:pe(a,20,c);break a;case 23:pe(a,21,c);break a;case 24:pe(a,22,c);break a;case 25:pe(a,23,c);break a;case 26:pe(a,24,c);break a;case 27:pe(a,25,c);break a;case 28:pe(a,26,c);break a;default:break b}}Fb(a)}}function PD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;e=zb(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);d=x[c>>2];g=x[g>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=d;x[c+52>>2]=f;e=Se(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;Re(c+36|0,c+8|0);while(1){if(pd(d,g)){SD(X_(x[c+56>>2]),d-20|0);d=Y_(c+60|0);Y_(c+56|0);d=x[d>>2];continue}break}Qe(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){g=fb-16|0;fb=g;d=vb(g+12|0,x[x[c+44>>2]>>2]);j=x[vb(g+8|0,x[x[c+40>>2]>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(di(d,j)){e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+12>>2]=x[e+12>>2]+20;fb=e+16|0;ub(X_(x[e+12>>2]));d=x[Sf(f+12|0)>>2];continue}break}fb=f+16|0;fb=g+16|0}fb=c- -64|0;x[b+4>>2]=i;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function $U(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;e=zb(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);d=x[c>>2];g=x[g>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=d;x[c+52>>2]=f;e=Se(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;Re(c+36|0,c+8|0);while(1){if(pd(d,g)){XB(_U(x[c+56>>2]),nn(d));d=_o(c+60|0);_o(c+56|0);d=x[d>>2];continue}break}Qe(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){g=fb-16|0;fb=g;d=vb(g+12|0,x[x[c+44>>2]>>2]);j=x[vb(g+8|0,x[x[c+40>>2]>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(di(d,j)){e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+12>>2]=x[e+12>>2]+32;fb=e+16|0;Ik(_U(x[e+12>>2]));d=x[er(f+12|0)>>2];continue}break}fb=f+16|0;fb=g+16|0}fb=c- -64|0;x[b+4>>2]=i;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function hla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;b=x[a+4>>2];if(Ed(y[b+223884|0])){PT(b+223860|0);b=x[a+4>>2]}x[a+24>>2]=0;x[a+28>>2]=0;x[b>>2]=0;c=x[a>>2];x[b+40>>2]=x[c+480196>>2];x[b+44>>2]=x[c+480204>>2];x[b+80>>2]=x[c+480200>>2];c=z[c+480188>>1];x[f+8>>2]=0;x[f+12>>2]=0;d=f+8|0;w[d+4>>1]=65280;x[d>>2]=0;e=fb-16|0;fb=e;x[e+12>>2]=c;b=a+8|0;a:{if(Zn(b)>>>0>=c>>>0){g=x[b>>2];h=kh(g,x[b+4>>2]);x[e+8>>2]=h;i=x[Gb(e+12|0,e+8|0)>>2];while(1){if(i){x[g>>2]=x[d>>2];w[g+4>>1]=z[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){_S(b,c-h|0,d);break a}uG(b,x[b>>2]+(c<<3)|0);break a}iU(b);xU(b,ns(b,c));_S(b,c,d)}fb=e+16|0;b=0;while(1){c=x[a>>2];if(z[c+480188>>1]<=b>>>0){fb=f+16|0}else{d=D(b,872);Wo((d+x[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+x[a+4>>2]|0;w[c+1432>>1]=0;v[c+1415|0]=0;b=b+1|0;continue}break}}function Oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=g+n|0;x[(g<<2)+e>>2]=((((D(v[f+4|0],q)+D(v[f+2|0],r)|0)+D(v[f+6|0],p)|0)+D(v[f+8|0],o)<<8>>1)+(((D(v[f-4|0],u)+D(v[f-6|0],b)|0)+D(v[f-2|0],t)|0)+D(v[f|0],s)<<8>>1)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Pb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function yka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;e=Fb(d+20|0);a:{b:{c:{if(c>>>0<=63){break c}x[31725]=0;c=R(186,b|0)|0;f=x[31725];x[31725]=0;d:{if((f|0)!=1){x[d+16>>2]=c;if((c|0)>0){break d}x[31725]=0;P(36,a|0,22255)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break b}}break a}x[31725]=0;c=R(204,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){g=d,h=vh(c),x[g+12>>2]=h;c=x[ud(d+16|0,d+12|0)>>2];x[31725]=0;O(116,e|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{x[31725]=0;c=R(199,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break f}if(!c){break e}x[31725]=0;U(894,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=x[31725];x[31725]=0;if((c|0)!=1){continue}}break}break a}x[31725]=0;P(185,b|0,4)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}_c(a,e)}tb(e);fb=d+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function Dra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=f0(c+4|0,a);gD(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;hc(a);fb=c+16|0;return}h=fb-32|0;fb=h;c=zb(a);c=d0(h+12|0,e0(a,Pr(x[a>>2],x[a+4>>2])+1|0),Pr(x[a>>2],x[a+4>>2]),c);gD(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=fb-16|0;fb=g;e=zb(a);b=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);f=vb(g+4|0,x[c+4>>2]);d=x[b>>2];i=x[i>>2];b=fb+-64|0;fb=b;f=x[f>>2];x[b+56>>2]=f;x[b+60>>2]=d;x[b+52>>2]=f;e=Se(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];f=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=f;Re(b+36|0,b+8|0);while(1){if(pd(d,i)){gD(kE(x[b+56>>2]),Nr(d));d=kw(b+60|0);kw(b+56|0);d=x[d>>2];continue}break}d=b+36|0;Qe(d);e=x[b+56>>2];b0(d);fb=b- -64|0;x[c+4>>2]=e;Ub(a,c+4|0);Ub(a+4|0,c+8|0);Ub(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;c0(c);fb=h+32|0}function Ama(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=x[a+16>>2];o=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=Gg(i,j,k);m=hb;f=x[a+76>>2];hg(b,g,vf(i,j,d),hb);h=hb>>>0>f>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=g+n|0;b=k;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(f,v[x[e+12>>2]+g|0]<<6);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(e,i,j);c=c+8|0;continue a}else{be(f,v[x[e+12>>2]+g|0]<<6);ae(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function dk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=f0(c+4|0,a);lE(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;hc(a);fb=c+16|0;return}h=fb-32|0;fb=h;c=zb(a);c=d0(h+12|0,e0(a,Pr(x[a>>2],x[a+4>>2])+1|0),Pr(x[a>>2],x[a+4>>2]),c);lE(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=fb-16|0;fb=g;e=zb(a);b=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);f=vb(g+4|0,x[c+4>>2]);d=x[b>>2];i=x[i>>2];b=fb+-64|0;fb=b;f=x[f>>2];x[b+56>>2]=f;x[b+60>>2]=d;x[b+52>>2]=f;e=Se(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];f=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=f;Re(b+36|0,b+8|0);while(1){if(pd(d,i)){lE(kE(x[b+56>>2]),Nr(d));d=kw(b+60|0);kw(b+56|0);d=x[d>>2];continue}break}d=b+36|0;Qe(d);e=x[b+56>>2];b0(d);fb=b- -64|0;x[c+4>>2]=e;Ub(a,c+4|0);Ub(a+4|0,c+8|0);Ub(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;c0(c);fb=h+32|0}function Qw(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;a:{if(!c){break a}if(d){b=gc(g+8|0,a,b);a=fb-16|0;fb=a;x[a+12>>2]=c;d=x[b+4>>2];b:{if(!d){d=x[b>>2];break b}c=32-d|0;x[a+8>>2]=c;e=x[b>>2];h=c;c=x[Gb(a+8|0,a+12|0)>>2];x[e>>2]=-1<<d&-1>>>h-c|x[e>>2];c=x[a+12>>2]-c|0;x[a+12>>2]=c;d=e+4|0;x[b>>2]=d}x[a+4>>2]=-1;e=d;d=c>>>5|0;JF(e,d,a+4|0);e=x[a+12>>2];c=c&-32;f=e-c|0;x[a+12>>2]=f;if((c|0)!=(e|0)){c=b;b=x[b>>2]+(d<<2)|0;x[c>>2]=b;x[b>>2]=x[b>>2]|-1>>>32-f}fb=a+16|0;break a}b=gc(g,a,b);a=fb-16|0;fb=a;x[a+12>>2]=c;d=x[b+4>>2];c:{if(!d){d=x[b>>2];break c}e=32-d|0;x[a+8>>2]=e;c=x[b>>2];f=x[c>>2];h=e;e=x[Gb(a+8|0,a+12|0)>>2];x[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=x[a+12>>2];d=c+4|0;x[b>>2]=d;c=f-e|0}e=d;d=c>>>5|0;IF(e,d);c=c&31;x[a+12>>2]=c;if(c){e=b;b=x[b>>2]+(d<<2)|0;x[e>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-c^-1)}fb=a+16|0}fb=g+16|0}function eM(a,b,c,d){var e=0,f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=0;e=fb-96|0;fb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){B[e+48>>2]=-B[a>>2];B[e>>2]=B[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=B[g+4>>2];f=B[g+8>>2];B[i+4>>2]=h+f;k=d<<1;B[(8-k<<2)+e>>2]=h-f;h=B[g+16>>2];f=B[g+12>>2];B[(7-k<<2)+e>>2]=h-f;B[i+8>>2]=-E(h+f);d=d+1|0;continue}break}dM(e+48|0);dM(e);B[e+4>>2]=-B[e+4>>2];B[e+12>>2]=-B[e+12>>2];B[e+20>>2]=-B[e+20>>2];B[e+28>>2]=-B[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=B[i>>2];f=B[d+(e+48|0)>>2];l=B[d+87600>>2];m=B[d+87636>>2];n=B[d+e>>2];B[i>>2]=E(f*l)-E(m*n);i=a+d|0;d=c+d|0;f=E(E(f*m)+E(n*l));B[i>>2]=E(h*B[d>>2])-E(B[d+36>>2]*f);B[(17-g<<2)+a>>2]=E(h*B[d+36>>2])+E(f*B[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}fb=e+96|0}function dva(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;ld(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=tw(a+4|0,a);d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=d;c=tw(a+8|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=f;c=(y[a+15|0]|y[a+16|0]<<8)<<1;x[b+24>>2]=c;c=y[a+15|0]|y[a+16|0]<<8?c:16726;x[b+24>>2]=c;g=b,h=(D(IE(v[a+17|0],y[a+14|0]<<28>>24),c)>>>0)/8363|0,x[g+24>>2]=h;v[e+15|0]=y[a+18|0];v[e+14|0]=127;g=b,h=(((y[Rb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;c=y[a+14|0];if(c>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=c&240}c=y[a+19|0];if(c&4){w[b+34>>1]=z[b+34>>1]|1;c=y[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=z[b+34>>1];d=f|2;w[b+34>>1]=d;c=y[a+19|0];if(c&16){d=f|6;w[b+34>>1]=d;c=y[a+19|0]}if(!(c&64)){break a}w[b+34>>1]=d|128}fb=e+16|0}function A_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!y[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=y[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?((i|0)==10&y[d-1|0]==13)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&y[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}tf(a);Cs(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=v[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}Zp(a,e);c=c+1|0;continue}break}}function _P(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=E(0),m=0,n=0,o=E(0);e=a+4208|0;j=E(E(B[yb(e,2)>>2]*E(2999.9990234375))+E(.0010000000474974513));l=E(B[yb(e,3)>>2]*E(.9980000257492065));f=-3e3/(+A[x[a+16>>2]+24620>>2]*+j);e=a+4272|0;c=wk(10,f*+A[yb(e,4)>>2]);g=a+4232|0;n=yb(g,0),o=E(c),B[n>>2]=o;c=wk(10,f*+A[yb(e,5)>>2]);n=yb(g,1),o=E(c),B[n>>2]=o;m=f*(1/+E(l+E(.0010000000474974513))+-1);c=0;while(1){if((d|0)==4){d=a+4208|0;f=wk(10,+YP(B[yb(d,0)>>2])*.05);b=4/M(c)*f;c=wk(10,+YP(B[yb(d,1)>>2])*.1);B[a+4228>>2]=b*M(c);B[a+4224>>2]=f*M(1-c)}else{h=x[yb(e,d)>>2];k=d>>>1|0;i=wk(10,m*+(x[yb(e,d)>>2]+x[yb(e,k+4|0)>>2]>>>0));b=wk(10,f*+(h>>>0));j=B[yb(g,k)>>2];h=d<<1;i=(1-i)*.5;n=yb(g,h+2|0),o=E(b*(1-i)),B[n>>2]=o;n=yb(g,h+3|0),o=E(b*i),B[n>>2]=o;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;d=d+1|0;continue}break}}function o5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=oJ(a,0);h=fb-32|0;fb=h;c=SI(f+12|0,b);d=c+172|0;i=c+4|0;a=i;while(1){a=Fb(a)+12|0;if((d|0)!=(a|0)){continue}break}e=c+460|0;a=d;while(1){a=Fb(a)+12|0;if((e|0)!=(a|0)){continue}break}g=c+484|0;a=e;while(1){a=Fb(a)+12|0;if((g|0)!=(a|0)){continue}break}g=Fb(g);j=Fb(c+496|0);k=Fb(c+508|0);l=Fb(c+520|0);x[31725]=0;a=P(1354,h+12|0,b|0)|0;b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){x[31725]=0;O(1355,c|0,a|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}Vs(a);fb=h+32|0;break a}b=N()|0;break b}b=N()|0;Vs(a)}tb(l);tb(k);tb(j);a=tb(g);while(1){a=tb(a-12|0);if((e|0)!=(a|0)){continue}break}while(1){e=tb(e-12|0);if((e|0)!=(d|0)){continue}break}while(1){d=tb(d-12|0);if((i|0)!=(d|0)){continue}break}Xs(c);Q(b|0);p()}x[f+8>>2]=116604;x[f>>2]=116528;return f|0}function m5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=nJ(a,0);h=fb-16|0;fb=h;c=SI(f+12|0,b);d=c+172|0;i=c+4|0;a=i;while(1){a=Fb(a)+12|0;if((d|0)!=(a|0)){continue}break}e=c+460|0;a=d;while(1){a=Fb(a)+12|0;if((e|0)!=(a|0)){continue}break}g=c+484|0;a=e;while(1){a=Fb(a)+12|0;if((g|0)!=(a|0)){continue}break}g=Fb(g);j=Fb(c+496|0);k=Fb(c+508|0);l=Fb(c+520|0);x[31725]=0;a=P(1356,h+4|0,b|0)|0;b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){x[31725]=0;O(1357,c|0,a|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}Ys(a);fb=h+16|0;break a}b=N()|0;break b}b=N()|0;Ys(a)}Qb(l);Qb(k);Qb(j);a=Qb(g);while(1){a=Qb(a-12|0);if((e|0)!=(a|0)){continue}break}while(1){e=Qb(e-12|0);if((e|0)!=(d|0)){continue}break}while(1){d=Qb(d-12|0);if((i|0)!=(d|0)){continue}break}Xs(c);Q(b|0);p()}x[f+8>>2]=116900;x[f>>2]=116824;return f|0}function BO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb+-64|0;fb=e;a:{b:{if((b|0)>=0){d=x[a+24>>2];if(Rj(Xb(x[d+484360>>2],y[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=x[a+24>>2];g=x[f+484344>>2];i=x[f+484348>>2];h=z[_b(x[Xb(x[f+484360>>2],y[f+484376|0])>>2],b)>>1];if(!yp(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<x[Wb(g,h)+12>>2]){break c}}a=a+16|0;break a}w[f+1074448>>1]=b;c=f;f=b&65535;kS(c,f);c=x[a+24>>2];x[c+1074392>>2]=-2;x[c+1074428>>2]=d;g=y[a+64|0];b=e+24|0;w[b+4>>1]=0;v[b+6|0]=255;x[b+16>>2]=2;x[b>>2]=0;w[b+12>>1]=f;x[b+8>>2]=d;d=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=d;d=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=d;d=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=d;b=e+52|0;Dv(b,c,g?7:1,e);j=a,k=C[nn(x[e+56>>2])>>3],C[j+16>>3]=k;Yi(b);a=a+16|0}fb=e- -64|0;return+C[a>>3]}function qL(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0;o(+a);b=j(1)|0;e=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){if(!(b&2147483647|e)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}c=1072693248;k=-1023;if((b|0)!=1072693248){c=b;break b}if(e){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;e=j(0)|0;c=b;k=-1077}l(0,e|0);c=c+614242|0;l(1,(c&1048575)+1072079006|0);d=+n()+-1;f=d*(d*.5);g=d/(d+2);h=g*g;a=h*h;o(+(d-f));b=j(1)|0;j(0)|0;l(0,0);l(1,b|0);i=+n();m=i*1.4426950407214463;p=+((c>>>20|0)+k|0);q=m+p;a=g*(f+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+h*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+(d-i-f);a=q+(m+(p-q)+((a+i)*1.6751713164886512e-10+a*1.4426950407214463))}return a}function gsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);i=a;a:{if(!c){Pc(e,a+32|0,5);d=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}d=fb-32|0;fb=d;f=x[a+36>>2];pg(f,d+30|0);b:{c:{d:{e:{a=z[d+30>>1];if(a>>>0>=4001){j=x[b+12>>2];a=fb-16|0;fb=a;g=d+4|0;h=tc(a+4|0,15969);_c(g,h);tb(h);fb=a+16|0;x[31725]=0;S(492,d+16|0,g|0,d+30|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}a=x[j+1298472>>2];x[31725]=0;S(387,a|0,2,d+16|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}tb(d+16|0);Eb(d+4|0);a=4e3}xg(Xj(x[b>>2],0),a);b=Xj(x[b>>2],0);k=d,l=wb(x[b>>2]),x[k+16>>2]=l;b=wb(x[b+4>>2]);break b}b=N()|0;break c}b=N()|0;tb(d+16|0)}Eb(d+4|0);Q(b|0);p()}while(1){a=x[d+16>>2];if(Ib(a,b)){pg(f,d+4|0);w[a>>1]=z[d+4>>1];Md(d+16|0);continue}break}fb=d+32|0;d=c}gf(i,d);fb=e+16|0}function KR(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=fb-16|0;fb=k;v[k+15|0]=c;v[k+14|0]=12;hh(b,y[Rb(k+15|0,k+14|0)|0]);c=0;l=x[b>>2];m=x[b+4>>2];p=Sd(l,m);while(1){if((c|0)==(p|0)){c=0;v[b+12|0]=0;a:{if(!(d&1)){break a}if(lc(l,m)){break a}c=1;v[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;v[b+12|0]=c}v[b+15|0]=e;v[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){v[b+12|0]=c|2}v[b+14|0]=g;v[b+13|0]=f}fb=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=yb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+96|0]|y[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=yb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+144|0]|y[i+145|0]<<8;i=i+146|0}v[j+2|0]=y[i|0]}e:{if(!c){break e}i=yb(l,c);j=z[i>>1];n=yb(l,c-1|0);o=z[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;w[i>>1]=j;if(j>>>0>=z[n>>1]){break e}w[i>>1]=j+256}c=c+1|0;continue}break}}function ona(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;p=w[e+38150>>1];q=w[e+38148>>1];r=w[e+38146>>1];e=w[e+38144>>1];h=0;while(1){if((h|0)!=2){i=(h<<1)+o|0;x[(h<<2)+b>>2]=(((D(w[i>>1],r)+D(w[i-4>>1],e)|0)+D(w[i+4>>1],q)|0)+D(w[i+8>>1],p)|0)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;ld(c,0);w[c+28>>1]=y[a+36|0]<<2;d=y[a+37|0];w[c+32>>1]=64;w[c+30>>1]=d<<2;x[c>>2]=y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24);x[c+4>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+8>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+24>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);d=y[b+151|0];if(d>>>0<=4){v[c+38|0]=y[d+41178|0]}d=y[b+152|0]|y[b+153|0]<<8;v[c+39|0]=d;e=(y[b+156|0]|y[b+157|0]<<8)>>>4|0;v[c+41|0]=e;b=(y[b+154|0]|y[b+155|0]<<8)>>>2|0;v[c+40|0]=b;if((b|e)&255){v[c+39|0]=d^-1}b=y[a+38|0]|y[a+39|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+38|0]|y[a+39|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+38|0]|y[a+39|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+38|0]|y[a+39|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}}function H7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=NJ(c);b:{if(b){b=k+4|0;sl(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;rl(b,a);break b}b=k+4|0;bt(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ki(b,a)}qh(i,b);Qb(b);l=e,m=vj(a),x[l>>2]=m;l=f,m=wj(a),x[l>>2]=m;b=k+4|0;th(b,a);Ab(g,b);tb(b);li(b,a);qh(h,b);Qb(b);a=Qk(a);break a}a=MJ(c);c:{if(b){b=k+4|0;sl(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;rl(b,a);break c}b=k+4|0;bt(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ki(b,a)}qh(i,b);Qb(b);l=e,m=vj(a),x[l>>2]=m;l=f,m=wj(a),x[l>>2]=m;b=k+4|0;th(b,a);Ab(g,b);tb(b);li(b,a);qh(h,b);Qb(b);a=Qk(a)}x[j>>2]=a;fb=k+16|0}function L7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=SJ(c);b:{if(b){b=k+4|0;sl(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;rl(b,a);break b}b=k+4|0;bt(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ki(b,a)}Ab(i,b);tb(b);l=e,m=vj(a),v[l|0]=m;l=f,m=wj(a),v[l|0]=m;b=k+4|0;th(b,a);Ab(g,b);tb(b);li(b,a);Ab(h,b);tb(b);a=Qk(a);break a}a=RJ(c);c:{if(b){b=k+4|0;sl(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;rl(b,a);break c}b=k+4|0;bt(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ki(b,a)}Ab(i,b);tb(b);l=e,m=vj(a),v[l|0]=m;l=f,m=wj(a),v[l|0]=m;b=k+4|0;th(b,a);Ab(g,b);tb(b);li(b,a);Ab(h,b);tb(b);a=Qk(a)}x[j>>2]=a;fb=k+16|0}function Cka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-48|0;fb=b;e=30624;a=Nb(a);a:{while(1){b:{if((e|0)==31056){e=31056;break b}c=qc(b+40|0,x[e+4>>2]);f=x[b+44>>2];c:{if(!f){break c}d=x[a+4>>2];if(!lc(x[a>>2],d)){c=x[c>>2];d=qc(b+32|0,x[xf(d)>>2]);g=x[d+4>>2];x[b+8>>2]=x[d>>2];x[b+12>>2]=g;if(Ic(c,f,b+8|0)){break c}}x[31725]=0;O(890,a|0,e+4|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}}e=e+8|0;continue}break}d:{while(1){if((e|0)==31104){break d}c=qc(b+40|0,x[e+8>>2]);e:{f=x[b+44>>2];f:{if(!f){break f}d=x[a+4>>2];if(!lc(x[a>>2],d)){g=x[c>>2];d=qc(b+24|0,x[xf(d)>>2]);h=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=h;if(Ic(g,f,b)){break f}}c=x[c>>2];x[31725]=0;x[b+20>>2]=c;O(891,a|0,b+20|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}}e=e+12|0;continue}break}break a}fb=b+48|0;return}b=N()|0;uc(a);Q(b|0);p()}function Xka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-880|0;fb=b;c=Tb(a,0,76);x[c+84>>2]=0;x[c+88>>2]=0;x[c+80>>2]=256;w[c+76>>1]=65535;x[c+92>>2]=0;x[c+96>>2]=0;v[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=hW(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Nb(d);g=iB(c+223860|0);f=b+8|0;Tb(f,0,108);nC(b+120|0,48e3);Tb(b+664|0,0,72);v[b+754|0]=0;w[b+752>>1]=65535;v[b+746|0]=0;w[b+744>>1]=65535;v[b+738|0]=0;w[b+736>>1]=65535;x[b+748>>2]=0;x[b+740>>2]=0;Tb(b+756|0,0,103);x[b+868>>2]=0;x[b+872>>2]=0;v[b+875|0]=0;v[b+876|0]=0;v[b+877|0]=0;v[b+878|0]=0;x[b+860>>2]=0;x[b+864>>2]=0;v[b+859|0]=y[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=Mq(e,f)+872|0;continue}break}x[31725]=0;O(554,d|0,32);a=x[31725];x[31725]=0;if((a|0)!=1){fb=b+880|0;return c|0}a=N()|0;Nq(g);dc(d);Q(a|0);p()}function sW(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=fb-16|0;fb=g;m=x[a+20>>2];h=z[a+34>>1]&65;x[g+12>>2]=h;x[g+8>>2]=h^65;h=b;n=d+1298224|0;e=d+1074992|0;j=Jj(d);o=a+4|0;p=a+12|0;q=a+8|0;r=a+16|0;while(1){if((e|0)!=(n|0)){if(x[e+104>>2]==(a|0)){if(x[e+16>>2]){x[e+16>>2]=h}if(A[e+4>>2]>c>>>0){x[e>>2]=0;x[e+4>>2]=0}b=a;if(x[e+76>>2]){wc(e+76|0,c);b=x[e+104>>2]}f=x[e+88>>2];b=WF(f,b);i=x[(b?p:o)>>2];x[e+84>>2]=x[(b?r:q)>>2];x[e+80>>2]=i;b=f|x[g+12>>2];x[e+88>>2]=b;x[e+88>>2]=b&(x[g+8>>2]^-1);f=x[e+704>>2];b=x[a+24>>2];a:{if(!f|!b){break a}if(En(x[d+480180>>2])){break a}i=ova(x[e+700>>2],0,j?b:f,0);f=j?f:b;k=i+(f>>>1|0)|0;l=hb;s=e,t=Bc(qva(k,i>>>0>k>>>0?l+1|0:l,f,0),hb),x[s+700>>2]=t}x[e+704>>2]=b}e=e+872|0;continue}break}x[a>>2]=c;x[a+20>>2]=h;aC(m);fb=g+16|0}function tga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}x[31725]=0;W(1003,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break g}x[31725]=0;W(1003,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break g}f=x[a+24>>2];x[31725]=0;d=P(36,e+20|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break g}x[31725]=0;c=P(36,e+8|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break f}x[31725]=0;V(1018,f|0,d|0,c|0,1);b=x[31725];x[31725]=0;if((b|0)==1){break e}tb(c);tb(d);b=1;break b}b=T(0)|0;break c}b=T(0)|0;break d}b=T(0)|0;tb(c)}tb(d)}Y(b|0)|0;b=0;x[31725]=0;V(989,6409,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}fb=e+32|0;return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-96|0;fb=d;x[31725]=0;e=x[b+12>>2];x[d+40>>2]=x[b+8>>2];x[d+44>>2]=e;e=x[b+4>>2];x[d+32>>2]=x[b>>2];x[d+36>>2]=e;e=R(1155,d+32|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){a:{b:{if(e){x[31725]=0;O(1156,d+72|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=d+80|0;Rp(b,x[d+72>>2],x[d+76>>2]);e=Ef(d+88|0,b);f=Ef(d- -64|0,c);g=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=g;e=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=e;Sp(a,d+8|0,d);break b}break a}x[31725]=0;O(1157,d+72|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=d+80|0;Rp(b,x[d+72>>2],x[d+76>>2]);e=Ef(d+56|0,b);f=Ef(d+48|0,c);g=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=g;e=x[f+4>>2];x[d+16>>2]=x[f>>2];x[d+20>>2]=e;Sp(a,d+24|0,d+16|0)}ke(b);ke(d+72|0);ke(c);fb=d+96|0;return}}a=N()|0;ke(c);Q(a|0);p()}function bo(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;x[31725]=0;W(1002,a|0);e=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=x[a+24>>2];x[31725]=0;O(d|0,f+4|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break i}d=x[f+4>>2];e=Ud(d,x[f+8>>2]);if(e>>>0<2147483647){break h}d=ac(8);x[31725]=0;b=P(1057,d|0,7429)|0;e=x[31725];x[31725]=0;if((e|0)==1){break g}x[31725]=0;S(99,b|0,125360,164);b=x[31725];x[31725]=0;if((b|0)!=1){break b}b=T(0)|0;break f}b=T(0)|0;break e}b=T(0)|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=Bg(22255);break j}b=Bg(Kb(Hd(d,b)))}Td(f+4|0);break d}b=T(0)|0;jc(d)}Td(f+4|0)}Y(b|0)|0;b=0;x[31725]=0;V(989,c|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Z()}fb=f+16|0;return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break a}T(0)|0;Sb()}p()}Q(a|0);p()}function kha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=Ri(a,b,c,d);x[b+4260>>2]=0;x[b>>2]=45212;c=b+4960|0;e=b+4504|0;d=e;while(1){d=Nb(d)+24|0;if((d|0)!=(c|0)){continue}break}v[b+5046|0]=1;w[b+5044>>1]=0;a=b+4208|0;f=yb(a,0),g=1063675494,x[f>>2]=g;f=yb(a,1),g=1065185444,x[f>>2]=g;f=yb(a,2),g=0,x[f>>2]=g;f=yb(a,3),g=1032805417,x[f>>2]=g;f=yb(a,4),g=1053079357,x[f>>2]=g;f=yb(a,5),g=1059859440,x[f>>2]=g;f=yb(a,6),g=1047457519,x[f>>2]=g;f=yb(a,7),g=1062836634,x[f>>2]=g;f=yb(a,8),g=1038174126,x[f>>2]=g;f=yb(a,9),g=1065353216,x[f>>2]=g;f=yb(a,10),g=1065353216,x[f>>2]=g;f=yb(a,11),g=1048525618,x[f>>2]=g;f=yb(a,12),g=1059760811,x[f>>2]=g;x[31725]=0;O(947,b+44|0,2);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;while(1){c=uc(c-24|0);if((e|0)!=(c|0)){continue}break}ag(b);Q(a|0);p()}return b|0}function A3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=Nb(a);a=0;a:{b:{c:{while(1){if((Kx(b,c,a)|0)==-1){break b}f=Kx(b,c,a);x[31725]=0;V(102,d+4|0,b|0,a|0,f-a|0);f=x[31725];x[31725]=0;if((f|0)!=1){x[31725]=0;O(103,e|0,d+4|0);f=x[31725];x[31725]=0;if((f|0)==1){break c}tb(d+4|0);a=Kx(b,c,a)+Yc(x[c+4>>2],y[c+11|0])|0;continue}break}a=N()|0;break a}a=N()|0;tb(d+4|0);break a}d:{e:{f:{g:{if(lc(x[e>>2],x[e+4>>2])){x[31725]=0;V(102,d+4|0,b|0,a|0,-1);c=x[31725];x[31725]=0;if((c|0)==1){break f}c=Yc(x[d+8>>2],y[d+15|0]);tb(d+4|0);if(!c){break g}}x[31725]=0;V(102,d+4|0,b|0,a|0,-1);a=x[31725];x[31725]=0;if((a|0)==1){break e}x[31725]=0;O(103,e|0,d+4|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}tb(d+4|0)}fb=d+16|0;return}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(d+4|0)}Td(e);Q(a|0);p()}function oK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=fb-32|0;fb=h;a:{b:{c:{if((b|0)!=(c|0)){j=x[31600];x[31600]=0;g=fb-16|0;fb=g;Od();e=fb-16|0;fb=e;f=fb-16|0;fb=f;Cy(f,b,h+28|0,2);k=x[f>>2];i=x[f+4>>2];b=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=b;x[e>>2]=k;x[e+4>>2]=i;fb=f+16|0;i=x[e>>2];f=x[e+4>>2];b=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=b;x[g>>2]=i;x[g+4>>2]=f;fb=e+16|0;f=x[g>>2];e=x[g+4>>2];b=x[g+12>>2];x[h+16>>2]=x[g+8>>2];x[h+20>>2]=b;x[h+8>>2]=f;x[h+12>>2]=e;fb=g+16|0;g=x[h+16>>2];i=x[h+20>>2];e=x[h+8>>2];f=x[h+12>>2];b=x[31600];if(!b){break c}if(x[h+28>>2]!=(c|0)){break b}l=e;m=f;n=g;o=i;if((b|0)!=68){break a}break b}x[d>>2]=4;break a}x[31600]=j;if(x[h+28>>2]==(c|0)){break a}}x[d>>2]=4;e=l;f=m;g=n;i=o}x[a>>2]=e;x[a+4>>2]=f;x[a+8>>2]=g;x[a+12>>2]=i;fb=h+32|0}function pna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;p=w[e+38150>>1];q=w[e+38148>>1];r=w[e+38146>>1];e=w[e+38144>>1];h=0;while(1){if((h|0)!=2){i=h+o|0;x[(h<<2)+b>>2]=(((D(v[i|0],r)+D(v[i-2|0],e)|0)+D(v[i+2|0],q)|0)+D(v[i+4|0],p)<<8)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Pb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function yr(a,b){var c=0;c=fb-16|0;fb=c;a=hs(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:RA(c,2);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;dg(a,107);break a;case 3:RA(c,4);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;dg(a,4);break a;case 2:break b;case 0:break c}}Lb(a,88,1);break a}RA(c,b);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b}fb=c+16|0}function dB(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=z[a+480188>>1];h=d>>>0<=256?256:d;f=x[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=D(c,872)+a|0;if(!x[e+1075068>>2]){if(!Lj(x[e+1075648>>2])|y[e+1075081|0]&24){break a}}if(y[e+1075081|0]&2){if(!Dd(f)){break a}if(!XS(f,c&65535)){break a}}c=c+1|0;continue}break}g=8388608;if(b>>>0<=255){b=D(b,872)+a|0;if(!x[b+1075688>>2]){c=65535;if(x[b+1075068>>2]){break a}}g=x[b+1075680>>2]|x[b+1075672>>2]<<9}e=0;c=65535;while(1){if((d|0)==(h|0)){break a}b=D(d,872)+a|0;if(!(x[b+1075688>>2]?0:x[b+1075068>>2])){f=(x[b+1075680>>2]|x[b+1075672>>2]<<9)>>>(x[b+1075080>>2]>>>1&1)|0;b:{c:{if(f>>>0<g>>>0){b=x[b+1075716>>2];break c}if((f|0)!=(g|0)){break b}b=x[b+1075716>>2];if(e>>>0>=b>>>0){break b}}g=f;c=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function Cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;k=Hf(a,c);$d(f,x[a+36>>2]);l=a;a:{if(!k){Pc(f,a+32|0,5);c=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}e=fb-48|0;fb=e;i=x[a+36>>2];vl(i,e+40|0);g=x[e+44>>2];if(!g&A[e+40>>2]>=257|g){x[e+40>>2]=256;x[e+44>>2]=0}g=x[e+40>>2];m=x[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=g>>>0){break b}pg(i,e+38|0);h=Fb(e+24|0);x[31725]=0;P(500,i|0,h|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;S(498,e+12|0,d|0,h|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}x[31725]=0;a=P(937,b|0,e+38|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break d}j=a;a=e+12|0;Ab(j,a);tb(a);tb(h);c=c+1|0;continue}break}c=N()|0;break c}c=N()|0;break c}c=N()|0;tb(e+12|0)}tb(h);Q(c|0);p()}fb=e+48|0;c=k}gf(l,c);fb=f+16|0}function mja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((qk(x[a>>2],x[a+4>>2])|0)==2){if((qk(x[a+12>>2],x[a+16>>2])|0)==(b|0)){break b}}x[31725]=0;O(949,a|0,2);c=x[31725];x[31725]=0;c:{if((c|0)==1){break c}x[31725]=0;O(949,a+12|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}x[31725]=0;O(950,a+24|0,2);c=x[31725];x[31725]=0;if((c|0)==1){break c}x[31725]=0;O(950,a+36|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=es(x[c+12>>2],a);f=yb(x[c+36>>2],a),g=d,x[f>>2]=g;a=a+1|0;continue}}else{e=es(x[a>>2],d);f=yb(x[a+24>>2],d),g=e,x[f>>2]=g;d=d+1|0;continue}}b=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;dA(a);$Q(a);b=a+12|0;dA(b);$Q(b);b=a+24|0;Nf(b);_Q(b);a=a+36|0;Nf(a);_Q(a);Z()}return}Q(b|0);p()}function sd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=x[a+112>>2];d=x[a+116>>2];i=!!(b|d);e=b;f=x[a+4>>2];h=x[a+44>>2];b=f-h|0;g=b;c=b+x[a+120>>2]|0;b=x[a+124>>2]+(b>>31)|0;a:{b=c>>>0<g>>>0?b+1|0:b;if(!(((b|0)>=(d|0)&c>>>0>=e>>>0|(b|0)>(d|0))&i)){i=Ky(a);if((i|0)>=0){break a}f=x[a+4>>2];h=x[a+44>>2]}x[a+112>>2]=-1;x[a+116>>2]=-1;x[a+104>>2]=f;g=c;c=h-f|0;d=g+c|0;b=(c>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=c>>>0>d>>>0?b+1|0:b;return-1}d=c+1|0;b=d?b:b+1|0;f=x[a+4>>2];h=x[a+8>>2];e=x[a+116>>2];g=e;c=x[a+112>>2];b:{if(!(e|c)){break b}e=c-d|0;c=g-(b+(c>>>0<d>>>0)|0)|0;j=h-f|0;g=j>>31;if((c|0)>=(g|0)&e>>>0>=j>>>0|(c|0)>(g|0)){break b}h=e+f|0}x[a+104>>2]=h;c=x[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){v[f-1|0]=i}return i}function Dia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=fb-4112|0;fb=c;h=ib[x[x[a>>2]+120>>2]](a)|0;if(!h){ib[x[x[a>>2]+124>>2]](a)}x[c+12>>2]=0;f=fb-16|0;fb=f;while(1){d=x[a+44>>2];if(qk(d,x[a+48>>2])>>>0<=e>>>0){fb=f+16|0}else{x[f+12>>2]=0;d=es(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){B[d>>2]=B[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){x[c+8>>2]=b;wc(c+8|0,512);e=c+16|0;VA(e);d=x[c+8>>2];ib[x[x[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;B[c+4>>2]=F(B[g>>2]);i=c,j=B[Wz(c+12|0,c+4|0)>>2],B[i+12>>2]=j;B[c+4>>2]=F(B[g+2048>>2]);i=c,j=B[Wz(c+12|0,c+4|0)>>2],B[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){ib[x[x[a>>2]+128>>2]](a)}fb=c+4112|0;return E(B[c+12>>2])}function $pa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb+-64|0;fb=c;i=c,j=lf(a)>>>5|0,w[i+32>>1]=j;w[c+20>>1]=3999;d=z[Nc(c+32|0,c+20|0)>>1];w[b+480190>>1]=d;g=1;while(1){f=g&65535;if(f>>>0<=d>>>0){d=ui(b,f);e=c+32|0;Fr(a,e);ld(d,0);h=c+8|0;wi(h,2,e);e=c+20|0;Cc(e,h);zc(((f<<5)+b|0)+946304|0,e);tb(e);x[d+24>>2]=8287;i=c,j=Bb(y[c+60|0]|y[c+61|0]<<8),w[i+20>>1]=j;w[c+8>>1]=64;i=d,j=z[Nc(e,h)>>1]<<2,w[i+30>>1]=j;i=d,j=$b(y[c+52|0]|y[c+53|0]<<8|(y[c+54|0]<<16|y[c+55|0]<<24))&-2,x[i>>2]=j;e=Bb(y[c+62|0]|y[c+63|0]<<8);i=yb(d+68|0,0),j=e,x[i>>2]=j;e=Bb(y[c+56|0]|y[c+57|0]<<8);f=Bb(y[c+58|0]|y[c+59|0]<<8);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>A[d>>2]){break a}x[d+16>>2]=f;x[d+12>>2]=e<<1;w[d+34>>1]=z[d+34>>1]|8}g=g+1|0;d=z[b+480190>>1];continue}break}fb=c- -64|0}function YT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;c=vb(g+12|0,x[a+4>>2]);d=vb(g+8|0,x[a>>2]);e=x[vb(g+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;j=h+8|0;f=fb-32|0;fb=f;Id(f+24|0,x[c>>2],x[d>>2]);k=f+16|0;c=x[f+24>>2];l=x[f+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=e;x[d+12>>2]=c;while(1){if(pd(c,l)){c=VT(c);e=VT(x[d+8>>2]);i=y[c+3|0]|y[c+4|0]<<8|(y[c+5|0]<<16|y[c+6|0]<<24);v[e+3|0]=i;v[e+4|0]=i>>>8;v[e+5|0]=i>>>16;v[e+6|0]=i>>>24;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=c;v[e+1|0]=c>>>8;v[e+2|0]=c>>>16;v[e+3|0]=c>>>24;c=UT(d+12|0);UT(d+8|0);c=x[c>>2];continue}break}Ac(k,c,d+8|0);fb=d+16|0;c=x[f+16>>2];x[f+12>>2]=x[f+20>>2];Ac(j,c,f+12|0);fb=f+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=g+16|0}function Dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb+-64|0;fb=e;x[e+60>>2]=c;a=re(a,e+60|0);c=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31725]=0;O(997,a|0,d|0);f=x[31725];x[31725]=0;a:{b:{c:{d:{if((f|0)!=1){oe(e+24|0,x[b>>2],x[b+4>>2]);mf(e+32|0,x[e+24>>2],x[e+28>>2]);b=Nd(e+16|0);x[31725]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;Os(1001,e+40|0,x[e+32>>2],x[e+36>>2],e+8|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;S(998,a|0,e+40|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}ub(e+40|0);x[31725]=0;W(999,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(e+40|0)}Td(j);of(i);Jl(h);xh(g);wh(c);Vc(a);Vc(e+60|0);Q(d|0);p()}Vc(e+60|0);fb=e- -64|0;return a|0}function Mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Pb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function Lha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=0,q=0,r=0,s=0;h=fb-16|0;fb=h;if(Ai(a+44|0)){g=x[a+44>>2];r=h,s=Hc(g,0),x[r+8>>2]=s;r=h,s=Hc(g,1),x[r+12>>2]=s;g=x[a+56>>2];l=Hc(g,0);x[h>>2]=l;m=Hc(g,1);x[h+4>>2]=m;p=y[a+4273|0];q=y[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=x[i>>2];x[i>>2]=e+4;f=E(B[e>>2]*B[a+4240>>2]);e=a+j|0;i=e+4228|0;f=E(f+E(B[i>>2]*B[a+4236>>2]));B[i>>2]=f;f=oQ(E(f*E(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=B[e>>2];o=B[a+4264>>2];f=E(E(E(f*B[a+4260>>2])-E(B[a+4268>>2]*B[i>>2]))-E(n*o));B[e>>2]=f;B[i>>2]=n+E(f*o);e=h+j|0;j=x[e>>2];x[e>>2]=j+4;B[j>>2]=f*E(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{Qi(a,b,c,l,m,d)}break}}fb=h+16|0}function Gda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb+-64|0;fb=f;x[f+60>>2]=d;a=re(a,f+60|0);d=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31725]=0;O(997,a|0,e|0);k=x[31725];x[31725]=0;a:{b:{c:{d:{if((k|0)!=1){bc(f+24|0,b,c);mf(f+32|0,x[f+24>>2],x[f+28>>2]);b=Nd(f+16|0);x[31725]=0;c=x[b+4>>2];x[f+8>>2]=x[b>>2];x[f+12>>2]=c;Os(1001,f+40|0,x[f+32>>2],x[f+36>>2],f+8|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;S(998,a|0,f+40|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}ub(f+40|0);x[31725]=0;W(999,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(f+40|0)}Td(j);of(i);Jl(h);xh(g);wh(d);Vc(a);Vc(f+60|0);Q(e|0);p()}Vc(f+60|0);fb=f- -64|0;return a|0}function aR(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;if(!(oc(x[a>>2],x[a+4>>2])>>>0>511|x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){d=fb-16|0;fb=d;f=Ec(64);x[31725]=0;g=R(879,f|0)|0;h=x[31725];x[31725]=0;a:{b:{if((h|0)!=1){f=yf(d+8|0,g);g=x[f>>2];x[31725]=0;g=U(944,g|0,b|0,c|0)|0;h=x[31725];x[31725]=0;c:{d:{if((h|0)!=1){if((g|0)==1){break d}sc(d+12|0);break c}a=N()|0;og(f);break b}re(d+12|0,f)}og(f);fb=d+16|0;d=x[d+12>>2];break a}a=N()|0;Db(f)}Q(a|0);p()}x[e+12>>2]=d;e:{f:{if(!Dd(d)){x[31725]=0;b=P(942,b|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break f}x[e+8>>2]=b;b=e+8|0;IZ(e+12|0,le(b));og(b);d=x[e+12>>2]}if(!Dd(d)){break e}x[31725]=0;O(502,a|0,e+12|0);a=x[31725];x[31725]=0;i=d;if((a|0)!=1){break e}}a=N()|0;og(e+12|0);Q(a|0);p()}og(e+12|0)}fb=e+16|0;return i}function Lo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[b+88>>2];d=c|2048;x[b+88>>2]=d;f=x[b+656>>2];if(!(!f|v[b+730|0]&1)){d=c|6144;x[b+88>>2]=d}a:{if(!x[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=x[b+104>>2];if(!c){break b}e=z[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;x[b+88>>2]=d;e=x[c>>2];x[b+76>>2]=e;g=x[c+4>>2];x[b+80>>2]=g;c=x[c+8>>2];x[b+84>>2]=c;if(c>>>0<e>>>0){x[b+76>>2]=c;h=c}else{h=e}e=x[b+4>>2];if(h>>>0>=e>>>0){break b}x[b>>2]=0;x[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;x[b+88>>2]=d;x[b+76>>2]=x[c>>2]}if(!f){break a}if(!(!(y[f+60|0]&2|x[a+480180>>2]&1064964)|!x[f>>2])){x[b+88>>2]=d|4096}if(y[f+65|0]==255|z[b+728>>1]!=65535){break a}i=b,j=ed(Xq(f+48|0,x[b+724>>2],256,64)),w[i+728>>1]=j;i=b,j=z[yb(x[f+48>>2],y[f+65|0])>>1],x[i+724>>2]=j}}function aI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[31725]=0;W(1002,a|0);e=x[31725];x[31725]=0;a:{b:{c:{if((e|0)!=1){e=Fb(d+20|0);x[31725]=0;W(c|0,d+8|0);c=x[31725];x[31725]=0;d:{e:{if((c|0)!=1){h=d,i=wb(x[d+8>>2]),x[h+4>>2]=i;f=1;while(1){g=wb(x[d+12>>2]);c=x[d+4>>2];if(!Ib(c,g)){c=Bg(Kb(e));Td(d+8|0);tb(e);break b}if(!f){x[31725]=0;P(991,e|0,14604)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}c=x[d+4>>2]}x[31725]=0;P(842,e|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}jl(d+4|0);f=0;continue}}c=T(0)|0;break d}c=T(0)|0;Td(d+8|0)}tb(e);break c}c=T(0)|0}Y(c|0)|0;c=0;x[31725]=0;V(989,b|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}fb=d+32|0;return c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){T(0)|0;Sb();p()}Q(a|0);p()}function Xq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;a:{e=x[a>>2];f=x[a+4>>2];if(lc(e,f)){break a}i=Sd(e,f)-1|0;while(1){b:{if(Sd(e,f)-1>>>0>g>>>0){j=Oc(e,f,g);f=x[a+4>>2];e=x[a>>2];if(z[j>>1]<(b|0)){break b}i=g}g=z[Oc(e,f,i)>>1];f=0;x[h+12>>2]=0;c:{if((b|0)>=(g|0)){k=h,l=(y[Oc(x[a>>2],x[a+4>>2],i)+2|0]<<16>>>0)/(d>>>0)|0,x[k+12>>2]=l;break c}e=0;if(i){e=i-1|0;f=(y[Oc(x[a>>2],x[a+4>>2],e)+2|0]<<16>>>0)/(d>>>0)|0;x[h+12>>2]=f;e=z[Oc(x[a>>2],x[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=g>>>0){break c}a=((y[Oc(x[a>>2],x[a+4>>2],i)+2|0]<<16>>>0)/(d>>>0)|0)-f|0;d=a;i=a>>31;a=b-e|0;b=ova(d,i,a,a>>31);a=g-e|0;k=h,l=Gc(pva(b,hb,a,a>>31),hb)+f|0,x[k+12>>2]=l}Fe(h+12|0,0,65536);g=(D(x[h+12>>2],c)+32768|0)/65536|0;break a}g=g+1|0;continue}}fb=h+16|0;return g}function Cq(a){var b=E(0),c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;e=(q(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=E(1);if(d>>>0<964689920){break a}b=Fi(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=E(-Fi(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=Gi(f+1.5707963267948966);break a}b=Gi(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Fi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=Gi(-4.71238898038469-+a);break a}b=Gi(+a+-4.71238898038469);break a}b=E(a-a);if(d>>>0>=2139095040){break a}b:{switch(Yy(a,c+8|0)&3){case 0:b=Fi(C[c+8>>3]);break a;case 1:b=Gi(-C[c+8>>3]);break a;case 2:b=E(-Fi(C[c+8>>3]));break a;default:break b}}b=Gi(C[c+8>>3])}a=b;fb=c+16|0;return a}function X2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;x[c+28>>2]=0;if(Ed(y[Mm(c+27|0,a,0)|0])){bd(c+16|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31725]=0;e=R(1181,x[c+16>>2])|0;d=x[31725];x[31725]=0;a:{b:{if((d|0)!=1){d=xp(c+12|0,a);f=sc(c+8|0);g=x[x[a>>2]-12>>2];f=x[f>>2];d=x[d>>2];x[31725]=0;ja(1183,e|0,d|0,f|0,a+g|0,c+28|0,c+20|0);e=x[31725];x[31725]=0;if((e|0)!=1){break b}}b=T(0)|0;Zb(c+16|0);Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;Km(x[x[a>>2]-12>>2]+a|0,b);c:{d:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break d}Q(a|0);p()}Z();break a}T(0)|0;Sb()}p()}Zb(c+16|0);x[b>>2]=x[c+20>>2]}fk(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}fb=c+32|0;return a|0}function VM(a,b){var c=0,d=0,e=0;x[a+4>>2]=b;x[a>>2]=126944;x[a+8>>2]=b;e=(b|0)!=0;x[a+12>>2]=e;c=b&31;if((b&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}x[a+24>>2]=0;c=c&65536;x[a+28>>2]=c;d=c^65536;a:{if((c|0)==(d|0)|c>>>0>d>>>0){c=b;break a}c=b>>>e|0;x[a+8>>2]=c;e=b?2:1;x[a+12>>2]=e;d=c&31;if((c&63)>>>0>=32){d=-1<<d}else{d=(1<<d)-1&-1>>>32-d|-1<<d}x[a+24>>2]=0;x[a+28>>2]=d&65536}x[a+16>>2]=e-((b>>>0)%(e>>>0)|0);d=63-c|0;b=d&31;if((d&63)>>>0>=32){d=0;b=-1>>>b|0}else{d=-1>>>b|0;b=d|(1<<b)-1<<32-b}x[a+48>>2]=b;x[a+52>>2]=d;d=64-c|0;b=d&31;if((d&63)>>>0>=32){d=0;b=-1>>>b|0}else{d=-1>>>b|0;b=d|(1<<b)-1<<32-b}x[a+40>>2]=c?b:0;x[a+44>>2]=c?d:0;c=c+1|0;b=c&31;if((c&63)>>>0>=32){c=-1<<b}else{c=(1<<b)-1&-1>>>32-b|-1<<b}x[a+32>>2]=0;x[a+36>>2]=c&65536;return a}function AF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;x[31725]=0;f=P(21,e+8|0,a|0)|0;d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!Ed(y[f|0])){break e}g=xp(e+4|0,a);d=x[x[a>>2]-12>>2]+a|0;h=x[d+4>>2];x[31725]=0;i=R(22,d|0)|0;j=x[31725];x[31725]=0;if((j|0)==1){break d}g=x[g>>2];x[31725]=0;c=b+c|0;b=ea(23,g|0,b|0,((h&176)==32?c:b)|0,c|0,d|0,i|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}if(b){break e}b=x[x[a>>2]-12>>2];x[31725]=0;O(24,a+b|0,5);b=x[31725];x[31725]=0;if((b|0)!=1){break e}break d}om(f);break b}b=T(0)|0;om(f);break c}b=T(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[31725]=0;W(25,a+b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}Z()}fb=e+16|0;return a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){T(0)|0;Sb();p()}Q(a|0);p()}function QP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=fb-48|0;fb=j;k=x[a+4>>2];l=x[a>>2];a=x[a+8>>2];x[j+32>>2]=b;x[j+44>>2]=a;x[j+36>>2]=l;x[j+40>>2]=k;x[31725]=0;a=P(982,(d?d:983)|0,e|0)|0;b=x[31725];x[31725]=0;a:{b:{c:{d:{if((b|0)!=1){x[j+24>>2]=a;a=x[re(j+28|0,j+24|0)>>2];b=x[j+44>>2];x[j+16>>2]=x[j+40>>2];x[j+20>>2]=b;x[31725]=0;b=x[j+36>>2];x[j+8>>2]=x[j+32>>2];x[j+12>>2]=b;c=+pa(984,j+8|0,+c,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}Vc(j+24|0);break b}a=T(0)|0;break c}a=T(0)|0;Vc(j+24|0)}Y(a|0)|0;x[31725]=0;ga(985,15043,d|0,e|0,f|0,g|0,h|0,i|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();c=0}fb=j+48|0;return+c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Mba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;j=d,k=kN(),x[j+12>>2]=k;g=a+24|0;c=d+12|0;iN(g,le(c));xh(c);w[a+28>>1]=0;WP();f=fb-16|0;fb=f;e=Ec(144);x[31725]=0;h=P(1134,e|0,4)|0;i=x[31725];x[31725]=0;a:{if((i|0)!=1){e=x[yf(f+12|0,h)>>2];fb=f+16|0;break a}a=N()|0;Db(e);Q(a|0);p()}x[d+12>>2]=e;hN(a+32|0,le(c));Jl(c);j=d,k=jN(x[a>>2]),x[j+12>>2]=k;gN(a+4|0,le(c));wh(c);Ao(x[g>>2],x[a+4>>2]);v[a+64|0]=1;x[a+60>>2]=0;x[a+48>>2]=1065353216;x[a+52>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;j=d,k=$i(x[b>>2]),x[j+12>>2]=k;e=Rf(b);b:{while(1){b=x[d+12>>2];if(!Zg(b,e)){break b}c=td(b);b=lg(d,c);x[31725]=0;V(1018,a|0,b|0,c+12|0,0);c=x[31725];x[31725]=0;if((c|0)!=1){tb(b);ah(d+12|0);continue}break}a=N()|0;tb(b);Q(a|0);p()}fb=d+16|0}function W1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;cd(b,y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24));h=Nb(a);a=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);x[31725]=0;O(181,h|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))>>>0<=a>>>0){break b}e=x[b+8>>2];f=x[b>>2];x[31725]=0;e=U(152,f|0,e|0,4)|0;f=x[31725];x[31725]=0;if((f|0)==1){break a}if(!e){break b}e=y[c+4|0]|y[c+5|0]<<8;x[31725]=0;e=P(182,b|0,e|0)|0;f=x[31725];x[31725]=0;c:{if((f|0)!=1){x[g+12>>2]=e;if(Ud(x[d>>2],x[d+4>>2])>>>0<=e>>>0){break c}x[31725]=0;O(183,h|0,g+12|0);e=x[31725];x[31725]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}fb=g+16|0;return}}a=N()|0;uc(h);Q(a|0);p()}function KQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;e=x[b+4220>>2];f=x[b+4224>>2];g=x[b+4228>>2];h=x[b+4232>>2];i=x[b+4240>>2];j=x[b+4236>>2];k=y[b+4244|0];_j(b+4208|0,33);d=x[b+4208>>2];v[d+32|0]=k;v[d+24|0]=j;v[d+25|0]=j>>>8;v[d+26|0]=j>>>16;v[d+27|0]=j>>>24;v[d+28|0]=i;v[d+29|0]=i>>>8;v[d+30|0]=i>>>16;v[d+31|0]=i>>>24;v[d+16|0]=g;v[d+17|0]=g>>>8;v[d+18|0]=g>>>16;v[d+19|0]=g>>>24;v[d+20|0]=h;v[d+21|0]=h>>>8;v[d+22|0]=h>>>16;v[d+23|0]=h>>>24;v[d+8|0]=e;v[d+9|0]=e>>>8;v[d+10|0]=e>>>16;v[d+11|0]=e>>>24;v[d+12|0]=f;v[d+13|0]=f>>>8;v[d+14|0]=f>>>16;v[d+15|0]=f>>>24;v[d|0]=76;v[d+1|0]=70;v[d+2|0]=79;v[d+3|0]=32;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;oe(c+8|0,x[b+4208>>2],x[b+4212>>2]);gc(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function C4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-160|0;fb=d;Tb(d+116|0,0,44);while(1){if((c|0)==7){a:{c=0;while(1){if((c|0)==12){break a}x[d+132>>2]=c;e=d+16|0;f=d+116|0;fa(e|0,100,14278,f|0,x[a>>2])|0;g=D(c,12)+a|0;id(g+172|0,e);fa(e|0,100,13333,f|0,x[a>>2])|0;id(g+316|0,e);c=c+1|0;continue}}}else{x[d+140>>2]=c;e=d+16|0;f=d+116|0;fa(e|0,100,14291,f|0,x[a>>2])|0;g=D(c,12)+a|0;id(g+4|0,e);fa(e|0,100,13540,f|0,x[a>>2])|0;id(g+88|0,e);c=c+1|0;continue}break}x[d+124>>2]=1;c=d+16|0;e=d+116|0;fa(c|0,100,9262,e|0,x[a>>2])|0;id(a+460|0,c);x[d+124>>2]=13;fa(c|0,100,9262,e|0,x[a>>2])|0;id(a+472|0,c);c=d+4|0;Us(c,a,99,b);Ab(a+484|0,c);tb(c);Us(c,a,114,b);Ab(a+496|0,c);tb(c);Us(c,a,120,b);Ab(a+508|0,c);tb(d+4|0);Us(c,a,88,b);Ab(a+520|0,c);tb(d+4|0);fb=d+160|0}function vx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;e=zb(a);c=vb(h+12|0,x[a+4>>2]);f=vb(h+8|0,x[a>>2]);g=vb(h+4|0,x[b+4>>2]);d=x[c>>2];f=x[f>>2];c=fb+-64|0;fb=c;g=x[g>>2];x[c+56>>2]=g;x[c+60>>2]=d;x[c+52>>2]=g;e=Se(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];g=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=g;Re(c+36|0,c+8|0);while(1){if(pd(d,f)){As(Xp(x[c+56>>2]),kl(d));d=uk(c+60|0);uk(c+56|0);d=x[d>>2];continue}break}Qe(c+36|0);g=x[c+56>>2];if(!y[c+48|0]){e=fb-16|0;fb=e;d=vb(e+12|0,x[x[c+44>>2]>>2]);i=x[vb(e+8|0,x[x[c+40>>2]>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(di(d,i)){Eb(ux(d));d=x[jl(f+12|0)>>2];continue}break}fb=f+16|0;fb=e+16|0}fb=c- -64|0;x[b+4>>2]=g;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function Vja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-32|0;fb=e;c=z[x[x[a+48>>2]+12>>2]+480188>>1];a:{if(!b){break a}c=D(b,c);b:{if(x[a+12>>2]!=(b|0)){break b}if((Pk(x[a>>2],x[a+4>>2])|0)!=(c|0)){break b}b=fb-16|0;fb=b;d=wb(x[a>>2]);a=wb(x[a+4>>2]);w[b+12>>1]=0;x[b+8>>2]=0;f=xu(a,d);c=fb-16|0;fb=c;x[c+12>>2]=d;while(1){if((f|0)>0){a=x[c+12>>2];d=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8;v[a+4|0]=d;v[a+5|0]=d>>>8;f=f-1|0;vg(c+12|0);continue}break}fb=c+16|0;fb=b+16|0;break a}w[e+16>>1]=0;x[e+12>>2]=0;c=UZ(e+20|0,c,e+12|0);BR(a);x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];f=zb(c);g=zb(a),h=x[f>>2],x[g>>2]=h;x[f>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Sk(c);x[a+12>>2]=b}fb=e+32|0}function rQ(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;e=(q(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Gi(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=E(-Fi(d+1.5707963267948966));break a}a=Fi(d+-1.5707963267948966);break a}a=Gi(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=Fi(d+4.71238898038469);break a}a=E(-Fi(d+-4.71238898038469));break a}a=Gi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=E(a-a);break a}b:{switch(Yy(a,b+8|0)&3){case 0:a=Gi(C[b+8>>3]);break a;case 1:a=Fi(C[b+8>>3]);break a;case 2:a=Gi(-C[b+8>>3]);break a;default:break b}}a=E(-Fi(C[b+8>>3]))}fb=b+16|0;return a}function dM(a){var b=E(0),c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=E(0),o=E(0);f=B[a>>2];i=B[a+24>>2];c=E(f-i);d=B[a+16>>2];b=B[a+32>>2];g=B[a+8>>2];e=E(d+E(b-g));B[a+16>>2]=c+e;j=E(c-E(e*E(.5)));c=B[a+4>>2];e=B[a+20>>2];h=B[a+28>>2];k=E(E(E(c-e)-h)*E(.8660253882408142));B[a+4>>2]=j+k;l=E(E(d-b)*E(.1736481785774231));f=E(f+E(i*E(.5)));i=E(E(g+b)*E(.7660444378852844));m=E(l+E(f-i));n=E(E(c+e)*E(.9848077297210693));b=E(B[a+12>>2]*E(.8660253882408142));c=E(E(c+h)*E(.6427876353263855));o=E(E(n-b)-c);B[a+12>>2]=m+o;B[a+20>>2]=m-o;B[a+28>>2]=j-k;d=E(E(g+d)*E(.9396926164627075));g=E(E(f+d)-l);e=E(E(e-h)*E(.3420201539993286));h=E(E(e-b)-n);B[a+32>>2]=g+h;d=E(E(f-d)+i);b=E(E(b+e)-c);B[a+24>>2]=d+b;B[a+8>>2]=d-b;B[a>>2]=g-h}function ara(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+15|0]=0;w[e+12>>1]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(k|0)){h=(k<<1)+b|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){w[e+10>>1]=0;yY(a,e+15|0,e+12|0,j,e+10|0);i=z[e+10>>1];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!Af(a,e+9|0)){break c}f=y[e+9|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&65535;e:{if(g>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=c-1|0;if(!(g&1<<m)){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&65534)>>>1)+l|0;w[e+10>>1]=l;w[h>>1]=l;h=(d<<1)+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-80|0;fb=c;a:{d=x[a+4>>2];b:{if(d>>>0<b>>>0){f=Nd(c+72|0);e=b-d|0;g=fv(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){fr(c+60|0,x[a>>2],d);gc(f,x[c+60>>2],x[c+64>>2]);x[a+4>>2]=x[a+4>>2]+e;break c}d=Zo(c+60|0);x[31725]=0;b=P(761,a|0,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}x[31725]=0;O(762,d|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[d+4>>2]=x[a+4>>2]+e;tn(c+44|0,x[a>>2]);fr(c+32|0,x[a>>2],x[a+4>>2]);tn(c+24|0,x[d>>2]);b=x[c+48>>2];x[c+8>>2]=x[c+44>>2];x[c+12>>2]=b;vX(c+52|0,c+8|0,x[c+32>>2],x[c+36>>2],x[c+24>>2],x[c+28>>2]);gc(f,x[c+52>>2],x[c+56>>2]);iC(a,d);uf(d)}a=gc(c+16|0,x[f>>2],x[f+4>>2]);Qw(x[a>>2],x[a+4>>2],e,0);break b}x[a+4>>2]=b}fb=c+80|0;return}a=N()|0;uf(d);Q(a|0);p()}function uB(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{f=a+1074312|0;if(j=Ob(f,77),k=0,l=x[(D(c,872)+b|0)+704>>2]&134218752,l?j:k){break a}g=x[a+480180>>2]!=2?c:0;e=D(g,872);if(!d){x[(b+e|0)+1380>>2]=x[b+48>>2];return}h=(b+e|0)+1457|0;c=y[h|0];b:{if(c){c=c-1|0;v[h|0]=c;if(c&255){break b}if(!Ob(f,16)&x[a+480180>>2]!=2){break a}x[(D(g,872)+b|0)+1380>>2]=x[b+48>>2]+1;return}c:{if(Ob(f,17)|y[a+480180|0]&3){break c}c=b+616|0;i=e+c|0;e=0;a=z[a+480188>>1];while(1){if(a>>>0<=(e&65535)>>>0){break c}if(y[c+841|0]?(c|0)!=(i|0):0){break a}c=c+872|0;e=e+1|0;continue}}v[h|0]=d}a=x[(D(g,872)+b|0)+1380>>2];x[b+56>>2]=a;if((a|0)==-1){break a}d:{if(x[b+60>>2]==-1){break d}if(!Ob(f,68)){break d}x[b+60>>2]=a}x[b+64>>2]=a;if(!Ob(f,103)){break a}w[b+68>>1]=65535}}function Mo(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;if(e){x[e>>2]=0}a:{i=x[a+484344>>2];if(!He(i,x[a+484348>>2],b)){break a}g=Wb(i,b);k=x[g+48>>2];b=jd(x[g>>2],x[k+12>>2],c,d);f=y[b+5|0];b:{c:{d:{e:{j=y[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}x[h+12>>2]=1;i=0;if((j|0)!=17){break b}i=x[a+480180>>2]==4;break b}x[h+12>>2]=2;i=0}x[h+8>>2]=x[g+12>>2]+(c^-1);d=0;a=x[Gb(h+8|0,h+12|0)>>2];c=a;while(1){f:{if(c){b=D(z[x[k+12>>2]+480188>>1],6)+b|0;if(y[b+3|0]==34){break f}a=d}f=(j-37&255)>>>0<254?f:a?f:f<<8;if(!e){break a}x[e>>2]=a;break a}g=f<<8;f=y[b+5|0]|(i?f>>>0>31?f>>>0<256?g+-8192|0:g:g:g);d=d+1|0;c=c-1|0;continue}}fb=h+16|0;return f}function Es(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;x[d+28>>2]=0;a:{b:{c:{if(Ed(y[Mm(d+27|0,a,0)|0])){bd(d+20|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31725]=0;g=R(1181,x[d+20>>2])|0;e=x[31725];x[31725]=0;d:{e:{if((e|0)==1){break e}e=xp(d+16|0,a);f=sc(d+12|0);h=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[31725]=0;ja(c|0,g|0,e|0,f|0,a+h|0,d+28|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break e}Zb(d+20|0);break d}b=T(0)|0;Zb(d+20|0);Y(b|0)|0;b=x[d+28>>2]|1;x[d+28>>2]=b;Km(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break c}Q(a|0);p()}Z()}fk(x[x[a>>2]-12>>2]+a|0,x[d+28>>2])}fb=d+32|0;break a}T(0)|0;Sb()}p()}return a}function hY(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=v[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=D(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=v[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=y[e+45|0];if(y[e+44|0]|c>>>0>64){break a}b=Bb(y[e+42|0]|y[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=y[a+470|0];if(d>>>0>128){break a}b=y[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=NC(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=Ut(y[a|0],y[c|0])?c:a;continue}}a=y[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function SB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;i=Yl(a,b);a:{if((i|0)==255){break a}if(Pj(x[a>>2])){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}g=c;f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=20-f|0;j=c&31;if((c&63)>>>0>=32){c=g<<j;g=0}else{c=(1<<j)-1&g>>>32-j;g=g<<j}g=g+24858e3|0;if(g>>>0<24858e3){c=c+1|0}c=Bc(qva(g,c,49716e3,0),hb)}if(e){w[h+14>>1]=(b&3)+c;w[h+12>>1]=1023;c=z[Nc(h+14|0,h+12|0)>>1]}g=cv(i);e=a+8|0;k=xb(e,i),l=(f<<10|c)>>>8|(d?0:32),v[k|0]=l;Ah(x[a>>2],x[a+4>>2],b,g|160,c&255);c=xb(e,i);Ah(x[a>>2],x[a+4>>2],b,g|176,y[c|0]);v[a+534|0]=1}fb=h+16|0}function G_(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=Fb(a);a=zd(b);x[e+12>>2]=a;f=Df(b);b=0;a:{while(1){b:{if(!Ib(a,f)){if(!b){break b}x[31725]=0;O(35,d|0,65533);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}a=y[a|0];c:{d:{if(!b){if(a<<24>>24>=0){b=0;x[31725]=0;O(35,d|0,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}if((a&224)==192){c=a&31;b=1;break c}if((a&240)==224){c=a&15;b=2;break c}c=65533;if((a&248)!=240){break d}c=a&7;b=3;break c}if((a&192)!=128){c=0;x[31725]=0;O(35,d|0,65533);g=x[31725];x[31725]=0;b=0;if((g|0)==1){break a}}c=a&63|c<<6;b=b-1|0;if(b){break c}}b=0;x[31725]=0;O(35,d|0,c|0);a=x[31725];x[31725]=0;c=0;if((a|0)==1){break a}}a=x[me(e+12|0)>>2];continue}break}fb=e+16|0;return}a=N()|0;Qb(d);Q(a|0);p()}function Kl(a,b,c){var d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;d=x[a+24>>2];g=x[d+24620>>2];a:{if(!((g|0)!=(b|0)|x[d+24624>>2]!=(c|0))){if(y[a+29|0]){break a}bS(d,1);break a}f=e+8|0;yc(f,d+24604|0,40);x[e+28>>2]=c;x[e+24>>2]=b;c=x[e+44>>2];au(f,x[e+40>>2]);Uo(f,c);MA(d,f);if((b|0)==(g|0)){break a}c=x[a+24>>2]+906300|0;d=Ij(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];b:{if(!b){break b}if(!(ib[x[x[b>>2]+120>>2]](b)|0)){break b}ib[x[x[b>>2]+112>>2]](b,0);ib[x[x[b>>2]+100>>2]](b);ib[x[x[b>>2]+128>>2]](b)}c=c+160|0;continue}break}c=x[a+24>>2]+906300|0;d=Ij(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];c:{if(!b){break c}if(ib[x[x[b>>2]+120>>2]](b)|0){break c}ib[x[x[b>>2]+112>>2]](b,1);ib[x[x[b>>2]+124>>2]](b)}c=c+160|0;continue}break}}v[a+29|0]=1;fb=e+48|0}function $qa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+15|0]=0;w[e+12>>1]=0;n=D(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){v[e+11|0]=0;xY(a,e+15|0,e+12|0,e+11|0);i=y[e+11|0];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!Af(a,e+10|0)){break c}f=y[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=c-1|0;if(!(g&1<<m)){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;v[e+11|0]=l;v[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function Bk(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-32|0;fb=b;a:{b:{while(1){f=(b+8|0)+(d<<2)|0;e=1<<d&2147483647;if(e|1){e=KK(d,e?a:22255)}else{e=x[d<<2>>2]}x[f>>2]=e;if((e|0)==-1){break b}d=d+1|0;if((d|0)!=6){continue}break}if(!JK(0)){c=121484;if(!kd(b+8|0,121484,24)){break a}c=121508;if(!kd(b+8|0,121508,24)){break a}d=0;if(!y[500144]){while(1){g=(d<<2)+500096|0,h=KK(d,22255),x[g>>2]=h;d=d+1|0;if((d|0)!=6){continue}break}v[500144]=1;x[125030]=x[125024]}c=500096;if(!kd(b+8|0,500096,24)){break a}c=500120;if(!kd(b+8|0,500120,24)){break a}c=Fd(24);if(!c){break b}}a=x[b+12>>2];x[c>>2]=x[b+8>>2];x[c+4>>2]=a;a=x[b+28>>2];x[c+16>>2]=x[b+24>>2];x[c+20>>2]=a;a=x[b+20>>2];x[c+8>>2]=x[b+16>>2];x[c+12>>2]=a;break a}c=0}fb=b+32|0;return c}function rS(a,b){var c=E(0),d=E(0),e=E(0);a:{b:{c:{switch(b|0){case 0:Hq(a,E(1));Dk(a,E(3.725290298461914e-9));Gq(a,E(268435456));Fq(a,0);break b;case 1:Hq(a,E(32));Dk(a,E(4.656612873077393e-10));Gq(a,E(2147483648));Fq(a,0);break b;case 2:Hq(a,E(2));Dk(a,E(7.450580596923828e-9));Gq(a,E(134217728));Fq(a,1);break b;default:Hq(a,E(1));Dk(a,E(7.450580596923828e-9));Gq(a,E(134217728));Fq(a,1);GA(a,0);FA(a,1);EA(a,1);d=E(256);c=E(128);e=E(128);b=0;break a;case 4:case 5:break c}}Hq(a,E(.75));Dk(a,E(7.450580596923828e-9));Gq(a,E(134217728));Fq(a,1);GA(a,0);b=(b|0)==4;FA(a,b?2:3);EA(a,1);d=E(256);c=b?E(256):E(192);e=c;b=1;break a}GA(a,1);FA(a,0);EA(a,0);d=E(128);e=E(100);c=E(256);b=4}B[a+16>>2]=c;B[a+20>>2]=e;B[a+24>>2]=d;x[a+28>>2]=b}function qY(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=x[b>>2];while(1){if((i|0)==128){xg(b,c);c=x[a+8>>2];d=c+d|0;i=z[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(lh(x[a>>2])&-2)){break c}cd(a,c+(f<<10)|0);if(!SC(a,16,1)){break b}w[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((lh(x[a>>2])|0)!=(d+D(f,i)|0)){break a}}cd(a,c+D(f,z[e>>1])|0);h=SC(a,64,1)?h:k}cd(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(D(c,z[e>>1])<<8)|0)==(lh(x[a>>2])|0)){break d}}if(c>>>0>=255){RC(b,254,65534);RC(b,255,65535)}l=h}a=l&65535}else{j=z[_b(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function DL(a,b,c,d){a:{switch(b-9|0){case 0:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];return;case 6:b=x[c>>2];x[c>>2]=b+4;b=w[b>>1];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 7:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=z[b>>1];x[a+4>>2]=0;return;case 8:b=x[c>>2];x[c>>2]=b+4;b=v[b|0];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 9:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=y[b|0];x[a+4>>2]=0;return;case 16:b=x[c>>2]+7&-8;x[c>>2]=b+8;C[a>>3]=C[b>>3];return;case 17:ib[d|0](a,c);default:return;case 1:case 4:case 14:b=x[c>>2];x[c>>2]=b+4;b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];x[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=x[c>>2]+7&-8;x[c>>2]=b+8;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c}function l3(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-176|0;fb=c;b=c+12|0;$k(b,a);x[31725]=0;O(104,c+24|0,b|0);a=x[31725];x[31725]=0;a:{b:{c:{d:{if((a|0)!=1){x[31725]=0;a=P(105,c+36|0,c+24|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break d}tb(c+24|0);tb(c+12|0);b=x[x[a>>2]-12>>2];x[31725]=0;d=ca(106)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;S(107,c+8|0,a+b|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}Zb(c+8|0);b=a+x[x[a>>2]-12>>2]|0;x[b+4>>2]=x[b+4>>2]&-75;x[b+4>>2]=x[b+4>>2]|8;x[31725]=0;b=P(108,a|0,c+24|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}a=xk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+24>>2];Ff(b);fb=c+176|0;return(a?0:d)|0}b=N()|0;break c}b=N()|0;tb(c+24|0)}tb(c+12|0);break a}b=N()|0;Ff(a)}Q(b|0);p()}function sq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}f=1072693248;g=-1023;if((b|0)!=1072693248){f=b;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;f=b;g=-1077}b=f+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function yfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;f=Kb(b);d=Cb(x[b+4>>2],y[b+11|0]);i=Kb(c);g=Cb(x[c+4>>2],y[c+11|0]);d=d+f|0;e=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(yq(i,g,y[d|0])){continue}break}e=d-f|0}b:{c:{if((e|0)!=-1){c=vb(h+12|0,Pe(Pe(zd(b),e),1));d=vb(h+8|0,Df(b));cs(b,x[c>>2],x[d>>2]);break c}if(!Yc(x[b+4>>2],y[b+11|0])){break c}f=Kb(b);d=Cb(x[b+4>>2],y[b+11|0]);i=Kb(c);g=Cb(x[c+4>>2],y[c+11|0]);if(!d|!g){c=-1}else{c=f;e=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(g|0)){break e}j=v[d|0];d=d+1|0;if(!lc(v[c|0],j)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-f|0}if(c){break c}Fb(a);break b}_c(a,b)}fb=h+16|0}function oT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;i=-1;a:{if(!HA(a,b,2)){break a}f=x[b+656>>2];d=a+1074312|0;g=Ob(d,31);h=x[b+740>>2];if(h?0:g){break a}h=h-Ob(d,31)|0;g=x[a+480180>>2];d=(g|0)==4096;j=f+88|0;f=d?64:(g|0)==16384?192:512;d=Xq(j,h,f,d?255:64)-(f>>>1|0)|0;if(y[b+746|0]&16){i=Pq(a,b,!(x[b+88>>2]&32768),d);break a}if(Uj(x[b+656>>2])){if((d|0)==w[b+772>>1]){break a}k=b,l=ed(d),w[k+772>>1]=l;v[b+851|0]=y[b+851|0]|64;break a}a=Jj(a);x[e+12>>2]=d;b:{if((d|0)<0){x[e+12>>2]=0-d;Bi(e+12|0,255);a=(x[e+12>>2]<<2)+(a?36592:35568)|0;break b}Bi(e+12|0,255);a=(x[e+12>>2]<<2)+(a?35568:36592)|0}a=x[a>>2];b=a;d=a>>31;a=x[c>>2];k=c,l=Gc(pva(ova(b,d,a,a>>31),hb,65536,0),hb),x[k>>2]=l}fb=e+16|0;return i}function z2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;f=Kb(b);d=Cb(x[b+4>>2],y[b+11|0]);i=Kb(c);g=Cb(x[c+4>>2],y[c+11|0]);d=d+f|0;e=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(Fu(i,g,y[d|0])){continue}break}e=d-f|0}b:{c:{if((e|0)!=-1){c=vb(h+12|0,Pe(Pe(zd(b),e),1));d=vb(h+8|0,Df(b));cs(b,x[c>>2],x[d>>2]);break c}if(!Yc(x[b+4>>2],y[b+11|0])){break c}f=Kb(b);d=Cb(x[b+4>>2],y[b+11|0]);i=Kb(c);g=Cb(x[c+4>>2],y[c+11|0]);if(!d|!g){c=-1}else{c=f;e=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(g|0)){break e}j=y[d|0];d=d+1|0;if(!lc(y[c|0],j)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-f|0}if(c){break c}Fb(a);break b}_c(a,b)}fb=h+16|0}function kma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-32|0;fb=g;h=a+8|0;c=x[a+8>>2];j=nc(a);a:{if((c|0)!=x[j>>2]){break a}i=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Wg(d,c,a+d|0);x[h>>2]=c;x[i>>2]=a+x[i>>2];break a}x[g+8>>2]=c-e>>1;x[g+28>>2]=1;d=g+8|0;c=x[ad(d,g+28|0)>>2];c=$f(d,c,c>>>2|0,x[a+16>>2]);e=vb(g+4|0,x[a+4>>2]);f=x[vb(g,x[a+8>>2])>>2];d=fb-16|0;fb=d;e=x[e>>2];x[d+12>>2]=e;e=Nn(d,c+8|0,Iv(f,e));f=x[e>>2];while(1){if(x[e+4>>2]!=(f|0)){k=f;f=x[d+12>>2];ip(k,z[f>>1]|z[f+2>>1]<<16);f=x[e>>2]+4|0;x[e>>2]=f;Je(d+12|0);continue}break}he(e);fb=d+16|0;Ub(a,c);Ub(i,c+4|0);Ub(h,c+8|0);Ub(j,nc(c));_f(c);c=x[a+8>>2]}ip(c,z[b>>1]|z[b+2>>1]<<16);x[h>>2]=x[h>>2]+4;fb=g+32|0}function QK(a,b,c,d,e,f){var g=0;g=fb-80|0;fb=g;a:{if((f|0)>=16384){Vd(g+32|0,b,c,d,e,0,0,0,2147352576);d=x[g+40>>2];e=x[g+44>>2];b=x[g+32>>2];c=x[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Vd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=x[g+24>>2];e=x[g+28>>2];b=x[g+16>>2];c=x[g+20>>2];break a}if((f|0)>-16383){break a}Vd(g- -64|0,b,c,d,e,0,0,0,7471104);d=x[g+72>>2];e=x[g+76>>2];b=x[g+64>>2];c=x[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Vd(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=x[g+56>>2];e=x[g+60>>2];b=x[g+48>>2];c=x[g+52>>2]}Vd(g,b,c,d,e,0,0,0,f+16383<<16);b=x[g+12>>2];x[a+8>>2]=x[g+8>>2];x[a+12>>2]=b;b=x[g+4>>2];x[a>>2]=x[g>>2];x[a+4>>2]=b;fb=g+80|0}function wla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=fb-80|0;fb=f;e=Tf(f+52|0);x[31725]=0;c=P(835,b|0,e|0)|0;d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(836,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];d=x[e>>2];x[31725]=0;h=f+12|0;c=$b(c);d:{if(!c){g=-1;if(($b(d)|0)==1112491097){break d}}g=c}c=g;S(187,h|0,b|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}d=f+12|0;g=ic(f+32|0,d);hd(e+8|0,g);ub(g);ub(d);e:{c=c&1;if(!c){break e}x[31725]=0;P(185,b|0,2-c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break e}break a}Vk(a,e)}Gd(e);fb=f+80|0;return}a=N()|0;Gd(e);Q(a|0);p()}function Uoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=$j(b),x[i+4>>2]=j;c=fb-16|0;fb=c;f=b;g=a;d=ce(a);a:{if(d){b=ec(g);while(1){a=d;d=a+13|0;if(mv(f,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!mv(d,f)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(g);b=a}x[c+12>>2]=a;d=b;b=x[b>>2];if(!b){f=fb-16|0;fb=f;a=ec(g);h=Dh(c,Ec(20),Mg(f+8|0,a));b=x[h>>2];a=x[e+4>>2];a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[b+17|0]=0;v[b+13|0]=a;v[b+14|0]=a>>>8;v[b+15|0]=a>>>16;v[b+16|0]=a>>>24;i=ec(h),j=1,v[i+4|0]=j;fb=f+16|0;$g(g,x[c+12>>2],d,x[c>>2]);b=le(c);a=x[c>>2];x[c>>2]=0;if(a){ec(c);Db(a)}h=1}_g(e+8|0,x[vb(c,b)>>2],h);fb=c+16|0;fb=e+16|0;return x[e+8>>2]+17|0}function Yy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=(q(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;C[b>>3]=d;g=d<-.7853981852531433;if(F(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){C[b>>3]=E(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;C[e+8>>3]=(l(2,i-(c<<23)|0),r());c=IL(e+8|0,e,c,1,0);d=C[e>>3];if((g|0)<0){C[b>>3]=-d;c=0-c|0;break a}C[b>>3]=d}fb=e+16|0;return c}function XC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;e=y[a|0];if(e&1){v[b+12|0]=y[b+12|0]|1;e=y[a|0]}if(e&2){v[b+12|0]=y[b+12|0]|4;e=y[a|0]}if(e&4){v[b+12|0]=y[b+12|0]|2;e=y[a|0]}if(e&16){v[b+12|0]=y[b+12|0]|16;e=y[a|0]}if(e&32){v[b+12|0]=y[b+12|0]|8}v[f+15|0]=y[a+1|0];v[f+14|0]=25;hh(b,y[Rb(f+15|0,f+14|0)|0]);v[b+15|0]=y[a+2|0];v[b+16|0]=y[((d|0)==4?a+2|0:a+3|0)|0];v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];h=x[b>>2];e=Sd(h,x[b+4>>2]);b=0;while(1){if((b|0)!=(e|0)){i=yb(h,b);g=(b<<2)+a|0;d=y[g+6|0]|y[g+7|0]<<8;w[i>>1]=d;a:{if(!b){break a}j=d;d=z[yb(h,b-1|0)>>1];if(j>>>0>=d>>>0){break a}w[i>>1]=d+1}k=i,l=Yb((y[g+8|0]|y[g+9|0]<<8)<<16>>16>>c,0,64),v[k+2|0]=l;b=b+1|0;continue}break}fb=f+16|0}function Fna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>18|0;p=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){i=(e<<1)+p|0;j=w[i>>1];x[(e<<2)+b>>2]=j+((D(w[i+4>>1]-j|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Eqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=fb-528|0;fb=b;d=-1;a:{if(!mh(a,1468)){break a}dm(a,1464);c=b+524|0;uY(a,c);if(!ne(c,25252)){d=0;if(!ne(b+524|0,15580)){break a}}dm(a,20);c=1;b:{while(1){if((c&65535)>>>0>31){break b}d=rY(a,b);if(!d){dY(b)}if(d){c=c+1|0;e=WC(b)+e|0;continue}break}d=-1;break a}d=0;if(e>>>0>40){break a}e=b+522|0;c=fb-16|0;fb=c;c:{if(!mh(a,2)){v[c|0]=0;sF(e,c);break c}Jp(c+8|0,e);VC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;if(y[b+522|0]>128){break a}e=Jc(b+522|0);c=fb-16|0;fb=c;d:{if(!mh(a,512)){cY(b);break d}xE(c+8|0,b);VC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;c=0;d=1;a=y[e|0];while(1){if((c|0)==512){break a}e=b+c|0;c=c+1|0;if(a>>>0>=y[e|0]){continue}break}d=0}fb=b+528|0;return d|0}function Laa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-80|0;fb=d;x[31725]=0;e=R(1159,b|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){a:{b:{if(e){x[31725]=0;O(1160,d+56|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=d- -64|0;Rp(b,x[d+56>>2],x[d+60>>2]);e=Ef(d+72|0,b);f=Ef(d+48|0,c);g=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=g;e=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=e;Sp(a,d+8|0,d);break b}break a}x[31725]=0;O(1161,d+56|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}b=d- -64|0;Rp(b,x[d+56>>2],x[d+60>>2]);e=Ef(d+40|0,b);f=Ef(d+32|0,c);g=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=g;e=x[f+4>>2];x[d+16>>2]=x[f>>2];x[d+20>>2]=e;Sp(a,d+24|0,d+16|0)}ke(b);ke(d+56|0);ke(c);fb=d+80|0;return}}a=N()|0;ke(c);Q(a|0);p()}function ama(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;c=Hf(a,c);$d(f,x[a+36>>2]);i=a;a:{if(!c){Pc(f,a+32|0,5);d=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}g=x[a+36>>2];a=fb-16|0;fb=a;x[a+12>>2]=0;qN(g,a+12|0,1);e=x[a+12>>2];d=e>>>2&3;v[a+11|0]=d;if(d){v[a+4|0]=3;d=y[Rb(a+4|0,a+11|0)|0];v[a+4|0]=0;v[a|0]=0;v[a+10|0]=0;b:{if(!d){break b}Li(g,a+4|0);if((d|0)==1){break b}Li(g,a);if(d>>>0<3){break b}Li(g,a+10|0);h=y[a+10|0]<<24}e=e&255|(y[a+4|0]<<8|y[a|0]<<16|h)}d=e>>>4|0;x[a+4>>2]=d;x[a>>2]=1e6;eC(b,x[Gb(a+4|0,a)>>2]);e=0;while(1){h=Cb(x[b+4>>2],y[b+11|0]);if(h>>>0<=e>>>0){if((d|0)!=(h|0)){Um(g,d-h|0)}fb=a+16|0}else{Ej(g,cc(b,e),1);e=e+1|0;continue}break}d=c}gf(i,d);fb=f+16|0}function UH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;x[f+44>>2]=c;a=re(a,f+44|0);c=sc(a+4|0);h=sc(a+24|0);i=sc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31725]=0;O(997,a|0,d|0);g=x[31725];x[31725]=0;a:{b:{c:{d:{if((g|0)!=1){oe(f+16|0,x[b>>2],x[b+4>>2]);b=Nd(f+8|0);x[31725]=0;g=x[b+4>>2];x[f>>2]=x[b>>2];x[f+4>>2]=g;Os(e,f+24|0,x[f+16>>2],x[f+20>>2],f);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;S(998,a|0,f+24|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}ub(f+24|0);x[31725]=0;W(999,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(f+24|0)}Td(k);of(j);Jl(i);xh(h);wh(c);Vc(a);Vc(f+44|0);Q(d|0);p()}Vc(f+44|0);fb=f+48|0;return a}function eY(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],1024)){x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;a=64;while(1){if(a){d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=d;v[b+5|0]=d>>>8;v[b+6|0]=d>>>16;v[b+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[b+8|0]=e;v[b+9|0]=e>>>8;v[b+10|0]=e>>>16;v[b+11|0]=e>>>24;v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}PC(c+8|0,b);rd(c+16|0,a,x[c+8>>2],x[c+12>>2])}fb=c+32|0}function PH(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=fb-80|0;fb=g;LA(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[g+44>>2]=b;x[g+40>>2]=c;x[g+36>>2]=d;i=B[a+48>>2];j=x[a+32>>2];x[g+8>>2]=b;c=x[g+40>>2];x[g>>2]=x[g+36>>2];x[g+4>>2]=c;d=fb-16|0;fb=d;x[d+8>>2]=x[g+8>>2];c=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=c;c=SM(g+48|0);x[c+8>>2]=j;x[c+4>>2]=0;x[c>>2]=f;f=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=f;x[c+20>>2]=x[d+8>>2];C[c+24>>3]=i;x[c>>2]=e;fb=d+16|0;while(1){if(b){d=x[a+24>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;d=TM(d,x[_r(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|h)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}fb=g+80|0;return h}function yx(a,b,c){var d=0,e=0,f=0,g=0;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31725]=0;O(116,d|0,Yc(e,a)|0);a=x[31725];x[31725]=0;if((a|0)!=1){a:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[Wd(b,f)>>2];g=e&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|(e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}else{x[31725]=0;O(117,d|0,a<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[31725]=0;O(117,d|0,a<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}x[31725]=0;O(117,d|0,63);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function Cba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb+-64|0;fb=d;a=x[a+4>>2];mx(d+16|0,b);x[31725]=0;b=P(1,d+4|0,18382)|0;e=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){x[31725]=0;S(2,d+28|0,d+16|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break h}x[31725]=0;S(491,d+40|0,d+28|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break g}x[31725]=0;O(1065,d+52|0,d+40|0);c=x[31725];x[31725]=0;if((c|0)==1){break f}c=x[x[a>>2]+8>>2];x[31725]=0;O(c|0,a|0,d+52|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}tb(d+52|0);tb(d+40|0);tb(d+28|0);tb(b);tb(d+16|0);fb=d- -64|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;tb(d+52|0)}tb(d+40|0)}tb(d+28|0)}tb(b)}tb(d+16|0);Q(a|0);p()}function Apa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-32|0;fb=f;ld(c,2);v[f+20|0]=y[b+13|0];v[f+8|0]=64;d=f+20|0;e=f+8|0;i=c,j=y[Rb(d,e)|0]<<2,w[i+30>>1]=j;x[c+24>>2]=(y[b+14|0]|y[b+15|0]<<8)<<1;Rk(e,2,b+1|0);Cc(d,e);ze(c+43|0,d);tb(d);d=Xc(a,8,1,0,2);a:{if((y[b|0]&3)!=1){break a}g=y[b+22|0]|y[b+23|0]<<8|(y[b+24|0]<<16|y[b+25|0]<<24);x[c>>2]=g;e=y[b+26|0]|y[b+27|0]<<8|(y[b+28|0]<<16|y[b+29|0]<<24);x[c+4>>2]=e;a=y[b+30|0]|y[b+31|0]<<8|(y[b+32|0]<<16|y[b+33|0]<<24);h=a-(a>>>0>e>>>0)|0;x[c+8>>2]=h;a=y[b|0];if(a&4){w[c+34>>1]=z[c+34>>1]|2;a=y[b|0]}if(a&8){w[c+34>>1]=z[c+34>>1]|4;a=y[b|0]}if(!(a&16)){break a}fd(d,16);yg(d,9);x[c+8>>2]=h>>>1;x[c+4>>2]=e>>>1;x[c>>2]=g>>>1}fb=f+32|0}function p_(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-176|0;fb=b;c=b+12|0;Wf(c,a);x[31725]=0;O(126,b+24|0,c|0);a=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31725]=0;a=P(105,b+36|0,b+24|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break e}tb(b+24|0);tb(b+12|0);c=x[x[a>>2]-12>>2];x[31725]=0;d=ca(106)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}x[31725]=0;S(107,b+8|0,a+c|0,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}Zb(b+8|0);x[31725]=0;x[b+24>>2]=0;x[b+28>>2]=0;c=P(411,a|0,b+24|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}a=xk(x[(c+x[x[c>>2]-12>>2]|0)+16>>2]);e=C[b+24>>3];Ff(c);fb=b+176|0;e=a?0:e;break a}c=N()|0;break d}c=N()|0;tb(b+24|0)}tb(b+12|0);break b}c=N()|0;Ff(a)}Q(c|0);p()}return+e}function Gna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>10&4194048;p=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){i=e+p|0;j=v[i|0];x[(e<<2)+b>>2]=((D(v[i+2|0]-j|0,o)|0)/16384|0)+(j<<8);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function $m(a,b){var c=0,d=0,e=0,f=0;c=fb+-64|0;fb=c;d=x[x[a>>2]-12>>2]+a|0;e=x[d+16>>2]&-3;kg(d,e);a:{b:{if(Ed(y[Mm(c+63|0,a,1)|0])){d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31725]=0;f=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=f;f=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=f;S(943,c+40|0,d|0,c+8|0);b=x[31725];x[31725]=0;c:{if((b|0)!=1){b=hi(c+24|0,-1,-1);b=go(x[c+48>>2],x[c+52>>2],x[b+8>>2],x[b+12>>2])?e|4:e;break c}Y(T(0)|0)|0;b=e|1;Km(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}fk(x[x[a>>2]-12>>2]+a|0,b)}fb=c- -64|0;return}T(0)|0;Sb()}p()}function sna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;n=w[e+38150>>1];o=w[e+38148>>1];p=w[e+38146>>1];e=w[e+38144>>1];f=0;while(1){if((f|0)!=2){g=(f<<1)+m|0;x[(f<<2)+b>>2]=(((D(w[g>>1],p)+D(w[g-4>>1],e)|0)+D(w[g+4>>1],o)|0)+D(w[g+8>>1],n)|0)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function Rh(a,b){var c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0;f=bQ(a);h=a+4208|0;c=E(E(B[yb(h,4)>>2]*E(1.899999976158142))+E(.10000000149011612));g=B[a+4268>>2];d=De(E(10),E(E(E(E(E(x[((b<<2)+a|0)+4292>>2])/g)*E(-60))/E(E(B[yb(h,3)>>2]*E(19.899999618530273))+E(.10000000149011612)))/E(20)));c=E(E(De(d,E(E(2)-E(E(2)/c)))+E(-1))/E(E(1)-Cq(c>E(1)?E(3.1415927410125732):E(f*E(E(6.2831854820251465)/g)))));a:{if(c==E(0)){break a}if(!an(c)){break a}g=E(c+c);f=E(E(-2)-g);c=E(E(f*f)+E(E(c*c)*E(-4)));if(c>E(0)){e=E(M(c))}c=E(E(e-f)/g);if(E(F(c))>E(1)){c=E(E(E(-f)-e)/g)}e=cg(c)}b=(b<<3)+a|0;B[b+4404>>2]=e;B[b+4400>>2]=d;c=B[a+4272>>2];c=E(c*c);e=E(E(1)-c);d=E(d*d);return E(E(E(e*E(d/E(E(1)-E(c*d))))*e)+c)}function Bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-48|0;fb=e;x[e+44>>2]=c;a=re(a,e+44|0);f=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31725]=0;O(997,a|0,d|0);c=x[31725];x[31725]=0;a:{b:{c:{d:{if((c|0)!=1){c=Nd(e+16|0);x[31725]=0;k=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=k;S(1121,e+24|0,b|0,e+8|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;S(998,a|0,e+24|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}ub(e+24|0);x[31725]=0;W(999,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(e+24|0)}Td(j);of(i);Jl(h);xh(g);wh(f);Vc(a);Vc(e+44|0);Q(d|0);p()}Vc(e+44|0);fb=e+48|0;return a|0}function fI(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;g=fb-48|0;fb=g;x[g+44>>2]=d;a=re(a,g+44|0);d=sc(a+4|0);h=sc(a+24|0);i=sc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31725]=0;O(997,a|0,e|0);l=x[31725];x[31725]=0;a:{b:{c:{d:{if((l|0)!=1){bc(g+16|0,b,c);b=Nd(g+8|0);x[31725]=0;c=x[b+4>>2];x[g>>2]=x[b>>2];x[g+4>>2]=c;Os(f,g+24|0,x[g+16>>2],x[g+20>>2],g);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;S(998,a|0,g+24|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}ub(g+24|0);x[31725]=0;W(999,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(g+24|0)}Td(k);of(j);Jl(i);xh(h);wh(d);Vc(a);Vc(g+44|0);Q(e|0);p()}Vc(g+44|0);fb=g+48|0;return a}function Ega(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;c=Fb(b+20|0);x[31725]=0;W(990,b+8|0);a=x[31725];x[31725]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=wb(x[b+8>>2]),x[f+4>>2]=g;d=1;while(1){e=wb(x[b+12>>2]);a=x[b+4>>2];if(!Ib(a,e)){a=Bg(Kb(c));Td(b+8|0);tb(c);break b}if(!d){x[31725]=0;P(991,c|0,14604)|0;a=x[31725];x[31725]=0;if((a|0)==1){break d}a=x[b+4>>2]}x[31725]=0;P(842,c|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break d}jl(b+4|0);d=0;continue}}a=T(0)|0;break c}a=T(0)|0;Td(b+8|0)}tb(c);Y(a|0)|0;a=0;x[31725]=0;V(989,7040,0,0,0);c=x[31725];x[31725]=0;if((c|0)==1){break a}Z()}fb=b+32|0;return a|0}b=N()|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){T(0)|0;Sb();p()}Q(b|0);p()}function KK(a,b){var c=0,d=0,e=0;a:{if(y[b|0]){break a}b=Gy(13900);if(y[b|0]?b:0){break a}b=Gy(D(a,12)+95776|0);if(y[b|0]?b:0){break a}b=Gy(14156);if(y[b|0]?b:0){break a}b=14737}b:{while(1){d=y[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14737;c:{d:{c=y[b|0];e:{f:{if(!(y[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!y[e+1|0]){break e}}if(!oi(e,14737)){break e}if(oi(e,13638)){break d}}if(!a){c=95848;if(y[e+1|0]==46){break c}}return 0}c=x[125023];if(c){while(1){if(!oi(e,c+8|0)){break c}c=x[c+32>>2];if(c){continue}break}}c=Fd(36);if(c){x[c+4>>2]=20;x[c>>2]=95744;b=c+8|0;yc(b,e,d);v[b+d|0]=0;x[c+32>>2]=x[125023];x[125023]=c}c=a|c?c:95848}return c}function wU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;g=ks(f+4|0,a,d);d=zb(a);a=fb-48|0;fb=a;e=x[g+4>>2];x[a+44>>2]=e;x[a+40>>2]=e;d=Se(a+12|0,d,a+40|0,a+44|0);x[a+8>>2]=x[d+8>>2];e=x[d+4>>2];x[a>>2]=x[d>>2];x[a+4>>2]=e;Re(a+24|0,a);while(1){if((b|0)!=(c|0)){C[x[a+44>>2]>>3]=C[b>>3];x[a+44>>2]=x[a+44>>2]+8;b=b+8|0;continue}break}Qe(a+24|0);h=x[a+44>>2];if(!y[a+36|0]){d=fb-16|0;fb=d;b=vb(d+12|0,x[x[a+32>>2]>>2]);i=x[vb(d+8|0,x[x[a+28>>2]>>2])>>2];e=fb-16|0;fb=e;b=x[b>>2];x[e+12>>2]=b;while(1){if(pd(b,i)){c=fb-16|0;fb=c;x[c+12>>2]=b;x[c+12>>2]=x[c+12>>2]-8;fb=c+16|0;b=x[Pp(e+12|0)>>2];continue}break}fb=e+16|0;fb=d+16|0}fb=a+48|0;x[g+4>>2]=h;hc(g);fb=f+16|0}function Vna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=fb-16|0;fb=b;k=x[a+16>>2];j=mg(1,2);e=hb;l=e;Pb(a,j,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];e=x[a+8>>2];o=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=((((x[b+12>>2]&2147483647)<<1|i>>>31)&2147483646)<<1)+k|0;h=0;while(1){if((h|0)!=2){x[(h<<2)+b>>2]=w[(h<<1)+i>>1];h=h+1|0;continue}break}g=g+n|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+m|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,e,o);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Hg(a,j,l);fb=b+16|0}function H9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=x[b+44>>2];i=x[b+24>>2];if(h>>>0<i>>>0){x[b+44>>2]=i;h=i}m=-1;n=-1;o=f&24;a:{if(!o|(e|0)==1&(o|0)==24){break a}if(h){j=h-Kb(b+32|0)|0;k=j>>31}b:{c:{switch(e|0){case 1:if(f&8){g=x[b+12>>2]-x[b+8>>2]|0;l=g>>31;break b}g=i-x[b+20>>2]|0;l=g>>31;break b;case 0:break b;case 2:break c;default:break a}}g=j;l=k}d=d+l|0;c=c+g|0;d=g>>>0>c>>>0?d+1|0:d;if((d|0)<0|(c>>>0>j>>>0&(d|0)>=(k|0)|(d|0)>(k|0))){break a}e=f&8;d:{if(!(c|d)){break d}if(x[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!i){break a}}if(e){e=x[b+8>>2];no(b,e,c+e|0,h)}if(f&16){Ny(b,x[b+20>>2],x[b+28>>2]);Ct(b,c)}m=c;n=d}hi(a,m,n)}function Po(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){v[b+809|0]=c;break a}c=y[b+809|0]}e=x[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=x[b+688>>2];b:{if(e&69206029){break b}g=d&255;f=d&15;if((f|0)==15){if(g>>>0>=16){Oo(a,b,(d&240)>>>4|0,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c-60|0;break b}if((g&240)!=240){break b}if(f){No(a,b,f,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c+60|0}c:{if(!(!(v[b+851|0]&1)|y[a+480208|0]&2)&(x[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&15;d:{if(a){if((d&255)>>>0>15?e&16777248:0){break c}c=c-(a<<2)|0;break d}c=((d&255)>>>2&60)+c|0}if((e|0)!=1){break c}x[b+88>>2]=x[b+88>>2]|2097152}h=b,i=Yb(c,0,256),x[h+688>>2]=i}function Y2(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-176|0;fb=c;b=c+12|0;Wf(b,a);x[31725]=0;O(126,c+24|0,b|0);a=x[31725];x[31725]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31725]=0;a=P(105,c+36|0,c+24|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}tb(c+24|0);tb(c+12|0);b=x[x[a>>2]-12>>2];x[31725]=0;d=ca(106)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}x[31725]=0;S(107,c+8|0,a+b|0,d|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}Zb(c+8|0);x[31725]=0;x[c+24>>2]=0;b=P(127,a|0,c+24|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}a=xk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+24>>2];Ff(b);fb=c+176|0;a=a?0:d;break a}b=N()|0;break d}b=N()|0;tb(c+24|0)}tb(c+12|0);break b}b=N()|0;Ff(a)}Q(b|0);p()}return a|0}function Woa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);a:{if(b){x[31725]=0;O(741,a|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}f=fb-16|0;fb=f;d=f+4|0;x[d>>2]=a;c=x[a+4>>2];x[d+4>>2]=c;x[d+8>>2]=c+D(b,36);b=x[d+4>>2];g=x[d+8>>2];while(1){if((b|0)==(g|0)){hc(d);fb=f+16|0}else{c=Tb(b,0,36);x[c>>2]=0;x[c+4>>2]=0;w[c+22>>1]=0;w[c+24>>1]=0;w[c+26>>1]=0;w[c+28>>1]=0;v[c+21|0]=64;v[c+19|0]=64;v[c+20|0]=100;v[c+15|0]=0;v[c+16|0]=0;v[c+17|0]=0;v[c+18|0]=0;x[c+8>>2]=0;x[c+12>>2]=0;w[c+30>>1]=0;w[c+32>>1]=0;b=b+36|0;x[d+4>>2]=b;continue}break}}b=e+8|0;Qd(b);qW(b);fb=e+16|0;return a|0}a=N()|0;qW(e+8|0);Q(a|0);p()}function $0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;ld(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=tw(a+4|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=f;c=tw(a+8|0,a);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=c;v[e+15|0]=127;v[e+14|0]=y[a+15|0];g=b,h=(((y[Rb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;d=y[a+12|0];if(d>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=d&240}d=(y[a+13|0]|y[a+14|0]<<8)<<1;x[b+24>>2]=d;d=y[a+13|0]|y[a+14|0]<<8?d:16726;x[b+24>>2]=d;g=b,h=(D(IE(0,y[a+12|0]<<28>>24),d)>>>0)/8363|0,x[g+24>>2]=h;if(c>>>0>f>>>0){w[b+34>>1]=z[b+34>>1]|2}if(y[a+16|0]&132){w[b+34>>1]=z[b+34>>1]|1}fb=e+16|0}function FN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;a:{b:{c:{d:{e:{if((b|0)>=0){e=x[a+32>>2];if((Co(e)|0)>(b|0)){break e}}a=ac(8);x[31725]=0;b=P(36,f+4|0,10735)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}d=(e+(b<<5)|0)+480280|0;g=c?134218752:0;x[d>>2]=g|x[d>>2]&-134218753;c=(e+D(b,872)|0)+1075080|0;x[c>>2]=x[c>>2]&-134218753|g;c=z[e+480188>>1];e=c>>>0<=256?256:c;b=b+1|0;a=x[a+32>>2];while(1){if((c|0)==(e|0)){break a}d=a+D(c,872)|0;if((b|0)==z[d+1075778>>1]){d=d+1075080|0;x[d>>2]=x[d>>2]&-134218753|g}c=c+1|0;continue}}c=N()|0;jc(a)}Q(c|0)}p()}fb=f+16|0}function Cs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Mc(a)>>>0>=b>>>0){break a}k=d,l=Cb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Eh(x[ad(d+12|0,d+8|0)>>2]);if((Mc(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;f=Cb(x[a+4>>2],y[a+11|0]);b:{c:{h=Uk(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Mc(a)>>>0<b>>>0){sg(e+8|0,c);break e}x[31725]=0;O(118,e+8|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);g=Kb(a);c=Cb(x[a+4>>2],c)}b=Cg(b,g,c+1|0);if(i){Db(g)}if(!h){pf(a,j);Yd(a,f);yd(a,b);break b}Me(a,f);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}qf();p()}function Ri(a,b,c,d){var e=0,f=0,g=0;x[a+20>>2]=d;x[a+16>>2]=c;x[a+12>>2]=b;x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=42776;c=a+24|0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;b=Nb(a+44|0);d=Nb(b+12|0);e=Nb(b+24|0);f=Nb(b+36|0);x[31725]=0;O(947,b|0,0);g=x[31725];x[31725]=0;if((g|0)==1){a=N()|0;uc(f);uc(e);nu(d);nu(b);Q(a|0);p()}w[a+4204>>1]=0;x[a+4196>>2]=1065353216;x[a+4200>>2]=0;d=x[a+16>>2];x[d+946300>>2]=x[d+946300>>2]+1;x[31725]=0;d=R(948,a+92|0)|0;e=x[31725];x[31725]=0;a:{if((e|0)!=1){b=a+4200|0;x[c>>2]=d;c=x[a+16>>2]+906300|0;d=y[a+4200|0];e=x[a+20>>2];while(1){if((vd(c,d)|0)==(e|0)|d>>>0>248){break a}d=d+1|0;v[b|0]=d;continue}}a=N()|0;GQ(b);Q(a|0);p()}return a}function GU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Mc(a)>>>0>=b>>>0){break a}k=d,l=Cb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Eh(x[ad(d+12|0,d+8|0)>>2]);if((Mc(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;f=Cb(x[a+4>>2],y[a+11|0]);b:{c:{h=Uk(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Mc(a)>>>0<b>>>0){sg(e+8|0,c);break e}x[31725]=0;O(52,e+8|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);g=Kb(a);c=Cb(x[a+4>>2],c)}b=Xg(b,g,c+1|0);if(i){Db(g)}if(!h){pf(a,j);Yd(a,f);yd(a,b);break b}Me(a,f);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}qf();p()}function gB(a,b,c){var d=0,e=0,f=0,g=0;d=fb+-64|0;fb=d;e=x[a>>2];f=x[e-4>>2];g=x[e-8>>2];x[d+28>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+56>>2]=0;e=0;v[d+59|0]=0;v[d+60|0]=0;v[d+61|0]=0;v[d+62|0]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+16>>2]=b;x[d+12>>2]=a;x[d+8>>2]=c;a=a+g|0;a:{if(oh(f,c,0)){x[d+56>>2]=1;ib[x[x[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=x[d+32>>2]==1?a:0;break a}ib[x[x[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(x[d+44>>2]){case 0:e=x[d+48>>2]==1?x[d+36>>2]==1?x[d+40>>2]==1?x[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(x[d+32>>2]!=1){if(x[d+48>>2]|x[d+36>>2]!=1|x[d+40>>2]!=1){break a}}e=x[d+24>>2]}fb=d- -64|0;return e}function ff(a,b,c){var d=0,e=0,f=0;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31725]=0;O(116,d|0,Yc(e,a)|0);a=x[31725];x[31725]=0;if((a|0)!=1){a:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[Wd(b,f)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((e|0)==x[(a<<2)+c>>2]){x[31725]=0;O(117,d|0,a<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[31725]=0;O(117,d|0,a<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}x[31725]=0;O(117,d|0,63);a=x[31725];x[31725]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function eR(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=fb-48|0;fb=e;d=Fb(e+36|0);x[31725]=0;O(938,b|0,e+24|0);g=x[31725];x[31725]=0;if((g|0)!=1){b:{g=x[e+28>>2];f=x[e+24>>2];tf(d);x[31725]=0;g=!g&f>>>0>=255|g?255:f;O(46,d|0,g|0);f=x[31725];x[31725]=0;if((f|0)==1){break b}c:{while(1){if((g|0)==(h|0)){b=m0(Kb(d),Cb(x[d+4>>2],y[d+11|0]));if((b|0)==-1){break c}x[31725]=0;O(46,d|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break c}break b}f=cc(d,h);x[31725]=0;P(939,b|0,f|0)|0;f=x[31725];x[31725]=0;if((f|0)!=1){h=h+1|0;continue}break}break b}x[31725]=0;S(498,e+12|0,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}a=e+12|0;Ab(c,a);tb(a);tb(d);fb=e+48|0;break a}}a=N()|0;tb(d);Q(a|0);p()}}function joa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;ld(b,4);w[b+30>>1]=y[a+12|0]<<2;Gf(b+30|0,256);e=y[a+15|0];w[b+34>>1]=32;w[b+28>>1]=e;v[b+37|0]=y[a+13|0];v[b+36|0]=y[a+16|0];f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=f;c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+4>>2]=c;d=(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+c|0;x[b+8>>2]=d;e=y[a+14|0];if(e&16){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;f=f>>>1|0;x[b>>2]=f;e=y[a+14|0]}if(e&32){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;x[b>>2]=f>>>1;e=y[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){w[b+34>>1]=34;w[b+34>>1]=y[a+14|0]&2?38:34}a=Dc(g+4|0,22255);ze(b+43|0,a);tb(a);fb=g+16|0}function Yka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<1073741808){a:{if(An(a)>>>0>=b>>>0){break a}k=d,l=Cb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=zn(x[ad(d+12|0,d+8|0)>>2]);if((An(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;i=1;f=b+1|0;c=An(a);g=Cb(x[a+4>>2],y[a+11|0]);b:{c:{j=lr(b);d:{if(j){h=x[a>>2];b=a;c=g;break d}e:{if(b>>>0>c>>>0){Wj(e+8|0,f);break e}x[31725]=0;O(54,e+8|0,f|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}}f=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);h=Kb(a);c=Cb(x[a+4>>2],c)}b=Zi(b,h,c+1|0);if(i){Db(h)}if(!j){pf(a,f);Yd(a,g);yd(a,b);break b}Me(a,g);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}qf();p()}function Nja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);b:{c=Pk(x[b>>2],x[b+4>>2]);if(!c){break b}x[31725]=0;O(462,a|0,c|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=x[b+4>>2];f=x[b>>2];x[31725]=0;vu(a,f,e,c);c=x[31725];x[31725]=0;if((c|0)!=1){break b}}a=N()|0;jm(d+8|0);Q(a|0);p()}c=d+8|0;Qd(c);jm(c);fb=d+16|0;x[a+20>>2]=x[b+20>>2];d=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=d;x[31725]=0;d=P(925,a+24|0,b+24|0)|0;c=x[31725];x[31725]=0;c:{d:{if((c|0)!=1){x[31725]=0;P(72,a+36|0,b+36|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}x[a+48>>2]=x[b+48>>2];break a}b=N()|0;break c}b=N()|0;uc(d)}Sk(a);Q(b|0);p()}}function tna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;n=w[e+38150>>1];o=w[e+38148>>1];p=w[e+38146>>1];e=w[e+38144>>1];f=0;while(1){if((f|0)!=2){g=f+m|0;x[(f<<2)+b>>2]=(((D(v[g|0],p)+D(v[g-2|0],e)|0)+D(v[g+2|0],o)|0)+D(v[g+4|0],n)<<8)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function iaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;e=x[a+28>>2];x[d+16>>2]=e;f=x[a+20>>2];x[d+28>>2]=c;x[d+24>>2]=b;b=f-e|0;x[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!Zy(Aa(x[a+60>>2],b|0,i|0,d+12|0)|0)){g=x[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];a=c;break a}h=x[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;x[e>>2]=h+x[e>>2];b=(j?12:4)+b|0;x[b>>2]=x[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a>>2]=x[a>>2]|32;a=0;if((i|0)==2){break a}a=c-x[b+4>>2]|0}fb=d+32|0;return a|0}function GT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-112|0;fb=f;x[f+108>>2]=0;e=Mo(a,e&65535,d,c,f+108|0);c=y[b+790|0];if(!x[f+108>>2]){d=(c|0)==15;h=d&!y[b+792|0];e=e<<8;a:{if(e){x[b+664>>2]=e;break a}e=0;if(d){break a}e=x[b+664>>2]}h=h?0:y[b+836|0]<<16}if((c|0)==15){c=y[b+792|0];b:{if(!c){c=x[b+76>>2];x[f+4>>2]=1;g=x[ad(f+4|0,f+108|0)>>2]<<3;e=ova(c,0,e,0);d=(256<<g>>>1|0)+e|0;c=hb;c=d>>>0<e>>>0?c+1|0:c;e=g+8|0;g=d;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}e=Bc(c,e);break b}Vv(f+4|0);if(c>>>0>9){break b}c=x[b+104>>2];if(!c){break b}e=x[yb(c+68|0,y[b+792|0]-1|0)>>2]+e|0}x[b+664>>2]=e}Qo(a,b,e+h|0);fb=f+112|0}function Wna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=fb-16|0;fb=b;k=x[a+16>>2];j=mg(1,2);e=hb;l=e;Pb(a,j,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];e=x[a+8>>2];o=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=(((x[b+12>>2]&2147483647)<<1|i>>>31)&-2)+k|0;h=0;while(1){if((h|0)!=2){x[(h<<2)+b>>2]=v[h+i|0]<<8;h=h+1|0;continue}break}g=g+n|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+m|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,e,o);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Hg(a,j,l);fb=b+16|0}function Iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;h=g+4|0;e=fb-32|0;fb=e;d=rf(e+20|0,1,0);a:{b:{c:{while(1){c=Kb(d);j=Cb(x[d+4>>2],y[d+11|0])+c|0;i=x[b>>2];k=e+12|0;f=x[b+4>>2];if(!((f|0)>0|(f|0)>=0|(c|0)==(j|0))){v[c|0]=45;i=TN(i,f);f=hb;c=c+1|0}SN(k,c,j,i,f);if(!x[e+16>>2]){break c}c=ri(Cb(x[d+4>>2],y[d+11|0]));x[31725]=0;O(45,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)!=1){continue}break}break b}b=x[e+12>>2];c=Kb(d);x[31725]=0;O(46,d|0,b-c|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(305,h|0,d|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(d);fb=e+32|0;break a}a=N()|0;tb(d);Q(a|0);p()}Sh(a,h);tb(h);fb=g+16|0}function pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;x[31725]=0;W(1002,a|0);e=x[31725];x[31725]=0;a:{b:{c:{if((e|0)==1){break c}x[31725]=0;W(1003,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break c}x[31725]=0;W(1003,c|0);f=x[31725];x[31725]=0;e=1;if((f|0)==1){break c}f=x[a+24>>2];b=qc(d+24|0,b);c=qc(d+16|0,c);g=x[c>>2];c=x[c+4>>2];x[31725]=0;h=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=h;Ps(1024,f,d+8|0,g,c,1);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,5507,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}fb=d+32|0;return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function eG(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-1641380927){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(b>>>0<36){break a}c=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);if(c>>>0<36){break a}d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);if(d>>>0<36){break a}e=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24);if(D(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function Pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Pb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Ng(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb+-64|0;fb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=x[a>>2];e=x[a+4>>2];if(He(d,e,b)){break b}c:{d:{if(qm(d,e)>>>0<=b>>>0){d=qA(f+12|0,a);x[31725]=0;S(201,a|0,b+1|0,d|0);e=x[31725];x[31725]=0;if((e|0)==1){break d}Ek(d);d=x[a>>2]}x[31725]=0;O(202,hj(d,b)|0,c|0);c=x[31725];x[31725]=0;e:{if((c|0)!=1){c=hj(x[a>>2],b);x[c+16>>2]=0;x[c+20>>2]=0;c=x[a>>2];x[31725]=0;W(203,hj(c,b)|0);c=x[31725];x[31725]=0;if((c|0)!=1){break e}}b=T(125e3)|0;a=gb;break c}a=hj(x[a>>2],b);g=Ib(x[a>>2],x[a+4>>2]);break b}b=T(125e3)|0;a=gb;Ek(d)}if(($(125e3)|0)!=(a|0)){break a}Y(b|0)|0;Z()}fb=f- -64|0;return g|0}Q(b|0);p()}function vu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;g=Kr(f+4|0,a,d);d=zb(a);a=fb-48|0;fb=a;e=x[g+4>>2];x[a+44>>2]=e;x[a+40>>2]=e;d=Se(a+12|0,d,a+40|0,a+44|0);x[a+8>>2]=x[d+8>>2];e=x[d+4>>2];x[a>>2]=x[d>>2];x[a+4>>2]=e;Re(a+24|0,a);while(1){if((b|0)!=(c|0)){Pv(x[a+44>>2],b);x[a+44>>2]=x[a+44>>2]+6;b=b+6|0;continue}break}Qe(a+24|0);h=x[a+44>>2];if(!y[a+36|0]){c=fb-16|0;fb=c;b=vb(c+12|0,x[x[a+32>>2]>>2]);i=x[vb(c+8|0,x[x[a+28>>2]>>2])>>2];d=fb-16|0;fb=d;b=x[b>>2];x[d+12>>2]=b;while(1){if(pd(b,i)){e=fb-16|0;fb=e;x[e+12>>2]=b;xR(e+12|0,-1);fb=e+16|0;b=x[nD(d+12|0)>>2];continue}break}fb=d+16|0;fb=c+16|0}fb=a+48|0;x[g+4>>2]=h;hc(g);fb=f+16|0}function kR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=E(0),k=0,l=E(0);g=fb-16|0;fb=g;e=w[d>>1];f=w[d+2>>1];if(!(!z[b>>1]|(e|0)>(f|0)|(!(B[c>>2]>E(0))|(f-e|0)>32766))){w[a>>1]=3;f=a+4|0;Nf(f);w[a+28>>1]=65472;x[g+12>>2]=1065353216;nR(f,g+12|0);x[a+32>>2]=0;w[a+30>>1]=0;Nf(a+16|0);h=w[d>>1];w[a+28>>1]=h;e=fb-16|0;fb=e;w[e+14>>1]=z[b>>1];w[e+12>>1]=32767;b=w[Nc(e+14|0,e+12|0)>>1];fb=e+16|0;w[a+30>>1]=b;i=E(F(B[c>>2]));B[a+32>>2]=i;i=De(i,E(E(1)/E(b|0)));Ll(f,(w[d+2>>1]-h|0)+1|0);b=x[a+4>>2];c=w[a+28>>1];e=w[d+2>>1];d=w[d>>1];while(1){if((d|0)>(e|0)){Eq(a)}else{j=De(i,E(d|0));k=yb(b,d-c|0),l=j,B[k>>2]=l;d=d+1|0;continue}break}h=1}fb=g+16|0;return h|0}function VO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=0;c=x[b+24>>2];c=Zu(x[c+484344>>2],x[c+484348>>2]);x[31725]=0;O(178,e|0,c|0);c=x[31725];x[31725]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=x[b+24>>2];f=x[c+484344>>2];if(Zu(f,x[c+484348>>2])>>>0<=a>>>0){break b}x[31725]=0;O(1072,d+8|0,Wb(f,a)|0);c=x[31725];x[31725]=0;if((c|0)!=1){c=x[b+24>>2];x[31725]=0;S(1059,d+20|0,c|0,d+8|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}x[31725]=0;O(180,e|0,d+20|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}a=a+1|0;tb(d+20|0);tb(d+8|0);continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(d+20|0)}tb(d+8|0);break a}fb=d+32|0;return}a=N()|0}Td(e);Q(a|0);p()}function HU(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=av(b);e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);x[31725]=0;O(802,a|0,2048);c=x[31725];x[31725]=0;a:{if((c|0)!=1){h=fb-16|0;fb=h;g=ks(h+4|0,a,2048);c=x[g+4>>2];j=x[g+8>>2];while(1){if((c|0)==(j|0)){hc(g);fb=h+16|0}else{x[c>>2]=0;x[c+4>>2]=0;c=c+8|0;x[g+4>>2]=c;continue}break}c=e+8|0;Qd(c);$u(c);fb=e+16|0;break a}a=N()|0;$u(e+8|0);Q(a|0);p()}while(1){b:{d=1;if((f|0)!=1024){if((f|0)==2048){break b}d=+(f-1024|0);k=av(M(d*d*-9.5367431640625e-7+1)*b);d=d*.0372006759294457;d=k*Xi(d)/(i*d)}l=Ve(x[a>>2],f),m=d*.011841342921061943,C[l>>3]=m;f=f+1|0;continue}break}}function Rz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;x[d>>2]=a;x[d+4>>2]=b;x[d+8>>2]=a;x[d+12>>2]=b;b=fb+-64|0;fb=b;a:{if(!x[d+4>>2]){break a}a=x[d>>2];h=x[d+4>>2];c=30624;while(1){if((c|0)==31056){c=31056;while(1){f=(c|0)!=31104;if((c|0)==31104){break a}x[b+40>>2]=a;x[b+44>>2]=h;e=qc(b+32|0,x[c+8>>2]);g=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=g;g=x[e+4>>2];x[b>>2]=x[e>>2];x[b+4>>2]=g;c=c+12|0;if(!TR(b+8|0,b)){continue}break}break a}x[b+56>>2]=a;x[b+60>>2]=h;f=qc(b+48|0,x[c+4>>2]);e=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=e;e=x[f+4>>2];x[b+16>>2]=x[f>>2];x[b+20>>2]=e;c=c+8|0;if(!TR(b+24|0,b+16|0)){continue}break}f=1}fb=b- -64|0;fb=d+16|0;return f}function lZ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;d=vb(g+12|0,x[a+4>>2]);c=vb(g+8|0,x[a>>2]);f=x[vb(g+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;i=h+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[d>>2],x[c>>2]);j=e+16|0;c=x[e+24>>2];k=x[e+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=f;x[d+12>>2]=c;while(1){if(pd(c,k)){c=xf(c);f=xf(x[d+8>>2]);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[f|0]=c;v[f+1|0]=c>>>8;v[f+2|0]=c>>>16;v[f+3|0]=c>>>24;c=Ni(d+12|0);Ni(d+8|0);c=x[c>>2];continue}break}Ac(j,c,d+8|0);fb=d+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,d,e+12|0);fb=e+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=g+16|0}function kv(a,b){var c=0,d=0,e=0;e=fb-48|0;fb=e;d=e+28|0;lW(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);a=e+8|0;lW(a,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=x[d>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a>>2];b=jv(c,y[b|0]|y[b+1|0]<<8);a:{if(!Vj(b)){break a}b=x[d+4>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a+4>>2];b=jv(c,y[b|0]|y[b+1|0]<<8);if(!Vj(b)){break a}b=x[d+8>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a+8>>2];b=jv(c,y[b|0]|y[b+1|0]<<8);if(!Vj(b)){break a}b=x[a+12>>2];b=(y[b|0]|y[b+1|0]<<8)<<16>>16;c=x[d+12>>2];c=xe((y[c|0]|y[c+1|0]<<8)<<16>>16);b=xe(b);b=(b|0)!=(c|0)?(c|0)<(b|0)?-1:1:0;if(!Vj(b)){break a}b=x[d+16>>2];a=x[a+16>>2];b=jv(y[b|0]|y[b+1|0]<<8,y[a|0]|y[a+1|0]<<8)}a=Cd(b);fb=e+48|0;return a}function aB(a,b,c,d){var e=0,f=0,g=0;a:{if(!d){break a}if(c){v[b+815|0]=c;break a}c=y[b+815|0]}e=x[a+480180>>2];d=e&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=x[a+480208>>2]&4096;if(!d){break h}if(!a){break b}c=0-(d>>>2|0)|0;break d}a=x[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!d|!(e&16777248)){break c}break b}c=0-(d>>>2|0)|0;break d}if(y[a+480209|0]&16){break b}d=c&240;c=d?d>>>2|0:0-(c<<2&60)|0;if(!Ob(a+1074312|0,56)){break d}c=c>>2}if(!c){break b}}a=x[b+692>>2];w[b+784>>1]=0;f=b,g=Yb(a+c|0,0,256),x[f+692>>2]=g}}function lL(a){a=a|0;var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[31725]=0;c=P(1187,d+8|0,a|0)|0;b=x[31725];x[31725]=0;c:{if((b|0)!=1){d:{if(!Ed(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31725]=0;b=R(1188,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[31725]=0;W(1189,a+b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}}b=T(0)|0;jL(c);break c}jL(c);break b}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31725]=0;W(25,a+c|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function _7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-416|0;fb=h;d=h+416|0;x[h+12>>2]=d;c=fb-144|0;fb=c;x[c+28>>2]=c+132;i=c+32|0;dK(x[a+8>>2],i,c+28|0,e,f,g);x[c+16>>2]=0;x[c+20>>2]=0;x[c+12>>2]=i;e=h+16|0;f=oc(e,x[h+12>>2]);a=Hi(e,c+12|0,f,c+16|0,x[a+8>>2]);if((a|0)==-1){ko(12661);p()}x[h+12>>2]=e+(a<<2);fb=c+144|0;f=fb-16|0;fb=f;i=f+8|0;a=fb-32|0;fb=a;Id(a+24|0,e,x[h+12>>2]);h=a+16|0;e=x[a+24>>2];g=x[a+28>>2];c=fb-16|0;fb=c;x[c+12>>2]=b;while(1){if((e|0)!=(g|0)){gL(c+12|0,x[e>>2]);e=e+4|0;continue}break}Ac(h,g,c+12|0);fb=c+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Ac(i,b,a+12|0);fb=a+32|0;fb=f+16|0;fb=d;return x[f+12>>2]}function upa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-160|0;fb=d;b=-1;a:{if(!Dm(a,80)){break a}b:{c:{if(!dm(a,60)){break c}if(!gX(a,d+140|0)){break c}c=15;if(vv(d+140|0,15)){break b}}if(!Dm(a,144)){break a}b=0;if(!dm(a,124)){break a}if(!gX(a,d+140|0)){break a}c=31;if(!vv(d+140|0,31)){break a}}qE(a);b=0;d:{while(1){if((b&65535)>>>0>=c>>>0){break d}b=b+1|0;if(eX(a)>>>0<=131072){continue}break}b=0;break a}b=-1;if(!gd(a,D(c,30)|20)){break a}c=fb-16|0;fb=c;e=d+10|0;TC(c+8|0,e);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){KC(e)}if(!a){break a}b=fX(y[d+10|0])}fb=d+160|0;return b|0}function io(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0,n=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;n=a&255;if((n|0)!=y[k+24|0]){m=45;if(y[k+25|0]!=(n|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Cb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;a=Mi(k,k+26|0,a)-k|0;if((a|0)>23){break c}d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(a|0)<22){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+111728|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+111728|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function Qma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Pb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Jn(a){a=a|0;var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[31725]=0;c=P(21,d+8|0,a|0)|0;b=x[31725];x[31725]=0;c:{if((b|0)!=1){d:{if(!Ed(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31725]=0;b=R(31,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[31725]=0;O(24,a+b|0,1);b=x[31725];x[31725]=0;if((b|0)!=1){break d}}b=T(0)|0;om(c);break c}om(c);break b}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31725]=0;W(25,a+c|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function I9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;a:{b:{if(!lc(b,-1)){i=x[a+8>>2];j=x[a+12>>2];d=x[a+24>>2];if((d|0)==x[a+28>>2]){c=-1;if(!(y[a+48|0]&16)){break a}k=x[a+44>>2];h=x[a+20>>2];x[31725]=0;g=a+32|0;O(117,g|0,0);e=x[31725];x[31725]=0;if((e|0)==1){break b}e=Mc(g);x[31725]=0;O(46,g|0,e|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}c=Kb(g);Ny(a,c,Cb(x[a+36>>2],y[a+43|0])+c|0);Ct(a,d-h|0);x[a+44>>2]=x[a+20>>2]+(k-h|0);d=x[a+24>>2]}x[f+12>>2]=d+1;d=x[ad(f+12|0,a+44|0)>>2];x[a+44>>2]=d;if(y[a+48|0]&8){c=Kb(a+32|0);no(a,c,c+(j-i|0)|0,d)}c=rL(a,b<<24>>24);break a}c=My(b);break a}Y(T(0)|0)|0;Z()}fb=f+16|0;return c|0}function ho(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;if(x[k+96>>2]!=(a|0)){m=45;if(x[k+100>>2]!=(a|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Cb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;f=ty(k,k+104|0,a)-k|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+111728|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+111728|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function ula(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;e=Tf(d+52|0);x[31725]=0;g=P(839,b|0,e|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(840,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[31725]=0;S(187,d+12|0,b|0,g|0);f=x[31725];x[31725]=0;if((f|0)==1){break a}f=d+12|0;h=ic(d+32|0,f);hd(e+8|0,h);ub(h);ub(f);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}x[31725]=0;P(185,b|0,2-c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break d}break a}Vk(a,e)}Gd(e);fb=d+80|0;return}a=N()|0;Gd(e);Q(a|0);p()}function qna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[h>>1],w[e+38146>>1])+D(w[h-2>>1],w[e+38144>>1])|0)+D(w[h+2>>1],w[e+38148>>1])|0)+D(w[h+4>>1],w[e+38150>>1])|0)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function xs(a){var b=0,c=0;b=fb-32|0;fb=b;c=b+8|0;Dc(c,15385);x[31725]=0;S(125,b+20|0,1,c|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)!=1){x[31725]=0;O(12,a|0,b+20|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}Qb(b+20|0);tb(b+8|0);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Qb(b+20|0)}tb(b+8|0);Q(a|0);p()}x[31725]=0;b=ca(119)|0;c=x[31725];x[31725]=0;d:{if((c|0)==1){break d}x[a+12>>2]=b;x[31725]=0;b=ca(120)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}v[a+16|0]=b;x[31725]=0;b=ca(121)|0;c=x[31725];x[31725]=0;if((c|0)==1){break d}v[a+18|0]=0;v[a+17|0]=b;x[31725]=0;W(122,a+20|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}return}b=N()|0;tb(a);Q(b|0);p()}function pT(a,b,c,d,e){var f=0,g=0,h=0,i=0;a:{b:{c:{if(v[b+851|0]&1){f=y[b+848|0];g=c&240;if(g){f=f&15|g;v[b+848|0]=f}c=c&15;if(c){f=c|f&-16;v[b+848|0]=f}v[b+849|0]=(f&240)>>>4;if(x[a+480180>>2]!=32768){break a}break c}if(x[a+480180>>2]==32768){break c}c=y[b+849|0]-1|0;v[b+849|0]=c;if(c&255){break a}f=y[b+848|0];break b}f=y[b+848|0];if((f&240)==16){break b}if(!(y[a+480209|0]&16)){break a}}v[b+849|0]=(f&240)>>>4;c=f&15;c=d?c:0-c|0;d=x[b+656>>2];d:{if(Uj(d)){x[b+852>>2]=x[b+852>>2]+D(c,x[x[d+44>>2]+36>>2]);break d}h=b,i=yh(a,Ku(a,x[b+700>>2],w[b+772>>1],x[b+704>>2])+c|0,w[b+772>>1],x[b+704>>2]),x[h+700>>2]=i}if(!e){break a}x[b>>2]=0;x[b+4>>2]=0}}function kG(a){a=a|0;var b=0,c=0,d=0,e=0;b=lF(x[(x[x[a>>2]-12>>2]+a|0)+28>>2],10);d=fb-16|0;fb=d;x[31725]=0;c=P(21,d+8|0,a|0)|0;e=x[31725];x[31725]=0;a:{b:{c:{d:{if((e|0)!=1){e:{if(!Ed(y[c|0])){break e}e=xp(d+4|0,a);x[31725]=0;b=P(30,e|0,b|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){if(x[b>>2]){break e}b=x[x[a>>2]-12>>2];x[31725]=0;O(24,a+b|0,1);b=x[31725];x[31725]=0;if((b|0)!=1){break e}}b=T(0)|0;om(c);break d}om(c);break c}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31725]=0;W(25,a+c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}Z()}fb=d+16|0;break a}a=N()|0;x[31725]=0;X(26);d=x[31725];x[31725]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return Jn(a)|0}function Isa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];d=Jr(c,x[a+4>>2]);if(d>>>0<b>>>0){f=fb-32|0;fb=f;c=b-d|0;b=x[zb(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=(b-e|0)/40>>>0){d=fb-16|0;fb=d;b=H$(d+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=d+16|0}else{oZ(a);a=a+40|0;x[b+4>>2]=a;continue}break}break a}b=zb(a);d=E$(f+12|0,F$(a,Jr(x[a>>2],e)+c|0),Jr(x[a>>2],x[a+4>>2]),b);e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=x[d+8>>2];g=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=D(c,40)+g;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){oZ(c);c=x[b>>2]+40|0;x[b>>2]=c;continue}break}he(b);fb=e+16|0;D$(a,d);C$(d)}fb=f+32|0;return}if(b>>>0<d>>>0){z$(a,c+D(b,40)|0)}}function Dsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=b;c=fb-48|0;fb=c;d=a;a:{if(Ov(x[d>>2],x[d+8>>2])){x[g>>2]=0;break a}tZ(c+16|0,c+32|0);kc(c+24|0,x[d>>2],x[d+8>>2],x[c+16>>2],x[c+20>>2]);h=x[c+28>>2];i=y[c+32|0];f=i&127;x[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(D(h,7)+a|0)+D(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}i=y[(c+32|0)+e|0];f=i&127|f<<7;x[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}Vb(d,h);tZ(c+8|0,c+32|0);kc(c+24|0,x[d>>2],x[d+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+28>>2];f=x[g>>2];e=0;a=b;continue}break}Vb(d,e);if(a>>>0<33){break a}x[g>>2]=-1}fb=c+48|0}function eI(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;x[31725]=0;W(1002,a|0);e=x[31725];x[31725]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}x[31725]=0;W(1003,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break f}g=x[a+24>>2];x[31725]=0;e=P(36,f+8|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break e}x[31725]=0;S(d|0,f+20|0,g|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}a=f+20|0;b=Bg(Kb(a));tb(a);tb(e);break b}b=T(0)|0;break c}b=T(0)|0;break c}b=T(0)|0;tb(e)}Y(b|0)|0;b=0;x[31725]=0;V(989,c|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}fb=f+32|0;return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function bsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[d+28>>2]=0;Ok(a,d+28|0);a:{b:{i=x[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Fb(d+16|0);x[31725]=0;w[d+14>>1]=0;e=U(497,a|0,g|0,255)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}if(!e){break d}x[31725]=0;O(486,a|0,d+14|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;S(498,d|0,c|0,g|0);e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;e=P(499,b|0,d+14|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break e}Ab(e,d);tb(d);tb(g);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(g)}fb=d+32|0;return}f=N()|0}tb(g);Q(f|0);p()}function vaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;h=Fb(a);f=Fb(d+20|0);a=1;a:{b:{c:{while(1){e=a&65535;c=x[b+24>>2];if(e>>>0>z[c+480192>>1]){if(!(i&1)){break c}x[31725]=0;O(249,h|0,f|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}a=N()|0;break a}c=hS(c,e);x[31725]=0;c=P(36,d+8|0,c|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break b}e=Ad(x[d+12>>2],y[d+19|0]);x[31725]=0;g=P(842,f|0,c|0)|0;j=x[31725];x[31725]=0;d:{if((j|0)==1){break d}x[31725]=0;P(991,g|0,22230)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}i=e^1|i;tb(c);a=a+1|0;continue}break}a=N()|0;tb(c);break a}tb(f);fb=d+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function rna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[h|0],w[e+38146>>1])+D(v[h-1|0],w[e+38144>>1])|0)+D(v[h+1|0],w[e+38148>>1])|0)+D(v[h+2|0],w[e+38150>>1])<<8)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function asa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;w[d+30>>1]=0;pg(a,d+30|0);a:{b:{i=z[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Fb(d+16|0);x[31725]=0;w[d+14>>1]=0;e=P(500,a|0,g|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break b}if(!e){break d}x[31725]=0;O(486,a|0,d+14|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}x[31725]=0;S(498,d|0,c|0,g|0);e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;e=P(499,b|0,d+14|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break e}Ab(e,d);tb(d);tb(g);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(g)}fb=d+32|0;return}f=N()|0}tb(g);Q(f|0);p()}function uaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;h=Fb(a);f=Fb(c+20|0);a=1;a:{b:{c:{while(1){d=a&65535;e=x[b+24>>2];if(d>>>0>z[e+480190>>1]){if(!(i&1)){break c}x[31725]=0;O(249,h|0,f|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}a=N()|0;break a}x[31725]=0;e=P(36,c+8|0,iS(e,d)|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break b}d=Ad(x[c+12>>2],y[c+19|0]);x[31725]=0;g=P(842,f|0,e|0)|0;j=x[31725];x[31725]=0;d:{if((j|0)==1){break d}x[31725]=0;P(991,g|0,22230)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}i=d^1|i;tb(e);a=a+1|0;continue}break}a=N()|0;tb(e);break a}tb(f);fb=c+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function q1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;ld(b,0);e=c+16|0;f=rf(e,1,v[a+1|0]);ze(b+43|0,f);tb(f);x[b>>2]=y[a+6|0]|y[a+7|0]<<8|(y[a+8|0]<<16|y[a+9|0]<<24);x[b+24>>2]=y[a+10|0]|y[a+11|0]<<8;v[c+16|0]=y[a+12|0];v[c+12|0]=64;g=b,h=y[Rb(e,c+12|0)|0]<<2,w[g+30>>1]=h;x[b+4>>2]=y[a+13|0]|y[a+14|0]<<8|(y[a+15|0]<<16|y[a+16|0]<<24);e=y[a+19|0];f=y[a+17|0]|y[a+18|0]<<8;v[c+14|0]=0;v[c+18|0]=e;w[c+16>>1]=f;w[c+12>>1]=0;while(1){if((d|0)!=3){e=y[xb(c+16|0,d)|0];g=xb(c+12|0,d),h=e,v[g|0]=h;d=d+1|0;continue}break}d=eg(c+12|0);x[b+8>>2]=d;if(!(!y[a|0]|d>>>0<=x[b+4>>2]+2>>>0|d>>>0>A[b>>2])){w[b+34>>1]=z[b+34>>1]|2}fb=c+32|0}function X7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;l=j;a:{if(a){a=k+4|0;b=SJ(b);sl(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;rl(a,b);Ab(i,a);tb(a);ki(a,b);Ab(h,a);tb(a);m=d,n=vj(b),v[m|0]=n;m=e,n=wj(b),v[m|0]=n;th(a,b);Ab(f,a);tb(k+4|0);li(a,b);Ab(g,a);tb(k+4|0);a=Qk(b);break a}a=k+4|0;b=RJ(b);sl(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;rl(a,b);Ab(i,a);tb(a);ki(a,b);Ab(h,a);tb(a);m=d,n=vj(b),v[m|0]=n;m=e,n=wj(b),v[m|0]=n;th(a,b);Ab(f,a);tb(k+4|0);li(a,b);Ab(g,a);tb(k+4|0);a=Qk(b)}x[l>>2]=a;fb=k+16|0}function rla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=Kb(b);d=Cb(x[b+4>>2],y[b+11|0]);i=Kb(c);j=Cb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(yq(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=vb(g+12|0,zd(b));d=vb(g+8|0,Pe(zd(b),f));cs(b,x[c>>2],x[d>>2]);break c}f=Yc(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Kb(b);i=Cb(x[b+4>>2],y[b+11|0]);j=Kb(c);d=-1;h=Cb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!yq(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Fb(a);break b}_c(a,b)}fb=g+16|0}function Q7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;l=j;a:{if(a){a=k+4|0;b=NJ(b);sl(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;rl(a,b);qh(i,a);Qb(a);ki(a,b);qh(h,a);Qb(a);m=d,n=vj(b),x[m>>2]=n;m=e,n=wj(b),x[m>>2]=n;th(a,b);Ab(f,a);tb(a);li(a,b);qh(g,a);Qb(k+4|0);a=Qk(b);break a}a=k+4|0;b=MJ(b);sl(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;rl(a,b);qh(i,a);Qb(a);ki(a,b);qh(h,a);Qb(a);m=d,n=vj(b),x[m>>2]=n;m=e,n=wj(b),x[m>>2]=n;th(a,b);Ab(f,a);tb(a);li(a,b);qh(g,a);Qb(k+4|0);a=Qk(b)}x[l>>2]=a;fb=k+16|0}function DC(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;h=x[a>>2];a:{if(Sc(h,x[a+4>>2])>>>0<=b>>>0){break a}b:{c:{switch(c|0){case 0:if((d|0)>=0){i=xb(h,b),j=d^128,v[i|0]=j}c=g+8|0;Jb(c,x[a+24>>2],b);Jf(c,0);break b;case 2:i=xb(h,b),j=128,v[i|0]=j;c=g+8|0;Jb(c,x[a+24>>2],b);Jf(c,1);break b;case 4:break c;default:break b}}i=xb(h,b),j=128,v[i|0]=j;c=g+8|0;Jb(c,x[a+24>>2],b);Jf(c,0)}if(y[e|0]){break a}c=x[f+4>>2];if(lc(x[f>>2],c)){break a}c=BX(c);if(y[xb(x[c>>2],b)|0]==y[xb(x[a>>2],b)|0]){Jb(g+8|0,x[c+24>>2],b);c=Hb(x[x[g+8>>2]>>2],x[g+12>>2]);Jb(g,x[a+24>>2],b);if((Hb(x[x[g>>2]>>2],x[g+4>>2])|0)==(c|0)){break a}}v[e|0]=1}fb=g+16|0}function I2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=Kb(b);d=Cb(x[b+4>>2],y[b+11|0]);i=Kb(c);j=Cb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(Fu(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=vb(g+12|0,zd(b));d=vb(g+8|0,Pe(zd(b),f));cs(b,x[c>>2],x[d>>2]);break c}f=Yc(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Kb(b);i=Cb(x[b+4>>2],y[b+11|0]);j=Kb(c);d=-1;h=Cb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!Fu(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Fb(a);break b}_c(a,b)}fb=g+16|0}function _ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;e=Tf(d+52|0);x[31725]=0;g=P(915,b|0,e|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(916,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[31725]=0;S(187,d+12|0,b|0,g|0);f=x[31725];x[31725]=0;if((f|0)==1){break a}f=d+12|0;h=ic(d+32|0,f);hd(e+8|0,h);ub(h);ub(f);d:{if(!(g&1)|c>>>0<2){break d}x[31725]=0;P(185,b|0,1)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break d}break a}Vk(a,e)}Gd(e);fb=d+80|0;return}a=N()|0;Gd(e);Q(a|0);p()}function yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-80|0;fb=d;e=Tf(d+52|0);x[31725]=0;c=P(831,b|0,e|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(832,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[31725]=0;c=$b(c);S(187,d+12|0,b|0,c|0);f=x[31725];x[31725]=0;if((f|0)==1){break a}f=d+12|0;g=ic(d+32|0,f);hd(e+8|0,g);ub(g);ub(f);d:{c=c&1;if(!c){break d}x[31725]=0;P(185,b|0,2-c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break d}break a}Vk(a,e)}Gd(e);fb=d+80|0;return}a=N()|0;Gd(e);Q(a|0);p()}function Xqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb-16|0;fb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Gb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Gb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=D(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k<<1)+i|0;f=si(E(Pd(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(32768)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=ed(g),w[m>>1]=n;a=a+1|0;continue}}}_(17362,8983,27,9525);p()}_(17312,8983,28,9525);p()}fb=c+16|0}function QA(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;c=x[a>>2];if(!lc(c,x[a+4>>2])){d=wb(c);x[e+12>>2]=d;c=wb(x[a+4>>2]);while(1){if(Ib(d,c)){Mp(d,4194304,67108864);f=x[d>>2];g=f+g|0;b=g>>>0<f>>>0?b+1|0:b;d=x[Je(e+12|0)>>2];continue}else{f=x[a>>2];c=oc(f,x[a+4>>2]);k=e,l=wb(f),x[k+8>>2]=l;d=c<<24;g=qva(g,b,c,0);c=g;h=((hb&1)<<31|c>>>1)&2147483647;i=wb(x[a+4>>2]);while(1){b=x[e+8>>2];if(Ib(b,i)){f=b;c=x[b>>2];b=c>>>8|0;c=h+(c<<24)|0;b=b+j|0;b=Bc(qva(c,c>>>0<h>>>0?b+1|0:b,g,j),hb);x[f>>2]=b;d=d-b|0;Je(e+8|0);continue}else{b=x[a>>2];if(!oc(b,x[a+4>>2])){Ew();p()}x[b>>2]=x[b>>2]+d}break}}break}}fb=e+16|0}function Lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb+-64|0;fb=f;d=f+16|0;h=fb-16|0;fb=h;i=CP(h+8|0);l=f+4|0;while(1){if((j|0)==12){fb=h+16|0}else{g=fb+-64|0;fb=g;c=x[i+4>>2];e=x[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=UM(VM(g+8|0,32));break a}e=G(c);e=VM(g+8|0,(c<<e&2147483647?32:31)-e|0);while(1){k=UM(e);if(c>>>0<=k>>>0){continue}break}c=x[i>>2]+k|0}fb=g- -64|0;m=yb(d,j),n=c,x[m>>2]=n;j=j+1|0;continue}break}d=LP(l,d,OP(d));FP(a,d);cn(d);fb=f- -64|0;d=wz(a+120|0,a,b);v[d+20|0]=1;x[31725]=0;O(1144,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){a=N()|0;zo(d);Q(a|0);p()}return a|0}function m4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{c:{if(oi(b,14276)){d=Ts(c+28|0,b);e=x[d>>2];if(!Dd(e)){x[31725]=0;b=P(36,c+4|0,b|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}x[31725]=0;S(1017,c+16|0,17801,b|0);a=x[31725];x[31725]=0;d:{e:{if((a|0)!=1){x[31725]=0;W(1345,c+16|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}p()}a=N()|0;break d}a=N()|0;tb(c+16|0)}tb(b);break a}kq(e);if(!Ss(a+8|0,16781,x[d>>2])){v[a+8|0]=v[a+8|0]}if(!Ss(a+9|0,22255,x[d>>2])){v[a+9|0]=v[a+9|0]}x[31725]=0;O(274,a+12|0,22255);a=x[31725];x[31725]=0;if((a|0)==1){break b}pl(d)}fb=c+32|0;return}a=N()|0;break a}a=N()|0}pl(d);Q(a|0);p()}function Wqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb-16|0;fb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Gb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Gb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=D(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k|0)+i|0;f=si(E(Pd(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(128)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=wY(g),v[m|0]=n;a=a+1|0;continue}}}_(17362,8983,27,9525);p()}_(17312,8983,28,9525);p()}fb=c+16|0}function bP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;f=Nb(a);a=z[x[b+24>>2]+480192>>1];x[31725]=0;O(178,f|0,a|0);c=x[31725];x[31725]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=a&65535;c=x[b+24>>2];if(d>>>0>z[c+480192>>1]){break b}c=hS(c,d);x[31725]=0;c=P(36,e+8|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){d=x[b+24>>2];x[31725]=0;S(1059,e+20|0,d|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;O(180,f|0,e+20|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}tb(e+20|0);tb(c);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(c);break a}fb=e+32|0;return}a=N()|0}Td(f);Q(a|0);p()}function Tw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;v[f+15|0]=d;v[b+12|0]=y[b+12|0]&240|y[a|0]&15;i=a+1|0;e=f+15|0;hh(b,y[Rb(i,e)|0]);g=y[Rb(a+2|0,e)|0];v[b+13|0]=g;k=b,l=Kd(y[a+3|0],g,d),v[k+14|0]=l;e=y[Rb(a+4|0,e)|0];v[b+15|0]=e;k=b,l=Kd(y[a+5|0],e,d),v[k+16|0]=l;g=x[b>>2];b=0;while(1){v[f+14|0]=25;if(b>>>0<y[Rb(f+14|0,i)|0]){e=D(b,3)+a|0;h=Yb(y[e+6|0]+c<<24>>24,0,64);d=yb(g,b);v[d+2|0]=h;e=y[e+7|0]|y[e+8|0]<<8;w[d>>1]=e;a:{if(!b){break a}h=yb(g,b-1|0);j=z[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;w[d>>1]=e;if(z[h>>1]<=(e&65535)>>>0){break a}w[d>>1]=e+256}b=b+1|0;continue}break}fb=f+16|0}function HN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Co(a)|0)>(b|0)){break d}}a=ac(8);x[31725]=0;d=P(36,d+4|0,10735)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}pc(a,d);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}if(c<0|c>1){a=ac(8);x[31725]=0;d=P(36,d+4|0,11752)|0;b=x[31725];x[31725]=0;if((b|0)!=1){pc(a,d);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}b=N()|0;jc(a);break b}e=(a+D(b,872)|0)+1075740|0,f=_i(c*64),x[e>>2]=f;fb=d+16|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function NW(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;d=vb(f+12|0,x[a+4>>2]);c=vb(f+8|0,x[a>>2]);g=x[vb(f+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;i=h+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[d>>2],x[c>>2]);j=e+16|0;c=x[e+24>>2];k=x[e+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=g;x[d+12>>2]=c;while(1){if(pd(c,k)){c=kl(c);g=kl(x[d+8>>2]);x[g+8>>2]=x[c+8>>2];l=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=l;c=uk(d+12|0);uk(d+8|0);c=x[c>>2];continue}break}Ac(j,c,d+8|0);fb=d+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,d,e+12|0);fb=e+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Bga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=$j(b),x[i+4>>2]=j;c=fb-16|0;fb=c;g=a;d=ce(a);a:{if(d){f=ec(g);while(1){a=d;d=a+16|0;if(Uu(b,d)){f=a;d=x[a>>2];if(d){continue}break a}if(!Uu(d,b)){break a}f=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(g);f=a}x[c+12>>2]=a;b=x[f>>2];if(!b){a=fb-16|0;fb=a;b=ec(g);b=Dh(c,Ec(40),Mg(a+8|0,b));Fb(_c(x[b>>2]+16|0,x[e+4>>2])+12|0);i=ec(b),j=1,v[i+4|0]=j;fb=a+16|0;$g(g,x[c+12>>2],f,x[c>>2]);b=le(c);a=x[c>>2];x[c>>2]=0;if(a){if(y[ec(c)+4|0]){hn(a+16|0)}Db(a)}h=1}_g(e+8|0,x[vb(c,b)>>2],h);fb=c+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+12|0}function RO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;f=Nb(a);a=z[x[b+24>>2]+480190>>1];x[31725]=0;O(178,f|0,a|0);d=x[31725];x[31725]=0;a=1;a:{if((d|0)!=1){b:{c:{d:{e:{while(1){c=a&65535;d=x[b+24>>2];if(c>>>0>z[d+480190>>1]){break b}x[31725]=0;d=P(36,e+8|0,iS(d,c)|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){c=x[b+24>>2];x[31725]=0;S(1059,e+20|0,c|0,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}x[31725]=0;O(180,f|0,e+20|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}tb(e+20|0);tb(d);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(d);break a}fb=e+32|0;return}a=N()|0}Td(f);Q(a|0);p()}function XY(a){var b=0,c=0,d=0,e=0,f=0;b=fb-32|0;fb=b;e=b,f=$b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788|0,x[e>>2]=f;x[b+4>>2]=0;e=b,f=$b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),x[e+8>>2]=f;x[b+12>>2]=0;c=$b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24));x[b+16>>2]=c?c:52;x[b+20>>2]=0;e=b,f=$b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+80|0,x[e+24>>2]=f;x[b+28>>2]=0;a=b;d=Ve(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=Nw(x[a>>2],x[a+4>>2],x[c>>2],x[c+4>>2])?c:a;continue}}fb=b+32|0;c=x[a>>2];b=c-52|0;hb=x[a+4>>2]-(c>>>0<52)|0;return b}function L3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(oh(a,x[b+8>>2],f)){Px(b,c,d,e);return}g=y[b+53|0];i=x[a+12>>2];v[b+53|0]=0;h=y[b+52|0];v[b+52|0]=0;Lx(x[a+16>>2],x[a+20>>2],b,c,d,e,f);j=y[b+53|0];l=g|j;k=y[b+52|0];h=h|k;g=a+24|0;i=(a+16|0)+(i<<3)|0;a:{if(g>>>0>=i>>>0){break a}while(1){if(y[b+54|0]){break a}b:{if(k){if(x[b+24>>2]==1){break a}if(y[a+8|0]&2){break b}break a}if(!j){break b}if(!(v[a+8|0]&1)){break a}}w[b+52>>1]=0;Lx(x[g>>2],x[g+4>>2],b,c,d,e,f);j=y[b+53|0];l=j|l;k=y[b+52|0];h=k|h;g=g+8|0;if(i>>>0>g>>>0){continue}break}}v[b+53|0]=(l&255)!=0;v[b+52|0]=(h&255)!=0}function GL(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-208|0;fb=f;x[f+204>>2]=c;c=f+160|0;Tb(c,0,40);x[f+200>>2]=x[f+204>>2];a:{if((FL(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=x[a+76>>2]>=0;g=x[a>>2];if(x[a+72>>2]<=0){x[a>>2]=g&-33}b:{c:{d:{if(!x[a+48>>2]){x[a+48>>2]=80;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;h=x[a+44>>2];x[a+44>>2]=f;break d}if(x[a+16>>2]){break c}}c=-1;if(Y0(a)){break b}}c=FL(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){ib[x[a+36>>2]](a,0,0)|0;x[a+48>>2]=0;x[a+44>>2]=h;x[a+28>>2]=0;b=x[a+20>>2];x[a+16>>2]=0;x[a+20>>2]=0;c=b?c:-1}b=a;a=x[a>>2];x[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}fb=f+208|0;return e}function FQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;ph(e+8|0,b);f=fb-16|0;fb=f;mf(f+8|0,x[e+8>>2],x[e+12>>2]);g=x[f+8>>2];b=x[f+12>>2];h=fb-16|0;fb=h;k=h,l=wb(a),x[k+12>>2]=l;a=b;b=fb-16|0;fb=b;j=x[h+12>>2];c=j;d=x[c+8>>2];c=x[c+12>>2];i=c;a:{if((c|0)<0){break a}c=x[j+4>>2];if(!i&d>>>0>c>>>0|i){break a}x[b+8>>2]=c-d;x[b+12>>2]=0-(i+(d>>>0>c>>>0)|0);x[b>>2]=a;x[b+4>>2]=0;c=J0(b+8|0,b);if((Tu(x[c>>2],x[c+4>>2])|0)!=(a|0)){break a}Wg(g,a+g|0,d+x[j>>2]|0);d=x[h+12>>2];g=d;c=x[d+8>>2];d=x[d+12>>2];i=a;a=a+c|0;d=i>>>0>a>>>0?d+1|0:d;x[g+8>>2]=a;x[g+12>>2]=d}fb=b+16|0;fb=h+16|0;fb=f+16|0;fb=e+16|0}function woa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;a:{if(!(c&1024)){break a}i=g,j=zd(b),x[i+12>>2]=j;c=Yc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[cc(b,0)|0]!=43){if(y[cc(b,0)|0]!=45){break b}}d=d+1|0;yV(g+12|0)}if(c>>>0>=d>>>0){break a}e=x[vb(g+8|0,x[g+12>>2])>>2];c=d-Yc(x[b+4>>2],y[b+11|0])|0;c:{e=Hk(e,zd(b));d=Cb(x[b+4>>2],y[b+11|0]);if(e>>>0<=d>>>0){if(c){f=Mc(b);d:{if(c>>>0<=f-d>>>0){f=Kb(b);if((d|0)==(e|0)){break d}h=e+f|0;Vi(c+h|0,h,d-e|0);break d}VB(b,f,(c+d|0)-f|0,d,e,c);f=x[b>>2]}im(e+f|0,c,48);c=c+d|0;ng(b,c);fd(c+f|0,0)}break c}ln();p()}zd(b)}_c(a,b);fb=g+16|0}function uV(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}v[a+798|0]=0;return}v[a+798|0]=1;return}v[a+798|0]=2;return}v[a+798|0]=3;return}v[a+730|0]=y[a+730|0]&254;return}v[a+730|0]=y[a+730|0]|1;return}v[a+738|0]=y[a+738|0]&254;return}v[a+738|0]=y[a+738|0]|1;return}v[a+746|0]=y[a+746|0]&254;return}v[a+746|0]=y[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=y[a+746|0];v[c+746|0]=(b|0)==13?a&238|1:a|17}}function fva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-208|0;fb=d;L0(c,a);K0(c,d+16|0,D(y[a+4|0],3));a:{if(y[a+4|0]<2){break a}c=fb-16|0;fb=c;x[c+12>>2]=64;x[c+8>>2]=255;e=y[Gb(c+12|0,c+8|0)|0];fb=c+16|0;v[d+12|0]=e;hh(b,y[Rb(a+4|0,d+12|0)|0]);v[b+13|0]=y[a+2|0];v[b+14|0]=y[a+3|0];a=y[a+1|0];v[b+15|0]=a;v[b+16|0]=a;e=x[b>>2];f=Sd(e,x[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=y[d+18|0];c=yb(e,0);break b}g=z[yb(e,a-1|0)>>1];x[d+12>>2]=1;b=(d+16|0)+D(a,3)|0;x[d+8>>2]=(v[b+1|0]&1)<<8|y[b|0];h=Ze(d+12|0,d+8|0);c=yb(e,a);w[c>>1]=z[h>>1]+g;b=y[b+2|0]}v[c+2|0]=b;a=a+1|0;continue}}fb=d+208|0}function Epa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;ld(b,0);f=d+8|0;nk(f,1,a);c=d+20|0;Cc(c,f);ze(b+43|0,c);tb(c);x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+24>>2]=y[a+62|0]|y[a+63|0]<<8;hm(b,+((y[a+60|0]^8)-120|0)/192);v[d+20|0]=y[a+61|0];v[d+8|0]=64;g=b,h=y[Rb(c,f)|0]<<2,w[g+30>>1]=h;w[b+34>>1]=0;c=y[a+47|0];if(c&4){w[b+34>>1]=1;x[b>>2]=x[b>>2]>>>1;e=1;c=y[a+47|0]}if(c&32){e=e|4;w[b+34>>1]=e;c=y[a+47|0]}if(c<<24>>24<0){w[b+34>>1]=e|2}fb=d+32|0}function BD(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;d=(c<<3)+a|0;f=y[d+356|0];v[b+12|0]=y[b+12|0]&248|f&1|f<<1&4|f>>>1&2;hh(b,Kd(y[d+352|0],2,16));v[b+13|0]=y[d+354|0];v[b+14|0]=y[d+355|0];d=y[d+353|0];v[b+15|0]=d;v[b+16|0]=d;d=0;w[e+14>>1]=0;f=((c|0)!=0)<<1;h=x[b>>2];j=Sd(h,x[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){AD(b,32);fb=e+16|0}else{a=k+(d<<2)|0;w[e+12>>1]=y[a+160|0]|y[a+161|0]<<8;g=qe(e+14|0,e+12|0);i=yb(h,d);g=z[g>>1];w[i>>1]=g;w[e+14>>1]=g+1;v[e+11|0]=(c^y[a+162|0])>>>f;v[e+10|0]=64;l=i,m=y[Rb(e+11|0,e+10|0)|0],v[l+2|0]=m;d=d+1|0;continue}break}}function VS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;a:{if(x[a+480180>>2]!=1){break a}c=y[b+846|0];if(!c){break a}e=x[b+104>>2];if(!e){break a}if(!je(x[e>>2],x[e+20>>2])){break a}f=z[e+34>>1];if(!(f&10)){break a}c=y[b+847|0]+y[(c&15)+31664|0]|0;v[b+847|0]=c;if(c<<24>>24>=0){break a}v[b+847|0]=0;h=f&2;c=x[(h?4:12)+e>>2];g=b;b=x[b+760>>2]+1|0;b=b>>>0<x[(h?8:16)+e>>2]-c>>>0?b:0;x[g+760>>2]=b;g=x[e+20>>2];c=b+c|0;b=el(f);bc(d+8|0,g+D(c,b)|0,b);i=d,j=wb(x[d+8>>2]),x[i+4>>2]=j;f=Yk(x[d+8>>2],x[d+12>>2]);while(1){b=x[d+4>>2];if(Ib(b,f)){v[b|0]=y[b|0]^-1;me(d+4|0);continue}else{Sj(e,a)}break}}fb=d+16|0}function Bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;f=c;e=fb-16|0;fb=e;g=b;d=ce(b);a:{if(d){c=ec(g);while(1){b=d;d=b+16|0;if(QR(f,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!QR(d,f)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=ec(g);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=fb-16|0;fb=b;d=ec(g);d=Dh(e,Ec(28),Mg(b+8|0,d));i=x[d>>2];x[31725]=0;O(893,i+16|0,f|0);f=x[31725];x[31725]=0;b:{if((f|0)!=1){j=ec(d),k=1,v[j+4|0]=k;fb=b+16|0;break b}a=N()|0;PR(d);Q(a|0);p()}$g(g,x[e+12>>2],c,x[e>>2]);b=le(e);PR(e);i=1}c=h+8|0;_g(c,x[vb(e,b)>>2],i);fb=e+16|0;sV(a,c);fb=h+16|0}function Tka(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){Du(a+484344|0);tf(a+1298308|0);tf(a+1298320|0);tf(a+1298332|0);fw(a+1298412|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){b=a+906300|0;c=Ij(b);while(1){if((b|0)==(c|0)){break a}t0(b);b=b+160|0;continue}}d=x[b>>2];if(d){Db(Jv(d))}x[b>>2]=0;b=b+4|0;continue}}}else{vn(c);c=c+104|0;continue}break}x[a+480180>>2]=0;x[a+480184>>2]=0;a=a+480186|0;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;w[a+6>>1]=0}else{x[b+104>>2]=0;x[b+656>>2]=0;x[b+76>>2]=0;x[b+16>>2]=0;b=b+872|0;continue}break}}function GR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-16|0;fb=h;v[h+15|0]=b;v[h+14|0]=10;hh(g,y[Rb(h+15|0,h+14|0)|0]);v[g+15|0]=c;v[g+16|0]=c;v[g+14|0]=e;v[g+13|0]=d;j=x[g>>2];k=Sd(j,x[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=y[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=yb(j,b);l=D(b,3)+f|0;i=(y[l|0]|y[l+1|0]<<8)>>>4|0;w[m>>1]=i;c:{if(b){n=z[yb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=yb(j,b),p=i,w[o>>1]=p}o=m,p=Kd(y[l+2|0],0,64),v[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}v[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;fb=h+16|0}function yt(a,b,c,d){var e=0,f=0,g=0,h=0;g=d?d:500084;d=x[g>>2];a:{b:{c:{if(!b){if(d){break c}return 0}e=-2;if(!c){break b}d:{if(d){e=c;break d}d=y[b|0];f=d<<24>>24;if((f|0)>=0){if(a){x[a>>2]=d}return(f|0)!=0}if(!x[x[124231]>>2]){e=1;if(!a){break b}x[a>>2]=f&57343;return 1}d=d-194|0;if(d>>>0>50){break c}d=x[(d<<2)+111520>>2];e=c-1|0;if(!e){break a}b=b+1|0}f=y[b|0];h=f>>>3|0;if((h-16|(d>>26)+h)>>>0>7){break c}while(1){e=e-1|0;d=f-128|d<<6;if((d|0)>=0){x[g>>2]=0;if(a){x[a>>2]=d}return c-e|0}if(!e){break a}b=b+1|0;f=y[b|0];if((f&192)==128){continue}break}}x[g>>2]=0;x[31600]=25;e=-1}return e}x[g>>2]=d;return-2}function cua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=fb-32|0;fb=f;e=b;b=x[a>>2];b=Hk(e,wb(b))+b|0;e=YD(c,d);a:{if((e|0)<=0){break a}g=x[zb(a)>>2];h=x[a+4>>2];if((e|0)<=(g-h|0)){x[f+12>>2]=d;g=h-b|0;if((g|0)<(e|0)){x[f+12>>2]=c;i$(f+12|0,g);XD(a,x[f+12>>2],d,e-g|0);if((g|0)<=0){break a}}h$(a,b,h,b+e|0);mp(c,x[f+12>>2],b);break a}g=zb(a);h=wn(f+12|0,cm(a,Sc(x[a>>2],h)+e|0),b-x[a>>2]|0,g);e=fb-16|0;fb=e;x[e+12>>2]=c;c=yC(e,h+8|0,YD(c,d));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){Fl(d,y[x[e+12>>2]]);d=x[c>>2]+1|0;x[c>>2]=d;me(e+12|0);continue}break}he(c);fb=e+16|0;b=g$(a,h,b);un(h)}wb(b);fb=f+32|0}function Ysa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;e=Tf(d+52|0);x[31725]=0;c=P(412,b|0,e|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(413,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}}break c}c=fb-16|0;fb=c;g=c,h=$b(x[e+4>>2]),x[g+12>>2]=h;x[c+8>>2]=8;f=x[ad(c+12|0,c+8|0)>>2];fb=c+16|0;x[31725]=0;S(187,d+12|0,b|0,f-8|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}a=N()|0;Gd(e);Q(a|0);p()}b=d+12|0;c=ic(d+32|0,b);hd(e+8|0,c);ub(c);ub(b);Vk(a,e)}Gd(e);fb=d+80|0}function Ti(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=c*d;k=b*e;h=j+k;l=b*d;m=c*e;i=l-m;a:{if(!Wi(i)){break a}if(!Wi(h)){break a}f=zf(b);g=zf(c);n=f|g;b:{if((n|0)!=1){break b}b=qi(f?1:0,b);c=qi(g?1:0,c);if(Wi(d)){d=qi(0,d)}if(!Wi(e)){break b}e=qi(0,e)}f=zf(d);g=zf(e);c:{if(f|g){d=qi(f?1:0,d);e=qi(g?1:0,e);if(Wi(b)){b=qi(0,b)}if(!Wi(c)){break c}c=qi(0,c);break c}if(n){break c}d:{if(zf(l)){break d}if(zf(m)){break d}if(zf(k)){break d}if(!zf(j)){break a}}if(Wi(b)){b=qi(0,b)}if(Wi(c)){c=qi(0,c)}if(Wi(d)){d=qi(0,d)}if(!Wi(e)){break c}e=qi(0,e)}h=(b*e+d*c)*Infinity;i=(b*d-e*c)*Infinity}Xl(a,i,h)}function NB(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);g=x[vb(f+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;i=h+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=g;x[c+12>>2]=d;while(1){if(pd(d,k)){d=Qp(d);g=Qp(x[c+8>>2]);l=x[d+4>>2];x[g>>2]=x[d>>2];x[g+4>>2]=l;d=Pp(c+12|0);Pp(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Ii(a,b,c,d){var e=0,f=0,g=0;e=fb-48|0;fb=e;f=x[x[a>>2]-12>>2]+a|0;g=x[f+16>>2]&-3;kg(f,g);a:{b:{if(Ed(y[Mm(e+47|0,a,1)|0])){f=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31725]=0;Ps(88,e+24|0,f,b,c,d);b=x[31725];x[31725]=0;c:{if((b|0)!=1){b=hi(e+8|0,-1,-1);d=go(x[e+32>>2],x[e+36>>2],x[b+8>>2],x[b+12>>2])?g|4:g;break c}Y(T(0)|0)|0;d=g|1;Km(x[x[a>>2]-12>>2]+a|0,d);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}fk(x[x[a>>2]-12>>2]+a|0,d)}fb=e+48|0;return a}T(0)|0;Sb()}p()}function sra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=$j(b),x[i+4>>2]=j;f=z[b>>1];d=fb-16|0;fb=d;g=a;c=ce(a);a:{if(c){b=ec(g);while(1){a=c;c=z[a+14>>1];if(fp(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!fp(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=fb-16|0;fb=a;c=ec(g);f=Dh(d,Ec(20),Mg(a+8|0,c));c=x[f>>2];h=z[x[e+4>>2]>>1];w[c+16>>1]=0;w[c+14>>1]=h;i=ec(f),j=1,v[i+4|0]=j;fb=a+16|0;$g(g,x[d+12>>2],b,x[d>>2]);a=le(d);em(d);h=1}_g(e+8|0,x[vb(d,a)>>2],h);fb=d+16|0;a=jp(x[e+8>>2]);fb=e+16|0;return a+2|0}function Oga(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=fb-80|0;fb=d;x[d+76>>2]=c;c=x[a>>2];e=x[a+4>>2];f=x[a+12>>2];x[d+48>>2]=x[a+8>>2];x[d+52>>2]=f;x[d+40>>2]=c;x[d+44>>2]=e;a=Nd(d+32|0);c=x[d+52>>2];x[d+16>>2]=x[d+48>>2];x[d+20>>2]=c;x[31725]=0;c=x[d+44>>2];x[d+8>>2]=x[d+40>>2];x[d+12>>2]=c;c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;S(986,d+56|0,d+8|0,d|0);a=x[31725];x[31725]=0;a:{b:{if((a|0)!=1){a=x[re(d+28|0,d+76|0)>>2];x[31725]=0;b=+pa(987,d+56|0,+b,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}ub(d+56|0);Vc(d+76|0);fb=d+80|0;return+b}a=N()|0;break a}a=N()|0;ub(d+56|0)}Vc(d+76|0);Q(a|0);p()}function n_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=$j(b),x[i+4>>2]=j;f=x[b>>2];d=fb-16|0;fb=d;g=a;c=ce(a);a:{if(c){b=ec(g);while(1){a=c;c=x[a+16>>2];if(pE(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!pE(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=fb-16|0;fb=a;c=ec(g);f=Dh(d,Ec(24),Mg(a+8|0,c));c=x[f>>2];h=x[x[e+4>>2]>>2];x[c+20>>2]=0;x[c+16>>2]=h;i=ec(f),j=1,v[i+4|0]=j;fb=a+16|0;$g(g,x[d+12>>2],b,x[d>>2]);a=le(d);em(d);h=1}_g(e+8|0,x[vb(d,a)>>2],h);fb=d+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+4|0}function v8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}bd(f+16|0,x[c+28>>2]);x[31725]=0;a=R(1218,x[f+16>>2])|0;b=x[31725];x[31725]=0;b:{if((b|0)!=1){Zb(f+16|0);c:{if(e){li(f+16|0,a);break c}ki(f+16|0,a)}g=f,h=zd(f+16|0),x[g+12>>2]=h;while(1){a=ul(f+16|0);b=x[f+12>>2];if(!Ib(b,a)){c=x[f+28>>2];Qb(f+16|0);break a}a=x[b>>2];x[31725]=0;P(1232,f+28|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){Je(f+12|0);continue}break}c=N()|0;Qb(f+16|0);break b}c=N()|0;Zb(f+16|0)}Q(c|0);p()}fb=f+32|0;return c|0}function Rt(a,b,c){var d=0,e=0;d=a,e=Cj(E(E(B[c+1792>>2]*E(75038))+E(E(E(B[c+2048>>2]-B[c+1536>>2])*E(37489))+E(E(E(B[c+1280>>2]+B[c+2304>>2])*E(6574))+E(E(E(B[c+2560>>2]-B[c+1024>>2])*E(5153))+E(E(E(B[c+768>>2]+B[c+2816>>2])*E(2037))+E(E(E(B[c+3072>>2]-B[c+512>>2])*E(459))+E(E(E(B[c+256>>2]+B[c+3328>>2])*E(213))+E(E(B[c+3584>>2]-B[c>>2])*E(29)))))))))),w[d>>1]=e;d=(b<<5)+a|0,e=Cj(E(E(B[c+8>>2]*E(-5))+E(E(B[c+520>>2]*E(146))+E(E(B[c+1032>>2]*E(-45))+E(E(B[c+1544>>2]*E(-9975))+E(E(B[c+2056>>2]*E(64019))+E(E(B[c+2568>>2]*E(9727))+E(E(B[c+3080>>2]*E(1567))+E(B[c+3592>>2]*E(104)))))))))),w[d>>1]=e}function wX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;Fc(a+8|0,0);d=x[b+4>>2];if(d){$r(a,d);tn(c+8|0,x[b>>2]);fr(c,x[b>>2],x[b+4>>2]);b=fb-32|0;fb=b;d=x[c+8>>2];j=x[c>>2];e=x[a+4>>2];g=x[c+12>>2];k=x[c+4>>2];f=e+uX(d,g,j,k)|0;x[a+4>>2]=f;a:{b:{if(!e){h=f-1|0;break b}h=f-1|0;if((h^e-1)>>>0>31){break b}x[b+24>>2]=d;x[b+28>>2]=g;i=x[a>>2];break a}i=x[a>>2];x[i+((f>>>0>=33?h>>>5|0:0)<<2)>>2]=0;x[b+24>>2]=d;x[b+28>>2]=g}Fp(b+16|0,i,e);d=x[b+28>>2];x[b>>2]=x[b+24>>2];x[b+4>>2]=d;vX(b+8|0,b,j,k,x[b+16>>2],x[b+20>>2]);fb=b+32|0}fb=c+16|0;return a|0}function F8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}bd(f+16|0,x[c+28>>2]);x[31725]=0;a=R(1201,x[f+16>>2])|0;b=x[31725];x[31725]=0;b:{if((b|0)!=1){Zb(f+16|0);c:{if(e){li(f+16|0,a);break c}ki(f+16|0,a)}g=f,h=zd(f+16|0),x[g+12>>2]=h;while(1){a=Df(f+16|0);b=x[f+12>>2];if(!Ib(b,a)){c=x[f+28>>2];tb(f+16|0);break a}a=v[b|0];x[31725]=0;P(30,f+28|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){me(f+12|0);continue}break}c=N()|0;tb(f+16|0);break b}c=N()|0;Zb(f+16|0)}Q(c|0);p()}fb=f+32|0;return c|0}function z3(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-32|0;fb=k;n=x[c>>2];l=x[c+8>>2];m=x[c+4>>2];c=k;x[c+8>>2]=m;x[c+12>>2]=l;x[c+24>>2]=m;x[c+28>>2]=l;x[c+20>>2]=n;x[c+16>>2]=d;x[31725]=0;d=x[c+20>>2];x[c>>2]=x[c+16>>2];x[c+4>>2]=d;a=Ia(1100,a|0,b|0,c|0)|0;b=x[31725];x[31725]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31725]=0;ga(985,10415,e|0,f|0,g|0,h|0,i|0,j|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Z();a=-255}fb=k+32|0;break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return a|0}function mA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(pd(d,k)){d=xf(d);l=xf(x[c+8>>2]),m=B[d>>2],B[l>>2]=m;d=Ni(c+12|0);Ni(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Jna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>18|0;n=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){g=(e<<1)+n|0;h=w[g>>1];x[(e<<2)+b>>2]=h+((D(w[g+4>>1]-h|0,m)|0)/16384|0);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function wH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=g+4|0;v[e+8|0]=1;x[e+4>>2]=c;x[e>>2]=a;h=y[e+8|0];a=x[e>>2];i=x[e+4>>2];j=Kb(b);b=Cb(x[b+4>>2],y[b+11|0]);d=fb-16|0;fb=d;x[d+8>>2]=b;x[d+12>>2]=i;b=a;e=x[Gb(d+12|0,d+8|0)>>2];f=e;while(1){a:{if(!f){f=0;break a}c=y[j|0];v[b|0]=c;if(!c){break a}j=j+1|0;b=b+1|0;f=f-1|0;continue}break}b:{if((h-1&255)>>>0<=1){v[d+7|0]=0;Wm(b,((b+i|0)-e|0)+f|0,d+7|0);break b}if((h-3&255)>>>0>1){break b}v[d+6|0]=32;Wm(b,((b+i|0)-e|0)+f|0,d+6|0)}c:{switch(h-1|0){case 0:case 3:v[(x[d+12>>2]+a|0)-1|0]=0;break;default:break c}}fb=d+16|0;fb=g+16|0}function Vpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;a:{c=x[a+12>>2];b:{if((c|0)==(b|0)){break b}f=b>>>0>c>>>0;c=D(z[x[x[a+48>>2]+12>>2]+480188>>1],f?b-c|0:c-b|0);d=wb(x[a+4>>2]);c:{if(f){d=vb(e+28|0,d);w[e+24>>1]=0;x[e+20>>2]=0;d=x[d>>2];x[31725]=0;V(664,a|0,d|0,c|0,e+20|0);c=x[31725];x[31725]=0;if((c|0)!=1){break c}a=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(a|0)|0;Z();break b}c=vb(e+16|0,MD(d,c));d=x[vb(e+12|0,wb(x[a+4>>2]))>>2];f=x[c>>2];c=x[a>>2];c=D(xu(f,wb(c)),6)+c|0;if(Ib(f,d)){sD(a,uA(c+D(xu(d,f),6)|0,x[a+4>>2],c))}wb(c)}x[a+12>>2]=b}fb=e+32|0;return}Q(a|0);p()}function ry(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;bd(f+12|0,b);x[31725]=0;b=R(1217,x[f+12>>2])|0;g=x[31725];x[31725]=0;a:{if((g|0)==1){break a}x[31725]=0;V(1228,b|0,111728,111760,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;b=R(1218,x[f+12>>2])|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;c=R(1229,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}x[d>>2]=c;x[31725]=0;c=R(1226,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[e>>2]=c;x[31725]=0;O(1227,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Zb(f+12|0);fb=f+16|0;return}a=N()|0;Zb(f+12|0);Q(a|0);p()}function _m(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(pd(d,k)){d=xf(d);l=xf(x[c+8>>2]),m=x[d>>2],x[l>>2]=m;d=Ni(c+12|0);Ni(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb+-64|0;fb=c;f=EU(a,1<<b-1);x[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=x[10073];d=c+32|0;x[d+8>>2]=x[10072];x[d+12>>2]=e;e=x[10071];x[d>>2]=x[10070];x[d+4>>2]=e;PB(d,h*+(b>>>0));zU(c+48|0,C[c+32>>3],C[c+40>>3]);d=Xd(x[f>>2],a);e=x[c+60>>2];x[d+8>>2]=x[c+56>>2];x[d+12>>2]=e;e=x[c+52>>2];x[d>>2]=x[c+48>>2];x[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=Xl(c+16|0,1,0);b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;zA(f,0,g,c);fb=c- -64|0;return f|0}function $g(a,b,c,d){var e=0,f=0;x[d+8>>2]=b;x[d>>2]=0;x[d+4>>2]=0;x[c>>2]=d;b=x[x[a>>2]>>2];if(b){x[a>>2]=b;d=x[c>>2]}f=x[ec(a)>>2];v[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=x[d+8>>2];if(y[c+12|0]){break a}b:{if(Uh(c)){b=x[c+8>>2];e=x[b+4>>2];if(!(!e|y[e+12|0])){break b}if(!Uh(d)){vr(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;ur(b);break a}b=x[c+8>>2];e=x[b>>2];if(!(!e|y[e+12|0])){break b}if(Uh(d)){ur(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;vr(b);break a}v[c+12|0]=1;d=b;v[d+12|0]=(d|0)==(f|0);v[e+12|0]=1;continue}break}a=zb(a);x[a>>2]=x[a>>2]+1}function mn(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function wy(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;bd(f+12|0,b);x[31725]=0;b=R(28,x[f+12>>2])|0;g=x[31725];x[31725]=0;a:{if((g|0)==1){break a}x[31725]=0;V(1215,b|0,111728,111760,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}x[31725]=0;b=R(1201,x[f+12>>2])|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;c=R(1216,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}v[d|0]=c;x[31725]=0;c=R(1213,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}v[e|0]=c;x[31725]=0;O(1214,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Zb(f+12|0);fb=f+16|0;return}a=N()|0;Zb(f+12|0);Q(a|0);p()}function hh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=fb-16|0;fb=c;b=Tg(c+4|0,a,b);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{Sw(a);a=a+4|0;x[b+4>>2]=a;continue}break}break a}c=zb(a);c=$f(e+12|0,Mf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Nn(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Sw(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}he(b);fb=f+16|0;bs(a,c);_f(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}function Mm(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[a|0]=0;a:{e=x[b>>2];f=x[e-12>>2]+b|0;b:{if(!x[f+16>>2]){f=x[f+72>>2];if(f){Jn(f);e=x[b>>2]}c:{if(c){break c}c=x[e-12>>2]+b|0;if(!(y[c+5|0]&16)){break c}bd(d+12|0,x[c+28>>2]);x[31725]=0;f=R(28,x[d+12>>2])|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}Zb(d+12|0);c=xp(d+8|0,b);e=sc(d+4|0);while(1){d:{if(uh(c,e)){break d}g=Cl(x[c>>2]);if(!Kf(x[f+8>>2],1,g)){break d}Lm(c);continue}break}if(uh(c,e)){fk(x[x[b>>2]-12>>2]+b|0,6)}e=x[b>>2]}v[a|0]=!x[(x[e-12>>2]+b|0)+16>>2];break b}fk(f,4)}fb=d+16|0;return a}a=N()|0;Zb(d+12|0);Q(a|0);p()}function n4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{if(oi(b,14276)){d=Ts(c+28|0,b);e=x[d>>2];if(!Dd(e)){x[31725]=0;b=P(36,c+4|0,b|0)|0;a=x[31725];x[31725]=0;c:{d:{e:{if((a|0)!=1){x[31725]=0;S(1017,c+16|0,17734,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}x[31725]=0;W(1345,c+16|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}p()}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(c+16|0)}tb(b);break a}kq(e);gq(a+8|0,16781,x[d>>2]);gq(a+12|0,22255,x[d>>2]);x[31725]=0;O(274,a+16|0,22255);a=x[31725];x[31725]=0;if((a|0)==1){break b}pl(d)}fb=c+32|0;return}a=N()|0}pl(d);Q(a|0);p()}function $L(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(hf(a)){fc(a,31);return 0}g=a,h=hf(a),v[g+1375|0]=h;d=Bj(a);b=Bj(a);Bj(a);g=a,h=Bj(a),x[g+1112>>2]=h;Bj(a);c=hf(a);x[a+1116>>2]=c;if(!dz(a,a+1120|0,c)){fc(a,10);return 0}x[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=x[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(y[(b+a|0)+1120|0]==255){continue}break}x[a+1408>>2]=d;x[a+1404>>2]=b}if(y[a+1377|0]){b=0;e=x[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=y[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}x[a- -64>>2]=d;x[a+60>>2]=(x[a+56>>2]+(c+e|0)|0)+27}x[a+1380>>2]=0;return 1}function uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)==1){break c}x[31725]=0;W(1003,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(c+12|0,b);x[31725]=0;e=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=e;V(1015,c+20|0,d|0,c|0,1);b=x[31725];x[31725]=0;if((b|0)==1){break c}a=c+20|0;b=Bg(Kb(a));tb(a);break b}Y(T(0)|0)|0;b=0;x[31725]=0;V(989,5535,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}fb=c+32|0;return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function il(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;f=a+36|0;c=x[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=x[a+20>>2];if(d>>>0>=A[a+24>>2]){yo(e,f,CG(f));rd(e+8|0,a,x[e>>2],x[e+4>>2]);c=x[e+12>>2];x[a+24>>2]=c;x[a+20>>2]=0;if(!c){break c}d=0;c=x[a+32>>2]}x[a+20>>2]=d+1;g=y[(a+d|0)+36|0];d=c+8|0;x[a+32>>2]=d;x[a+28>>2]=x[a+28>>2]|g<<c;c=d;continue}break}a=ac(8);x[31725]=0;b=R(163,a|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}x[a+32>>2]=c-b;d=a;a=x[a+28>>2];x[d+28>>2]=a>>>b;fb=e+16|0;return a&(-1<<b^-1)}da(b|0,28848,164);p()}function Kna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>10&4194048;n=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){g=e+n|0;h=v[g|0];x[(e<<2)+b>>2]=((D(v[g+2|0]-h|0,m)|0)/16384|0)+(h<<8);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function qua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{b:{if(b){x[31725]=0;O(323,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}e=fb-16|0;fb=e;d=Kr(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){hc(d);fb=e+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+4|0]=6;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=8;v[b+3|0]=4;b=b+6|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Qd(b);jm(b);fb=c+16|0;break a}a=N()|0;jm(c+8|0);Q(a|0);p()}v[a+16|0]=6;x[a+12>>2]=2015363072;return a|0}function T4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=fb+-64|0;fb=g;fo(g+16|0,c);x[31725]=0;c=g+28|0;O(93,c|0,d|0);d=x[31725];x[31725]=0;b:{c:{d:{if((d|0)==1){break d}x[31725]=0;c=g+40|0;O(93,c|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}x[31725]=0;c=g+52|0;O(93,c|0,f|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}Ux(g+8|0,g+16|0);x[31725]=0;V(94,a|0,b|0,x[g+8>>2],x[g+12>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}EI(g+16|0);fb=g- -64|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=N()|0;EI(g+16|0)}Q(a|0);p()}}function O$(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=y[e|0];if(!i){break a}j=2240>>>d&d>>>0<12;g=D(c,-6);k=(d-2&255)>>>0>2;while(1){if(!b){break a}c=a;a=c+g|0;f=y[a+3|0];b:{c:{if(!((f-2&255)>>>0>2|k)){f=1;if(y[(c+g|0)+5|0]<224){break c}break a}f=!(1<<f&2240)|(!j|f>>>0>11)?(d|0)==(f|0):1;if(k){break b}}h=c+g|0;if((y[h+2|0]-11&255)>>>0>2){break b}if(y[h+4|0]){break a}}d:{if(!j){break d}h=c+g|0;if((y[h+2|0]-3&255)>>>0>3){break d}if(y[h+4|0]){break a}}b=b-1|0;if(!f){continue}c=y[(c+g|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}v[e|0]=0}}function $d(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a=hi(a,-1,-1);a:{b:{if(Ed(y[Mm(c+31|0,b,1)|0])){d=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31725]=0;Ps(88,c+8|0,d,0,0,1);d=x[31725];x[31725]=0;c:{if((d|0)!=1){d=x[c+12>>2];x[a>>2]=x[c+8>>2];x[a+4>>2]=d;d=x[c+20>>2];x[a+8>>2]=x[c+16>>2];x[a+12>>2]=d;break c}Y(T(0)|0)|0;e=1;Km(x[x[b>>2]-12>>2]+b|0,1);if(x[(x[x[b>>2]-12>>2]+b|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}fk(x[x[b>>2]-12>>2]+b|0,e)}fb=c+32|0;return}T(0)|0;Sb()}p()}function iN(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];x[a>>2]=b;if(c){x[31725]=0;W(857,c|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){d=x[c+4>>2];if(d){e=fb-16|0;fb=e;f=vb(e+12|0,d);a=x[f>>2];if(x[a>>2]){g=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(g|0)){b=b-4|0;og(b);continue}break}x[a+4>>2]=g;a=x[f>>2];b=x[a>>2];Ug(a);Db(b)}fb=e+16|0;Db(d)}x[c+4>>2]=0;FS(c+1298412|0);YA(c+1298344|0);tb(c+1298332|0);tb(c+1298320|0);tb(c+1298308|0);XA(c+1298304|0);WA(c+1298300|0);Qu(c+1298264|0);kB(c+1074376|0);ES(c+906300|0);_B(c+484360|0);wS(c+484344|0);uc(c+480248|0);break a}T(0)|0;Sb();p()}Db(c)}}function Dta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;c=65535;e=x[a>>2];a:{if(Zc(e,x[a+4>>2])>>>0<=b>>>0){break a}e=z[_b(e,b)>>1];b:{if(!cj(a,b)){break b}c=x[a+24>>2];d=wb(x[c+484360>>2]);x[g+12>>2]=d;h=wb(x[c+484364>>2]);while(1){if(!Ib(d,h)){break b}f=0;i=mm(x[d>>2],x[d+4>>2]);while(1){if((f|0)!=(i|0)){c:{if(!((a|0)!=(d|0)|(b|0)!=(f|0))|(e|0)!=z[_b(x[d>>2],f)>>1]){break c}c=XX(x[a+24>>2]+484344|0,e);if((c|0)==65535){break c}j=_b(x[a>>2],b),k=c,w[j>>1]=k;break a}f=f+1|0;continue}break}d=x[er(g+12|0)>>2];continue}}c=e}fb=g+16|0;return c&65535}function x3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=fb-16|0;fb=c;x[31725]=0;W(1002,a|0);e=x[31725];x[31725]=0;a:{b:{c:{d:{if((e|0)==1){break d}x[31725]=0;W(1003,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break d}e=x[a+24>>2];b=qc(c+8|0,b);x[31725]=0;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;Ps(1023,e,c,f,d,1);d=x[31725];x[31725]=0;b=1;if((d|0)!=1){break c}}Y(T(0)|0)|0;x[31725]=0;V(989,8642,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Z();b=0}fb=c+16|0;break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return b|0}function dG(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+4>>2]=D(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),5)+(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24));x[b+8>>2]=(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))+((y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))<<3);x[b+12>>2]=(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+((y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24))<<2);a=b+4|0;d=yb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=nr(x[a>>2],x[c>>2])?c:a;continue}}fb=b+16|0;return x[a>>2]-36|0}function Fr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;PE(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;v[b+31|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function Zna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;i=x[a+16>>2];h=mg(1,2);e=hb;j=e;Pb(a,h,e);k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[b+8>>2];g=((((x[b+12>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+i|0;f=0;while(1){if((f|0)!=2){x[(f<<2)+b>>2]=w[(f<<1)+g>>1];f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],k);Pb(b+8|0,e,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Hg(a,h,j);fb=b+16|0}function OL(a,b){var c=0,d=0,e=0,f=0,g=0;if(!y[496816]){f=496817,g=Qa()|0,v[f|0]=g;v[496816]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!y[496817]){break c}d=+Ga();break a}x[31600]=28;return-1}d=+Xa()}c=d/1e3;e:{if(F(c)<0x8000000000000000){e=~~c>>>0;a=F(c)>=1?~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break e}a=-2147483648}x[b>>2]=e;x[b+4>>2]=a;c=(d-(+(ova(e,a,1e3,0)>>>0)+ +(hb|0)*4294967296))*1e3*1e3;f:{if(F(c)<2147483648){a=~~c;break f}a=-2147483648}x[b+8>>2]=a;return 0}function YQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(pd(d,k)){d=WQ(d);yc(WQ(x[c+8>>2]),d,2048);d=UQ(c+12|0);UQ(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Ina(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;h=v[e|0];e=((D(v[e+1|0]-h|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(h<<8)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function D$(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(pd(d,k)){d=bw(d);yc(bw(x[c+8>>2]),d,36);d=A$(c+12|0);A$(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Q6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[a>>2];d=oc(c,x[a+4>>2]);if(d>>>0<b>>>0){h=fb-32|0;fb=h;e=b-d|0;b=x[zb(a)>>2];c=x[a+4>>2];a:{if(e>>>0<=b-c>>2>>>0){$q(a,e);break a}f=jq(a);d=Mf(a,oc(x[a>>2],c)+e|0);g=oc(x[a>>2],x[a+4>>2]);c=fb-16|0;fb=c;b=h+12|0;Kg(b+12|0,f);b:{if(!d){f=0;d=0;break b}iJ(c+8|0,x[b+16>>2],d);f=x[c+12>>2];d=x[c+8>>2]}x[b>>2]=d;g=d+(g<<2)|0;x[b+8>>2]=g;x[b+4>>2]=g;i=nc(b),j=d+(f<<2)|0,x[i>>2]=j;fb=c+16|0;jA(b,e);_m(a,b);iQ(b);a=x[b>>2];if(a){cy(x[b+16>>2],a,Tz(b))}}fb=h+32|0;return}if(b>>>0<d>>>0){Ih(a,c+(b<<2)|0)}}function rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[31725]=0;W(1002,a|0);e=x[31725];x[31725]=0;a:{b:{c:{if((e|0)==1){break c}x[31725]=0;W(1003,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break c}e=x[a+24>>2];b=qc(d+8|0,b);x[31725]=0;f=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=f;V(1020,e|0,d|0,(c|0)!=0|0,1);c=x[31725];x[31725]=0;b=1;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,10005,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}fb=d+16|0;return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+12>>2]=b;a:{if(Cu(a)>>>0>=b>>>0){e=x[a>>2];g=qm(e,x[a+4>>2]);x[f+8>>2]=g;d=x[Gb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=AR(e,c)+52|0;continue}break}if(b>>>0>g>>>0){pA(a,b-g|0,c);break a}vR(a,x[a>>2]+D(b,52)|0);break a}if(x[a>>2]){Du(a);d=x[a>>2];Cu(a);Db(d);h=zb(a),i=0,x[h>>2]=i;x[a>>2]=0;x[a+4>>2]=0}e=uR(a,b);d=fb-16|0;fb=d;if(Lh(82595524)>>>0<e>>>0){dd();p()}rR(d+8|0,e);e=x[d+8>>2];x[a+4>>2]=e;x[a>>2]=e;h=zb(a),i=e+D(x[d+12>>2],52)|0,x[h>>2]=i;fb=d+16|0;pA(a,b,c)}fb=f+16|0}function Iga(a){a=a|0;var b=0;b=8016;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=22255;break a}b=8049;break a}b=18177;break a;case 0:b=5011;break a;case 9:b=8072;break a;case 10:b=8086;break a;case 11:b=5388;break a;case 12:b=5408;break a;case 19:b=8098;break a;case 20:b=8030;break a;case 21:b=12898;break a;case 22:b=12221;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=6019;break a}b=7983}return Bg(b)|0}function Hn(a,b,c,d,e,f){var g=0;g=fb-16|0;fb=g;v[g+14|0]=d;v[g+15|0]=c;v[g+13|0]=e;v[g+12|0]=f;d=0;a:{b:{while(1){c=d&255;if(c>>>0>3){break b}e=y[g+15|0];qw(g+10|0,e,y[g+14|0],c>>>0>1);if(!(y[g+10|0]|!e)){d=d+1|0;tg(g+15|0,g+13|0);tg(g+14|0,g+12|0);continue}break}c=z[g+10>>1];v[b+2|0]=c;v[b+4|0]=c>>>8;c=y[g+13|0];v[b+5|0]=y[g+12|0];v[b+3|0]=c;v[g+9|0]=0;de(a,0,g+9|0);break a}d=y[g+15|0];e=yi(d);c=y[g+13|0];if(e>>>0>yi(c)>>>0){tg(g+15|0,g+13|0);tg(g+14|0,g+12|0);d=y[g+15|0];c=y[g+13|0]}v[b+4|0]=0;v[b+2|0]=0;v[b+5|0]=y[g+12|0];v[b+3|0]=c;de(a,d,g+14|0)}fb=g+16|0}function Hna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;h=w[e>>1];e=h+((D(w[e+2>>1]-h|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function AQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=Ri(a,b,c,d);v[a+4260|0]=e;x[a>>2]=44748;c=Nb(a+4264|0);d=Nb(a+4276|0);x[a+4328>>2]=0;b=a+4320|0;x[b>>2]=0;x[b+4>>2]=0;x[a+4312>>2]=0;x[a+4316>>2]=0;b=a+4208|0;f=yb(b,0),g=1056964608,x[f>>2]=g;f=yb(b,1),g=1036831949,x[f>>2]=g;f=yb(b,2),g=1038174126,x[f>>2]=g;f=yb(b,3),g=1065353216,x[f>>2]=g;f=yb(b,4),g=1061158912,x[f>>2]=g;f=yb(b,5),g=1059082943,x[f>>2]=g;f=yb(b,6),g=1061997773,x[f>>2]=g;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;uc(d);uc(c);ag(a);Q(b|0);p()}function y3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[31725]=0;W(1003,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}c=x[a+24>>2];b=qc(d+8|0,b);x[31725]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=kI(c,d,1);e=x[31725];x[31725]=0;c=hb;if((e|0)!=1){break c}}Y(T(0)|0)|0;x[31725]=0;V(989,8673,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Z();b=0;c=0}fb=d+16|0;a=c;break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}gb=a;return b|0}function g9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=y[a+52|0];a:{if(lc(b,-1)){if(d){break a}b=x[a+48>>2];e=a,f=lc(b,-1)^1,v[e+52|0]=f;break a}b:{if(!d){break b}v[c+19|0]=x[a+48>>2]<<24>>24;c:{d:{e:{d=c+20|0;switch(tr(x[a+36>>2],x[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((At(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}fb=c+32|0;return b|0}function jr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Kb(c);ws(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=ri(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Kb(c);x[31725]=0;O(46,c|0,b-d|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(305,g|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Sh(a,g);tb(g);fb=f+16|0}function Jba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Kb(c);ws(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=ri(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Kb(c);x[31725]=0;O(46,c|0,b-d|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(305,g|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Sh(a,g);tb(g);fb=f+16|0}function k9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(lc(b,-1)){break c}v[c+23|0]=b<<24>>24;if(y[a+44|0]){d=-1;if((Tk(c+23|0,1,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=tr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Tk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Tk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=My(b);break a}d=-1}fb=c+32|0;return d|0}function Z_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Kb(c);ww(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=ri(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Kb(c);x[31725]=0;O(46,c|0,b-d|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(47,g|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Sh(a,g);tb(g);fb=f+16|0}function Wp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Kb(c);ws(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=ri(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Kb(c);x[31725]=0;O(46,c|0,b-d|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(47,g|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Sh(a,g);tb(g);fb=f+16|0}function Rv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Kb(c);ww(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,z[b>>1]);if(!x[e+16>>2]){break c}d=ri(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Kb(c);x[31725]=0;O(46,c|0,b-d|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(47,g|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Sh(a,g);tb(g);fb=f+16|0}function wz(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);a:{b:{if(c){x[31725]=0;O(1141,a|0,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}f=fb-16|0;fb=f;d=Tg(f+4|0,a,c);c=x[d+4>>2];g=x[d+8>>2];while(1){if((c|0)==(g|0)){hc(d);fb=f+16|0}else{x[c>>2]=0;sc(c);c=c+4|0;x[d+4>>2]=c;continue}break}}c=e+8|0;Qd(c);dh(c);fb=e+16|0;break a}a=N()|0;dh(e+8|0);Q(a|0);p()}e=a;a=0;c=0;d=fb-16|0;fb=d;f=d+12|0;while(1){if(a>>>0<32){a=a+48|0;c=uS(b);continue}break}x[f>>2]=c;Jo(f);fb=d+16|0;x[e+12>>2]=x[f>>2];return e}function FK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{if(a>>>0>131071){break a}f=a&255;c=(f>>>0)/3|0;g=x[((D(c,-3)+a&255)<<2)+99048>>2];e=c;c=a>>>8|0;d=x[(((D(g,y[(e+D(y[c+100432|0],86)|0)+100432|0])>>>11>>>0)%6|0)+y[c+103104|0]<<2)+99072>>2];c=d>>8;d=d&255;if(d>>>0<=1){return(c&0-(b^d))+a|0}d=c&255;if(!d){break a}c=c>>>8|0;while(1){h=d>>>1|0;e=h+c|0;i=y[(e<<1)+100032|0];if((i|0)==(f|0)){c=x[(y[(e<<1)+100033|0]<<2)+99072>>2];d=c&255;if(d>>>0<=1){return(0-(b^d)&c>>8)+a|0}return(b?-1:1)+a|0}g=e;e=f>>>0<i>>>0;c=e?c:g;d=e?h:d-h|0;if(d){continue}break}}return a}function ts(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a=Fb(a);a:{b:{c:{switch(b|0){case 0:x[31725]=0;b=P(1,d+4|0,15899)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}Ab(a,b);tb(b);break b;case 1:x[31725]=0;b=P(1,d+4|0,15924)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Ab(a,b);tb(b);break b}break a;case 2:x[31725]=0;b=P(1,d+4|0,15872)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Ab(a,b);tb(b);break b}break a;case 3:break c;default:break b}}x[31725]=0;b=P(1,d+4|0,15846)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}Ab(a,b);tb(b)}fb=d+16|0;return}b=N()|0;tb(a);Q(b|0);p()}function cia(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+24620>>2];b=Gc(pva(ova(b,b>>31,3840,0),hb,1e3,0),hb);x[a+4316>>2]=b;x[31725]=0;x[c+12>>2]=0;S(953,a+4264|0,b|0,c+12|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){d:{if(!y[a+4260|0]){break d}b=x[a+4316>>2];x[31725]=0;x[c+12>>2]=0;S(953,a+4276|0,b|0,c+12|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}b=T(125e3)|0;break c}x[c+12>>2]=0;b=c+12|0;wQ(a+4288|0,b);x[c+12>>2]=0;wQ(a+4300|0,b);break b}b=T(125e3)|0}if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;x[a+4316>>2]=0;Z()}fb=c+16|0;return}Q(b|0);p()}function tV(a,b){var c=0,d=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+14|0]=5;w[a+12>>1]=0;x[a+8>>2]=128;x[a>>2]=256;x[a+4>>2]=64;x[a+28>>2]=0;v[a+27|0]=60;x[a+40>>2]=0;x[a+44>>2]=0;v[a+33|0]=2;v[a+34|0]=0;v[a+35|0]=0;v[a+36|0]=2;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=255;v[a+26|0]=0;v[a+32|0]=0;cC(a+48|0);cC(a+68|0);cC(a+88|0);dv(a+492|0);dv(a+524|0);mk(a,0,0);lk(a,0,0);x[a+40>>2]=0;x[a+44>>2]=0;Kv(a,b);b=a+108|0;d=NC(b);c=1;while(1){if((b|0)!=(d|0)){v[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function qga(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=fb-16|0;fb=e;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)==1){break c}x[31725]=0;W(1003,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(e+8|0,b);x[31725]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;Za(1022,d|0,e|0,+c,1);d=x[31725];x[31725]=0;b=1;if((d|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,5926,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}fb=e+16|0;return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function _na(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;i=x[a+16>>2];h=mg(1,2);e=hb;j=e;Pb(a,h,e);k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[b+8>>2];g=(((x[b+12>>2]&2147483647)<<1|g>>>31)&-2)+i|0;f=0;while(1){if((f|0)!=2){x[(f<<2)+b>>2]=v[f+g|0]<<8;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],k);Pb(b+8|0,e,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Hg(a,h,j);fb=b+16|0}function r9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(po(b)){break c}x[c+20>>2]=b;if(y[a+44|0]){d=-1;if((Tk(c+20|0,4,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=tr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Tk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Tk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=po(b)?0:b;break a}d=-1}fb=c+32|0;return d|0}function Nra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-48|0;fb=e;c=x[a+8>>2];d=x[a>>2];x[31725]=0;c=U(152,d|0,c|0,1)|0;d=x[31725];x[31725]=0;a:{if((d|0)==1){break a}b:{if(!c){break b}x[31725]=0;W(518,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;c=R(199,a|0)|0;d=x[31725];x[31725]=0;c:{if((d|0)!=1){while(1){if(!(c&255)){break b}x[31725]=0;d=P(519,a|0,e+15|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break c}f=y[e+15|0];if(d&f>>>0<64){yc(iZ(x[b>>2],f),e+15|0,33)}c=c-1|0;continue}}break a}break a}ub(a);fb=e+48|0;return}b=N()|0;ub(a);Q(b|0);p()}function O6(a){a=a|0;if(y[500512]){return x[125127]}if(!y[501616]){v[501616]=1}wd(501328,120492);wd(501340,120524);wd(501352,120560);wd(501364,120584);wd(501376,120608);wd(501388,120624);wd(501400,120644);wd(501412,120664);wd(501424,120692);wd(501436,120732);wd(501448,120764);wd(501460,120800);wd(501472,120836);wd(501484,120852);wd(501496,120868);wd(501508,120884);wd(501520,120608);wd(501532,120900);wd(501544,120916);wd(501556,120932);wd(501568,120948);wd(501580,120964);wd(501592,120980);wd(501604,120996);v[500512]=1;x[125127]=501328;return 501328}function n9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=y[a+52|0];a:{if(po(b)){if(d){break a}b=x[a+48>>2];e=a,f=po(b)^1,v[e+52|0]=f;break a}b:{if(!d){break b}x[c+16>>2]=x[a+48>>2];c:{d:{e:{d=c+20|0;switch(tr(x[a+36>>2],x[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((At(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}fb=c+32|0;return b|0}function hpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31725]=0;O(712,a|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}f=fb-16|0;fb=f;c=f+4|0;x[c>>2]=a;e=x[a+4>>2];x[c+4>>2]=e;x[c+8>>2]=e+D(b,9);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){hc(c);fb=f+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;b=b+9|0;x[c+4>>2]=b;continue}break}}b=d+8|0;Qd(b);LW(b);fb=d+16|0;return a|0}a=N()|0;LW(d+8|0);Q(a|0);p()}function TX(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1196314451){break a}c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(y[c|0]|y[c+1|0]<<8){break a}b=a+1096|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))-5>>>0<4294967292){break a}if(!Bv(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|y[a+32|0]>15|y[a+33|0]>64){break a}b=Bv(a);a=a+34|0;if(b){continue}break}}return d}function wD(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=y[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!y[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=y[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=D(c>>>3|0,b);b=((d|0)==10)<<4}c=b+D(qr(y[a+1|0]),c)|0}return c}function tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-48|0;fb=d;c=d+28|0;ck(c,b,1819307379);hd(a+40|0,c);ub(c);ck(c,b,1953721961);hd(a+60|0,c);ub(c);ck(c,b,543520099);hd(a+120|0,c);ub(c);ck(c,b,1414744396);x[31725]=0;c=P(414,c|0,13830)|0;e=x[31725];x[31725]=0;a:{if((e|0)!=1){b:{if(c){x[31725]=0;S(811,d+8|0,d+28|0,2);c=x[31725];x[31725]=0;if((c|0)==1){break b}c=d+8|0;zv(a+140|0,c);ie(c)}x[31725]=0;S(812,d+8|0,b|0,1634890872);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}}a=N()|0;ub(d+28|0);Q(a|0);p()}b=a+80|0;a=d+8|0;hd(b,a);ub(a);ub(d+28|0);fb=d+48|0}function Fs(a,b,c,d){var e=0,f=0;e=fb-80|0;fb=e;f=x[c>>2];pH(e+52|0,c,72);x[31725]=0;S(d|0,e+4|0,b|0,(f&2?16:10)|0);b=x[31725];x[31725]=0;a:{b:{c:{d:{if((b|0)!=1){b=e+16|0;SV(b,e+4|0,x[e+52>>2]);x[31725]=0;V(301,e+28|0,b|0,x[e+52>>2],x[e+56>>2]);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;S(302,e+40|0,e+28|0,e+52|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=a;a=e+40|0;Sh(b,a);tb(a);tb(e+28|0);tb(e+16|0);tb(e+4|0);Hh(e+52|0);fb=e+80|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;tb(e+28|0)}tb(e+16|0);tb(e+4|0)}Hh(e+52|0);Q(c|0);p()}function zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;h=Hf(a,c);$d(e,x[a+36>>2]);a:{b:{if(!h){Pc(e,a+32|0,5);c=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}c=x[h+16>>2]}f=x[a+36>>2];c:{if(!((c|0)!=4&(c|0)!=-1)){d=fb-16|0;fb=d;x[d+12>>2]=0;Dq(f,d+12|0);B[b>>2]=B[d+12>>2];break c}d=fb-16|0;fb=d;x[d+12>>2]=c;x[d+8>>2]=4;c=x[Gb(d+12|0,d+8|0)>>2];g=fb-16|0;fb=g;tz(g+8|0,f);f=x[g+12>>2];if(iq(-1,2147483647,c,0)^1){i=iq(c,0,0,-2147483648)^1}else{i=0}if(i){Ii(f,c,0,1)}fb=g+16|0;x[b>>2]=0}fb=d+16|0;d=h}gf(a,d);fb=e+16|0}function xw(a,b){var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Kb(c);ww(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=ri(Cb(x[c+4>>2],y[c+11|0]));x[31725]=0;O(45,c|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Kb(c);x[31725]=0;O(46,c|0,b-d|0);b=x[31725];x[31725]=0;d:{if((b|0)!=1){x[31725]=0;O(47,g|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Sh(a,g);tb(g);fb=f+16|0}function vga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)==1){break c}x[31725]=0;W(1003,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(c+8|0,b);x[31725]=0;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;e=+oa(1013,d|0,c|0,1);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,5963,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}fb=c+16|0;return+e}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Xna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;j=x[a+16>>2];h=mg(1,2);e=hb;k=e;Pb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];e=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=w[(x[b+12>>2]<<1)+j>>1];g=g+m|0;x[c>>2]=x[c>>2]+D(i,g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(f>>12,i);Pb(b+8|0,e,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Hg(a,h,k);fb=b+16|0}function wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;a:{b:{c:{if((c|0)==1){break c}x[31725]=0;W(1003,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break c}c=x[a+24>>2];b=qc(d+8|0,b);x[31725]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=U(1009,c|0,d|0,1)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,10036,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}fb=d+16|0;return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function jma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;h=z[c>>1];i=c;e=fb-16|0;fb=e;f=b;d=ce(b);a:{if(d){c=ec(f);while(1){b=d;d=z[b+14>>1];if(dl(h,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!dl(d,h)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=ec(f);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=fb-16|0;fb=b;d=ec(f);d=Dh(e,Ec(16),Mg(b+8|0,d));gj(x[d>>2]+14|0,z[i>>1]);k=ec(d),l=1,v[k+4|0]=l;fb=b+16|0;$g(f,x[e+12>>2],c,x[e>>2]);b=le(e);em(e);j=1}c=g+8|0;_g(c,x[vb(e,b)>>2],j);fb=e+16|0;sV(a,c);fb=g+16|0}function cq(a,b,c,d){var e=0,f=0;e=fb-80|0;fb=e;f=x[c>>2];pH(e+52|0,c,3);x[31725]=0;S(d|0,e+4|0,b|0,(f&2?16:10)|0);b=x[31725];x[31725]=0;a:{b:{c:{d:{if((b|0)!=1){b=e+16|0;SV(b,e+4|0,x[e+52>>2]);x[31725]=0;V(19,e+28|0,b|0,x[e+52>>2],x[e+56>>2]);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;S(20,e+40|0,e+28|0,e+52|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}b=a;a=e+40|0;Sh(b,a);tb(a);tb(e+28|0);tb(e+16|0);tb(e+4|0);Hh(e+52|0);fb=e+80|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;tb(e+28|0)}tb(e+16|0);tb(e+4|0)}Hh(e+52|0);Q(c|0);p()}function mF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;x[f+8>>2]=e;x[f+12>>2]=d;tf(a);Cs(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;x[f+4>>2]=i;g=x[Gb(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=Bs(Gt(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){x[f+4>>2]=i-g;e=h+1|0;d=x[Gb(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=v[cc(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=cc(j,e),n=32,v[m|0]=n}e=e+1|0;continue}}break}fb=f+16|0}function Yna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;j=x[a+16>>2];h=mg(1,2);e=hb;k=e;Pb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];e=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=v[x[b+12>>2]+j|0]<<8;g=g+m|0;x[c>>2]=x[c>>2]+D(i,g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(f>>12,i);Pb(b+8|0,e,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Hg(a,h,k);fb=b+16|0}function Mt(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;h=fb-240|0;fb=h;x[h+236>>2]=d;x[h+232>>2]=c;x[h>>2]=a;a:{b:{c:{d:{if((c|0)!=1){j=a;k=1;break d}j=a;k=1;if(d){break d}i=a;break c}while(1){i=j-x[(e<<2)+g>>2]|0;if((so(i,a,b)|0)<=0){i=j;break c}e:{if(!((e|0)<2|f)){f=x[((e<<2)+g|0)-8>>2];l=j-4|0;if((so(l,i,b)|0)>=0){break e}if((so(l-f|0,i,b)|0)>=0){break e}}x[(k<<2)+h>>2]=i;c=ML(c,d);Nt(h+232|0,c);k=k+1|0;e=c+e|0;f=0;j=i;d=x[h+236>>2];c=x[h+232>>2];if(d|(c|0)!=1){continue}break b}break}i=j;break b}if(f){break a}}LL(h,k);$y(i,b,e,g)}fb=h+240|0}function Rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-208|0;fb=e;w[a+480212>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;zS(a+946304|0);f=a+906300|0;g=Ij(f);d=e+48|0;Tb(d,0,160);d=BS(d);x[31725]=0;S(864,f|0,g|0,d|0);f=x[31725];x[31725]=0;a:{if((f|0)!=1){UA(d);d=Ge(e+28|0,b);x[31725]=0;f=x[d+12>>2];x[e+16>>2]=x[d+8>>2];x[e+20>>2]=f;x[e+24>>2]=x[d+16>>2];f=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=f;a=U(865,a|0,e+8|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){a=N()|0;break a}ub(b);fb=e+208|0;return a|0}a=N()|0;UA(d)}ub(b);Q(a|0);p()}function gz(a,b,c){var d=0,e=0,f=E(0),g=E(0),h=E(0),i=E(0),j=0,k=E(0),l=E(0),m=E(0);e=fb-32|0;fb=e;g=B[a+24>>2];f=B[a+12>>2];h=B[a+48>>2];i=B[a+36>>2];cM(E(-B[a>>2]),E(g+f),E(h+i),e+20|0);cM(B[a+60>>2],E(h-i),E(g-f),e+8|0);B[e+12>>2]=-B[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=B[j>>2];f=B[d+(e+20|0)>>2];h=B[d+87680>>2];i=B[d+87692>>2];k=B[d+(e+8|0)>>2];B[j>>2]=E(f*h)-E(i*k);j=b+d|0;l=B[(0-a<<2)+87688>>2];d=5-a<<2;m=B[d+87680>>2];f=E(E(f*i)+E(k*h));B[j>>2]=E(g*l)-E(m*f);B[b+d>>2]=E(g*m)+E(f*l);a=a+1|0;continue}break}fb=e+32|0}function kx(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;f=x[b>>2];g=ib[x[x[f>>2]+36>>2]](f,c,d)|0;a:{if(!g){bi(a);break a}xm(e+32|0,x[b>>2],x[b+4>>2]);b=x[e+36>>2];x[e+16>>2]=x[e+32>>2];x[e+20>>2]=b;b=fb-16|0;fb=b;d=e+16|0;f=xm(b+8|0,x[d>>2],x[d+4>>2]);x[31725]=0;h=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=h;V(168,e+40|0,b|0,c|0,g|0);c=x[31725];x[31725]=0;b:{if((c|0)!=1){ke(d);fb=b+16|0;break b}a=N()|0;ke(d);Q(a|0);p()}b=Nd(e+24|0);c=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=c;c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;Sp(a,e+8|0,e)}fb=e+48|0}function dC(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=x[a>>2];a:{if(!lc(c,x[a+4>>2])){w[c>>1]=0;Qf(c+2|0,b);f=d,g=Mk(wb(x[a>>2]),1),x[f+12>>2]=g;while(1){e=wb(x[a+4>>2]);c=x[d+12>>2];if(Ib(c,e)){f=c,g=z[qe(c,Mk(c,-1))>>1],w[f>>1]=g;Qf(c+2|0,b);BW(d+12|0);continue}else{Qf(a+14|0,Sd(x[a>>2],x[a+4>>2])-1&255);Qf(a+13|0,y[a+14|0]);Qf(a+16|0,Sd(x[a>>2],x[a+4>>2])-1&255);Qf(a+15|0,y[a+16|0]);if(y[a+17|0]==255){break a}Qf(a+17|0,Sd(x[a>>2],x[a+4>>2])-1&255);break a}}}v[a+17|0]=255;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0}fb=d+16|0}function qF(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if((y[a|0]|y[a+1|0]<<8)!=26217){if((y[a|0]|y[a+1|0]<<8)!=20042){break a}if(y[a+110|0]<=64){break b}break a}if(y[a+110|0]>64){break a}}if(v[a+112|0]<0|y[a+111|0]>128){break a}c=a+110|0;b=a+2|0;while(1){if((b|0)==(c|0)){while(1){b=(e|0)==128;if(b){break a}c=a+e|0;d=v[c+113|0];if((d|0)<-2){break a}f=y[c+241|0];if(!f&(d|0)>=0|f>>>0>15){break a}e=e+1|0;if(y[c+369|0]<64){continue}break a}}c:{if((y[b|0]-1&255)>>>0>30){break c}d=d+1|0;if((d&255)>>>0<=40){break c}return 0}b=b+1|0;continue}}return b}function Go(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}Jb(e+8|0,a+1074312|0,3);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break c}if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break a}c=D(d&15,c>>31|(c|0)!=0);c=d>>>0>239?c<<2:c;break b}if(v[(D(b,872)+a|0)+1075843|0]&1){Jb(e+8|0,a+1074312|0,3);if(!Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=D(b,872)+a|0;d=x[f+1075648>>2];a=Kq(a,x[f+1075080>>2],d);if(!a){break a}ib[x[x[a>>2]+84>>2]](a,c,(d?y[d+33|0]:13)<<24>>24,b)}fb=e+16|0}function vna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[f>>1],w[e+38146>>1])+D(w[f-2>>1],w[e+38144>>1])|0)+D(w[f+2>>1],w[e+38148>>1])|0)+D(w[f+4>>1],w[e+38150>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function usa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=x[a>>2];d=Pk(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;d=b-d|0;b=x[zb(a)>>2];f=x[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){tD(a,d,c);break a}b=zb(a);b=AZ(e+12|0,oD(a,Pk(x[a>>2],f)+d|0),Pk(x[a>>2],x[a+4>>2]),b);zZ(b,d,c);c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);f=vb(c+8|0,x[a>>2]);g=vb(c+4|0,x[b+4>>2]);h=b,i=wZ(x[d>>2],x[f>>2],x[g>>2]),x[h+4>>2]=i;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0;yZ(b)}fb=e+32|0;return}if(b>>>0<d>>>0){sD(a,e+D(b,6)|0)}}function jka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=fb-32|0;fb=f;a=Nb(a);b:{c:{d:{e:{while(1){e=x[b+8>>2];g=x[b>>2];x[31725]=0;e=U(152,g|0,e|0,8)|0;g=x[31725];x[31725]=0;if((g|0)==1){break c}if(e){x[31725]=0;S(913,f+4|0,b|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break e}x[31725]=0;O(914,a|0,f+4|0);e=x[31725];x[31725]=0;if((e|0)==1){break d}e=f+4|0;Gd(e);g=e;e=Nr(x[a+4>>2]);xi(g,x[e>>2],x[e+4>>2]);if(x[f+4>>2]!=(d|0)){continue}}break}fb=f+32|0;break a}b=N()|0;break b}b=N()|0;Gd(f+4|0);break b}b=N()|0}ie(a);Q(b|0);p()}}function pS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=16777216;h=e+12|0;d=x[a>>2];c=oc(d,x[a+4>>2]);a:{if(c>>>0<b>>>0){f=fb-32|0;fb=f;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){XE(a,b,h);break b}c=zb(a);c=$f(f+12|0,Mf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);g=fb-16|0;fb=g;b=Nn(g+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Eo(d,x[h>>2]);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}he(b);fb=g+16|0;_m(a,c);_f(c)}fb=f+32|0;break a}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}QA(a);fb=e+16|0}function o1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;ld(b,0);f=e+8|0;nk(f,1,a+33|0);d=e+20|0;Cc(d,f);ze(b+43|0,d);tb(d);g=y[a+50|0]|y[a+51|0]<<8|(y[a+52|0]<<16|y[a+53|0]<<24);x[b>>2]=g;x[b+24>>2]=y[a+54|0]|y[a+55|0]<<8;v[e+20|0]=y[a+56|0];v[e+8|0]=64;h=b,i=y[Rb(d,f)|0]<<2,w[h+30>>1]=i;d=y[a+57|0]|y[a+58|0]<<8|(y[a+59|0]<<16|y[a+60|0]<<24);x[b+4>>2]=d;f=y[a+61|0]|y[a+62|0]<<8|(y[a+63|0]<<16|y[a+64|0]<<24);c=c?d?g:f:f;x[b+8>>2]=c;if(!(!y[a|0]|c>>>0<=d+2>>>0|c>>>0>g>>>0)){w[b+34>>1]=z[b+34>>1]|2}fb=e+32|0}function Ej(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;x[a+4>>2]=0;d=4;a:{b:{c:{if(!Ed(y[Mm(e+15|0,a,1)|0])){break c}d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31725]=0;b=U(87,d|0,b|0,c|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}Y(T(0)|0)|0;d=1;Km(x[x[a>>2]-12>>2]+a|0,1);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31725]=0;X(86);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}fk(x[x[a>>2]-12>>2]+a|0,d);fb=e+16|0;return a}T(0)|0;Sb()}p()}function wZ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=e+8|0;d=fb-32|0;fb=d;Id(d+24|0,a,b);h=d+16|0;b=x[d+24>>2];i=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(pd(b,i)){b=vZ(b);c=vZ(x[a+8>>2]);f=y[b+4|0]|y[b+5|0]<<8;v[c+4|0]=f;v[c+5|0]=f>>>8;b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;b=nD(a+12|0);nD(a+8|0);b=x[b>>2];continue}break}Ac(h,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(g,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function dqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;e=Tf(d+52|0);x[31725]=0;c=P(651,b|0,e|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(652,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}}break c}c=x[e+4>>2];x[31725]=0;S(187,d+12|0,b|0,(c>>>0>=9?c-8|0:0)|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}a=N()|0;Gd(e);Q(a|0);p()}b=d+12|0;c=ic(d+32|0,b);hd(e+8|0,c);ub(c);ub(b);Vk(a,e)}Gd(e);fb=d+80|0}function LQ(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=0;Zz(a);c=Pd(c,E(0));a:{switch(b|0){case 0:B[a+4220>>2]=c;return;case 1:B[a+4224>>2]=c;return;case 2:B[a+4228>>2]=c;qu(a);return;case 3:v[a+4240|0]=c>=E(.5);qu(a);return;case 4:b=fb-16|0;fb=b;e=b,f=Sl(E(c*E(32))),x[e+12>>2]=f;x[b+8>>2]=0;x[b+4>>2]=5;d=x[hk(b+12|0,b+8|0,b+4|0)>>2];fb=b+16|0;x[a+4232>>2]=d;return;case 5:v[a+4241|0]=c>=E(.5);return;case 6:v[a+4242|0]=c>=E(.5);return;case 7:v[a+4244|0]=c>=E(.5);return;case 8:if(c==E(0)){Xz(a)}C[a+4256>>3]=c;break;default:break a}}}function tia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=ej(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Wh(c);if((c|0)!=10){break b}}c=fb-16|0;fb=c;e:{if((d|0)!=2147483631){f=Kb(a);g=c+4|0;if(d>>>0<=1073741798){x[c+12>>2]=d<<1;x[c+4>>2]=d+1;e=Eh(x[ad(c+4|0,c+12|0)>>2])+1|0}else{e=2147483631}sg(g,e);e=x[c+4>>2];if(d){Cg(e,f,d)}if((d|0)!=10){Db(f)}yd(a,e);pf(a,x[c+8>>2]);fb=c+16|0;break e}qf();p()}c=d}d=x[a>>2];Yd(a,c+1|0);break a}Me(a,c+1|0);d=a}a=c+d|0;fd(a,b);fd(a+1|0,0)}function zla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(x[a+4>>2]!=x[zb(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+7;WT(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+7;hc(c);fb=d+16|0;return}f=fb-32|0;fb=f;g=zb(a);h=f+12|0;e=FB(x[a>>2],x[a+4>>2])+1|0;c=fb-16|0;fb=c;x[c+12>>2]=e;a:{d=Lh(613566756);if(e>>>0<=d>>>0){e=GB(a);if(e>>>0<d>>>1>>>0){x[c+8>>2]=e<<1;d=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;break a}dd();p()}c=ZT(h,d,FB(x[a>>2],x[a+4>>2]),g);WT(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+7;YT(a,c);XT(c);fb=f+32|0}function qta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=fb-32|0;fb=d;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];e=x[b>>2];x[31725]=0;c=U(152,e|0,c|0,8)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}if(c){x[31725]=0;O(409,d+4|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}x[31725]=0;O(410,a|0,d+4|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}c=d+4|0;Gd(c);e=c;c=Nr(x[a+4>>2]);xi(e,x[c>>2],x[c+4>>2]);if(($b(x[d+4>>2])|0)!=1162757187){continue}}break}fb=d+32|0;break a}b=N()|0;break b}b=N()|0;Gd(d+4|0);break b}b=N()|0}ie(a);Q(b|0);p()}}function N1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=16384;d=x[Gb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=17;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=il(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}ds(c+4|0,il(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}ds(c+4|0,d-e|0);break b}QF(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}QF(a,e,0,b)}d=x[a+1072>>2];continue}break}fb=c+16|0}function wna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[f|0],w[e+38146>>1])+D(v[f-1|0],w[e+38144>>1])|0)+D(v[f+1|0],w[e+38148>>1])|0)+D(v[f+2|0],w[e+38150>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function Era(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=Tf(d+52|0);x[31725]=0;e=P(523,b|0,c|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(524,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}}break c}e=z[c+2>>1]|z[c+4>>1]<<16;x[31725]=0;S(187,d+12|0,b|0,e|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}a=N()|0;Gd(c);Q(a|0);p()}b=d+12|0;e=ic(d+32|0,b);hd(c+8|0,e);ub(e);ub(b);ZY(a,c)}Gd(c);fb=d+80|0}function WW(a){var b=0,c=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=1297236819){break a}b=y[a+28|0]|y[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=y[a+42|0];if(b>>>0>64&(b|0)!=88|(y[a+48|0]|y[a+49|0]<<8)>>>0>64|(y[a+50|0]|y[a+51|0]<<8)>>>0>96){break a}b=y[a+52|0]|y[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(y[a+30|0]|y[a+31|0]<<8)|(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24)|(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1)){break a}c=_W(a+20|0)}return c}function yR(a,b,c,d){var e=0,f=0;e=fb-48|0;fb=e;x[e+44>>2]=d;x[e+40>>2]=d;a=Se(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[a+8>>2];d=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=d;Re(e+24|0,e);while(1){if((b|0)!=(c|0)){Eo(x[e+44>>2],x[b>>2]);x[e+44>>2]=x[e+44>>2]+4;b=b+4|0;continue}break}Qe(e+24|0);d=x[e+44>>2];if(!y[e+36|0]){b=fb-16|0;fb=b;a=vb(b+12|0,x[x[e+32>>2]>>2]);f=x[vb(b+8|0,x[x[e+28>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[a>>2];x[c+12>>2]=a;while(1){if(pd(a,f)){rA(a);a=x[Ni(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}fb=e+48|0;return d}function M1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=32768;d=x[Gb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=9;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=il(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}ds(c+4|0,il(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}ds(c+4|0,d-e|0);break b}PF(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}PF(a,e,0,b)}d=x[a+1072>>2];continue}break}fb=c+16|0}function oua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ld(b,0);g=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=g;e=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+12>>2]=e;f=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+16>>2]=f;c=y[a+12|0]|y[a+13|0]<<8;w[b+32>>1]=64;x[b+24>>2]=c;c=y[a+14|0];w[b+30>>1]=c?c+1|0:256;d=z[b+34>>1]&32767|!y[a+14|0]<<15;w[b+34>>1]=d;c=y[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;w[b+34>>1]=d;c=y[a+15|0]}if(c&2){x[b+16>>2]=f>>>1;x[b+12>>2]=e>>>1;x[b>>2]=g>>>1;w[b+34>>1]=d|1}}function nj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?G(c):G(d)+32|0;bg(f,d,e,0,0,c+49|0);i=x[f>>2];h=x[f+4>>2];e=15372-c<<16;c=x[f+8>>2];d=e|x[f+12>>2]^65536}x[a>>2]=i;x[a+4>>2]=h;x[a+8>>2]=c;x[a+12>>2]=g&-2147483648|d;fb=f+16|0}function Uc(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=d+4|0;x[b+4>>2]=1211;x[b>>2]=a;x[b+8>>2]=0;c=fb-16|0;fb=c;if(x[a>>2]!=-1){a:{b=vb(c+8|0,yf(c+12|0,b));while(1){if(x[a>>2]==1){continue}break}b:{if(!x[a>>2]){yd(a,1);b=x[x[b>>2]>>2];x[31725]=0;W(1212,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break b}x[a>>2]=-1}break a}Y(T(0)|0)|0;yd(a,0);x[31725]=0;X(86);a=x[31725];x[31725]=0;c:{if((a|0)==1){a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){break c}T(0)|0;Sb()}p()}Q(a|0);p()}}fb=c+16|0;fb=d+16|0;return x[a+4>>2]-1|0}function CN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a:{b:{c:{a=x[a+32>>2];e=Aq(a);d:{if(!e){if(zq(a)>>>0<=b>>>0){break d}a=ui(a,b+1&65535);w[a+34>>1]=z[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=ac(8);x[31725]=0;b=P(36,d+4|0,6e3)|0;c=x[31725];x[31725]=0;e:{if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;jc(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];if(!a){break b}v[a+15|0]=y[a+15|0]&253|(c?2:0)}fb=d+16|0;return}p()}function fma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);b:{d=Zc(x[b>>2],x[b+4>>2]);if(!d){break b}x[31725]=0;O(642,a|0,d|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=x[b+4>>2];f=x[b>>2];x[31725]=0;aV(a,f,e,d);d=x[31725];x[31725]=0;if((d|0)!=1){break b}}a=N()|0;ak(c+8|0);Q(a|0);p()}d=c+8|0;Qd(d);ak(d);fb=c+16|0;x[31725]=0;P(3,a+12|0,b+12|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){x[a+24>>2]=x[b+24>>2];w[a+28>>1]=z[b+28>>1];break a}b=N()|0;md(a);Q(b|0);p()}}function YW(a,b,c,d,e,f){b=y[(b&15)+25392|0];v[a+3|0]=b;a:{b:{switch(b-11|0){case 0:b=y[a+5|0];c=b&15;if(c){v[a+5|0]=c;return}v[a+5|0]=b&240;return;case 3:b=y[a+5|0];b=D(b&240,10)|b&15;v[a+5|0]=b;d=b&255;b=z[e>>1];if(!(d|(b|0)==65535)){v[a+5|0]=b;v[a+3|0]=12;w[e>>1]=65535}wc(f,c);return;case 1:w[e>>1]=y[a+5|0];x[f>>2]=63;v[a+3|0]=0;return;case 5:b=y[a+5|0];if(d>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|D(c,-10)+b;v[a+5|0]=b}if(b&255){break a}v[a+3|0]=0;return;case 7:break a;default:break b}}if(y[a+5|0]){break a}v[a+3|0]=0}}function Rpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=fb-32|0;fb=d;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];e=x[b>>2];x[31725]=0;c=U(152,e|0,c|0,8)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}if(c){x[31725]=0;O(682,d+4|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break e}x[31725]=0;O(683,a|0,d+4|0);c=x[31725];x[31725]=0;if((c|0)==1){break d}c=d+4|0;Gd(c);e=c;c=Nr(x[a+4>>2]);xi(e,x[c>>2],x[c+4>>2]);if(x[d+4>>2]!=1413891155){continue}}break}fb=d+32|0;break a}b=N()|0;break b}b=N()|0;Gd(d+4|0);break b}b=N()|0}ie(a);Q(b|0);p()}}function Gqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-608|0;fb=f;b=fb-16|0;fb=b;d=f+8|0;gY(b+8|0,d);c=x[b+12>>2];od(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(c|0)){gd(a,x[b+12>>2])}fb=b+16|0;c=(c|0)==(e|0);if(!c){fY(d)}b=-1;a:{if(!c){break a}b=0;if(!hY(f+8|0)){break a}b=-1;if(!mh(a,1024)){break a}b=0;d=fb-1024|0;fb=d;c=fb-16|0;fb=c;PC(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((e|0)==(g|0)){gd(a,x[c+12>>2])}fb=c+16|0;if((e|0)==(g|0)){b=QC(d,0)>>>0<17}fb=d+1024|0}fb=f+608|0;return b|0}function qP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;e=Nb(a);a=0;a:{b:{c:{d:{e:{while(1){d=x[b+24>>2];if(z[d+480188>>1]<=a>>>0){break a}x[31725]=0;O(1058,c+8|0,(d+(a<<5)|0)+480289|0);d=x[31725];x[31725]=0;if((d|0)!=1){d=x[b+24>>2];x[31725]=0;S(1059,c+20|0,d|0,c+8|0);d=x[31725];x[31725]=0;if((d|0)==1){break e}x[31725]=0;O(180,e|0,c+20|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}a=a+1|0;tb(c+20|0);tb(c+8|0);continue}break}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(c+20|0)}tb(c+8|0)}Td(e);Q(a|0);p()}fb=c+32|0}function bB(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;g=Ou(a,a+1074376|0,b,c);a:{if(!g){break a}h=a+1074312|0;Jb(d+8|0,h,117);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}e=D(b,872)+a|0;i=e+1075648|0;c=x[i>>2];if(!c|!y[c+33|0]){break a}f=a;a=e+1074992|0;e=Kq(f,x[a+88>>2],c);if(!e){break a}Jb(d+8|0,h,34);f=!Hb(x[x[d+8>>2]>>2],x[d+12>>2]);c=bh(y[a+797|0]-w[a+770>>1]|0);b:{if(f|c-1<<24>>24<0){break b}a=x[a+656>>2];if(!a){break b}c=y[xb(a+108|0,c-1|0)|0]}ib[x[x[e>>2]+88>>2]](e,g,c&255,v[x[i>>2]+33|0],b)}fb=d+16|0}function Pga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;v[a+4202|0]=1;c=Jk(E(E(A[x[a+16>>2]+24620>>2])*E(.04500000178813934)));d=Jk(E(E(c>>>0)*E(1.1892070770263672)));e=Jk(E(E(d>>>0)*E(1.1892070770263672)));h=Jk(E(E(e>>>0)*E(1.1892070770263672)));f=Jk(E(E(c+e>>>0)*E(.11546666920185089)));g=Jk(E(E(d+h>>>0)*E(.11546666920185089)));b=a+4272|0;i=yb(b,0),j=c-f|0,x[i>>2]=j;i=yb(b,1),j=e-f|0,x[i>>2]=j;i=yb(b,2),j=d-g|0,x[i>>2]=j;i=yb(b,3),j=h-g|0,x[i>>2]=j;i=yb(b,4),j=f,x[i>>2]=j;i=yb(b,5),j=g,x[i>>2]=j;_P(a);ZP(a)}function RS(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{if(b){v[c|0]=b;break a}b=y[c|0]}e=x[a+480180>>2];c=e&1048580?(b&240?-16:15)&b:b;b=c&15;c=c&255;b:{c:{d:{if(!((b|0)!=15|c>>>0<16)){if(!(y[a+480209|0]&16)){break b}b=c>>>3&30;break d}f=x[a+480208>>2]&4096;g=c&240;if(!(!b|(g|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(g){if(e&59314208?b:0){break b}b=c>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}a=a+1074456|0;x[d+12>>2]=x[a>>2]+(b<<!(e&59314208));Fe(d+12|0,0,256);x[a>>2]=x[d+12>>2]}fb=d+16|0}function EB(a,b){var c=0;if(b>>>0<=999999){if(b>>>0<=9999){if(b>>>0<=99){if(b>>>0<=9){return Qq(a,b)}return Tl(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Tl(Qq(c,a),D(a,-100)+b|0)}return zB(a,b)}if(b>>>0<=99999){c=a;a=(b>>>0)/1e4|0;return zB(Qq(c,a),D(a,-1e4)+b|0)}return xB(a,b)}if(b>>>0<=99999999){if(b>>>0<=9999999){c=a;a=(b>>>0)/1e6|0;return xB(Qq(c,a),D(a,-1e6)+b|0)}return Ru(a,b)}if(b>>>0<=999999999){c=a;a=(b>>>0)/1e8|0;return Ru(Qq(c,a),D(a,-1e8)+b|0)}c=a;a=(b>>>0)/1e8|0;return Ru(Tl(c,a),D(a,-1e8)+b|0)}function iua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;ld(b,0);e=c+8|0;nk(e,1,a);d=c+20|0;Cc(d,e);ze(b+43|0,d);tb(d);x[b+24>>2]=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);w[b+34>>1]=z[b+34>>1]&65533|(y[a+13|0]|y[a+14|0]<<8)<<1&2;x[b>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b+4>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[b+8>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);v[c+20|0]=y[a+15|0];v[c+8|0]=64;f=b,g=y[Rb(d,e)|0]<<2,w[f+30>>1]=g;fb=c+32|0}function Hpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=Tf(c+52|0);x[31725]=0;e=P(689,b|0,d|0)|0;f=x[31725];x[31725]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(690,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[31725]=0;S(187,c+12|0,b|0,e|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}a=N()|0;Gd(d);Q(a|0);p()}b=c+12|0;e=ic(c+32|0,b);hd(d+8|0,e);ub(e);ub(b);Vk(a,d)}Gd(d);fb=c+80|0}function paa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;d=rf(e+20|0,1,0);a:{b:{while(1){f=Kb(d);ON(e+12|0,f,Cb(x[d+4>>2],y[d+11|0])+f|0,y[b|0],c);if(!x[e+16>>2]){break b}f=ri(Cb(x[d+4>>2],y[d+11|0]));x[31725]=0;O(45,d|0,f|0);f=x[31725];x[31725]=0;if((f|0)!=1){continue}break}break a}b=x[e+12>>2];c=Kb(d);x[31725]=0;O(46,d|0,b-c|0);b=x[31725];x[31725]=0;c:{if((b|0)!=1){x[31725]=0;O(305,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}break a}tb(d);fb=e+32|0;return}a=N()|0;tb(d);Q(a|0);p()}function Qsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;d=rf(e+20|0,1,0);a:{b:{while(1){f=Kb(d);fC(e+12|0,f,Cb(x[d+4>>2],y[d+11|0])+f|0,z[b>>1],c);if(!x[e+16>>2]){break b}f=ri(Cb(x[d+4>>2],y[d+11|0]));x[31725]=0;O(45,d|0,f|0);f=x[31725];x[31725]=0;if((f|0)!=1){continue}break}break a}b=x[e+12>>2];c=Kb(d);x[31725]=0;O(46,d|0,b-c|0);b=x[31725];x[31725]=0;c:{if((b|0)!=1){x[31725]=0;O(47,a|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}break a}tb(d);fb=e+32|0;return}a=N()|0;tb(d);Q(a|0);p()}function x1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;c=-1;a:{if(!eF(a,b+12|0)){break a}b:{if(dF(b+12|0)){if(gd(a,32)){break b}break a}c=0;if(!cF(b+12|0)){break a}}e=b+7|0;d=bF(y[b+15|0]);c=fb-32|0;fb=c;x[c+28>>2]=d;x[c+8>>2]=5;d=x[Gb(c+28|0,c+8|0)>>2];if(!mh(a,d)){d=(ib[x[x[a>>2]+24>>2]](a)|0)-x[a+12>>2]|0}f=c+8|0;ik(f,e);g=gc(c+16|0,x[c+8>>2],d);od(c,a,x[g>>2],x[g+4>>2]);ik(f,e);Tb(x[c+8>>2]+d|0,0,5-d|0);gd(a,x[c+28>>2]);fb=c+32|0;if(!d){c=-1;break a}c=aF(b+7|0,y[b+15|0])}fb=b+16|0;return c|0}function cP(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-16|0;fb=b;a:{c=x[a+36>>2];d=x[a+40>>2];b:{if(Ib(c,d)){sc(b+12|0);break b}Bo(b,a);x[31725]=0;c=R(1062,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[b+12>>2]=c;of(b);d=x[a+40>>2];c=x[a+36>>2]}c=(f=a+36|0,g=x[b+12>>2],h=Ib(c,d),h?f:g);a=x[a+8>>2];c:{if((a|0)==-1){f=b,g=wb(x[c>>2]),x[f>>2]=g;a=wb(x[c+4>>2]);while(1){c=x[b>>2];if(!Ib(c,a)){break c}e=e+C[c>>3];fA(b);continue}}e=C[wf(x[c>>2],a)>>3]}Gl(b+12|0);fb=b+16|0;return+e}a=N()|0;of(b);Q(a|0);p()}function A6(a){a=a|0;if(y[500504]){return x[125125]}if(!y[501312]){v[501312]=1}id(501024,5034);id(501036,5025);id(501048,10875);id(501060,10619);id(501072,5261);id(501084,11652);id(501096,5118);id(501108,5609);id(501120,8886);id(501132,8869);id(501144,8877);id(501156,8896);id(501168,10073);id(501180,13314);id(501192,8959);id(501204,7714);id(501216,5261);id(501228,9762);id(501240,10478);id(501252,10887);id(501264,9249);id(501276,6463);id(501288,5492);id(501300,13232);v[500504]=1;x[125125]=501024;return 501024}function nV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=y[a+16|0];k=c?-1:1;l=c?1:-1;e=x[a+8>>2]-1|0;m=c?e-(y[a+17|0]!=0&(e|0)!=0)|0:0;f=x[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=x[a>>2]+D(f,62)|0;d=b?1:-1;p=D(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=D(c,f);q=x[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{w[(b<<1)+h>>1]=z[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function R3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(oh(a,x[b+8>>2],e)){Ox(b,c,d);return}a:{if(oh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}w[b+52>>1]=0;a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,c,1,e);if(y[b+53|0]){x[b+44>>2]=3;if(!y[b+52|0]){break b}break a}x[b+44>>2]=4}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}a=x[a+8>>2];ib[x[x[a>>2]+24>>2]](a,b,c,d,e)}}function Qv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;x[g+12>>2]=0;x[g+8>>2]=a;h=fb-16|0;fb=h;c=gc(h+8|0,x[g+8>>2],x[g+12>>2]);f=fb-16|0;fb=f;b=121;x[f+12>>2]=121;d=x[c+4>>2];a:{if(!d){d=x[c>>2];break a}e=32-d|0;x[f+8>>2]=e;b=x[c>>2];i=x[b>>2];j=e;e=x[Gb(f+8|0,f+12|0)>>2];x[b>>2]=(-1<<d&-1>>>j-e^-1)&i;i=x[f+12>>2];d=b+4|0;x[c>>2]=d;b=i-e|0}e=d;d=b>>>5|0;IF(e,d);b=b&31;x[f+12>>2]=b;if(b){e=c;c=x[c>>2]+(d<<2)|0;x[e>>2]=c;x[c>>2]=x[c>>2]&(-1>>>32-b^-1)}fb=f+16|0;fb=h+16|0;fb=g+16|0;return a}function uH(a,b,c,d){var e=0,f=0,g=0;e=fb-80|0;fb=e;f=Tf(e+52|0);x[31725]=0;d=P(d|0,b|0,f|0)|0;g=x[31725];x[31725]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31725]=0;R(c|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}}break c}c=x[f+4>>2];x[31725]=0;S(187,e+12|0,b|0,$b(c)|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}a=N()|0;Gd(f);Q(a|0);p()}b=e+12|0;c=ic(e+32|0,b);hd(f+8|0,c);ub(c);ub(b);Vk(a,f)}Gd(f);fb=e+80|0}function rqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,26);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function zK(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{g=x[31600];x[31600]=0;Od();a=yK(a,e+12|0,d);d=hb;d:{f=x[31600];if(f){if(x[e+12>>2]!=(b|0)){break c}if((f|0)!=68){break d}x[c>>2]=4;b=2147483647;if(!!a&(d|0)>=0|(d|0)>0){break a}break b}x[31600]=g;if(x[e+12>>2]==(b|0)){break d}break c}if((d|0)<0&a>>>0<=2147483647|(d|0)<-1){x[c>>2]=4;break b}if((d|0)>=0&a>>>0>=2147483648|(d|0)>0){x[c>>2]=4;b=2147483647;break a}b=a;break a}}x[c>>2]=4;b=0;break a}b=-2147483648}fb=e+16|0;return b}function fn(a,b,c,d){var e=0;a:{e=a+1074312|0;if(Ob(e,84)){break a}b:{if(y[a+480209|0]&64){break b}if((d|0)!=8){if(!Ob(e,10)){break b}}x[b+88>>2]=x[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0>=64?64:c)<<2;break d;default:break e}}if(!(x[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}x[b+88>>2]=x[b+88>>2]|256;c=128}x[b+692>>2]=c}w[b+784>>1]=0;x[b+88>>2]=x[b+88>>2]|2097152;if(!Ob(e,10)){break a}v[b+831|0]=0;w[b+778>>1]=0}}function Yra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=xx(c+4|0,a);d=x[a+4>>2];x[31725]=0;O(503,d|0,b|0);b=x[31725];x[31725]=0;a:{if((b|0)!=1){x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;break a}b=N()|0;hc(a);Q(b|0);p()}return}d=fb-32|0;fb=d;c=zb(a);c=Em(d+12|0,Yp(a,Ud(x[a>>2],x[a+4>>2])+1|0),Ud(x[a>>2],x[a+4>>2]),c);e=x[c+8>>2];x[31725]=0;O(503,e|0,b|0);b=x[31725];x[31725]=0;b:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+12;vx(a,c);zs(c);fb=d+32|0;break b}a=N()|0;zs(c);Q(a|0);p()}}function Wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=E(0);x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;a:{if((d|0)==1){break a}x[31725]=0;W(1074,c|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}d=x[a+24>>2];e=B[d+48>>2];d=x[d+24>>2];x[31725]=0;b=Ya(1075,d|0,E(e),b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[c>>2]=b;return 1}Y(T(0)|0)|0;x[31725]=0;V(989,10353,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function P4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&512;f=b&256;g=b&128;h=b&64;i=b&32;j=b&16;k=b&8;l=b&4;m=b&2;b=b&1;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];b:{c:{if(b){if(vt(a)){break c}}if(m){if(ut(a)){break c}}if(l){if(tt(a)){break c}}if(k){if(st(a)){break c}}if(j){if(rt(a)){break c}}if(i){if(qt(a)){break c}}if(h){if(Oh(a)){break c}}if(g){if(pt(a)){break c}}if(f){if(ot(a)){break c}}if(!e){break b}if(!nt(a)){break b}}c=c+4|0;continue}break}d=c}return d|0}function hI(a,b,c,d,e){var f=0,g=0,h=0;g=fb-16|0;fb=g;h=Fb(a);a=0;a:{b:{c:{d:{while(1){f=x[b>>2];if(Ud(f,x[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){f=Hd(f,0);break e}x[31725]=0;P(d|0,h|0,c|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break b}f=Hd(x[b>>2],a)}x[31725]=0;O(e|0,g+4|0,f|0);f=x[31725];x[31725]=0;if((f|0)!=1){x[31725]=0;P(d|0,h|0,g+4|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break d}a=a+1|0;tb(g+4|0);continue}break}a=N()|0;break a}a=N()|0;tb(g+4|0);break a}fb=g+16|0;return}a=N()|0}tb(h);Q(a|0);p()}function IT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=-1;a:{if(!(y[b+851|0]&2)){break a}d=x[a+480208>>2]&8192;b:{c:{f=x[b+656>>2];if(f){c=y[f+22|0];if(Cd(c)){g=b,h=Wh(c),v[g+838|0]=h;c=1}else{c=!d}d=y[f+21|0];if(Cd(d)){g=b,h=Wh(d),v[g+837|0]=h;break c}if(c){break c}break b}c=!d;x[b+776>>2]=0;x[b+780>>2]=0;break b}c=1;d=y[f+25|0];if((d|0)==255){break b}v[b+845|0]=d}d:{if(y[b+837|0]>=127){if(Ob(a+1074312|0,36)&c){break d}break a}if(!c){break a}}e=Pq(a,b,1,256);if((e|0)<0){break a}e=y[b+837|0]>>>1|0}return e}function Lpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=fb-32|0;fb=e;ld(b,0);d=e+8|0;ND(d,a+1|0);c=e+20|0;Cc(c,d);ze(b+43|0,c);tb(c);x[b+24>>2]=y[a+73|0]|y[a+74|0]<<8|(y[a+75|0]<<16|y[a+76|0]<<24);c=y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);d=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);if(d){x[b+8>>2]=d+1}w[b+30>>1]=(y[a+68|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;wc(b+8|0,c);wc(b+4|0,x[b+8>>2]);fb=e+32|0}function gn(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function _k(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(y[a+35|0]&2)){break a}Ep(a)}d=z[a+34>>1]&-513|d;w[a+34>>1]=d;if(b){x[a>>2]=4;w[a+34>>1]=d&65470;Fh(a);b=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+76|0]=b;v[a+77|0]=b>>>8;v[a+78|0]=b>>>16;v[a+79|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+68|0]=c;v[a+69|0]=c>>>8;v[a+70|0]=c>>>16;v[a+71|0]=c>>>24;v[a+72|0]=b;v[a+73|0]=b>>>8;v[a+74|0]=b>>>16;v[a+75|0]=b>>>24}}function Qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;x[a>>2]=x[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){e=fb-16|0;fb=e;g=x[c+4>>2];h=x[c+8>>2];f=Yj(g,h);a:{if(f>>>0<=ep(d)>>>0){j=h;k=x[d>>2];i=Sc(k,x[d+4>>2]);l=i>>>0>=f>>>0;if(!l){x[e+12>>2]=g;c$(e+12|0,i);j=x[e+12>>2]}i=Wg(g,j,k);if(!l){wv(d,j,h,f-Sc(x[d>>2],x[d+4>>2])|0);break a}pr(d,i);break a}_v(d);bl(d,cm(d,f));wv(d,g,h,f)}fb=e+16|0}yc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function Gga(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{b:{if(!a){a=Bg(22255);break b}x[31725]=0;c=P(36,b+8|0,a|0)|0;a=x[31725];x[31725]=0;c:{d:{if((a|0)!=1){x[31725]=0;O(988,b+20|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break d}d=b+20|0;a=Bg(Kb(d));tb(d);tb(c);break b}a=T(0)|0;break c}a=T(0)|0;tb(c)}Y(a|0)|0;a=0;x[31725]=0;V(989,11015,0,0,0);c=x[31725];x[31725]=0;if((c|0)==1){break a}Z()}fb=b+32|0;return a|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function oH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=rf(f+20|0,1,0);a:{b:{while(1){g=Kb(e);fC(f+12|0,g,Cb(x[e+4>>2],y[e+11|0])+g|0,x[b>>2],c);if(!x[f+16>>2]){break b}g=ri(Cb(x[e+4>>2],y[e+11|0]));x[31725]=0;O(45,e|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Kb(e);x[31725]=0;O(46,e|0,b-c|0);b=x[31725];x[31725]=0;c:{if((b|0)!=1){x[31725]=0;O(d|0,a|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function eH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=rf(f+20|0,1,0);a:{b:{while(1){g=Kb(e);ON(f+12|0,g,Cb(x[e+4>>2],y[e+11|0])+g|0,x[b>>2],c);if(!x[f+16>>2]){break b}g=ri(Cb(x[e+4>>2],y[e+11|0]));x[31725]=0;O(45,e|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Kb(e);x[31725]=0;O(46,e|0,b-c|0);b=x[31725];x[31725]=0;c:{if((b|0)!=1){x[31725]=0;O(d|0,a|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function zH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=rf(f+20|0,1,0);a:{b:{while(1){g=Kb(e);fC(f+12|0,g,Cb(x[e+4>>2],y[e+11|0])+g|0,y[b|0],c);if(!x[f+16>>2]){break b}g=ri(Cb(x[e+4>>2],y[e+11|0]));x[31725]=0;O(45,e|0,g|0);g=x[31725];x[31725]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Kb(e);x[31725]=0;O(46,e|0,b-c|0);b=x[31725];x[31725]=0;c:{if((b|0)!=1){x[31725]=0;O(d|0,a|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function Ls(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;a=sO(a);x[a+8>>2]=0;x[a>>2]=47692;x[31725]=0;i=R(856,104)|0;h=x[31725];x[31725]=0;a:{b:{c:{d:{if((h|0)!=1){x[31725]=0;d=R(1105,d|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break d}x[g+8>>2]=d;d=x[re(g+12|0,g+8|0)>>2];x[31725]=0;b=ha(f|0,i|0,b|0,c|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}x[a+8>>2]=b;Vc(g+8|0);b=x[a+8>>2];Yd(a,b?b+8|0:0);fb=g+16|0;return a}b=N()|0;break a}b=N()|0;break b}b=N()|0;Vc(g+8|0)}Db(i)}Vm(a);Q(b|0);p()}function YF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=x[b+16>>2];x[a+4>>2]=0;x[a>>2]=f;a:{if(!f){break a}c=b+80|0;d=x[b+84>>2];if(d>>>0<=15){d=x[c>>2]}else{x[e+12>>2]=d-16;d=x[ad(c,e+12|0)>>2]}x[a+8>>2]=d;c=x[b+88>>2];if(!(c&2)){break a}d=c;c=x[b+104>>2];b:{c:{if(!WF(d,c)){d=x[b+84>>2];break c}d=x[b+84>>2];if(x[b+80>>2]!=x[c+12>>2]){break c}b=1;if(x[c+16>>2]==(d|0)){break b}}b=0;if(x[c+8>>2]!=(d|0)){break a}}g=a,h=D((x[c>>2]-d|0)+(b?112:48)|0,el(z[c+34>>1]))+f|0,x[g+4>>2]=h}fb=e+16|0}function Hoa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=fb-48|0;fb=f;Or(f+12|0,c);x[31725]=0;c=f+24|0;O(598,c|0,d|0);d=x[31725];x[31725]=0;b:{c:{d:{if((d|0)==1){break d}x[31725]=0;c=f+36|0;O(598,c|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}rx(f+4|0,f+12|0);x[31725]=0;V(303,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}_n(f+12|0);fb=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;_n(f+12|0)}Q(a|0);p()}}function Vo(a){var b=0,c=0,d=0,e=0;d=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;b=((d&3)<<4)+26192|0;x[a+40>>2]=b;e=z[a+24>>1];d=d>>>2|0;c=e+d|0;w[a+36>>1]=c>>>0<12?1:1<<c-12;c=12-c|0;c=c>>>0<=12?c:0;w[a+32>>1]=c;w[a+34>>1]=-1<<c^-1;if((e|0)==15){w[a+36>>1]=4095}x[a+52>>2]=b;x[a+64>>2]=b;b=d+z[a+26>>1]|0;w[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;c=b>>>0<=12?b:0;w[a+44>>1]=c;b=d+z[a+30>>1]|0;w[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+56>>1]=b;w[a+46>>1]=-1<<c^-1;w[a+58>>1]=-1<<b^-1}function Q2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=fb-48|0;fb=f;Wp(f+12|0,c);x[31725]=0;c=f+24|0;O(135,c|0,d|0);d=x[31725];x[31725]=0;b:{c:{d:{if((d|0)==1){break d}x[31725]=0;c=f+36|0;O(135,c|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}rx(f+4|0,f+12|0);x[31725]=0;V(94,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}_n(f+12|0);fb=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;_n(f+12|0)}Q(a|0);p()}}function BN(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a:{b:{c:{a=x[a+32>>2];c=Aq(a);d:{if(!c){if(zq(a)>>>0<=b>>>0){break d}c=(y[ui(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=ac(8);x[31725]=0;b=P(36,d+4|0,6e3)|0;c=x[31725];x[31725]=0;e:{if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;jc(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(y[a+15|0]&2)>>>1|0}fb=d+16|0;return c|0}p()}function pP(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;e=Nb(a);ge(c+24|0);a=0;b=x[c+28>>2];d=x[c+24>>2];x[31725]=0;O(178,e|0,mM(d,b)|0);b=x[31725];x[31725]=0;a:{if((b|0)!=1){b:{while(1){b=x[c+24>>2];if((mM(b,x[c+28>>2])|0)<=(a|0)){fb=c+32|0;return}b=x[b+(a<<3)>>2];x[31725]=0;b=P(36,c+12|0,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;O(180,e|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}tb(b);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0}Td(e);Q(a|0);p()}function W2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{d:{if(f=Ad(x[b+4>>2],y[b+11|0]),g=1,h=x[b+12>>2],h?f:g){Fb(a);break d}d=Cb(x[b+4>>2],y[b+11|0]);e=is(14294);im(Xg(Xg(Kb(Fz(c+20|0,d+e|0)),Kb(b),d)+d|0,14294,e)+e|0,1,0);x[31725]=0;O(128,c+8|0,b+12|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}x[31725]=0;S(2,a|0,c+20|0,c+8|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}tb(c+8|0);tb(c+20|0)}fb=c+32|0;return}b=N()|0;break a}b=N()|0;tb(c+8|0)}tb(c+20|0);Q(b|0);p()}function msa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;e=c+12|0;f=Nb(e+8|0);x[31725]=0;d=R(204,b|0)|0;g=x[31725];x[31725]=0;a:{b:{if((g|0)==1){break b}x[31725]=0;S(171,e|0,b|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break b}d=x[e>>2];x[31725]=0;P(185,b|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;dc(f);Q(a|0);p()}Tn(c+4|0,e);x[31725]=0;S(477,a|0,x[c+4>>2],x[c+8>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Kc(c+12|0);fb=c+32|0;return}a=N()|0;Kc(c+12|0);Q(a|0);p()}function Q4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&512;f=b&256;g=b&128;h=b&64;i=b&32;j=b&16;k=b&8;l=b&4;m=b&2;b=b&1;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];b:{if(b){if(vt(a)){break b}}if(m){if(ut(a)){break b}}if(l){if(tt(a)){break b}}if(k){if(st(a)){break b}}if(j){if(rt(a)){break b}}if(i){if(qt(a)){break b}}if(h){if(Oh(a)){break b}}if(g){if(pt(a)){break b}}if(f){if(ot(a)){break b}}if(e){if(nt(a)){break b}}c=c+4|0;continue}break}d=c}return d|0}function Ks(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;a=sO(a);x[a+8>>2]=0;x[a>>2]=47692;x[31725]=0;h=R(856,104)|0;g=x[31725];x[31725]=0;a:{b:{c:{d:{if((g|0)!=1){x[31725]=0;c=R(1105,c|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break d}x[f+8>>2]=c;c=x[re(f+12|0,f+8|0)>>2];x[31725]=0;b=ba(e|0,h|0,b|0,c|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}x[a+8>>2]=b;Vc(f+8|0);b=x[a+8>>2];Yd(a,b?b+8|0:0);fb=f+16|0;return a}b=N()|0;break a}b=N()|0;break b}b=N()|0;Vc(f+8|0)}Db(h)}Vm(a);Q(b|0);p()}function Bja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);e=fb-16|0;fb=e;f=Hf(a,c);$d(e,x[a+36>>2]);h=a;a:{if(!f){Pc(e,a+32|0,5);c=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}c=0;d=fb-16|0;fb=d;g=x[a+36>>2];vl(g,d+8|0);i=d,j=Bc(x[d+8>>2],x[d+12>>2]),x[i+4>>2]=j;x[d>>2]=256;Ll(b,x[Gb(d+4|0,d)>>2]);a=x[b>>2];while(1){if(oc(a,x[b+4>>2])>>>0<=c>>>0){fb=d+16|0}else{x[d+4>>2]=0;Dq(g,d+4|0);a=x[b>>2];i=yb(a,c),k=B[d+4>>2],B[i>>2]=k;c=c+1|0;continue}break}c=f}gf(h,c);fb=e+16|0}function ft(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}h=x[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((up(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=ny(i+4|0,b,f);h=Kb(f);x[31725]=0;h=U(1235,a|0,h|0,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}Qb(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((up(a,c,b)|0)!=(b|0)){break b}}qE(e);j=a}fb=i+16|0;return j|0}a=N()|0;Qb(f);Q(a|0);p()}function wN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-32|0;fb=d;C[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31725]=0;d=P(36,d+8|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,d);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=x[a+32>>2];x[d+8>>2]=0;x[d+12>>2]=-1074790400;x[d>>2]=0;x[d+4>>2]=1072693248;e=(a+D(b,872)|0)+1075684|0,f=_i(C[Yg(d+24|0,d+8|0,d)>>3]*128+128),x[e>>2]=f;fb=d+32|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function fS(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;a:{f=b-1&65535;if(f>>>0>3998){break a}c=D(b,104)+a|0;e=c+484380|0;if(!je(x[e>>2],x[c+484400>>2])){break a}g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)==(g|0)){vn(e);x[e>>2]=0;a=(D(b,104)+a|0)+484414|0;w[a>>1]=z[a>>1]&65470;x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;_k(e,0,d);break a}if(x[c+104>>2]==(e|0)){x[c+76>>2]=0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0}c=c+872|0;continue}}fb=d+32|0;return f>>>0<3999}function UM(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=x[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(A[a+12>>2]<=d>>>0)){while(1){f=TA(x[a>>2]);e=hb;c=x[a+36>>2];if((e|0)==(c|0)&A[a+32>>2]<=f>>>0|e>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){f=TA(x[a>>2]);d=hb;c=x[a+28>>2];if((d|0)==(c|0)&A[a+24>>2]<=f>>>0|d>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function N7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;e=Cb(x[a+4>>2],y[a+11|0]);d=An(a);f=Sd(b,c);a:{if(!f){break a}b:{if(!KJ(a,b)){if(d-e>>>0<f>>>0){hy(a,d,(e-d|0)+f|0,e,e,0)}d=Kb(a)+(e<<2)|0;while(1){if((b|0)==(c|0)){break b}yd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=jo(g+4|0,b,c);c=Kb(b);e=y[b+11|0];d=x[b+4>>2];x[31725]=0;U(1253,a|0,c|0,Cb(d,e)|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){Qb(b);break a}a=N()|0;Qb(b);Q(a|0);p()}yd(d,0);ng(a,e+f|0)}fb=g+16|0;return a|0}function oV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;i=b?33:32;c=x[a+8>>2]-1|0;e=x[a+12>>2];f=x[a>>2]+D(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(i|0)){break b}while(1)if((b|0)>=(e|0)){b=x[a+8>>2]-1|0;c:{if(!((b|0)!=(c|0)|(d|0)<=0)){if(!y[a+16|0]){d=1;c=0;break c}d=-1;c=c-(y[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=y[a+16|0];d=c?1:-1;c=c?0:b;break c}c=c+d|0}f=D(e,g)+f|0;h=h+1|0;continue a}else{v[b+f|0]=y[x[a+4>>2]+(D(c,e)+b|0)|0];b=b+1|0;e=x[a+12>>2];continue}}break}}function eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;f=e+8|0;bj(f,2,a+2|0);d=e+20|0;Cc(d,f);zc(b+492|0,d);f=b+236|0;g=c+1|0;tb(d);c=0;while(1){if((c|0)==120){x[b>>2]=(y[a+223|0]|y[a+224|0]<<8)<<5;a=a+158|0;GR(y[a|0]&15,y[a+1|0]&15,y[a+2|0]&15,y[a+3|0]&15,y[a+4|0]&15,a+5|0,b+48|0);GR(y[a|0]>>>4|0,y[a+1|0]>>>4|0,y[a+2|0]>>>4|0,y[a+3|0]>>>4|0,y[a+4|0]>>>4|0,a+35|0,b+68|0);fb=e+32|0}else{d=y[(a+c|0)+31|0];h=_b(f,c),i=d+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function NX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+8|0]){while(1){if((d|0)==8){x[c+24>>2]=0;x[c+28>>2]=0;d=gc(c+8|0,c+24|0,8);e=x[d>>2];kc(c+16|0,x[a>>2],x[a+8>>2],e,x[d+4>>2]);d=0;if(!(x[c+24>>2]!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|x[c+28>>2]!=(y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24))|x[c+20>>2]!=8)){Vb(a,8);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17491,9079,601,13222);p()}_(17470,9079,599,13222);p()}return d|0}function T7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;e=Cb(x[a+4>>2],y[a+11|0]);d=Mc(a);f=Yj(b,c);a:{if(!f){break a}b:{if(!Lz(a,b)){if(d-e>>>0<f>>>0){Xm(a,d,(e-d|0)+f|0,e,e,0,0)}d=Kb(a)+e|0;while(1){if((b|0)==(c|0)){break b}fd(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=ti(g+4|0,b,c);c=Kb(b);e=y[b+11|0];d=x[b+4>>2];x[31725]=0;U(1246,a|0,c|0,Cb(d,e)|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}fd(d,0);ng(a,e+f|0)}fb=g+16|0;return a|0}function r1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;ld(b,0);e=d+8|0;nk(e,1,a+33|0);c=d+20|0;Cc(c,e);ze(b+43|0,c);tb(c);f=y[a+50|0]|y[a+51|0]<<8;x[b>>2]=f;x[b+24>>2]=y[a+52|0]|y[a+53|0]<<8;v[d+20|0]=y[a+54|0];v[d+8|0]=64;g=b,h=y[Rb(c,e)|0]<<2,w[g+30>>1]=h;e=y[a+55|0]|y[a+56|0]<<8;x[b+4>>2]=e;c=y[a+57|0]|y[a+58|0]<<8;x[b+8>>2]=c;a:{if((c|0)==65535){x[b+4>>2]=0;x[b+8>>2]=0;break a}if(!y[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}fb=d+32|0}function px(a){var b=0,c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){b=fb-16|0;fb=b;a=sG(b+4|0,a);c=x[a+4>>2];x[31725]=0;W(166,c|0);c=x[31725];x[31725]=0;a:{if((c|0)!=1){x[a+4>>2]=x[a+4>>2]+36;hc(a);fb=b+16|0;break a}b=N()|0;hc(a);Q(b|0);p()}return}c=fb-32|0;fb=c;b=zb(a);b=qG(c+12|0,rG(a,js(x[a>>2],x[a+4>>2])+1|0),js(x[a>>2],x[a+4>>2]),b);d=x[b+8>>2];x[31725]=0;W(166,d|0);d=x[31725];x[31725]=0;b:{if((d|0)!=1){x[b+8>>2]=x[b+8>>2]+36;oG(a,b);dx(b);fb=c+32|0;break b}a=N()|0;dx(b);Q(a|0);p()}}function bg(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function tS(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=x[a+104>>2];d=(g<<3)+a|0;b=((g+7>>>0)%12<<3)+a|0;f=x[b>>2];e=x[b+4>>2];b=x[a+100>>2];j=b;h=x[a+96>>2];a:{if(!(b|h)){c=x[d+4>>2];b=x[d>>2];i=(c|0)==(e|0)&b>>>0>f>>>0|e>>>0<c>>>0;break a}c=x[d+4>>2];b=x[d>>2];i=!(e|f)|((c|0)==(e|0)&b>>>0>=f>>>0|e>>>0<c>>>0)}c=c+j|0;b=b+h|0;c=b>>>0<h>>>0?c+1|0:c;x[d>>2]=f-b;x[d+4>>2]=e-(c+(b>>>0>f>>>0)|0)&65535;x[a+104>>2]=(g+1>>>0)%12;x[a+96>>2]=i;x[a+100>>2]=0;hb=x[d+4>>2];return x[d>>2]}function lp(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;f=(y[xb(b,0)|0]&15)<<8|y[xb(b,1)|0];d=0;a:{if(!f){break a}d=0;if((f|0)==4095){break a}while(1){d=108;if((e|0)==84){break a}b:{d=z[(e<<1)+31104>>1];if(f>>>0>=d>>>0){if(!e|(f|0)==(d|0)|(z[(e<<1)+31102>>1]-f|0)>=(f-d|0)){break b}d=e+24|0;break a}e=e+1|0;continue}break}d=e+25|0}v[c|0]=d;e=y[xb(b,2)|0];d=y[xb(b,0)|0];v[c+3|0]=0;v[c+1|0]=d&16|e>>>4;c=y[xb(b,2)|0];h=g,i=y[xb(b,3)|0],v[h+15|0]=i;de(a,c&15,g+15|0);fb=g+16|0}function zA(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;a:{if(!c){b=Xd(x[a>>2],b);a=x[d+12>>2];x[b+8>>2]=x[d+8>>2];x[b+12>>2]=a;a=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=a;break a}f=x[d+12>>2];x[e+24>>2]=x[d+8>>2];x[e+28>>2]=f;f=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=f;f=c>>>1|0;zA(a,b,f,e+16|0);g=C[d>>3];h=C[d+8>>3];d=Xd(x[a>>2],c);Ti(e+32|0,g,h,C[d>>3],C[d+8>>3]);d=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;zA(a,b|c,f,e)}fb=e+48|0}function sja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-48|0;fb=f;d=x[a+36>>2];kg(x[x[d>>2]-12>>2]+d|0,0);e=x[b>>2];d=x[e+8>>2];e=x[e+12>>2];g=e;if(d|e){h=x[a+36>>2];g=x[a+20>>2]+g|0;e=x[a+16>>2];d=d+e|0;e=hi(f+32|0,d,d>>>0<e>>>0?g+1|0:g);d=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=d;d=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=d;$m(h,f)}d=f+16|0;$d(d,x[a+36>>2]);WB(x[a+36>>2],c,x[x[b>>2]+16>>2]);c=x[b>>2];b=yl(d,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);gf(a,c);Eb(b);fb=f+48|0}function Wra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=$j(b),x[i+4>>2]=j;g=z[b>>1];c=fb-16|0;fb=c;f=a;d=ce(a);a:{if(d){b=ec(f);while(1){a=d;d=z[a+16>>1];if(fp(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!fp(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){FZ(c,f,e+4|0);$g(f,x[c+12>>2],b,x[c>>2]);a=le(c);EZ(c);h=1}_g(e+8|0,x[vb(c,a)>>2],h);fb=c+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+4|0}function jR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=$j(b),x[i+4>>2]=j;g=z[b>>1];c=fb-16|0;fb=c;f=a;d=ce(a);a:{if(d){b=ec(f);while(1){a=d;d=z[a+16>>1];if(cr(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!cr(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){FZ(c,f,e+4|0);$g(f,x[c+12>>2],b,x[c>>2]);a=le(c);EZ(c);h=1}_g(e+8|0,x[vb(c,a)>>2],h);fb=c+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+4|0}function Jqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb+-64|0;fb=d;b=-1;a:{if(!Dm(a,1084)){break a}dm(a,1080);c=d+60|0;uY(a,c);f=tY(d+40|0);b=0;if(!sY(c,f)){break a}dm(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=A[f+4>>2]>=h>>>0}else{c=y[f+16|0];e=fb-16|0;fb=e;b:{g=d+10|0;if(!rY(a,g)|!c){break b}Ev(e+8|0,g);c=0;while(1){if(c>>>0>=30){break b}i=x[e+8>>2];tg(xb(i,c),xb(i,c|1));c=c+2|0;continue}}fb=e+16|0;b=b+1|0;h=WC(g)+h|0;continue}break}}fb=d- -64|0;return b|0}function wba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=_i(C[a+24>>3]*65536);if((d|0)==65536){break a}j=d>>31;k=x[b>>2];h=x[b+4>>2];l=x[b+8>>2];b:while(1){if((g|0)==(l|0)){break a}m=D(g,h);e=0;while(1)if((e|0)==(h|0)){g=g+1|0;continue b}else{i=(e+m<<2)+k|0;f=x[i>>2];f=pva(ova(f,f>>31,d,j),hb,65536,0);n=i,o=Gc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;RM(a,c);fb=c+16|0}function nba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=_i(C[a+24>>3]*65536);if((d|0)==65536){break a}j=d>>31;k=x[b>>2];h=x[b+4>>2];l=x[b+8>>2];b:while(1){if((g|0)==(l|0)){break a}m=D(g,h);e=0;while(1)if((e|0)==(h|0)){g=g+1|0;continue b}else{i=(e+m<<2)+k|0;f=x[i>>2];f=pva(ova(f,f>>31,d,j),hb,65536,0);n=i,o=Gc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;LM(a,c);fb=c+16|0}function tja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;e=x[a+36>>2];kg(x[x[e>>2]-12>>2]+e|0,0);f=x[b>>2];e=x[f+8>>2];f=x[f+12>>2];h=f;if(e|f){i=x[a+36>>2];h=x[a+20>>2]+h|0;f=x[a+16>>2];e=e+f|0;f=hi(g+32|0,e,e>>>0<f>>>0?h+1|0:h);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;$m(i,g)}e=g+16|0;$d(e,x[a+36>>2]);eR(d,x[a+36>>2],c);c=x[b>>2];b=yl(e,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);gf(a,c);Eb(b);fb=g+48|0}function rja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;e=x[a+36>>2];kg(x[x[e>>2]-12>>2]+e|0,0);f=x[b>>2];e=x[f+8>>2];f=x[f+12>>2];h=f;if(e|f){i=x[a+36>>2];h=x[a+20>>2]+h|0;f=x[a+16>>2];e=e+f|0;f=hi(g+32|0,e,e>>>0<f>>>0?h+1|0:h);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;$m(i,g)}e=g+16|0;$d(e,x[a+36>>2]);aR(c,x[a+36>>2],d);c=x[b>>2];b=yl(e,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);gf(a,c);Eb(b);fb=g+48|0}function SN(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=c-b|0;a:{if((f|0)<=19){i=D(64-cu(d|1,e)|0,1233)>>>12|0;j=(i<<3)+124032|0;g=f;f=x[j+4>>2];h=61;if((g|0)<(((e|0)==(f|0)&d>>>0>=A[j>>2]|e>>>0>f>>>0)+i|0)){break a}}b:{if(!e){c=EB(b,d);break b}if((e|0)==2&d>>>0>=1410065408|e>>>0>2){c=qva(d,e,1410065408,2);f=ova(c,hb,-1410065408,-3);e=e+hb|0;g=d;d=d+f|0;e=g>>>0>d>>>0?e+1|0:e;b=EB(b,c)}c=qva(d,e,1e8,0);e=hb;b=Tl(b,c);c=ova(c,e,-1e8,0)+d|0;c=Ru(b,c)}h=0}x[a+4>>2]=h;x[a>>2]=c}function Hm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;a:{b:{c:{d=An(a);e=Sd(b,c);if(d>>>0<e>>>0){if(KJ(a,b)){break c}g=d;h=e-d|0;d=Cb(x[a+4>>2],y[a+11|0]);hy(a,g,h,d,0,d)}d=Kb(a);while(1){if((b|0)==(c|0)){break b}yd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=jo(f+4|0,b,c);c=Kb(b);d=y[b+11|0];e=x[b+4>>2];x[31725]=0;S(1358,a|0,c|0,Cb(e,d)|0);c=x[31725];x[31725]=0;if((c|0)!=1){Qb(b);break a}a=N()|0;Qb(b);Q(a|0);p()}yd(d,0);ng(a,e)}fb=f+16|0;return a|0}function us(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!Cd(y[a+11|0])){c=y[b+11|0];if(!Cd(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Kb(b);b=Cb(x[b+4>>2],c);a:{if(b>>>0<=10){Me(a,b);fd(Xg(a,d,b)+b|0,0);break a}e=a;a=Wh(y[a+11|0]);Zq(e,10,b-10|0,a,0,a,b,d)}return}d=Kb(b);b=Cb(x[b+4>>2],y[b+11|0]);c=ej(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];Yd(a,b);fd(Xg(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];Zq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function tP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;a:{b:{c:{d=Mc(a);e=Yj(b,c);if(d>>>0<e>>>0){if(Lz(a,b)){break c}g=d;h=e-d|0;d=Cb(x[a+4>>2],y[a+11|0]);Xm(a,g,h,d,0,d,0)}d=Kb(a);while(1){if((b|0)==(c|0)){break b}fd(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=ti(f+4|0,b,c);c=Kb(b);d=y[b+11|0];e=x[b+4>>2];x[31725]=0;S(74,a|0,c|0,Cb(e,d)|0);c=x[31725];x[31725]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}fd(d,0);ng(a,e)}fb=f+16|0;return a|0}function pw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!Cd(y[a+11|0])){c=y[b+11|0];if(!Cd(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Kb(b);b=Cb(x[b+4>>2],c);a:{if(b>>>0<=10){Me(a,b);fd(Cg(a,d,b)+b|0,0);break a}e=a;a=Wh(y[a+11|0]);fq(e,10,b-10|0,a,0,a,b,d)}return}d=Kb(b);b=Cb(x[b+4>>2],y[b+11|0]);c=ej(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];Yd(a,b);fd(Cg(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];fq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function nia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=fb-16|0;fb=b;d=x[a+20>>2];c=x[d+4>>2];a:{if(!((Sc(c,x[d+8>>2])|0)!=7|(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=1869112133)){d=wb(c);g=wb(x[x[a+20>>2]+8>>2]);Rr(b+8|0,a+4228|0);f=wb(x[b+8>>2]);e=fb-16|0;fb=e;c=fb-32|0;fb=c;Id(c+24|0,d,g);yn(c+16|0,x[c+24>>2],x[c+28>>2],f);d=e$(d,x[c+16>>2]);h=c,i=WD(f,x[c+20>>2]),x[h+12>>2]=i;Ac(e+8|0,d,c+12|0);fb=c+32|0;fb=e+16|0;break a}aA(a,a)}lu(a);fb=b+16|0}function xY(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;e=z[c>>1];while(1){a:{e=e<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!Af(a,f+15|0)){break a}e=y[f+15|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;w[c>>1]=y[c|0]}v[d|0]=y[b|0]+(y[d|0]<<1);e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!Af(a,f+14|0)){break a}e=y[f+14|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;e=y[c|0];w[c>>1]=e;if(y[b|0]){continue}break a}if(y[b|0]){continue}}break}fb=f+16|0}function cI(a,b,c,d,e,f,g,h){var i=0,j=0;i=fb-16|0;fb=i;x[31725]=0;W(1002,a|0);j=x[31725];x[31725]=0;a:{b:{if((j|0)!=1){c:{j=x[a+24>>2];x[31725]=0;ga(h|0,i+4|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}a=i+4|0;b=Bg(Kb(a));tb(a);break b}}Y(T(0)|0)|0;b=0;x[31725]=0;V(989,g|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}fb=i+16|0;return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function ow(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b|0;if((h|0)>0){if((up(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=rf(i+4|0,b,f);g=Kb(f);x[31725]=0;g=U(32,a|0,g|0,b|0)|0;h=x[31725];x[31725]=0;if((h|0)==1){break a}tb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((up(a,c,b)|0)!=(b|0)){break b}}qE(e);j=a}fb=i+16|0;return j|0}a=N()|0;tb(f);Q(a|0);p()}function $7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;c=fb-128|0;fb=c;x[c+12>>2]=c+116;d=c+16|0;dK(x[a+8>>2],d,c+12|0,e,f,g);f=fb-16|0;fb=f;h=f+8|0;a=fb-32|0;fb=a;Id(a+24|0,d,x[c+12>>2]);i=a+16|0;e=x[a+24>>2];g=x[a+28>>2];d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if((e|0)!=(g|0)){nL(d+12|0,v[e|0]);e=e+1|0;continue}break}Ac(i,g,d+12|0);fb=d+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Ac(h,b,a+12|0);fb=a+32|0;fb=f+16|0;fb=c+128|0;return x[f+12>>2]}function wK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[31600];x[31600]=0;Od();a=xy(a,e+12|0,d);d=hb;g=x[31600];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}x[31600]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0<65536){break b}}x[c>>2]=4;a=65535;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a&65535}function kH(a,b,c,d,e,f){var g=0;a:{g=fb-48|0;fb=g;fo(g+12|0,c);x[31725]=0;c=g+24|0;O(f|0,c|0,d|0);d=x[31725];x[31725]=0;b:{c:{d:{if((d|0)==1){break d}x[31725]=0;c=g+36|0;O(93,c|0,e|0);d=x[31725];x[31725]=0;if((d|0)==1){break d}rx(g+4|0,g+12|0);x[31725]=0;V(94,a|0,b|0,x[g+4>>2],x[g+8>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}_n(g+12|0);fb=g+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+12|0)){continue}break}break b}a=N()|0;_n(g+12|0)}Q(a|0);p()}}function Bua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;a:{g=x[c+12>>2];if(!g){break a}e=lg(d+4|0,c+16|0);f=Yc(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){tb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[cc(b,0)|0]==43){break c}if(y[cc(b,0)|0]==45){break c}}x[31725]=0;U(306,b|0,f-c|0,e|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=N()|0;tb(e);Q(a|0);p()}_c(a,b);fb=d+16|0}function soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;a:{g=x[c+12>>2];if(!g){break a}e=Cm(d+4|0,c+16|0);f=Yc(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){tb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[cc(b,0)|0]==43){break c}if(y[cc(b,0)|0]==45){break c}}x[31725]=0;U(48,b|0,f-c|0,e|0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=N()|0;tb(e);Q(a|0);p()}_c(a,b);fb=d+16|0}function bI(a,b,c,d,e,f,g){var h=0,i=0;h=fb-16|0;fb=h;x[31725]=0;W(1002,a|0);i=x[31725];x[31725]=0;a:{b:{if((i|0)!=1){c:{i=x[x[a+24>>2]+24>>2];x[31725]=0;ja(g|0,h+4|0,i|0,b|0,c|0,d|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}a=h+4|0;b=Bg(Kb(a));tb(a);break b}}Y(T(0)|0)|0;b=0;x[31725]=0;V(989,f|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}fb=h+16|0;return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ri(a,b,c,d);x[a>>2]=42540;b=Nb(a+4208|0);x[a+4236>>2]=-1;x[a+4240>>2]=0;x[a+4228>>2]=1049926264;x[a+4232>>2]=0;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;v[a+4244|0]=0;Tb(a+4248|0,0,48);x[31725]=0;X(854);c=x[31725];x[31725]=0;a:{if((c|0)==1){break a}e=a,f=AS(),x[e+4296>>2]=f;qu(a);pu(a);x[31725]=0;O(947,a+44|0,2);c=x[31725];x[31725]=0;if((c|0)==1){break a}return a|0}c=N()|0;dc(b);ag(a);Q(c|0);p()}function wia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;e=d+4|0;c=fb-32|0;fb=c;f=c+8|0;Wf(f,b);x[31725]=0;S(11,c+20|0,0,f|0);b=x[31725];x[31725]=0;a:{b:{c:{if((b|0)!=1){x[31725]=0;O(968,e|0,c+20|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}Qb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}x[31725]=0;P(966,a|0,e|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){tb(d+4|0);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function vT(a,b){var c=0,d=0,e=0,f=0,g=0;a:{if(y[b+791|0]!=27){a=v[b+831|0];break a}e=a+1074312|0;c=Ob(e,21);d=a;a=y[b+821|0];a=JA(d,y[b+828|0],c?a:a+16>>>2|0);b:{if(!(!Ob(e,45)|y[b+828|0]!=3)){c=y[b+821|0];c:{if(!(!c|c>>>0>=y[b+829|0])){a=y[b+832|0];d=c+1|0;break c}v[b+832|0]=a;d=1}v[b+821|0]=d;a=a<<24>>24;break b}v[b+821|0]=y[b+821|0]+y[b+829|0]}if(!Ob(e,47)){break a}v[b+831|0]=a}if(a){f=b,g=Yb(x[b+684>>2]+((D(y[b+830|0],a)+2|0)/8|0)|0,0,256),x[f+684>>2]=g}}function nR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<=127){f=fb-32|0;fb=f;c=128-c|0;e=x[zb(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){nA(a,c,b);break a}e=zb(a);d=$f(f+12|0,Mf(a,oc(x[a>>2],d)+c|0),oc(x[a>>2],x[a+4>>2]),e);g=fb-16|0;fb=g;c=Nn(g+4|0,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){Dk(e,B[b>>2]);e=x[c>>2]+4|0;x[c>>2]=e;continue}break}he(c);fb=g+16|0;mA(a,d);_f(d)}fb=f+32|0;return}if((c|0)!=128){Ih(a,d+512|0)}}function Kz(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==y[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}if(!(y[a|0]==(b&255)|c>>>0<4)){d=D(b&255,16843009);while(1){e=d^x[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==y[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function WR(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{if((c|0)<2){break a}i=c-2>>>1|0;e=d-a|0;if((i|0)<e>>1){break a}g=e+1|0;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=Nl(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(Nl(b,z[f>>1],z[d>>1])){break a}j=z[d>>1];while(1){b:{e=d;d=f;w[e>>1]=z[f>>1];if((g|0)>(i|0)){break b}e=g<<1;g=e|1;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=Nl(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(!Nl(b,z[f>>1],j)){continue}}break}w[d>>1]=j}}function O5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a|0)!=(b|0)){d=fb-16|0;fb=d;c=x[b>>2];b=x[b+4>>2];e=Sd(c,b);a:{if(e>>>0<=Ug(a)>>>0){f=b;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=c;$C(d+12|0,h);f=x[d+12>>2]}c=Wg(c,f,g);if(!i){xI(a,f,b,e-oc(x[a>>2],x[a+4>>2])|0);break a}Ih(a,c);break a}if(x[a>>2]){Nf(a);cy(jq(a),x[a>>2],Ug(a));j=zb(a),k=0,x[j>>2]=k;x[a>>2]=0;x[a+4>>2]=0}AJ(a,Mf(a,e));xI(a,c,b,e)}fb=d+16|0}return a|0}function jL(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if(BL()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31725]=0;b=R(1188,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[31725]=0;W(1189,a+b|0);a=x[31725];x[31725]=0;if((a|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break a}}return}T(0)|0;Sb();p()}function dpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;qn(c+52|0,b);oe(c+24|0,x[c+52>>2],x[c+56>>2]);b=Nd(c+16|0);x[31725]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=jg(162,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31725];x[31725]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31725]=0;S(734,b|0,d|0,Sc(e,a)>>>5|0);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;Yi(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function apa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;qn(c+52|0,b);oe(c+24|0,x[c+52>>2],x[c+56>>2]);b=Nd(c+16|0);x[31725]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=jg(162,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31725];x[31725]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31725]=0;S(735,b|0,d|0,Sc(e,a)>>>2|0);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;uc(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function _oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;qn(c+52|0,b);oe(c+24|0,x[c+52>>2],x[c+56>>2]);b=Nd(c+16|0);x[31725]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=jg(162,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31725];x[31725]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31725]=0;S(737,b|0,d|0,Sc(e,a)>>>4|0);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;rn(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function Kpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;ld(b,0);e=d+8|0;ND(e,a+1|0);c=d+20|0;Cc(c,e);ze(b+43|0,c);tb(c);x[b+24>>2]=y[a+78|0]|y[a+79|0]<<8;c=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);x[b+8>>2]=y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24);w[b+30>>1]=(y[a+73|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;wc(b+8|0,c);wc(b+4|0,x[b+8>>2]);fb=d+32|0}function $oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;qn(c+52|0,b);oe(c+24|0,x[c+52>>2],x[c+56>>2]);b=Nd(c+16|0);x[31725]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=jg(162,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31725];x[31725]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31725]=0;S(736,b|0,d|0,Sc(e,a)>>>8|0);a=x[31725];x[31725]=0;if((a|0)==1){a=N()|0;tv(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function C1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;c=e+12|0;f=fb-16|0;fb=f;h=Ec(168);x[31725]=0;g=P(36,f+4|0,22255)|0;d=x[31725];x[31725]=0;a:{b:{c:{if((d|0)!=1){x[31725]=0;d=U(37,h|0,g|0,0)|0;i=x[31725];x[31725]=0;if((i|0)==1){break c}tb(g);x[c>>2]=d;hl(d);fb=f+16|0;break a}a=N()|0;break b}a=N()|0;tb(g)}Db(h);Q(a|0);p()}x[31725]=0;S(27,a|0,c|0,b|0);a=x[31725];x[31725]=0;if((a|0)!=1){Zb(c);fb=e+16|0;return}a=N()|0;Zb(c);Q(a|0);p()}function wI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(1073741806-b>>>0>=c>>>0){k=Kb(a);j=i+4|0;if(b>>>0<=536870886){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=zn(x[ad(i+4|0,i+12|0)>>2])+1|0}else{c=1073741807}Wj(j,c);c=x[i+4>>2];if(e){Zi(c,k,e)}if(g){Zi(c+(e<<2)|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){d=e<<2;Zi((d+c|0)+(g<<2)|0,(d+k|0)+(f<<2)|0,h)}if((b|0)!=1){Db(k)}yd(a,c);pf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Yd(b,a);yd(c+(a<<2)|0,0);fb=i+16|0;return}qf();p()}function om(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if(BL()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31725]=0;b=R(31,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[31725]=0;O(24,a+b|0,1);a=x[31725];x[31725]=0;if((a|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break a}}return}T(0)|0;Sb();p()}function Pra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=wb(x[b>>2]);h=wb(x[b+4>>2]);g=fb-16|0;fb=g;x[g+12>>2]=d;while(1){a:{if(!Ib(d,h)){break a}e=fb-16|0;fb=e;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[e+10|0]=f;v[e+11|0]=f>>>8;v[e+12|0]=f>>>16;v[e+13|0]=f>>>24;f=y[d+4|0]|y[d+5|0]<<8;v[e+14|0]=f;v[e+15|0]=f>>>8;fb=e+16|0;if(z[e+10>>1]==(c|0)){break a}d=x[nm(g+12|0)>>2];continue}break}fb=g+16|0;if(lc(d,wb(x[b+4>>2]))){bi(a);return}tp(a,d)}function MT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;j=d,k=$j(b),x[j+4>>2]=k;c=fb-16|0;fb=c;g=eB(a,c+12|0,y[b|0],x[b+4>>2]);b=x[g>>2];if(!b){e=fb-16|0;fb=e;b=ec(a);h=Dh(c,Ec(28),Mg(e+8|0,b));b=x[h>>2];f=x[d+4>>2];i=x[f>>2];f=x[f+4>>2];x[b+24>>2]=0;x[b+16>>2]=i;x[b+20>>2]=f;j=ec(h),k=1,v[j+4|0]=k;fb=e+16|0;$g(a,x[c+12>>2],g,x[c>>2]);b=le(c);em(c);e=1}_g(d+8|0,x[vb(c,b)>>2],e);fb=c+16|0;a=td(x[d+8>>2]);fb=d+16|0;return a+8|0}function Ika(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=z[a+30>>1];if(d){b=hA(b<<16>>16,d<<16>>16)}w[e+14>>1]=b;a=a+52|0;a:{if(!Ad(x[c+4>>2],y[c+11|0])){us(jR(a,e+14|0),c);break a}b=iA(a,e+14|0);if(!Zg(b,Rf(a))){break a}c=fb-16|0;fb=c;b=x[vb(c+8|0,b)>>2];d=fb-16|0;fb=d;f=ah(vb(d+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[f>>2]}g=zb(a);x[g>>2]=x[g>>2]-1;rV(x[ec(a)>>2],b);a=x[f>>2];fb=d+16|0;Zj(td(b));Db(b);vb(c+12|0,a);fb=c+16|0}fb=e+16|0}function daa(){var a=0,b=0,c=0,d=0,e=0,f=0;c=fb-48|0;fb=c;if(OL(1,c+24|0)){Jt(x[31600],12779);p()}b=we(c+16|0,x[c+24>>2],x[c+28>>2]);f=ZA(c+8|0,x[c+32>>2]);d=fb-16|0;fb=d;e=fb-16|0;fb=e;a=we(e+8|0,ova(x[b>>2],x[b+4>>2],1e9,0),hb);b=x[a>>2];a=x[a+4>>2];fb=e+16|0;x[d>>2]=b;x[d+4>>2]=a;a=x[d>>2];e=a+x[f>>2]|0;f=x[f+4>>2]+x[d+4>>2]|0;b=we(d+8|0,e,a>>>0>e>>>0?f+1|0:f);a=x[b>>2];fb=d+16|0;b=we(c+40|0,a,x[b+4>>2]);a=x[b>>2];fb=c+48|0;hb=x[b+4>>2];return a|0}function tK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){b:{c:{f=y[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=x[31600];x[31600]=0;Od();a=xy(a,e+12|0,d);d=hb;d:{g=x[31600];if(g){if(x[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}x[c>>2]=4;b=-1;a=-1;break a}x[31600]=h;if(x[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}x[c>>2]=4;b=0;a=0}fb=e+16|0;hb=a;return b}function lva(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{b:{if(!mh(a,7)){break b}c=0;if(!OE(a,18431)){break a}if(!mh(a,1)){break b}c=-1;if(!gd(a,Sr(a))){break a}c=fb-16|0;fb=c;f=d+9|0;Rr(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){DE(f)}c=-1;if(!e){break a}c=0;if(!P0(y[d+9|0],y[d+10|0])){break a}c=ve(a,b,O0(d+9|0),hb);break a}c=-1}fb=d+16|0;return c|0}function eba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;d=fb-32|0;fb=d;Id(d+24|0,a,b);h=d+16|0;e=x[d+24>>2];g=x[d+28>>2];b=fb-16|0;fb=b;x[b+12>>2]=c;a:{while(1){if((e|0)==(g|0)){break a}c=Dc(b,x[e>>2]);x[31725]=0;P(1151,b+12|0,c|0)|0;i=x[31725];x[31725]=0;if((i|0)!=1){tb(c);e=e+4|0;continue}break}a=N()|0;tb(c);Q(a|0);p()}Ac(h,g,b+12|0);fb=b+16|0;b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f+8|0,kA(a,b),d+12|0);fb=d+32|0;fb=f+16|0}function ZE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Zc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){QE(a,b);break a}c=zb(a);c=ok(e+12|0,pk(a,Zc(x[a>>2],d)+b|0),Zc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Ip(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Vw(d);d=x[b>>2]+2|0;x[b>>2]=d;continue}break}he(b);fb=f+16|0;Yr(a,c);kj(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Kn(a,d+(b<<1)|0)}}function Mna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;f=v[e|0];e=((D(v[e+1|0]-f|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(f<<8)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function caa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;x[e+16>>2]=b;d=x[a+48>>2];x[e+20>>2]=c-((d|0)!=0);f=x[a+44>>2];x[e+28>>2]=d;x[e+24>>2]=f;a:{b:{if(Zy(cb(x[a+60>>2],e+16|0,2,e+12|0)|0)){b=32}else{d=x[e+12>>2];if((d|0)>0){break b}b=d?32:16}x[a>>2]=b|x[a>>2];break a}g=d;f=x[e+20>>2];if(f>>>0>=d>>>0){break a}d=x[a+44>>2];x[a+4>>2]=d;x[a+8>>2]=d+(g-f|0);if(x[a+48>>2]){x[a+4>>2]=d+1;v[(b+c|0)-1|0]=y[d|0]}g=c}fb=e+32|0;return g|0}function Zta(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);x[31725]=0;W(346,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=a;c=x[a+4>>2];x[b+4>>2]=c;x[b+8>>2]=c+32768;c=x[b+4>>2];f=x[b+8>>2];while(1){if((c|0)==(f|0)){hc(b);fb=e+16|0}else{w[c>>1]=0;w[c+2>>1]=0;c=c+4|0;x[b+4>>2]=c;continue}break}b=d+8|0;Qd(b);dh(b);fb=d+16|0;return a|0}a=N()|0;dh(d+8|0);Q(a|0);p()}function Caa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;e=x[b+292>>2];kg(x[x[e>>2]-12>>2]+e|0,0);$d(g+16|0,x[b+292>>2]);f=hi(g,-1,-1);e=x[g+24>>2];h=x[g+28>>2];a:{if(!go(e,h,x[f+8>>2],x[f+12>>2])){b:{if((c|0)!=(e|0)|h){break b}break a}}Ii(x[b+292>>2],c,0,0)}e=x[d>>2];d=x[d+4>>2];c=0;while(1){if(d){f=x[b+292>>2];h=vh(d);Ej(f,c+e|0,h);f=x[x[b+292>>2]+4>>2];d=d-f|0;c=c+f|0;if((f|0)==(h|0)){continue}}break}bc(a,e,c);fb=g+32|0}function Lna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;f=w[e>>1];e=f+((D(w[e+2>>1]-f|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function cH(a,b,c,d,e){var f=0,g=0,h=0;a:{f=fb-32|0;fb=f;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[31725]=0;a=U(152,g|0,a|0,8)|0;g=x[31725];x[31725]=0;if((g|0)==1){break c}if(!a){break d}x[31725]=0;S(e|0,f+4|0,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;O(d|0,h|0,f+4|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}Gd(f+4|0);continue}break}a=N()|0;break b}a=N()|0;Gd(f+4|0);break b}fb=f+32|0;break a}a=N()|0}ie(h);Q(a|0);p()}}function iu(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(x[31594]){b=iu(x[31594])}if(!x[31520]){break a}c=b|c;a=x[31520];continue}break}d=x[a+76>>2]>=0;b:{c:{if(x[a+20>>2]==x[a+28>>2]){break c}ib[x[a+36>>2]](a,0,0)|0;if(x[a+20>>2]){break c}b=-1;if(d){break b}break a}b=x[a+8>>2];e=x[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;ib[x[a+40>>2]](a,b,b>>31,1)|0}b=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;if(!d){break a}}}return b|c}function bq(a,b,c,d,e){var f=0,g=0,h=0;a:{f=fb-32|0;fb=f;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[31725]=0;a=U(152,g|0,a|0,e|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break c}if(!a){break d}x[31725]=0;O(d|0,f+4|0,b|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[31725]=0;O(c|0,h|0,f+4|0);a=x[31725];x[31725]=0;if((a|0)==1){break e}Gd(f+4|0);continue}break}a=N()|0;break b}a=N()|0;Gd(f+4|0);break b}fb=f+32|0;break a}a=N()|0}ie(h);Q(a|0);p()}}function _j(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Sc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>>0){YX(a,b);break a}c=zb(a);c=wn(e+12|0,cm(a,Sc(x[a>>2],d)+b|0),Sc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=yC(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){FX(d);d=x[b>>2]+1|0;x[b>>2]=d;continue}break}he(b);fb=f+16|0;ir(a,c);un(c)}fb=e+32|0;return}if(b>>>0<c>>>0){pr(a,b+d|0)}}function U2(a,b){a=a|0;b=b|0;var c=0;a=Fb(a);a:{if(y[b+16|0]){x[31725]=0;P(129,a|0,4945)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}}if(y[b+17|0]){x[31725]=0;P(129,a|0,12608)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}}if(Ad(x[a+4>>2],y[a+11|0])){x[31725]=0;P(129,a|0,10067)|0;c=x[31725];x[31725]=0;if((c|0)==1){break a}}if(y[b+18|0]){x[31725]=0;P(129,a|0,11127)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}}return}b=N()|0;tb(a);Q(b|0);p()}function wta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31725]=0;O(376,a|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break a}f=fb-16|0;fb=f;e=$h(f+4|0,a,b);b=x[e+4>>2];g=x[e+8>>2];while(1){if((b|0)==(g|0)){hc(e);fb=f+16|0}else{ij(b,y[c|0]|y[c+1|0]<<8);b=b+2|0;x[e+4>>2]=b;continue}break}}b=d+8|0;Qd(b);ak(b);fb=d+16|0;return a|0}a=N()|0;ak(d+8|0);Q(a|0);p()}function rc(a,b){var c=0,d=0,e=0;c=x[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return rc(a,24)+(rc(a,b-24|0)<<24)|0}if(!c){x[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=Qt(a);d=0;if((e|0)==-1){break a}d=x[a+1396>>2];c=d+8|0;x[a+1396>>2]=c;x[a+1392>>2]=x[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){_(10077,13258,1632,6865);p()}d=x[a+1392>>2];x[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}x[a+1396>>2]=c}return d}function bpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-4096|0;fb=c;qn(a,b);a:while(1){if(Sc(x[a>>2],x[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;d=0;while(1)if((b|0)==2048){h=f|2048;b=0;while(1){g=x[a>>2];if((b|0)!=2048){d=y[xb(g,b+h|0)|0]+d|0;i=xb(c,b<<1),j=d,v[i|0]=j;b=b+1|0;continue}break}pv(c,sC(c),Pe(wb(g),f));e=e+1|0;continue a}else{d=y[xb(x[a>>2],b+f|0)|0]+d|0;i=xb(c,b<<1|1),j=d,v[i|0]=j;b=b+1|0;continue}}break}fb=c+4096|0}function iga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=c;c=x[re(e+24|0,e+28|0)>>2];x[31725]=0;f=x[b+12>>2];x[e+16>>2]=x[b+8>>2];x[e+20>>2]=f;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;ba(996,a+8|0,e+8|0,c|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){a=Ez(a);b=Dz(a+88|0);c=Cz(a+92|0);d=Bz(a+96|0);x[a>>2]=47772;x[b>>2]=47888;x[c>>2]=47968;x[d>>2]=48008;Vc(e+28|0);fb=e+32|0;return a|0}a=N()|0;Vc(e+28|0);Q(a|0);p()}function LR(a,b,c,d,e,f,g,h){var i=0,j=0;i=fb-16|0;fb=i;x[i+12>>2]=d;a:{if(!(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))){break a}x[i+8>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);j=b;b=x[Gb(i+8|0,i+12|0)>>2];x[j>>2]=b;b=Kd(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),b,d);x[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=z[e>>1]|f;w[e>>1]=b;if((y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1){break a}w[e>>1]=b|g}fb=i+16|0}function Xy(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!x[x[124231]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){v[a+1|0]=b&63|128;v[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){v[a+2|0]=b&63|128;v[a|0]=b>>>12|224;v[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){v[a+3|0]=b&63|128;v[a|0]=b>>>18|240;v[a+2|0]=b>>>6&63|128;v[a+1|0]=b>>>12&63|128;return 4}}x[31600]=25;a=-1}else{a=1}return a}v[a|0]=b;return 1}function nZ(a,b){var c=0,d=0,e=0,f=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){jD(a,b);break a}c=zb(a);c=$f(e+12|0,Mf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Nn(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){In(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}he(b);fb=f+16|0;lZ(a,c);_f(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}function eU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;j=e,k=$j(b),x[j+4>>2]=k;c=fb-16|0;fb=c;f=LB(a,c+12|0,z[b>>1],x[b+4>>2]);b=x[f>>2];if(!b){b=fb-16|0;fb=b;d=ec(a);g=Dh(c,Ec(36),Mg(b+8|0,d));d=x[g>>2]+16|0;h=x[e+4>>2];i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;Nb(d+8|0);j=ec(g),k=1,v[j+4|0]=k;fb=b+16|0;$g(a,x[c+12>>2],f,x[c>>2]);b=le(c);jU(c);d=1}_g(e+8|0,x[vb(c,b)>>2],d);fb=c+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+8|0}function Ooa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=Xc(c+12|0,16,1,1,0);x[c+8>>2]=0;ld(a,0);xc(b);a:{b:{if(Tr(b,13822)){cd(b,12);if(!vp(b)){Dp(d,2)}cd(b,24);break b}if(kk(b,13709)){xc(b);x[c+8>>2]=4;e=1;break a}fd(d,8)}e=0}f=a,g=(lf(b)>>>0)/(D(y[d|0],qr(y[d+1|0]))>>>3>>>0)|0,x[f>>2]=g;b=fg(d,a,b);if(!(!b|!e)){d=x[a+20>>2];f=c,g=Xk(x[a>>2],z[a+34>>1]),x[f+4>>2]=g;Tb(d,0,x[Gb(c+8|0,c+4|0)>>2])}fb=c+16|0;return(b|0)!=0|0}function $fa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;x[31725]=0;W(1027,a|0);f=x[31725];x[31725]=0;a:{b:{if((f|0)!=1){f=x[a+28>>2];g=x[x[f>>2]+72>>2];x[31725]=0;b=Ta(g|0,f|0,b|0,c|0,+d,+e)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11298,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function b3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;pw(c,b);x[a+44>>2]=0;b=x[a+48>>2];if(b&8){b=Kb(c)+Cb(x[a+36>>2],y[a+43|0])|0;x[a+44>>2]=b;d=Kb(c);no(a,d,d,b);b=x[a+48>>2]}a:{if(!(b&16)){break a}b=Cb(x[a+36>>2],y[a+43|0]);e=a,f=b+Kb(c)|0,x[e+44>>2]=f;eC(c,Mc(c));c=Kb(c);Ny(a,c,Cb(x[a+36>>2],y[a+43|0])+c|0);if(!(y[a+48|0]&3)){break a}while(1){if((b|0)<0){Ct(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}Ct(a,b)}}function $aa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;e=f+4|0;x[e+4>>2]=1;h=e,i=Ec(56),x[h+8>>2]=i;c=zm(x[e+8>>2]);x[c>>2]=77472;g=nc(c);c=fb-16|0;fb=c;d=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=d;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=EM(g);x[d>>2]=77636;b=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=b;b=x[c+12>>2];x[d+32>>2]=x[c+8>>2];x[d+36>>2]=b;v[d+40|0]=0;fb=c+16|0;b=a;a=Yn(e);Xn(b,nc(a),a);Am(e);fb=f+16|0}function xaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;x[e+44>>2]=d;x[e+40>>2]=d;a=Se(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[a+8>>2];d=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=d;Re(e+24|0,e);a:{while(1){if((b|0)==(c|0)){break a}x[31725]=0;O(1166,x[e+44>>2],b|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[e+44>>2]=x[e+44>>2]+12;b=b+12|0;continue}break}a=N()|0;qM(e+24|0);Q(a|0);p()}a=e+24|0;Qe(a);b=x[e+44>>2];qM(a);fb=e+48|0;return b|0}function vl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;x[b>>2]=0;x[b+4>>2]=0;v[e+15|0]=0;ni(a,e+15|0);c=y[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){x[b>>2]=f;x[b+4>>2]=d;if(!h&(g|0)==(i|0)){fb=e+16|0}else{v[e+15|0]=0;ni(a,e+15|0);d=x[b>>2];j=x[b+4>>2];f=y[e+15|0];c=h;g=g+1|0;h=g?c:c+1|0;k=d;c=(g<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=f<<d;d=0}else{c=(1<<d)-1&f>>>32-d;d=f<<d}f=k|d;d=c|j;continue}break}}function ata(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;a:{if(z[a+480192>>1]<b>>>0){break a}b=x[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+4|0;q_(h,b);j=g,k=wb(x[g+4>>2]),x[j>>2]=k;h=rg(h);i=z[a+480190>>1];while(1){b=x[g>>2];if(!Ib(b,h)){Tv(g+4|0);break a}b=z[jp(b)>>1];if(b>>>0<=i>>>0){b=D(b,104)+a|0;v[b+484421|0]=f;v[b+484418|0]=c;v[b+484420|0]=e;v[b+484419|0]=d}ah(g);continue}}fb=g+16|0}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;x[e+44>>2]=d;x[e+40>>2]=d;a=Se(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[a+8>>2];d=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=d;Re(e+24|0,e);a:{while(1){if((b|0)==(c|0)){break a}x[31725]=0;O(1130,x[e+44>>2],b|0);a=x[31725];x[31725]=0;if((a|0)!=1){x[e+44>>2]=x[e+44>>2]+16;b=b+16|0;continue}break}a=N()|0;nN(e+24|0);Q(a|0);p()}a=e+24|0;Qe(a);b=x[e+44>>2];nN(a);fb=e+48|0;return b|0}function ema(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Lg(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;a:{b:{d=b-d|0;b=x[zb(a)>>2];f=x[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){ZB(a,d,c);break c}b=zb(a);b=gv(e+12|0,ar(a,Lg(x[a>>2],f)+d|0),Lg(x[a>>2],x[a+4>>2]),b);x[31725]=0;S(788,b|0,d|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}$U(a,b);YB(b)}fb=e+32|0;break a}a=N()|0;YB(b);Q(a|0);p()}return}if(b>>>0<d>>>0){bV(a,e+(b<<5)|0)}}function Wu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;i=OB(x[a+24>>2],y[a+32|0]);g=Rj(i);j=65535;a:{while(1){if((d|0)==(g|0)){d=g;a=-1;break a}b:{c:{if(!cj(i,d&65535)){break c}e=x[a>>2];if(Ud(e,x[a+4>>2])>>>0<=d>>>0){break b}f=0;h=Hd(e,d);while(1){d:{e=x[h+4>>2];if(e>>>0>f>>>0){if(!BC(x[h>>2],f)){break d}e=x[h+4>>2]}if((f|0)==(e|0)){break b}break c}f=f+1|0;continue}}d=d+1|0;continue}break}j=d;a=0}w[b>>1]=j;x[c>>2]=a;return d>>>0<g>>>0}function cV(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function Hz(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=fb-48|0;fb=b;x[b+40>>2]=e;x[b+44>>2]=f;c=gc(b+32|0,c,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a:{a=Au(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ac(8);x[31725]=0;b=P(36,b+20|0,8057)|0;c=x[31725];x[31725]=0;b:{if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0);p()}fb=b+48|0;return a|0}p()}function fq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(2147483630-b>>>0>=c>>>0){k=Kb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Eh(x[ad(i+4|0,i+12|0)>>2])+1|0}else{c=2147483631}sg(j,c);c=x[i+4>>2];if(e){Cg(c,k,e)}if(g){Cg(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){Cg((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Db(k)}yd(a,c);pf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Yd(b,a);fd(a+c|0,0);fb=i+16|0;return}qf();p()}function Zq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(2147483630-b>>>0>=c>>>0){k=Kb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Eh(x[ad(i+4|0,i+12|0)>>2])+1|0}else{c=2147483631}sg(j,c);c=x[i+4>>2];if(e){Xg(c,k,e)}if(g){Xg(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){Xg((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Db(k)}yd(a,c);pf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Yd(b,a);fd(a+c|0,0);fb=i+16|0;return}qf();p()}function Of(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;i=ova(b,c,h,i);h=hb;e=ova(d,e,f,g);i=e+i|0;d=hb+h|0;h=e>>>0>i>>>0?d+1|0:d;j=g;e=0;k=c;d=0;c=ova(g,e,c,d);g=c+i|0;i=hb+h|0;l=g;c=c>>>0>g>>>0?i+1|0:i;g=ova(f,0,b,0);h=hb;i=0;d=ova(f,i,k,d);h=h+d|0;f=hb+i|0;f=d>>>0>h>>>0?f+1|0:f;i=f+l|0;d=c;f=f>>>0>i>>>0?d+1|0:d;c=ova(b,m,j,e)+h|0;e=hb;e=c>>>0<h>>>0?e+1|0:e;h=e+i|0;i=f;x[a+8>>2]=h;x[a+12>>2]=e>>>0>h>>>0?i+1|0:i;x[a>>2]=g;x[a+4>>2]=c}function mV(a,b,c,d){var e=0,f=0,g=0;g=fb-16|0;fb=g;d=$h(g+4|0,a,d);e=zb(a);a=fb+-64|0;fb=a;f=x[d+4>>2];x[a+56>>2]=f;x[a+60>>2]=b;x[a+52>>2]=f;e=Se(a+24|0,e,a+52|0,a+56|0);x[a+16>>2]=x[e+8>>2];f=x[e+4>>2];x[a+8>>2]=x[e>>2];x[a+12>>2]=f;Re(a+36|0,a+8|0);while(1){if(Ib(b,c)){gj(x[a+56>>2],z[b>>1]);b=Md(a+60|0);x[a+56>>2]=x[a+56>>2]+2;b=x[b>>2];continue}break}b=a+36|0;Qe(b);c=x[a+56>>2];oE(b);fb=a- -64|0;x[d+4>>2]=c;hc(d);fb=g+16|0}function x$(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(D(b,6)+a|0)+1072|0,g=il(a,7),v[f|0]=g;d=il(a,1);e=il(a,1);c=x[a+1060>>2];if((c|0)>255){break a}b=x[a+1064>>2]+1|0;x[a+1060>>2]=b;x[a+1064>>2]=b;b:{if(d){w[(D(c,6)+a|0)+1068>>1]=b;x$(a);b=x[a+1064>>2];break b}w[(D(c,6)+a|0)+1068>>1]=65535}x[a+1060>>2]=b;if(e){w[(D(c,6)+a|0)+1070>>1]=b;continue}break}w[(D(c,6)+a|0)+1070>>1]=65535}}function XD(a,b,c,d){var e=0,f=0,g=0;g=fb-16|0;fb=g;d=am(g+4|0,a,d);e=zb(a);a=fb+-64|0;fb=a;f=x[d+4>>2];x[a+56>>2]=f;x[a+60>>2]=b;x[a+52>>2]=f;e=Se(a+24|0,e,a+52|0,a+56|0);x[a+16>>2]=x[e+8>>2];f=x[e+4>>2];x[a+8>>2]=x[e>>2];x[a+12>>2]=f;Re(a+36|0,a+8|0);while(1){if(Ib(b,c)){Fl(x[a+56>>2],y[b|0]);b=me(a+60|0);x[a+56>>2]=x[a+56>>2]+1;b=x[b>>2];continue}break}b=a+36|0;Qe(b);c=x[a+56>>2];d$(b);fb=a- -64|0;x[d+4>>2]=c;hc(d);fb=g+16|0}function $na(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;h=x[a+16>>2];f=mg(1,2);e=hb;i=e;Pb(a,f,e);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){g=w[(x[b+12>>2]<<1)+h>>1];x[c>>2]=x[c>>2]+D(g,k);x[c+4>>2]=x[c+4>>2]+D(j,g);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Hg(a,f,i);fb=b+16|0}function hu(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=ce(a);d=ec(a);f=fb-16|0;fb=f;while(1){if(c){g=Uu(c+16|0,b);d=g?d:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[vb(f+12|0,d)>>2];fb=f+16|0;a:{if(Ib(c,rg(a))){if(!Uu(b,td(c))){break a}}c=rg(a)}if(!lc(c,rg(a))){b=x[vb(e+12|0,c)>>2];c=fb-16|0;fb=c;d=ah(vb(c+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[d>>2]}d=zb(a);x[d>>2]=x[d>>2]-1;rV(x[ec(a)>>2],b);fb=c+16|0;hn(td(b));Db(b)}fb=e+16|0}function cga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31725]=0;W(1027,a|0);e=x[31725];x[31725]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+12>>2];x[31725]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11443,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function uK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[31600];x[31600]=0;Od();a=xy(a,e+12|0,d);d=hb;g=x[31600];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}x[31600]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d){break b}}x[c>>2]=4;a=-1;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a}function bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31725]=0;W(1027,a|0);e=x[31725];x[31725]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+8>>2];x[31725]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11479,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function jc(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{c=ql(a);a=c;if(a>>>0<502720&a>>>0>=502208){b=c-4|0;e=x[125550];d=e;while(1){a=d;if(!(!a|(a|0)==502720)){if((sI(a)|0)==(b|0)){w[a+2>>1]=z[c-2>>1]+z[a+2>>1];break a}if((sI(b)|0)==(a|0)){d=c-2|0;w[d>>1]=z[a+2>>1]+z[d>>1];if(!f){x[125550]=b;w[b>>1]=z[a>>1];break a}g=f,h=Qx(b),w[g>>1]=h;break a}else{d=Rx(z[a>>1]);f=a;continue}}break}g=b,h=Qx(e),w[g>>1]=h;x[125550]=b;break a}Db(c)}}function aoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;h=x[a+16>>2];f=mg(1,2);e=hb;i=e;Pb(a,f,e);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){g=v[x[b+12>>2]+h|0]<<8;x[c>>2]=x[c>>2]+D(g,k);x[c+4>>2]=x[c+4>>2]+D(j,g);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Hg(a,f,i);fb=b+16|0}function KH(a,b,c,d,e,f){var g=0,h=0;g=fb-256|0;fb=g;x[g+248>>2]=37;x[g+252>>2]=0;h=g+248|0;ht(h|1,10616,f,x[b+4>>2]);f=Od();x[g>>2]=d;x[g+4>>2]=e;d=g+224|0;e=rh(d,24,f,h,g)+d|0;f=tj(d,e,x[b+4>>2]);h=g+20|0;bd(h,x[b+28>>2]);x[31725]=0;ga(1233,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[31725];x[31725]=0;a:{if((d|0)!=1){Zb(g+20|0);a=ft(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);fb=g+256|0;break a}a=N()|0;Zb(g+20|0);Q(a|0);p()}return a}function zF(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((y[a|0]|y[a+1|0]<<8)!=26215|(y[a+514|0]-16&255)>>>0<241|y[a+515|0]>128){break a}d=a+514|0;c=a+2|0;while(1){if((c|0)!=(d|0)){f=zb(c);b=c;while(1){if((b|0)!=(f|0)){g=y[b|0];b=b+1|0;if(g>>>0>31){continue}break a}break}c=c+8|0;continue}break}d=a+772|0;b=a+516|0;c=-1;while(1){e=(b|0)==(d|0);if(e){break a}a=c;c=y[b|0]|y[b+1|0]<<8;a=(a|0)<(c|0);b=b+2|0;if(a){continue}break}}return e}function g1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[d+12>>2]=-1;if(gh(a,d+11|0)){x[d+4>>2]=y[d+11|0];f=x[Gb(d+4|0,d+12|0)>>2];c=fb+-64|0;fb=c;e=c+44|0;ug(e,a,f);g=x[c+44>>2];a=c+20|0;wg(a,3,$e(e),g);x[31725]=0;O(220,c+32|0,a|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){a=c+12|0;gc(a,b,11);b=a;a=c+32|0;um(b,a);tb(a);Kc(c+44|0);fb=c- -64|0;e=!f|(g|0)!=0;break a}a=N()|0;Kc(c+44|0);Q(a|0);p()}}fb=d+16|0;return e|0}function VW(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+4>>2]=((y[a+48|0]|y[a+49|0]<<8)<<1)+((y[a+32|0]|y[a+33|0]<<8)<<4);x[b+8>>2]=((y[a+50|0]|y[a+51|0]<<8)<<1)+((y[a+34|0]|y[a+35|0]<<8)<<4);x[b+12>>2]=(D(y[a+52|0]|y[a+53|0]<<8,5)+((y[a+36|0]|y[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=yb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=dr(x[a>>2],x[c>>2])?c:a;continue}}fb=b+16|0;a=x[a>>2];hb=a>>31;return a}function Saa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=zm(a);x[e>>2]=76972;d=nc(e);a=fb-16|0;fb=a;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;b=fb-16|0;fb=b;c=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=c;c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;d=xM(d,yM(b));x[d>>2]=77136;c=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=c;c=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=c;fb=b+16|0;fb=a+16|0;return e|0}function MH(a,b,c,d,e,f){var g=0,h=0;g=fb-112|0;fb=g;x[g+104>>2]=37;x[g+108>>2]=0;h=g+104|0;ht(h|1,10616,f,x[b+4>>2]);f=Od();x[g>>2]=d;x[g+4>>2]=e;d=g+80|0;e=rh(d,24,f,h,g)+d|0;f=tj(d,e,x[b+4>>2]);h=g+20|0;bd(h,x[b+28>>2]);x[31725]=0;ga(1230,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[31725];x[31725]=0;a:{if((d|0)!=1){Zb(g+20|0);a=ow(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);fb=g+112|0;break a}a=N()|0;Zb(g+20|0);Q(a|0);p()}return a}function Zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[31725]=0;W(1027,a|0);d=x[31725];x[31725]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+64>>2];x[31725]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,6695,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[31725]=0;W(1027,a|0);d=x[31725];x[31725]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+56>>2];x[31725]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,6749,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Tr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=gc(c+8|0,c+24|0,7);kc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(kd(c+24|0,b,7)){break b}Vb(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17491,9079,601,13222);p()}_(17470,9079,599,13222);p()}return d|0}function Kra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=Uf(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;a:{b:{c=b-c|0;b=x[zb(a)>>2];e=x[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){WE(a,c);break c}b=zb(a);b=QD(d+12|0,RD(a,Uf(x[a>>2],e)+c|0),Uf(x[a>>2],x[a+4>>2]),b);x[31725]=0;O(522,b|0,c|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}PD(a,b);Yv(b)}fb=d+32|0;break a}a=N()|0;Yv(b);Q(a|0);p()}return}if(b>>>0<c>>>0){SE(a,d+D(b,20)|0)}}function xg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;w[d+12>>1]=65535;w[d+14>>1]=b;f=d+12|0;b=z[Nc(41420,d+14|0)>>1];e=x[a>>2];c=Zc(e,x[a+4>>2]);a:{if(b>>>0>c>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];g=x[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){Ap(a,b,f);break b}c=zb(a);c=ok(e+12|0,pk(a,Zc(x[a>>2],g)+b|0),Zc(x[a>>2],x[a+4>>2]),c);rF(c,b,f);Yr(a,c);kj(c)}fb=e+32|0;break a}if(b>>>0<c>>>0){Kn(a,e+(b<<1)|0)}}fb=d+16|0}function HV(a,b,c,d){var e=0,f=0,g=0;a:{b:{if(!((c|0)==255|(b|0)!=11)){e=c+1|0;f=11;break b}if((b&254)==16){e=c&15|b<<4|-128;f=14;break b}if((b|0)==18){break b}e=c;f=b;if(b>>>0>18){break a}}Bf(a,f,e&255);b=y[a+3|0];c:{d:{if(!((d|0)!=4|(b|0)!=13)){b=y[a+5|0];if(b&3?(b|0)!=255:0){break d}v[a+5|0]=b+3>>>2;return 1}if((b&255)!=13){break c}}b=46;v[a+3|0]=46}g=1;if((d|0)==4|(b&255)!=17|y[a+5|0]!=32){break a}v[a+3|0]=16}return g}function ve(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=lh(a);a:{b:{if(!b){i=e,j=lh(a),x[i+8>>2]=j;x[e+12>>2]=0;break b}g=x[b>>2];b=x[b+4>>2];h=b;x[e+8>>2]=g;x[e+12>>2]=b;a=x[a+12>>2];x[e>>2]=2048;x[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=_r(e+8|0,e);c=x[a>>2];a=x[a+4>>2];if(!a&c>>>0>f>>>0|a){a=-1;if(!d&b>>>0<=f>>>0){break b}break a}a=0;if((d|0)==(h|0)&b>>>0>g>>>0|d>>>0>h>>>0){break a}}a=1}fb=e+16|0;return a}function ru(a){var b=0,c=0,d=0;b=y[a+4266|0];B[a+4236>>2]=E(b>>>0)*E(.00390625);B[a+4240>>2]=E(256-b|0)*E(.00390625);c=y[a+4267|0];b=y[a+4265|0];B[a+4244>>2]=E(D(c,b)|0)*E(152587890625e-16);d=c|-256;B[a+4256>>2]=E(D(d,b|-256)|0)*E(152587890625e-16);B[a+4252>>2]=E(D(b,d)|0)*E(152587890625e-16);B[a+4248>>2]=E(D(256-b|0,c)|0)*E(152587890625e-16);b=a;c=x[a+4232>>2];a=y[a+4264|0];x[b+4228>>2]=(D(c,(a?a:-89)&255)+250>>>0)/500}function k4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-32|0;fb=f;g=jo(f+20|0,b,c);x[31725]=0;e=U(1364,f+8|0,d|0,e|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){a=Kb(g);d=Kb(e);b=x[d>>2];c=x[a>>2];a:{if(!b|!c|(b|0)!=(c|0)){break a}while(1){b=x[d+4>>2];c=x[a+4>>2];if(!b|!c){break a}d=d+4|0;a=a+4|0;if((b|0)==(c|0)){continue}break}}Qb(e);Qb(g);fb=f+32|0;a=c-b|0;return((a|0)<0?-1:(a|0)!=0)|0}a=N()|0;Qb(g);Q(a|0);p()}function C3(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;x[31725]=0;m=a;a=0;a=jI(1099,m|a,b,c,d,a|e,f);b=x[31725];x[31725]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31725]=0;ga(985,8843,g|0,h|0,i|0,j|0,k|0,l|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return a|0}function aV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=fb-16|0;fb=g;d=$h(g+4|0,a,d);e=zb(a);a=fb-48|0;fb=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=Se(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Re(a+24|0,a);while(1){if((b|0)!=(c|0)){gj(x[a+44>>2],z[b>>1]);x[a+44>>2]=x[a+44>>2]+2;b=b+2|0;continue}break}b=a+24|0;Qe(b);c=x[a+44>>2];oE(b);fb=a+48|0;x[d+4>>2]=c;hc(d);fb=g+16|0}function wv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=fb-16|0;fb=g;d=am(g+4|0,a,d);e=zb(a);a=fb-48|0;fb=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=Se(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Re(a+24|0,a);while(1){if((b|0)!=(c|0)){Fl(x[a+44>>2],y[b|0]);x[a+44>>2]=x[a+44>>2]+1;b=b+1|0;continue}break}b=a+24|0;Qe(b);c=x[a+44>>2];d$(b);fb=a+48|0;x[d+4>>2]=c;hc(d);fb=g+16|0}function hba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;c=fb-16|0;fb=c;h=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;HM(a,c);a:{f=C[a+24>>3];if(f==1){break a}i=E(f);d=x[b+4>>2];j=x[b+8>>2];b:while(1){if((e|0)==(j|0)){break a}k=D(x[a+16>>2],e+h|0);l=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{g=(b+k<<2)+l|0;B[g>>2]=B[g>>2]*i;b=b+1|0;continue}}}fb=c+16|0}function XL(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=E(0),p=0;c=B[a>>2];i=a-16|0;d=B[i>>2];e=E(c+d);b=a-8|0;f=B[b>>2];j=a-24|0;g=B[j>>2];h=E(f+g);B[a>>2]=e+h;B[b>>2]=e-h;b=a-12|0;h=B[b>>2];k=a-28|0;l=B[k>>2];e=E(h+l);p=b;b=a-4|0;m=B[b>>2];a=a-20|0;n=B[a>>2];o=E(m+n);B[p>>2]=o-e;f=E(f-g);g=E(m-n);B[k>>2]=f+g;c=E(c-d);d=E(h-l);B[i>>2]=c+d;B[j>>2]=c-d;B[b>>2]=e+o;B[a>>2]=g-f}function fu(a,b,c,d,e){var f=0,g=0;a:{if(!St(b)){break a}f=x[a+484344>>2];if(!He(f,x[a+484348>>2],b&65535)){break a}b=Wb(f,b);if(x[b+12>>2]<=(c|0)|e>>>0>5|z[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=jd(x[b>>2],x[x[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=y[b|0]}return g}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+12>>2];f=x[a+16>>2];b:{if(d>>>0<f>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=f-d>>2;x[e+4>>2]=c-g;f=d;d=x[ud(e+12|0,ud(e+8|0,e+4|0))>>2];b=Zi(b,f,d);f=d<<2;x[a+12>>2]=f+x[a+12>>2];b=b+f|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}x[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}fb=e+16|0;return g|0}function MO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ac(8);x[31725]=0;b=P(36,h+4|0,8200)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}Kl(a,b,4);c=sz(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}d=N()|0;jc(a)}Q(d|0)}p()}function EO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ac(8);x[31725]=0;b=P(36,h+4|0,8200)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}Kl(a,b,4);c=uz(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}d=N()|0;jc(a)}Q(d|0)}p()}function D3(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;b=tc(c+8|0,16781);x[31725]=0;S(100,c+20|0,a|0,b|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){tb(b);a=0;b=0;while(1){d=x[c+20>>2];if(!(b>>>0<=3&Ud(d,x[c+24>>2])>>>0>b>>>0)){Td(c+20|0);fb=c+32|0;return a|0}x[31725]=0;d=R(101,Hd(d,b)|0)|0;e=x[31725];x[31725]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=N()|0;Td(c+20|0);break a}a=N()|0;tb(b)}Q(a|0);p()}function Vfa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31725]=0;W(1027,a|0);d=x[31725];x[31725]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+48>>2];x[31725]=0;ra(f|0,d|0,b|0,+c);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11678,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Lfa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31725]=0;W(1027,a|0);d=x[31725];x[31725]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+96>>2];x[31725]=0;ra(f|0,d|0,b|0,+c);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11616,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Jfa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31725]=0;W(1027,a|0);d=x[31725];x[31725]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+88>>2];x[31725]=0;ra(f|0,d|0,b|0,+c);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11066,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function t0(a){a=a|0;var b=0,c=0,d=0;b=x[a>>2];if(b){DQ(x[b+12>>2],b);b=x[a>>2];ib[x[x[b>>2]+8>>2]](b);x[a>>2]=0}a=a+4|0;gp(a);b=fb-32|0;fb=b;a:{b:{d=ep(a);c=Sc(x[a>>2],x[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}x[31725]=0;c=ba(956,b+12|0,c|0,c|0,zb(a)|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){ir(a,c);un(c);break c}Y(T(0)|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break b}}fb=b+32|0;break a}T(0)|0;Sb();p()}}function qba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;c=fb-16|0;fb=c;h=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;NM(a,c);a:{f=C[a+24>>3];if(f==1){break a}i=E(f);d=x[b+4>>2];j=x[b+8>>2];b:while(1){if((e|0)==(j|0)){break a}k=e+h|0;l=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{g=x[(b<<2)+l>>2]+(k<<2)|0;B[g>>2]=B[g>>2]*i;b=b+1|0;continue}}}fb=c+16|0}function baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+16>>2];d=x[a+12>>2];b:{if(g>>>0>d>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=g-d;x[e+4>>2]=c-f;g=d;d=x[ud(e+12|0,ud(e+8|0,e+4|0))>>2];b=Cg(b,g,d);x[a+12>>2]=x[a+12>>2]+d;b=b+d|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b|0]=d<<24>>24;d=1;b=b+1|0}f=d+f|0;continue}break}fb=e+16|0;return f|0}function m8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=fb-208|0;fb=a;f=Od();x[a>>2]=e;g=a+176|0;i=rh(g,20,f,9262,a);e=i+g|0;g=tj(g,e,x[c+4>>2]);bd(a+12|0,x[c+28>>2]);x[31725]=0;f=R(1217,x[a+12>>2])|0;h=x[31725];x[31725]=0;if((h|0)!=1){Zb(a+12|0);h=f;f=a+16|0;mK(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=ft(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);fb=a+208|0;return b|0}b=N()|0;Zb(a+12|0);Q(b|0);p()}function bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-32|0;fb=f;d=f+8|0;We(d,2,a+6|0);e=f+20|0;Cc(e,d);zc(b+492|0,e);d=b+236|0;g=c+1|0;tb(e);c=0;while(1){if((c|0)==128){x[b>>2]=(y[a+226|0]|y[a+227|0]<<8)<<5;vA(a+180|0,b+48|0,0);vA(a+228|0,b+88|0,2);vA(a+276|0,b+68|0,1);if(!(y[a+324|0]|y[a+325|0]<<8)){Tb(d,0,256)}fb=f+32|0}else{e=y[(a+c|0)+38|0];h=_b(d,c),i=e+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function q2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;f=g+4|0;x[f+4>>2]=1;j=f,k=Ec(32),x[j+8>>2]=k;e=zm(x[f+8>>2]);x[e>>2]=41432;h=nc(e);e=fb-16|0;fb=e;b=xm(e+8|0,x[b>>2],x[b+4>>2]);d=x[d>>2];c=x[c>>2];i=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=i;b=Wn(h);x[b>>2]=41568;xm(b+4|0,x[e>>2],x[e+4>>2]);x[b+16>>2]=d;x[b+12>>2]=c;ke(e);fb=e+16|0;b=a;a=Yn(f);Xn(b,nc(a),a);Am(f);fb=g+16|0}function pU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;x[a+4>>2]=0;a:{if(b){b:{if(fv(a)>>>0>=b>>>0){x[a+4>>2]=b;break b}e=Zo(d+20|0);x[31725]=0;f=P(761,a|0,b|0)|0;g=x[31725];x[31725]=0;if((g|0)==1){break a}x[31725]=0;O(762,e|0,f|0);f=x[31725];x[31725]=0;if((f|0)==1){break a}x[e+4>>2]=b;iC(a,e);uf(e)}tn(d+12|0,x[a>>2]);Qw(x[d+12>>2],x[d+16>>2],b,y[c|0])}fb=d+32|0;return}a=N()|0;uf(e);Q(a|0);p()}function Zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ri(a,b,c,d);x[a>>2]=43620;c=Nb(a+4256|0);b=a+4208|0;e=yb(b,0),f=1056964608,x[e>>2]=f;e=yb(b,1),f=1017370378,x[e>>2]=f;e=yb(b,2),f=1028670828,x[e>>2]=f;e=yb(b,3),f=1059760811,x[e>>2]=f;e=yb(b,4),f=1017370378,x[e>>2]=f;e=yb(b,5),f=1065353216,x[e>>2]=f;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;uc(c);ag(a);Q(b|0);p()}function WL(a,b){var c=0,d=0,e=0;if(!y[b+21|0]){fc(a,21);return-1}if(x[a+1396>>2]<=9){El(a)}d=x[a+1392>>2];c=w[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=y[d+x[b+8>>2]|0];x[a+1392>>2]=e>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break a}c=Om(a,b)}if(!((c|0)>=x[b+2092>>2]?y[b+23|0]:0)){if(!(!(x[a+1384>>2]?y[a+1376|0]:1)|(c|0)>=0)){fc(a,21)}return c}_(7566,13258,1793,5750);p()}function LH(a,b,c,d,e){var f=0,g=0,h=0;f=fb-144|0;fb=f;x[f+136>>2]=37;x[f+140>>2]=0;g=f+136|0;ht(g|1,10783,e,x[b+4>>2]);e=Od();x[f>>2]=d;d=f+123|0;e=rh(d,13,e,g,f)+d|0;g=tj(d,e,x[b+4>>2]);h=f+4|0;bd(h,x[b+28>>2]);x[31725]=0;ga(1233,d|0,g|0,e|0,f+16|0,f+12|0,f+8|0,h|0);d=x[31725];x[31725]=0;a:{if((d|0)!=1){Zb(f+4|0);a=ft(a,f+16|0,x[f+12>>2],x[f+8>>2],b,c);fb=f+144|0;break a}a=N()|0;Zb(f+4|0);Q(a|0);p()}return a}function JA(a,b,c){if(Ob(a+1074312|0,21)){c=c&255;a:{switch((b&3)-1|0){default:return v[c+31872|0];case 0:return 64-(c+1>>>1|0)|0;case 1:return(c>>>0<128)<<6;case 2:break a}}return YR(Ko(a))+-64|0}if(z[a+480182>>1]&1032){return v[(c>>>1&31)+30528|0]}a=c&63;b:{switch((b&3)-1|0){default:return v[a+31744|0];case 0:return(a>>>0>=32?255:0)-(a<<2)|0;case 1:return a>>>0<32?127:-127;case 2:break b}}return v[a+31808|0]}function ez(a){var b=0,c=0,d=0;a:{b:{if(!x[a+1384>>2]){b=x[a+1380>>2];if((b|0)==-1){x[a+1388>>2]=x[a+1116>>2]-1;if(!Pt(a)){x[a+1384>>2]=1;return 0}if(!(v[a+1375|0]&1)){break b}b=x[a+1380>>2]}d=b+1|0;x[a+1380>>2]=d;c=y[(a+b|0)+1120|0];if((c|0)!=255){x[a+1388>>2]=b;x[a+1384>>2]=1}if(x[a+1116>>2]<=(d|0)){x[a+1380>>2]=-1}if(y[a+1376|0]){break a}v[a+1376|0]=c}return c}fc(a,32);return 0}_(15794,13258,1564,6036);p()}function uD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=fb-16|0;fb=c;if(Mb(x[a>>2],x[a+8>>2],b)){while(1){if((d|0)==4){Rm(c+4|0,x[c+12>>2]);d=x[c+4>>2]}else{v[c+11|0]=0;b:{if(b>>>0>d>>>0){gh(a,c+11|0);e=v[c+11|0];g=e>>>31|0;break b}e=0-g|0}v[(c+12|0)+d|0]=e;d=d+1|0;continue}break}}fb=c+16|0;c=d;break a}c=Pg(a);Vb(a,b-4|0)}v[f|0]=c}function Ppa(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;v[b+15|0]=128;a=ew(a,127,b+15|0);x[31725]=0;v[b+14|0]=64;d=U(601,a+12|0,127,b+14|0)|0;c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){x[31725]=0;v[b+13|0]=0;P(681,a+24|0,b+13|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}x[a+44>>2]=0;x[a+48>>2]=0;x[a+36>>2]=-1;x[a+40>>2]=108855296;w[a+52>>1]=0;fb=b+16|0;return a|0}b=N()|0;break a}b=N()|0;dc(d)}dc(a);Q(b|0);p()}function NH(a,b,c,d,e){var f=0,g=0,h=0;f=fb+-64|0;fb=f;x[f+56>>2]=37;x[f+60>>2]=0;g=f+56|0;ht(g|1,10783,e,x[b+4>>2]);e=Od();x[f>>2]=d;d=f+43|0;e=rh(d,13,e,g,f)+d|0;g=tj(d,e,x[b+4>>2]);h=f+4|0;bd(h,x[b+28>>2]);x[31725]=0;ga(1230,d|0,g|0,e|0,f+16|0,f+12|0,f+8|0,h|0);d=x[31725];x[31725]=0;a:{if((d|0)!=1){Zb(f+4|0);a=ow(a,f+16|0,x[f+12>>2],x[f+8>>2],b,c);fb=f- -64|0;break a}a=N()|0;Zb(f+4|0);Q(a|0);p()}return a}function NF(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=e+8|0;d=fb-32|0;fb=d;Id(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(pd(b,h)){b=xf(b);c=xf(x[a+8>>2]);v[c+2|0]=y[b+2|0];w[c>>1]=z[b>>1];b=Ni(a+12|0);Ni(a+8|0);b=x[b>>2];continue}break}Ac(g,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function Kta(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;x[h+12>>2]=d;g=Cb(x[a+4>>2],y[a+11|0]);f=Mc(a);a:{if(f-g>>>0>=b>>>0){f=Kb(a);if((c|0)==(g|0)){break a}i=c+f|0;Vi(i+b|0,i,g-c|0);break a}Xm(a,f,(b+g|0)-f|0,g,c,0,b);f=x[a>>2]}b=b+g|0;ng(a,b);fd(b+f|0,0);b=c+f|0;while(1){if(Ib(d,e)){fd(b,y[d|0]);b=b+1|0;d=x[me(h+12|0)>>2];continue}break}a=Pe(zd(a),c);fb=h+16|0;return a|0}function w8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=fb-96|0;fb=a;f=Od();x[a>>2]=e;g=a- -64|0;i=rh(g,20,f,9262,a);e=i+g|0;g=tj(g,e,x[c+4>>2]);bd(a+12|0,x[c+28>>2]);x[31725]=0;f=R(28,x[a+12>>2])|0;h=x[31725];x[31725]=0;if((h|0)!=1){Zb(a+12|0);h=f;f=a+16|0;rK(h,a- -64|0,e,f);h=b;b=f+i|0;b=ow(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);fb=a+96|0;return b|0}b=N()|0;Zb(a+12|0);Q(b|0);p()}function aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+76>>2];x[31725]=0;O(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11308,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+16>>2];x[31725]=0;O(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,12847,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Ifa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+84>>2];x[31725]=0;O(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,12330,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Hfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+80>>2];x[31725]=0;O(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11152,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Gfa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+104>>2];x[31725]=0;la(e|0,c|0,+b);c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,15123,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);d=x[31725];x[31725]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function eea(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0;d=fb-48|0;fb=d;x[d+44>>2]=c;c=Nd(d+16|0);x[31725]=0;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;S(1121,d+24|0,a|0,d|0);a=x[31725];x[31725]=0;a:{b:{if((a|0)!=1){a=x[re(d+12|0,d+44|0)>>2];x[31725]=0;b=+pa(987,d+24|0,+b,a|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}ub(d+24|0);Vc(d+44|0);fb=d+48|0;return+b}c=N()|0;break a}c=N()|0;ub(d+24|0)}Vc(d+44|0);Q(c|0);p()}function Tfa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+40>>2];x[31725]=0;la(e|0,c|0,+b);c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11716,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);d=x[31725];x[31725]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Ofa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+20>>2];x[31725]=0;O(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,9312,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Mfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+100>>2];x[31725]=0;d=+qa(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11634,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Wfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+52>>2];x[31725]=0;d=+qa(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11697,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Rfa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+32>>2];x[31725]=0;la(e|0,c|0,+b);c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7777,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);d=x[31725];x[31725]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Pfa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+24>>2];x[31725]=0;la(e|0,c|0,+b);c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7725,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);d=x[31725];x[31725]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Kx(a,b,c){var d=0,e=0,f=0,g=0;e=Kb(a);a=Cb(x[a+4>>2],y[a+11|0]);d=Kb(b);b=Cb(x[b+4>>2],y[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}c=c+e|0;a=a+e|0;b=b+d|0;b:{if((b|0)==(d|0)){break b}c:{b=b-d|0;if((b|0)>(a-c|0)){break c}g=y[d|0];while(1){f=a-c|0;if((f|0)<(b|0)){break c}c=Fu(c,(f-b|0)+1|0,g);if(!c){break c}if(!ZG(c,d,b)){break b}c=c+1|0;continue}}c=a}c=(a|0)==(c|0)?-1:c-e|0}else{c=-1}}return c}function Kfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+92>>2];x[31725]=0;d=+qa(e|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11086,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function EU(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[31725]=0;O(804,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}e=fb-16|0;fb=e;d=hv(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){hc(d);fb=e+16|0}else{Xl(b,0,0);b=b+16|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Qd(b);tU(b);fb=c+16|0;return a}a=N()|0;tU(c+8|0);Q(a|0);p()}function mB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Fk(a,b,b+700|0,0-(c<<2)|0,0);if(x[b+700>>2]<65536){break b}if(Ob(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function kk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=gc(c+8|0,c+28|0,4);kc(c+20|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);if(!(x[c+24>>2]!=4|x[c+28>>2]!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)))){Vb(a,4);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17491,9079,601,13222);p()}_(17470,9079,599,13222);p()}return d|0}function _fa(a,b){a=a|0;b=b|0;var c=0,d=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+68>>2];x[31725]=0;b=P(d|0,c|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,6722,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Yfa(a,b){a=a|0;b=b|0;var c=0,d=0;x[31725]=0;W(1027,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+60>>2];x[31725]=0;b=P(d|0,c|0,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,6773,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Oaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;a:{if(y[b+8|0]){f=x[b+12>>2];h=e,i=Sc(f,x[b+16>>2])-c|0,x[h+28>>2]=i;x[e+24>>2]=x[d+4>>2];g=x[Gb(e+28|0,e+24|0)>>2];f=Pe(wb(f),c);c=Pe(Pe(wb(x[b+12>>2]),c),g);b=x[d>>2];mp(f,c,b);bc(a,b,g);break a}g=x[d+4>>2];d=x[d>>2];x[e+16>>2]=d;x[e+20>>2]=g;f=x[x[b>>2]+40>>2];x[e+8>>2]=d;x[e+12>>2]=g;ib[f|0](a,b,c,e+8|0)}fb=e+32|0}function OF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=e+8|0;d=fb-32|0;fb=d;Id(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(pd(b,h)){b=On(b);i=On(x[a+8>>2]),j=z[b>>1],w[i>>1]=j;b=jj(a+12|0);jj(a+8|0);b=x[b>>2];continue}break}Ac(g,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function $9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+28>>2];d=x[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=Pf(v[b|0]),h=x[x[a>>2]+52>>2],ib[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{x[e+12>>2]=g-d;x[e+8>>2]=c-f;g=d;d=x[ud(e+12|0,e+8|0)>>2];Cg(g,b,d);x[a+24>>2]=d+x[a+24>>2];f=f+d|0;b=b+d|0}continue}break}fb=e+16|0;return f|0}function kf(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=dq(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(pI(a,b)&3){case 0:c=dq(C[b>>3],C[b+8>>3]);break a;case 1:c=-eq(C[b>>3],C[b+8>>3],1);break a;case 2:c=-dq(C[b>>3],C[b+8>>3]);break a;default:break b}}c=eq(C[b>>3],C[b+8>>3],1)}a=c;fb=b+16|0;return a}function jk(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c)){break a}wc(f+12|0,65535);xg(a,z[f+12>>1]);c=wb(x[a>>2]);x[f+4>>2]=c;h=wb(x[a+4>>2]);while(1){if(!Ib(c,h)){break a}a=f+11|0;if(!gh(b,a)){fh(a)}a=y[f+11|0];w[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}w[c>>1]=g}c=x[Md(f+4|0)>>2];continue}}fb=f+16|0}function wO(a,b){var c=0;a:{b:{if((a^b)&3){c=y[b|0];break b}if(b&3){while(1){c=y[b|0];v[a|0]=c;if(!c){break a}a=a+1|0;b=b+1|0;if(b&3){continue}break}}c=x[b>>2];if((c^-1)&c-16843009&-2139062144){break b}while(1){x[a>>2]=c;c=x[b+4>>2];a=a+4|0;b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}v[a|0]=c;if(!(c&255)){break a}while(1){c=y[b+1|0];v[a+1|0]=c;a=a+1|0;b=b+1|0;if(c){continue}break}}}function koa(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=hC(c+4|0,a);Rm(x[a+4>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Rm(x[c+8>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[c+8>>2]=x[c+8>>2]+4;lZ(a,c);_f(c);fb=d+32|0}function XW(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=e+8|0;d=fb-32|0;fb=d;Id(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(pd(b,h)){b=HW(b);i=HW(x[a+8>>2]),j=y[b|0],v[i|0]=j;b=tC(a+12|0);tC(a+8|0);b=x[b>>2];continue}break}Ac(g,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function bv(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[b+40>>2]=0;x[b+44>>2]=0;f=b- -64|0;x[f>>2]=0;x[f+4>>2]=0;x[b+56>>2]=0;x[b+60>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=wb(x[c>>2]);x[e+12>>2]=d;f=wb(x[c+4>>2]);while(1){if(!Ib(d,f)){break a}g=d,h=vU(b,C[d>>3]),C[g>>3]=h;d=x[_u(e+12|0)>>2];continue}}}else{vU(b,C[Ve(x[c>>2],0)>>3]);d=d+1|0;continue}break}$l(a,c);fb=e+16|0}function yS(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];x[a>>2]=b;if(c){b=fb-16|0;fb=b;d=wb(x[c>>2]);x[b+12>>2]=d;f=wb(x[c+4>>2]);while(1){a:{b:{if(Ib(d,f)){while(1){a=x[d>>2];e=x[a>>2];if(!e){break b}DQ(a,e);a=x[x[e>>2]+8>>2];x[31725]=0;W(a|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){continue}break}T(0)|0;Sb();p()}a=uc(c);fb=b+16|0;break a}Eb(a+20|0);Eb(a+8|0);Db(a);d=x[Je(b+12|0)>>2];continue}break}Db(a)}}function lB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Fk(a,b,b+700|0,0-c|0,0);if(x[b+700>>2]<65536){break b}if(Ob(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function jsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);a:{b:{if(!c){Pc(e,a+32|0,5);d=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}d=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(d+1|0){case 0:case 2:d=fb-32|0;fb=d;v[d+31|0]=0;Dj(d+8|0,d+31|0);Sm(d+20|0,f,x[d+8>>2],x[d+12>>2]);v[b|0]=y[d+31|0];fb=d+32|0;break c;default:break d}}CZ(f,b,d)}f=c}gf(a,f);fb=e+16|0}function _ba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Xo(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31725]=0;O(112,a|0,zh(e,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){a:{while(1){if(zh(x[c+8>>2],y[c+15|0])>>>0>b>>>0){d=v[cc(c+4|0,b)|0];x[31725]=0;O(113,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}b=b+1|0;continue}break}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function ZH(a,b,c,d,e,f,g,h,i){var j=0;x[31725]=0;W(1002,a|0);j=x[31725];x[31725]=0;a:{b:{if((j|0)!=1){j=x[a+24>>2];x[31725]=0;b=sa(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,h|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function SA(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=0;v[a+1074368|0]=b;rS(a+1074332|0,b);a=a+906300|0;f=Ij(a);while(1){if((a|0)!=(f|0)){b=x[a>>2];if(b){c=E(1);d=x[b+20>>2];if(d){c=E(E(y[d+26|0])*E(.10000000149011612))}c=c<E(.10000000149011612)?E(1):c;if(ib[x[x[b>>2]+140>>2]](b)|0){d=x[b+16>>2];e=d+1074332|0;c=E(E(c/B[e+8>>2])*E(E(A[d+480232>>2])/B[e+20>>2]))}B[b+4196>>2]=c}a=a+160|0;continue}break}}function wo(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;$k(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31725]=0;O(112,a|0,zh(e,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){a:{b:{while(1){if(zh(x[c+8>>2],y[c+15|0])>>>0<=b>>>0){break b}d=v[cc(c+4|0,b)|0];x[31725]=0;O(113,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){b=b+1|0;continue}break}break a}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function KO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=ac(8);x[31725]=0;b=P(36,f+4|0,8200)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}Kl(a,b,2);c=sz(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=N()|0;jc(a)}Q(e|0)}p()}function DO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=ac(8);x[31725]=0;b=P(36,f+4|0,8200)|0;c=x[31725];x[31725]=0;if((c|0)==1){break c}pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}Kl(a,b,2);c=uz(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=N()|0;jc(a)}Q(e|0)}p()}function Ax(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;$k(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31725]=0;O(112,a|0,zh(e,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){a:{while(1){if(zh(x[c+8>>2],y[c+15|0])>>>0>b>>>0){d=v[cc(c+4|0,b)|0];x[31725]=0;O(113,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}b=b+1|0;continue}break}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function Aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[31725]=0;S(1098,d|0,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,10321,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function gI(a,b,c){a=Fb(a);x[31725]=0;O(c|0,a|0,4);c=x[31725];x[31725]=0;a:{b:{if((c|0)==1){break b}x[31725]=0;O(b|0,a|0,32);c=x[31725];x[31725]=0;if((c|0)==1){break b}x[31725]=0;O(b|0,a|0,10);c=x[31725];x[31725]=0;if((c|0)==1){break b}x[31725]=0;O(b|0,a|0,13);c=x[31725];x[31725]=0;if((c|0)==1){break b}x[31725]=0;O(b|0,a|0,9);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}b=N()|0;tb(a);Q(b|0);p()}}function eoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=fb-16|0;fb=b;d=-1;a:{if(!mh(a,1)){break a}e=Sr(a);if((e-5&255)>>>0>=253){while(1){if((f|0)==127){d=1;break a}c=fb-16|0;fb=c;bE(c+8|0,b);g=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);h=x[c+4>>2];if((h|0)==(g|0)){gd(a,x[c+12>>2])}fb=c+16|0;c=(g|0)==(h|0);if(!c){Lr(b)}if(!c){break a}f=f+1|0;if(IV(b,e)){continue}break}}d=0}fb=b+16|0;return d|0}function cqa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;b=-1;a:{if(!mh(a,8)){break a}b=fb-32|0;fb=b;x[b+24>>2]=0;x[b+28>>2]=0;d=gc(b+8|0,b+24|0,8);od(b+16|0,a,x[d>>2],x[d+4>>2]);d=x[b+24>>2]==1096043343&x[b+28>>2]==1196314451&x[b+20>>2]==8;if(d){gd(a,8)}fb=b+32|0;b=0;if(!d){break a}b=-1;if(!rk(a,c+8|0)){break a}b=0;if(!$b(x[c+12>>2])){break a}b=!($b(x[c+8>>2])&-2139062144)}fb=c+16|0;return b|0}function mN(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Wf(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31725]=0;O(95,a|0,zh(e,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){a:{b:{while(1){if(zh(x[c+8>>2],y[c+15|0])>>>0<=b>>>0){break b}d=y[cc(c+4|0,b)|0];x[31725]=0;O(97,a|0,d|0);d=x[31725];x[31725]=0;if((d|0)!=1){b=b+1|0;continue}break}break a}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function OE(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=gc(c+8|0,c+24|0,7);od(c+16|0,a,x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(kd(c+24|0,b,7)){break b}gd(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17491,9079,601,13222);p()}_(17470,9079,599,13222);p()}return d}function c_(a){var b=0,c=0,d=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=808537417|(y[a+32|0]|y[a+33|0]<<8)>>>0>256|(y[a+49|0]<32|(y[a+36|0]|y[a+37|0]<<8)>>>0>255)){break a}if(v[a+51|0]<4|y[a+50|0]>64){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(y[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function Cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[31725]=0;e=+oa(1094,d|0,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,5350,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();e=0}return+e}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function toa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;w[b+12>>1]=0;w[b+14>>1]=1;Gf(b+14|0,z[x[x[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=fb-16|0;fb=d;c=z[b+14>>1];x[d+12>>2]=c;a:{if(Pn(a)>>>0>=c>>>0){g=x[a>>2];f=Zc(g,x[a+4>>2]);x[d+8>>2]=f;Hv(g,x[Gb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){Ap(a,c-f|0,e);break a}Kn(a,x[a>>2]+(c<<1)|0);break a}lV(a);GC(a,pk(a,c));Ap(a,c,e)}fb=d+16|0;fb=b+16|0}
function Ufa(a){a=a|0;var b=0,c=0,d=0;x[31725]=0;W(1027,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+44>>2];x[31725]=0;c=+ia(d|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,11734,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function EN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Co(a)|0)>(b|0)){break d}}b=ac(8);x[31725]=0;c=P(36,c+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return(x[(a+D(b,872)|0)+1075080>>2]&134218752)!=0|0}a=N()|0;jc(b)}Q(a|0)}p()}function B3(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;x[31725]=0;a=Ha(1101,a|0,b|0,c|0,d|0)|0;b=x[31725];x[31725]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31725]=0;ga(985,11192,e|0,f|0,g|0,h|0,i|0,j|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return a|0}function YY(a){var b=0;a:{if(kd(a,14260,3)|(y[a+3|0]-52&255)>>>0<252){break a}if($b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788>>>0<840){break a}if($b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))>>>0<52){break a}if($b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))-1>>>0<51){break a}b=$b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))>>>0<4294967216}return b}function Sfa(a){a=a|0;var b=0,c=0,d=0;x[31725]=0;W(1027,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+36>>2];x[31725]=0;c=+ia(d|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7794,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Qfa(a){a=a|0;var b=0,c=0,d=0;x[31725]=0;W(1027,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+28>>2];x[31725]=0;c=+ia(d|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7742,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Hla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);x[31725]=0;W(809,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){e=fb-16|0;fb=e;d=$h(e+4|0,a,2304);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){hc(d);fb=e+16|0}else{Vw(b);b=b+2|0;x[d+4>>2]=b;continue}break}b=c+8|0;Qd(b);ak(b);fb=c+16|0;return a|0}a=N()|0;ak(c+8|0);Q(a|0);p()}function Xi(a){var b=0,c=0;b=fb-16|0;fb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=eq(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(pI(a,b)&3){case 0:a=eq(C[b>>3],C[b+8>>3],1);break a;case 1:a=dq(C[b>>3],C[b+8>>3]);break a;case 2:a=-eq(C[b>>3],C[b+8>>3],1);break a;default:break b}}a=-dq(C[b>>3],C[b+8>>3])}fb=b+16|0;return a}function Z1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;if(!Mb(x[b>>2],x[b+8>>2],c)){c=lf(b)}x[a>>2]=c;c=x[b>>2];a:{if(ib[x[x[c>>2]+16>>2]](c)|0){c=a;a=x[b>>2];e=c,f=(ib[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0,x[e+4>>2]=f;break a}_j(a+8|0,x[a>>2]);c=x[a+8>>2];a=x[a+12>>2];if(lc(c,a)){break a}oe(d+8|0,c,a);kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2])}fb=d+16|0}function oz(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;a:{if(y[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=x[a+16>>2];if(b>>>0<=c>>>0){break a}b=AM(b,4096);zM(a,b-c|0);c=x[a+16>>2];b=gc(d+16|0,xb(x[a+4>>2],c),b-c|0);c=x[x[a>>2]+44>>2];e=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=e;ib[c|0](d+24|0,a,d+8|0);x[a+16>>2]=x[a+16>>2]+x[d+28>>2];if(!(ib[x[x[a>>2]+40>>2]](a)|0)){break a}v[a+20|0]=1}fb=d+32|0}function dua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{e=Zd(a);b:{if(e>>>0>1){break b}c:{if(e){x[31725]=0;S(336,d+4|0,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){a=d+4|0;Fn(b,a);dc(a);break c}a=T(28848)|0;if((gb|0)!=($(28848)|0)){break a}Y(a|0)|0;Z();break b}if(!Mb(x[a>>2],x[a+8>>2],c)){break b}uw(a,b,c)}f=Sc(x[b>>2],x[b+4>>2])>>>0>=c>>>0}fb=d+16|0;return f|0}Q(a|0);p()}function GN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Co(a)|0)>(b|0)){break d}}b=ac(8);x[31725]=0;c=P(36,c+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+x[(a+D(b,872)|0)+1075740>>2]*.015625)}a=N()|0;jc(b)}Q(a|0)}p()}function uE(a,b,c){var d=0,e=0,f=0;d=x[c+16>>2];a:{if(!d){if(Y0(c)){break a}d=x[c+16>>2]}f=x[c+20>>2];if(d-f>>>0<b>>>0){return ib[x[c+36>>2]](c,a,b)|0}b:{if(x[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(y[e+a|0]!=10){continue}break}e=ib[x[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=x[c+20>>2]}yc(f,a,b);x[c+20>>2]=x[c+20>>2]+b;e=b+d|0}return e}function Xba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=Lk(x[b+4>>2],x[b+8>>2]);if(!d){break a}x[31725]=0;O(1127,a|0,d|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=x[b+8>>2];b=x[b+4>>2];x[31725]=0;V(1128,a|0,b|0,e|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){break a}}a=N()|0;pN(c+8|0);Q(a|0);p()}a=c+8|0;Qd(a);pN(a);fb=c+16|0}function YH(a,b,c,d,e,f,g){var h=0;x[31725]=0;W(1002,a|0);h=x[31725];x[31725]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[31725]=0;b=ha(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,f|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Rma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Kb(c);c=Cb(x[c+4>>2],y[c+11|0]);a:{d=Cb(x[a+4>>2],y[a+11|0]);if(d>>>0>=b>>>0){e=Mc(a);if(c>>>0<=e-d>>>0){if(!c){break a}e=Kb(a);h=e+b|0;if((b|0)!=(d|0)){g=b+e|0;Vi(c+g|0,g,d-b|0);f=(f>>>0>=g>>>0?d+e>>>0>f>>>0?c:0:0)+f|0}Vi(h,f,c);b=c+d|0;ng(a,b);fd(b+e|0,0);break a}Zq(a,e,(c+d|0)-e|0,d,b,0,c,f);break a}ln();p()}return a|0}function sK(a,b,c){var d=0,e=0,f=E(0),g=0,h=E(0);e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[31600];x[31600]=0;Od();d=fb-16|0;fb=d;Cy(d,a,e+12|0,0);f=TG(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);fb=d+16|0;a=x[31600];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[31600]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}fb=e+16|0;return f}function dY(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function csa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);b:{f=b+c|0;c=Yj(b,f);if(c){x[31725]=0;O(347,a|0,c|0);e=x[31725];x[31725]=0;if((e|0)==1){break b}e=fb-16|0;fb=e;a=am(e+4|0,a,c);g=a,h=Cr(b,f,x[a+4>>2]),x[g+4>>2]=h;hc(a);fb=e+16|0}a=d+8|0;Qd(a);dj(a);fb=d+16|0;break a}a=N()|0;dj(d+8|0);Q(a|0);p()}}function VV(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+30|0]=0;v[a+31|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function Qta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,15);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0}}function Fea(a,b){a=a|0;b=b|0;var c=0,d=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[31725]=0;O(1093,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,10900,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Sv(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a:{b:{switch(a|0){case 0:a=b>>31<<6|b>>>26;b=b<<6;a=Gc(pva(b- -8192|0,a-((b>>>0<4294959104)-1|0)|0,16384,0),hb);break a;case 1:a=b>>31<<6|b>>>26;b=(b<<6)+2048|0;a=b>>>0<2048?a+1|0:a;a=Gc(pva(b,a,4096,0),hb);break a;default:break b}}x[c+8>>2]=1;a=_i(qL(8192/+x[Ze(c+12|0,c+8|0)>>2])*24+8)}fb=c+16|0;a=(a|0)>=64?64:a;return(a|0)>0?a:0}function Mra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,14);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0}}function t4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a>>2];f=6;a:{b:{if((e|0)==(b|0)){break b}e=v[e|0];f=4;if(!Kf(x[d+8>>2],64,e)){break b}f=4;g=tl(d,e);while(1){c:{e=x[a>>2]+1|0;x[a>>2]=e;g=g-48|0;if((b|0)==(e|0)|f>>>0<2){break c}e=v[e|0];if(!Kf(x[d+8>>2],64,e)){break a}f=f-1|0;g=tl(d,e)+D(g,10)|0;continue}break}if((b|0)!=(e|0)){break a}f=2}x[c>>2]=f|x[c>>2]}return g|0}function rj(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(uh(a,f+12|0)){break b}h=Cl(x[a>>2]);g=4;if(!Kf(x[d+8>>2],64,h)){break b}b=tl(d,h);while(1){c:{b=b-48|0;h=Lm(a);if(uh(h,f+12|0)|(e|0)<2){break c}g=Cl(x[h>>2]);if(!Kf(x[d+8>>2],64,g)){break a}e=e-1|0;b=tl(d,g)+D(b,10)|0;continue}break}g=2;if(!uh(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}fb=f+16|0;return b}function NO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=ac(8);x[31725]=0;c=P(36,e+4|0,8200)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Kl(a,b,1);c=sz(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=N()|0;jc(a)}Q(b|0)}p()}function FO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=ac(8);x[31725]=0;c=P(36,e+4|0,8200)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Kl(a,b,1);c=uz(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=N()|0;jc(a)}Q(b|0)}p()}function hja(a){a=a|0;var b=0,c=0;b=x[a+20>>2];x[b+148>>2]=-1;x[31725]=0;O(289,b+4|0,8);b=x[31725];x[31725]=0;if((b|0)!=1){b=x[a+4264>>2];c=x[x[a+20>>2]+4>>2];a=x[a+4260>>2];v[c|0]=a;v[c+1|0]=a>>>8;v[c+2|0]=a>>>16;v[c+3|0]=a>>>24;v[c+4|0]=b;v[c+5|0]=b>>>8;v[c+6|0]=b>>>16;v[c+7|0]=b>>>24;return}b=T(125e3)|0;if((gb|0)==($(125e3)|0)){Y(b|0)|0;gp(x[a+20>>2]+4|0);Z();return}Q(b|0);p()}function ega(a){a=a|0;var b=0;x[31725]=0;W(1027,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){x[a+24>>2]=0;b=x[a+28>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+28>>2]=0;b=x[a+20>>2];if(b){Db(b);x[a+20>>2]=0}Db(a);return}Y(T(0)|0)|0;x[31725]=0;V(989,5051,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=kh(x[b>>2],x[b+4>>2]);if(!d){break a}x[31725]=0;O(802,a|0,d|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31725]=0;wU(a,b,e,d);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;$u(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);$u(b);fb=c+16|0;return a|0}function Mja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=oc(x[b>>2],x[b+4>>2]);if(!d){break a}x[31725]=0;O(227,a|0,d|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31725]=0;wu(a,b,e,d);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;dh(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);dh(b);fb=c+16|0;return a|0}function Jpa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=zC(a,b);x[31725]=0;c=P(685,a+12|0,b+12|0)|0;d=x[31725];x[31725]=0;b:{c:{if((d|0)!=1){x[31725]=0;P(686,a+24|0,b+24|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}c=x[b+40>>2];x[a+36>>2]=x[b+36>>2];x[a+40>>2]=c;w[a+52>>1]=z[b+52>>1];c=x[b+48>>2];x[a+44>>2]=x[b+44>>2];x[a+48>>2]=c;break a}b=N()|0;break b}b=N()|0;dc(c)}dc(a);Q(b|0);p()}}function Iha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ri(a,b,c,d);x[a>>2]=44240;b=Nb(a+4208|0);x[a+4240>>2]=0;x[a+4244>>2]=0;c=x[c+24620>>2];x[a+4260>>2]=0;x[a+4256>>2]=c;x[a+4236>>2]=0;c=a+4228|0;x[c>>2]=1048550822;x[c+4>>2]=1048550822;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[31725]=0;O(947,a+44|0,2);c=x[31725];x[31725]=0;if((c|0)!=1){return a|0}c=N()|0;uc(b);ag(a);Q(c|0);p()}function zC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=Sc(x[b>>2],x[b+4>>2]);if(!d){break a}x[31725]=0;O(324,a|0,d|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31725]=0;wv(a,b,e,d);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;dj(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);dj(b);fb=c+16|0;return a|0}function uN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31725]=0;d=P(36,d+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,d);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}e=(x[a+32>>2]+D(b,872)|0)+1075766|0,f=qC(c*32768),w[e>>1]=f;fb=d+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function ao(a,b,c,d,e,f){var g=0;x[31725]=0;W(1002,a|0);g=x[31725];x[31725]=0;a:{b:{if((g|0)!=1){g=x[a+24>>2];x[31725]=0;b=ba(f|0,g|0,b|0,c|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,e|0,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function xO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=fb-32|0;fb=b;c=gc(b+24|0,c,d);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;a:{a=Au(a,b,0);if(a+1>>>0>=3){a=ac(8);x[31725]=0;b=P(36,b+12|0,8057)|0;c=x[31725];x[31725]=0;b:{if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0);p()}fb=b+32|0;return a|0}p()}function vba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;QM(a,c);fb=c+16|0}function pba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;MM(a,c);fb=c+16|0}function pK(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[31600];x[31600]=0;Od();d=fb-16|0;fb=d;Cy(d,a,e+12|0,1);f=wx(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);fb=d+16|0;a=x[31600];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[31600]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}fb=e+16|0;return f}function mba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;KM(a,c);fb=c+16|0}function k1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=-1;a:{if(!mh(a,7)){break a}c=0;if(!OE(a,11774)){break a}c=fb-16|0;fb=c;f=d+5|0;Hw(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){LE(f)}c=-1;if(!e){break a}c=0;if(!NE(y[d+6|0])){break a}c=ve(a,b,ME(d+5|0),hb)}fb=d+16|0;return c|0}function gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;GM(a,c);fb=c+16|0}function $_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=wb(x[b>>2]);x[d+28>>2]=a;b=wb(x[b+4>>2]);a:{while(1){if(Ib(a,b)){xi(d+8|0,x[a>>2],x[a+4>>2]);if(($b(x[d+8>>2])|0)==(c|0)){f=d+8|0;tp(f,a);x[31725]=0;O(362,e|0,f|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}ub(d+8|0)}a=x[nm(d+28|0)>>2];continue}break}fb=d+32|0;return}a=N()|0;ub(d+8|0);Qc(e);Q(a|0);p()}function ska(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-16|0;fb=e;b=Ec(2500);c=fb-2496|0;fb=c;NQ(a,c,c+2496|0);a=0;while(1){if((a|0)==624){x[b+2496>>2]=0;a:{if(x[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!x[b+d>>2]){continue}break a}break}x[b>>2]=-2147483648}fb=c+2496|0}else{d=a<<2;x[d+b>>2]=x[c+d>>2];a=a+1|0;continue}break}a=x[yf(e+12|0,b)>>2];fb=e+16|0;return a|0}function O9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+24>>2];e=x[a+28>>2];if(d>>>0>=e>>>0){if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{x[f+12>>2]=e-d>>2;x[f+8>>2]=c-g;e=d;d=x[ud(f+12|0,f+8|0)>>2];Zi(e,b,d);e=d<<2;x[a+24>>2]=e+x[a+24>>2];g=g+d|0;b=b+e|0}continue}break}fb=f+16|0;return g|0}function foa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{c=x[b+4>>2];if(!c){break a}w[d>>1]=z[a+480190>>1];w[d+14>>1]=c-1;c=z[Nc(d,d+14|0)>>1];while(1){if(!c){break a}b:{if(BC(x[b>>2],c)){break b}if(fS(a,c&65535)){e=Dc(d,22255);zc(((c<<5)+a|0)+946304|0,e);tb(e)}if(c>>>0<2){break b}e=z[a+480190>>1];if((e|0)!=(c|0)){break b}w[a+480190>>1]=e-1}c=c-1|0;continue}}fb=d+16|0}function bL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=Dc(d+8|0,c);x[31725]=0;S(1191,d+20|0,b|0,e|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){x[31725]=0;a=P(1192,a|0,d+20|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}tb(d+20|0);tb(e);x[a>>2]=124272;c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;fb=d+32|0;return a|0}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(e);Q(c|0);p()}function Bea(a,b){a=a|0;b=+b;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[31725]=0;b=+Wa(1095,c|0,+b);c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7606,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}return+b}a=N()|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function oY(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+5|0]){while(1){if((d|0)==5){d=0;v[c+28|0]=0;x[c+24>>2]=0;e=gc(c+8|0,c+24|0,5);kc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=5){break b}if(kd(c+24|0,b,5)){break b}Vb(a,5);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17491,9079,601,13222);p()}_(17470,9079,599,13222);p()}return d}function Hx(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;x[a+4>>2]=0;x[a>>2]=47652;h=Ec(80);x[31725]=0;d=R(1105,d|0)|0;i=x[31725];x[31725]=0;a:{b:{if((i|0)!=1){x[g+8>>2]=d;d=x[re(g+12|0,g+8|0)>>2];x[31725]=0;b=ha(f|0,h|0,b|0,c-b|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}x[a+4>>2]=b;Vc(g+8|0);fb=g+16|0;return a}a=N()|0;break a}a=N()|0;Vc(g+8|0)}Db(h);Q(a|0);p()}function Uia(a,b){a=a|0;b=b|0;var c=E(0);a:{switch(b|0){case 0:return E(B[a+4220>>2]);case 1:return E(B[a+4224>>2]);case 2:return E(B[a+4228>>2]);case 3:return E(y[a+4240|0]?E(1):E(0));case 4:return E(E(E(x[a+4232>>2])*E(.03125)));case 5:return E(y[a+4241|0]?E(1):E(0));case 6:return E(y[a+4242|0]?E(1):E(0));case 7:c=y[a+4244|0]?E(1):E(0);break;default:break a}}return E(c)}function eaa(){var a=0,b=0,c=0,d=0,e=0,f=0;b=fb-48|0;fb=b;if(OL(0,b+24|0)){Jt(x[31600],12742);p()}a=we(b+16|0,x[b+24>>2],x[b+28>>2]);d=ZA(b+8|0,x[b+32>>2]/1e3|0);c=fb-16|0;fb=c;a=Eu(c,x[a>>2],x[a+4>>2]);e=x[a>>2];f=e+x[d>>2]|0;a=x[d+4>>2]+x[a+4>>2]|0;a=we(c+8|0,f,f>>>0<e>>>0?a+1|0:a);d=x[a>>2];fb=c+16|0;c=we(b+40|0,d,x[a+4>>2]);a=x[c>>2];fb=b+48|0;hb=x[c+4>>2];return a|0}function bfa(a){a=a|0;var b=0,c=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[31725]=0;b=R(1070,b|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7278,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();b=0}return b|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function P6(a){a=a|0;if(y[500496]){return x[125123]}if(!y[501016]){v[501016]=1}wd(500848,120152);wd(500860,120180);wd(500872,120208);wd(500884,120240);wd(500896,120280);wd(500908,120316);wd(500920,120344);wd(500932,120380);wd(500944,120396);wd(500956,120412);wd(500968,120428);wd(500980,120444);wd(500992,120460);wd(501004,120476);v[500496]=1;x[125123]=500848;return 500848}function Is(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;x[a+4>>2]=0;x[a>>2]=47652;h=Ec(80);x[31725]=0;d=R(1105,d|0)|0;i=x[31725];x[31725]=0;a:{b:{if((i|0)!=1){x[g+8>>2]=d;d=x[re(g+12|0,g+8|0)>>2];x[31725]=0;b=ha(f|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}x[a+4>>2]=b;Vc(g+8|0);fb=g+16|0;return a}a=N()|0;break a}a=N()|0;Vc(g+8|0)}Db(h);Q(a|0);p()}function EC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=wb(x[b>>2]);x[d+28>>2]=a;b=wb(x[b+4>>2]);a:{while(1){if(Ib(a,b)){xi(d+8|0,x[a>>2],x[a+4>>2]);if(x[d+8>>2]==(c|0)){f=d+8|0;tp(f,a);x[31725]=0;O(362,e|0,f|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}ub(d+8|0)}a=x[nm(d+28|0)>>2];continue}break}fb=d+32|0;return}a=N()|0;ub(d+8|0);Qc(e);Q(a|0);p()}function y_(a){var b=0,c=0;a:{if(kd(a,15221,3)){break a}c=y[a+3|0];if(c>>>0>9){break a}if((Bb(y[a+202|0]|y[a+203|0]<<8)-1e4&65535)>>>0<57516){break a}b=1;b:{if(c>>>0>5){break b}if(!Bb(y[a+228|0]|y[a+229|0]<<8)){break a}if(!Bb(y[a+230|0]|y[a+231|0]<<8)){break a}b=0;if(Bb(y[a+232|0]|y[a+233|0]<<8)>>>0>4095){break b}b=Bb(y[a+234|0]|y[a+235|0]<<8)>>>0<100}return b}return 0}function lfa(a){a=a|0;var b=0,c=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[31725]=0;c=+ia(1061,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31725]=0;V(989,7678,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function jQ(a){var b=E(0),c=0,d=E(0);b=B[a+4224>>2];B[a+4260>>2]=M(E(E(1)-E(b*b)));v[a+4264|0]=B[a+4236>>2]>E(.5);d=E(A[a+4256>>2]);b=E(E(E(E(B[a+4228>>2]*E(1999))+E(1))/E(1e3))*d);a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}x[a+4248>>2]=c;c=a+4252|0;b=E(E(E(E(B[a+4232>>2]*E(1999))+E(1))/E(1e3))*d);b:{if(b<E(4294967296)&b>=E(0)){a=~~b>>>0;break b}a=0}x[c>>2]=a}function hy(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;if(1073741807-b>>>0>=c>>>0){i=Kb(a);h=g+4|0;if(b>>>0<=536870886){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=zn(x[ad(g+4|0,g+12|0)>>2])+1|0}else{c=1073741807}Wj(h,c);c=x[g+4>>2];if(e){Zi(c,i,e)}h=e+f|0;if((h|0)!=(d|0)){e=e<<2;Zi(e+c|0,(e+i|0)+(f<<2)|0,d-h|0)}if((b|0)!=1){Db(i)}yd(a,c);pf(a,x[g+8>>2]);fb=g+16|0;return}qf();p()}function hB(a,b,c){var d=0,e=0,f=0;f=Fb(a);d=y[b+11|0];e=x[b+4>>2];a=0;x[31725]=0;O(53,f|0,Yc(e,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){a:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=65533;e=v[cc(b,a)|0];if((e|0)>=-96){d=x[((e&255)<<2)+c>>2]}x[31725]=0;O(35,f|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Qb(f);Q(a|0);p()}function E4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a>>2];f=6;a:{b:{if((e|0)==(b|0)){break b}e=x[e>>2];f=4;if(!zj(d,64,e)){break b}g=yk(d,e);f=4;while(1){c:{e=x[a>>2]+4|0;x[a>>2]=e;g=g-48|0;if((b|0)==(e|0)|f>>>0<2){break c}e=x[e>>2];if(!zj(d,64,e)){break a}f=f-1|0;g=yk(d,e)+D(g,10)|0;continue}break}if((b|0)!=(e|0)){break a}f=2}x[c>>2]=f|x[c>>2]}return g|0}
function sta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-240|0;fb=d;c=fb-16|0;fb=c;f=d+4|0;w_(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){v_(f)}c=-1;a:{if(!e){break a}c=0;if(!y_(d+4|0)){break a}c=ve(a,b,x_(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24)),hb)}fb=d+240|0;return c|0}function qja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=Ec(64);x[31725]=0;e=R(879,c|0)|0;f=x[31725];x[31725]=0;a:{if((f|0)!=1){c=yf(d+8|0,e);e=x[c>>2];x[31725]=0;a=U(945,e|0,a|0,b|0)|0;b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}sc(d+12|0);break b}a=N()|0;og(c);break a}re(d+12|0,c)}og(c);fb=d+16|0;return x[d+12>>2]}a=N()|0;Db(c)}Q(a|0);p()}function Bba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a:{b:{if((Ck(y[a+140|0])|0)!=1){break b}if((dN(a)|0)!=(b|0)){break b}d=a+120|0;$t(y[d+20|0]);b=fb-16|0;fb=b;x[b+12>>2]=c+15;a=fb-16|0;fb=a;e=x[18383];x[a+8>>2]=x[18382];x[a+12>>2]=e;e=x[18381];x[a>>2]=x[18380];x[a+4>>2]=e;ib[x[vq(a,Ck(y[d+20|0]))>>2]](b+12|0,d);fb=a+16|0;fb=b+16|0;break a}cN(a,1,b)}fb=c+16|0}function e1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;b:{c:{d:{e:{if((b|0)==4){Wf(a,c);break e}e=d+8|0;Wf(e,c);x[31725]=0;S(125,d+20|0,b|0,e|0);b=x[31725];x[31725]=0;if((b|0)==1){break d}x[31725]=0;S(246,a|0,4,d+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(d+20|0);tb(d+8|0)}fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function Xm(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;if(2147483631-b>>>0>=c>>>0){j=Kb(a);i=h+4|0;if(b>>>0<=1073741798){x[h+12>>2]=b<<1;x[h+4>>2]=b+c;c=Eh(x[ad(h+4|0,h+12|0)>>2])+1|0}else{c=2147483631}sg(i,c);c=x[h+4>>2];if(e){Cg(c,j,e)}i=e+f|0;if((i|0)!=(d|0)){Cg((c+e|0)+g|0,(e+j|0)+f|0,d-i|0)}if((b|0)!=10){Db(j)}yd(a,c);pf(a,x[h+8>>2]);fb=h+16|0;return}qf();p()}function Vz(a){var b=E(0),c=E(0),d=0,e=E(0),f=0;b=E(A[x[a+16>>2]+24620>>2]);c=E(E(E(ib[x[x[a>>2]+208>>2]](a))*b)/E(1e3));d=a,e=E(E(c*E(ib[x[x[a>>2]+200>>2]](a)))*E(2048)),B[d+4248>>2]=e;d=a,f=Sl(E(E(c+E(2))*E(4096))),x[d+4256>>2]=f;c=E(ib[x[x[a>>2]+212>>2]](a));B[a+4252>>2]=c;b=E(c/b);if(!(ib[x[x[a>>2]+196>>2]](a)|0)){b=rQ(E(b*E(3.1415927410125732)))}B[a+4244>>2]=b+b}function AV(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31725]=0;O(116,d|0,Yc(e,a)|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){a=zd(b);x[c+12>>2]=a;b=Df(b);while(1){if(!Ib(a,b)){break a}a=y[a|0];x[31725]=0;O(117,d|0,((a|0)==13?10:a)<<24>>24);a=x[31725];x[31725]=0;if((a|0)!=1){a=x[me(c+12|0)>>2];continue}break}}a=N()|0;tb(d);Q(a|0);p()}fb=c+16|0}function qj(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(mi(a,f+12|0)){break b}g=4;h=Bl(x[a>>2]);if(!zj(d,64,h)){break b}b=yk(d,h);while(1){c:{b=b-48|0;h=oo(a);if(mi(h,f+12|0)|(e|0)<2){break c}g=Bl(x[h>>2]);if(!zj(d,64,g)){break a}e=e-1|0;b=yk(d,g)+D(b,10)|0;continue}break}g=2;if(!mi(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}fb=f+16|0;return b}function XH(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=ac(8);x[31725]=0;c=P(36,f+4|0,8200)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Kl(a,b,e);c=PH(a,c,e,d,76144,76916);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=N()|0;jc(a)}Q(b|0)}p()}function WH(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=ac(8);x[31725]=0;c=P(36,f+4|0,8200)|0;b=x[31725];x[31725]=0;if((b|0)==1){break c}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Kl(a,b,e);c=PH(a,c,e,d,75316,76088);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=N()|0;jc(a)}Q(b|0)}p()}function NN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=ac(8);x[31725]=0;c=P(36,c+4|0,7854)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=_e(65536/b),x[e+480244>>2]=f;Iq(a);fb=c+16|0;return}d=N()|0;jc(a)}Q(d|0)}p()}function LN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=ac(8);x[31725]=0;c=P(36,c+4|0,7875)|0;d=x[31725];x[31725]=0;if((d|0)==1){break c}pc(a,c);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=_e(b*65536),x[e+480240>>2]=f;Iq(a);fb=c+16|0;return}d=N()|0;jc(a)}Q(d|0)}p()}function YO(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;a:{c=x[a+36>>2];d=x[a+40>>2];b:{if(Ib(c,d)){sc(b+12|0);break b}Bo(b,a);x[31725]=0;c=R(1062,b|0)|0;d=x[31725];x[31725]=0;if((d|0)==1){break a}x[b+12>>2]=c;of(b);d=x[a+40>>2];c=x[a+36>>2]}c:{if(Ib(c,d)){a=a+36|0;break c}a=x[b+12>>2];c=x[a>>2]}a=pj(c,x[a+4>>2]);Gl(b+12|0);fb=b+16|0;return a|0}a=N()|0;of(b);Q(a|0);p()}function Pm(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return v[a+89120|0]}if(a>>>0<=511){return v[(a>>>5|0)+89120|0]+5|0}return v[(a>>>10|0)+89120|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return v[(a>>>15|0)+89120|0]+15|0}return v[(a>>>20|0)+89120|0]+20|0}if(a>>>0<=536870911){return v[(a>>>25|0)+89120|0]+25|0}a=v[(a>>>30|0)+89120|0]+30|0}else{a=0}return a}function Hs(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[a+4>>2]=0;x[a>>2]=47652;g=Ec(80);x[31725]=0;c=R(1105,c|0)|0;h=x[31725];x[31725]=0;a:{b:{if((h|0)!=1){x[f+8>>2]=c;c=x[re(f+12|0,f+8|0)>>2];x[31725]=0;b=ba(e|0,g|0,b|0,c|0,d|0)|0;c=x[31725];x[31725]=0;if((c|0)==1){break b}x[a+4>>2]=b;Vc(f+8|0);fb=f+16|0;return a}a=N()|0;break a}a=N()|0;Vc(f+8|0)}Db(g);Q(a|0);p()}function G5(a,b){a=a|0;b=b|0;var c=0,d=0;c=Kb(b);b=fb-32|0;fb=b;a=xd(a,0);x[a>>2]=113264;d=Bk(c);x[a+8>>2]=d;if(!d){a=Dc(b+8|0,c);x[31725]=0;S(1017,b+20|0,17527,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){x[31725]=0;W(1345,b+20|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}p()}c=N()|0;break a}c=N()|0;tb(b+20|0)}tb(a);Q(c|0);p()}fb=b+32|0;x[a>>2]=119640;return a|0}function Faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=zm(a);x[d>>2]=77892;a=xM(nc(d),uM(b));x[a>>2]=78224;x[31725]=0;P(343,a+24|0,65536)|0;c=x[31725];x[31725]=0;a:{if((c|0)!=1){c=a+36|0;Tb(c,0,192);e=a+228|0;while(1){x[c>>2]=0;x[c+4>>2]=0;v[c+8|0]=0;c=c+12|0;if((e|0)!=(c|0)){continue}break}Tb(e,0,64);break a}b=N()|0;Tt(a);Q(b|0);p()}x[a+292>>2]=b;x[a>>2]=78036;return d|0}function zN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31725]=0;c=P(36,c+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=x[a+32>>2]+D(b,872)|0;x[a+1075008>>2]=0;x[a+1075068>>2]=0;fb=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function wt(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-160|0;fb=e;g=b?a:e+158|0;x[e+148>>2]=g;a=b-1|0;x[e+152>>2]=a>>>0<=b>>>0?a:0;while(1){v[e+h|0]=0;a=h+1|0;f=a?f:f+1|0;h=a;if(!f&a>>>0<144){continue}break}a=-1;x[e+76>>2]=-1;x[e+36>>2]=1200;x[e+80>>2]=-1;x[e+44>>2]=e+159;x[e+84>>2]=e+148;a:{if((b|0)<0){x[31600]=61;break a}v[g|0]=0;a=GL(e,c,d,1176,1177)}fb=e+160|0;return a}function vua(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=d+14|0;X$(c,a,b);Bf(b,y[d+14|0],y[Jc(c)|0]);a=y[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=y[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}v[b+3|0]=45;v[b+5|0]=a&15;break a}if((a|0)!=64){break a}v[b+3|0]=0;v[b|0]=254;break a}v[b+3|0]=20;v[b+5|0]=a&15|160;break a}v[b+3|0]=0}fb=d+16|0}function lq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(lr(d)){Me(c,d);break c}if(d>>>0>=1073741808){break b}Wj(e+8|0,zn(d)+1|0);b=x[e+8>>2];yd(c,b);pf(c,x[e+12>>2]);Yd(c,d);c=b}Zi(c,f,d+1|0);fb=e+16|0;break a}qf();p()}return a|0}function lg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Uk(d)){Me(c,d);break c}if(d>>>0>=2147483632){break b}sg(e+8|0,Eh(d)+1|0);b=x[e+8>>2];yd(c,b);pf(c,x[e+12>>2]);Yd(c,d);c=b}Cg(c,f,d+1|0);fb=e+16|0;break a}qf();p()}return a|0}function gt(a,b,c){var d=0,e=0;if(c&2048){v[a|0]=43;a=a+1|0}if(c&1024){v[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){v[a|0]=46;v[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}v[a|0]=b;return(d|0)!=260}function g0(a,b){var c=0,d=0;b=!x[a+24>>2]|b;x[a+16>>2]=b;if(b&x[a+20>>2]){a=fb-16|0;fb=a;c=ac(16);b=fb-16|0;fb=b;if(!y[496960]){v[496960]=1}gc(b+8|0,1,126084);d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;fb=b+16|0;b=x[a+12>>2];a=x[a+8>>2];x[31725]=0;a=Ca(1193,c|0,8943,a|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){da(a|0,94572,1194);p()}a=N()|0;jc(c);Q(a|0);p()}}function Cm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Uk(d)){Me(c,d);break c}if(d>>>0>=2147483632){break b}sg(e+8|0,Eh(d)+1|0);b=x[e+8>>2];yd(c,b);pf(c,x[e+12>>2]);Yd(c,d);c=b}Xg(c,f,d+1|0);fb=e+16|0;break a}qf();p()}return a|0}function vN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31725]=0;c=P(36,c+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+(x[(x[a+32>>2]+D(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=N()|0;jc(b)}Q(a|0)}p()}function tN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31725]=0;c=P(36,c+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+w[(x[a+32>>2]+D(b,872)|0)+1075766>>1]*30517578125e-15)}a=N()|0;jc(b)}Q(a|0)}p()}function isa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;c=Hf(a,c);$d(f,x[a+36>>2]);a:{if(!c){Pc(f,a+32|0,5);e=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}h=x[a+36>>2];g=fb-16|0;fb=g;e=Fb(g+4|0);x[31725]=0;ba(471,b|0,h|0,e|0,d|0)|0;b=x[31725];x[31725]=0;b:{if((b|0)!=1){tb(e);fb=g+16|0;break b}a=N()|0;tb(e);Q(a|0);p()}e=c}gf(a,e);fb=f+16|0}function cR(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0);c=fb-16|0;fb=c;d=0;a:{if(x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){break a}x[c+12>>2]=0;Ok(a,c+12|0);e=x[c+12>>2];d=0;if(e>>>0>65535){break a}Ll(b,e);while(1){if((f|0)==(e|0)){d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}else{x[c+8>>2]=0;Dq(a,c+8|0);g=yb(x[b>>2],f),h=B[c+8>>2],B[g>>2]=h;f=f+1|0;continue}break}}a=d;fb=c+16|0;return a}function R4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;while(1){if((b|0)!=(c|0)){a=x[b>>2];a:{b:{if(a>>>0<=127){a=x[(a<<2)+112112>>2];break b}e=(vt(a)|0)!=0;e=ut(a)?e|2:e;e=tt(a)?e|4:e;e=st(a)?e|8:e;e=rt(a)?e|16:e;e=qt(a)?e|32:e;e=Oh(a)?e|64:e;e=pt(a)?e|128:e;e=ot(a)?e|256:e;x[d>>2]=e;if(!nt(a)){break a}a=e|512}x[d>>2]=a}d=d+4|0;b=b+4|0;continue}break}return c|0}function $R(a,b){var c=0,d=0,e=0,f=0;a:{if(z[a+480188>>1]<=b>>>0){break a}b:{c:{c=D(b,872)+a|0;d=y[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(y[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=v[c+1075785|0];d:{if((c|0)>=0){d=Oe(a+901692|0,y[(D(b,872)+a|0)+1075836|0]);break d}d=Oe(a+902204|0,c&127)}wT(a,e,b,f,d,c&255)}}function tX(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28486832|y[a+63|0]!=26){break a}b=y[a+65|0];if(y[a+66|0]|(b|0)!=16&(b|0)!=1|(y[a+64|0]&3|(y[a+78|0]|y[a+79|0]<<8)>>>0>127)){break a}if((y[a+80|0]|y[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=dl(y[a|0]|y[a+1|0]<<8,y[b|0]|y[b+1|0]<<8)?b:a;c=(y[a|0]|y[a+1|0]<<8)!=0}return c}function qX(a){var b=0;a:{if((y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1179472976|y[a+28|0]!=26|(y[a+40|0]|y[a+41|0]<<8|y[a+30|0]>2)){break a}if(((y[a+38|0]|y[a+39|0]<<8)-33&65535)>>>0<65504|((y[a+32|0]|y[a+33|0]<<8)-257&65535)>>>0<65280|((y[a+34|0]|y[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((y[a+36|0]|y[a+37|0]<<8)-1&65535)>>>0<128}return b}function Oo(a,b,c,d){a:{if(x[a+480180>>2]==4){if(c){v[b+810|0]=y[b+810|0]&15|c<<4;break a}c=y[b+810|0]>>>4|0;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]+((c&255)<<2)|0;x[b+688>>2]=(c|0)>=256?256:c;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function zR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)!=(b|0)){d=fb-16|0;fb=d;c=x[b>>2];b=x[b+4>>2];e=Sd(c,b);a:{if(e>>>0<=Ug(a)>>>0){f=b;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=c;$C(d+12|0,h);f=x[d+12>>2]}c=Wg(c,f,g);if(!i){wu(a,f,b,e-oc(x[a>>2],x[a+4>>2])|0);break a}Ih(a,c);break a}wr(a);sm(a,Mf(a,e));wu(a,c,b,e)}fb=d+16|0}return a}function Pha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ri(a,b,c,d);x[a>>2]=43860;b=a+4208|0;e=yb(b,0),f=1060320051,x[e>>2]=f;e=yb(b,1),f=1041865114,x[e>>2]=f;e=yb(b,2),f=1065353216,x[e>>2]=f;e=yb(b,3),f=1049951732,x[e>>2]=f;e=yb(b,4),f=1049951732,x[e>>2]=f;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;ag(a);Q(b|0);p()}function Aaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(!c){break a}x[31725]=0;O(1163,a|0,c|0);e=x[31725];x[31725]=0;if((e|0)!=1){x[31725]=0;V(1164,a|0,b|0,Hd(b,c)|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;rM(d+8|0);Q(a|0);p()}b=d+8|0;Qd(b);rM(b);fb=d+16|0;return a|0}function iqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-1120|0;fb=d;c=fb-16|0;fb=c;RX(c+8|0,d+12|0);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!TX(d+12|0)){break a}c=ve(a,b,SX(y[d+1116|0]|y[d+1117|0]<<8|(y[d+1118|0]<<16|y[d+1119|0]<<24)),hb)}fb=d+1120|0;return c|0}function mv(a,b){var c=0,d=0;c=fb-32|0;fb=c;d=c+16|0;mW(d,a,a+1|0,a+2|0,a+3|0);mW(c,b,b+1|0,b+2|0,b+3|0);b=lv(y[x[d>>2]],y[x[c>>2]]);a:{if(!Vj(b)){break a}b=y[x[d+4>>2]];a=y[x[c+4>>2]];b=(a|0)!=(b|0)?b<<24>>24<a<<24>>24?-1:1:0;if(!Vj(b)){break a}b=lv(y[x[d+8>>2]],y[x[c+8>>2]]);if(!Vj(b)){break a}b=lv(y[x[d+12>>2]],y[x[c+12>>2]])}a=Cd(b);fb=c+32|0;return a}function una(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Fb(a);c=y[b+11|0];e=x[b+4>>2];a=0;x[31725]=0;O(49,d|0,Yc(e,c)|0);c=x[31725];x[31725]=0;if((c|0)!=1){a:{b:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0<=a>>>0){break b}c=v[cc(b,a)|0];x[31725]=0;O(50,d|0,Pf(Pf(c))|0);c=x[31725];x[31725]=0;if((c|0)!=1){a=a+1|0;continue}break}break a}return}}a=N()|0;tb(d);Q(a|0);p()}function oga(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=x[a+24>>2];if(b){Db(Bq(b))}x[a+24>>2]=0;b=x[a+20>>2];if(b){Db(b);x[a+20>>2]=0}Db(a);return}Y(T(0)|0)|0;x[31725]=0;V(989,5078,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function xK(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){g=x[31600];x[31600]=0;Od();a=yK(a,e+12|0,d);d=hb;f=x[31600];b:{if(f){if(x[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}x[c>>2]=4;b=!!a&(d|0)>=0|(d|0)>0;a=b?-1:0;d=b?2147483647:-2147483648;break a}x[31600]=g;if(x[e+12>>2]==(b|0)){break a}}}x[c>>2]=4;a=0;d=0}fb=e+16|0;hb=d;return a}function Rg(a,b){var c=0,d=0,e=0,f=0,g=0;e=Kb(a);d=Cb(x[a+4>>2],y[a+11|0]);c=Cf(b);a=0;a:{if(!c){break a}a=e;d=d+a|0;c=b+c|0;b:{if((c|0)==(b|0)){break b}c:{c=c-b|0;if((c|0)>(d-a|0)){break c}g=y[b|0];while(1){f=d-a|0;if((c|0)>(f|0)){break c}a=yq(a,(f-c|0)+1|0,g);if(!a){break c}if(!py(a,b,c)){break b}a=a+1|0;continue}}a=d}a=(a|0)==(d|0)?-1:a-e|0}return a}function VB(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;if(2147483631-b>>>0>=c>>>0){h=Kb(a);i=g+4|0;if(b>>>0<=1073741798){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=Eh(x[ad(g+4|0,g+12|0)>>2])+1|0}else{c=2147483631}sg(i,c);c=x[g+4>>2];if(e){Xg(c,h,e)}if((d|0)!=(e|0)){Xg((c+e|0)+f|0,e+h|0,d-e|0)}if((b|0)!=10){Db(h)}yd(a,c);pf(a,x[g+8>>2]);fb=g+16|0;return}qf();p()}function kga(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){x[a+16>>2]=b;b=x[a+20>>2];if(!b){break b}Db(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[31725]=0;V(989,5660,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function cB(a,b,c,d){a:{if(x[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=D(b,872)+a|0;x[c+1075688>>2]=0;d=c+1075e3|0;x[d>>2]=0;x[d+4>>2]=0;c=x[c+1075080>>2]|4096;break b}c=D(b,872)+a|0;x[c+1075680>>2]=0;c=x[c+1075080>>2]}d=D(b,872)+a|0;x[d+1075080>>2]=c|2097152;dn(a,b,255,0);if(!(y[d+1075081|0]&2)){break a}a=x[a+1298300>>2];if(!Dd(a)){break a}Oj(a,b,0)}}function mq(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;bd(d+12|0,b);x[31725]=0;b=R(1218,x[d+12>>2])|0;e=x[31725];x[31725]=0;a:{if((e|0)==1){break a}x[31725]=0;e=R(1226,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break a}x[c>>2]=e;x[31725]=0;O(1227,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Zb(d+12|0);fb=d+16|0;return}a=N()|0;Zb(d+12|0);Q(a|0);p()}function jla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=b;c=fb-16|0;fb=c;d=Ec(223888);x[31725]=0;b=P(846,d|0,b+1074376|0)|0;e=x[31725];x[31725]=0;a:{if((e|0)!=1){b=x[yf(c+12|0,b)>>2];fb=c+16|0;break a}a=N()|0;Db(d);Q(a|0);p()}x[a+4>>2]=b;b=Nb(a+8|0);x[31725]=0;W(608,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return a|0}c=N()|0;Ae(b);kT(a+4|0);Q(c|0);p()}function e9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=x[a+84>>2];f=x[e>>2];d=x[e+4>>2];h=x[a+28>>2];g=x[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){yc(f,h,g);f=g+x[e>>2]|0;x[e>>2]=f;d=x[e+4>>2]-g|0;x[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){yc(f,b,d);f=d+x[e>>2]|0;x[e>>2]=f;x[e+4>>2]=x[e+4>>2]-d}v[f|0]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;return c|0}function SH(a,b,c){var d=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31725]=0;c=P(36,d+4|0,10735)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=(x[a+32>>2]+D(b,872)|0)+1075080|0;x[a>>2]=x[a>>2]|c;fb=d+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function PN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=ac(8);x[31725]=0;c=P(36,c+4|0,9363)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074420>>2]=D(b,1e4);fb=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function Bha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=AQ(a,b,c,d,e^1);x[b>>2]=44472;a=b+4208|0;f=yb(a,0),g=1056964608,x[f>>2]=g;f=yb(a,1),g=1065353216,x[f>>2]=g;f=yb(a,2),g=1020054733,x[f>>2]=g;f=yb(a,3),g=1065353216,x[f>>2]=g;f=yb(a,4),g=1056964608,x[f>>2]=g;f=yb(a,5),g=1048406533,x[f>>2]=g;f=yb(a,6),g=1056964608,x[f>>2]=g;return b|0}function oq(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;bd(d+12|0,b);x[31725]=0;b=R(1201,x[d+12>>2])|0;e=x[31725];x[31725]=0;a:{if((e|0)==1){break a}x[31725]=0;e=R(1213,b|0)|0;f=x[31725];x[31725]=0;if((f|0)==1){break a}v[c|0]=e;x[31725]=0;O(1214,a|0,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Zb(d+12|0);fb=d+16|0;return}a=N()|0;Zb(d+12|0);Q(a|0);p()}function Xsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-576|0;fb=d;c=fb-16|0;fb=c;a_(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){$Z(d)}c=-1;a:{if(!e){break a}c=0;if(!c_(d)){break a}c=ve(a,b,b_(y[d+34|0]|y[d+35|0]<<8,y[d+36|0]|y[d+37|0]<<8),hb)}fb=d+576|0;return c|0}function JQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=YD(b,c);a:{if(e>>>0<=ep(a)>>>0){x[d+12>>2]=c;g=x[a>>2];f=Sc(g,x[a+4>>2]);h=f>>>0>=e>>>0;if(h){f=c}else{x[d+12>>2]=b;i$(d+12|0,f);f=x[d+12>>2]}b=mp(b,f,g);if(!h){XD(a,x[d+12>>2],c,e-Sc(x[a>>2],x[a+4>>2])|0);break a}pr(a,b);break a}_v(a);bl(a,cm(a,e));XD(a,b,c,e)}fb=d+16|0}function B6(a){a=a|0;if(y[500488]){return x[125121]}if(!y[500840]){v[500840]=1}id(500672,5240);id(500684,5247);id(500696,5213);id(500708,5221);id(500720,5204);id(500732,5254);id(500744,5231);id(500756,9758);id(500768,9964);id(500780,11294);id(500792,12930);id(500804,5503);id(500816,10797);id(500828,6622);v[500488]=1;x[125121]=500672;return 500672}function cs(a,b,c){var d=0,e=0,f=0,g=0;a:{d=Hk(b,zd(a));b=Hk(c,b);if(Cb(x[a+4>>2],y[a+11|0])>>>0>=d>>>0){if((b|0)==-1){qU(a,d);break a}e=fb-16|0;fb=e;x[e+12>>2]=b;if(b){f=Cb(x[a+4>>2],y[a+11|0]);g=Kb(a);c=f-d|0;x[e+8>>2]=c;b=x[Gb(e+12|0,e+8|0)>>2];b:{if((c|0)==(b|0)){b=c;break b}d=d+g|0;Vi(d,b+d|0,c-b|0)}Yu(a,g,f-b|0)}fb=e+16|0;break a}ln();p()}}function _sa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(A[a+4>>2]<A[zb(a)>>2]){d=fb-16|0;fb=d;a=Tg(d+4|0,a,1);i_(x[a+4>>2],z[b>>1],y[c|0]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=d+16|0;return}e=fb-32|0;fb=e;d=zb(a);d=$f(e+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),d);i_(x[d+8>>2],z[b>>1],y[c|0]);x[d+8>>2]=x[d+8>>2]+4;bs(a,d);_f(d);fb=e+32|0}function FR(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1163089229){break a}b=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))}return c}function E_(a){var b=0,c=0;a:{if(kd(a,13907,3)|(y[a+3|0]-1&255)>>>0>3){break a}if(Bb(y[a+196|0]|y[a+197|0]<<8)>>>0>255){break a}if((Bb(y[a+198|0]|y[a+199|0]<<8)-1&65535)>>>0>255){break a}if((Bb(y[a+200|0]|y[a+201|0]<<8)-1&65535)>>>0>31){break a}b=Bb(y[a+202|0]|y[a+203|0]<<8);if(b>>>0>256){break a}c=Bb(y[a+204|0]|y[a+205|0]<<8)>>>0<b>>>0}return c}function Cua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if(!(c&1024)){break a}f=e,g=zd(b),x[f+12>>2]=g;c=Yc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[cc(b,0)|0]!=43){if(y[cc(b,0)|0]!=45){break b}}d=d+1|0;yV(e+12|0)}if(c>>>0>=d>>>0){break a}JE(b,x[vb(e+8|0,x[e+12>>2])>>2],d-Yc(x[b+4>>2],y[b+11|0])|0,48)}_c(a,b);fb=e+16|0}function No(a,b,c,d){a:{if(x[a+480180>>2]==4){d=y[b+810|0];if(c){v[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]-((c&255)<<2)|0;x[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function Qba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{e=x[b+1298404>>2];b=fb-32|0;fb=b;d=b+8|0;Wf(d,c);x[31725]=0;S(504,b+20|0,e|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){x[31725]=0;S(246,a|0,0,b+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(b+20|0);tb(b+8|0);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Qb(b+20|0)}tb(b+8|0);Q(a|0);p()}}function QN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=ac(8);x[31725]=0;c=P(36,c+4|0,5848)|0;a=x[31725];x[31725]=0;if((a|0)==1){break c}pc(b,c);x[31725]=0;S(99,b|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074416>>2]=b;fb=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function Px(a,b,c,d){v[a+53|0]=1;a:{if(x[a+4>>2]!=(c|0)){break a}v[a+52|0]=1;c=x[a+16>>2];b:{if(!c){x[a+36>>2]=1;x[a+24>>2]=d;x[a+16>>2]=b;if((d|0)!=1){break a}if(x[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=x[a+24>>2];if((c|0)==2){x[a+24>>2]=d;c=d}if(x[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}x[a+36>>2]=x[a+36>>2]+1}v[a+54|0]=1}}function GE(a,b,c,d){var e=0,f=0;a:{e=y[a|0];f=y[c|0];b:{if(!(y[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){v[a|0]=(f|0)==5?7:6;break b}if(!(y[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){v[a|0]=(e|0)==5?7:6;v[b|0]=y[d|0];break b}if(!((e|0)!=10|(f|0)!=20|y[d|0]!=159)){v[a|0]=42;break b}if((f|0)!=10|(e|0)!=20|y[b|0]!=159){break a}v[a|0]=42;v[b|0]=y[d|0]}v[c|0]=0}}function yM(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a>>2];b:{if(!b){break b}c=x[a+8>>2];if(!c){break b}d=x[a+12>>2];if(!d){break b}a=ib[d|0](b)|0;e=hb;if((e|0)<0){break b}if((ib[c|0](b,0,0,0)|0)<0){break a}if((ib[c|0](b,0,0,2)|0)<0){break a}d=ib[d|0](b)|0;f=hb;ib[c|0](b,a,e,0)|0;if((f|0)<0){break b}g=Tu(d,f)}return g}ib[c|0](b,a,e,0)|0;return 0}function nga(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){x[a+16>>2]=0;b=x[a+20>>2];if(!b){break b}Db(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[31725]=0;V(989,8916,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function ml(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+8>>2]=a;x[f+12>>2]=b;h=x[a+8>>2]+120|0;$t(y[h+20|0]);g=fb-16|0;fb=g;x[g+12>>2]=f+8;e=fb-16|0;fb=e;i=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=i;d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;ib[x[vq(e,Ck(y[h+20|0]))>>2]](g+12|0,h);fb=e+16|0;fb=g+16|0;x[a+4>>2]=x[a+4>>2]+x[b+8>>2];fb=f+16|0}function Xf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Cb(x[a+4>>2],y[a+11|0])|(c-b|0)<5){break a}jt(b,c);e=c-4|0;c=Kb(a);g=c+Cb(x[a+4>>2],y[a+11|0])|0;b:{while(1){c:{a=v[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=x[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>x[e>>2]-1>>>0){break a}}x[d>>2]=4}}function TH(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;a:{b:{c:{if(b<g|b>f){a=ac(8);x[31725]=0;d=P(36,h+4|0,e|0)|0;e=x[31725];x[31725]=0;if((e|0)==1){break c}pc(a,d);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}e=N()|0;tb(d);break b}i=x[a+32>>2]+d|0,j=_e(b*c),x[i>>2]=j;fb=h+16|0;return}e=N()|0;jc(a)}Q(e|0)}p()}function T3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb+-64|0;fb=d;e=1;a:{if(oh(a,b,0)){break a}e=0;if(!b){break a}b=gB(b,124608,124656);e=0;if(!b){break a}Tb(d+12|0,0,52);x[d+56>>2]=1;x[d+20>>2]=-1;x[d+16>>2]=a;x[d+8>>2]=b;ib[x[x[b>>2]+28>>2]](b,d+8|0,x[c>>2],1);a=x[d+32>>2];if((a|0)==1){x[c>>2]=x[d+24>>2]}e=(a|0)==1}a=e;fb=d- -64|0;return a|0}function Hta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-112|0;fb=d;c=fb-16|0;fb=c;f=d+14|0;U_(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){T_(f)}c=-1;a:{if(!e){break a}c=0;if(!W_(d+14|0)){break a}c=ve(a,b,V_(y[d+61|0]|y[d+62|0]<<8),hb)}fb=d+112|0;return c|0}function BF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<3){if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==2){ij(c+10|0,z[c+14>>1]);d=z[c+10>>1];break a}else{v[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){gh(a,c+13|0);e=y[c+13|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11235,9079,324,14199);p()}fb=c+16|0;return d&65535}function i1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;EE(e+8|0,c);c=y[d|0];x[31725]=0;O(245,e+20|0,c|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){vk(e,e+8|0);x[31725]=0;V(94,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function XI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=wJ(a,c);x[a>>2]=113144;c=Bk(Kb(b));x[a+16>>2]=c;a:{b:{c:{if(!c){x[31725]=0;S(1008,d+4|0,17988,b|0);b=x[31725];x[31725]=0;if((b|0)==1){break c}x[31725]=0;W(1345,d+4|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}b=N()|0;tb(d+4|0);break b}fb=d+16|0;return a|0}b=N()|0}Zs(a);Q(b|0)}p()}function Hka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;w[a>>1]=0;c=Nb(a+4|0);d=Nb(a+16|0);x[a+36>>2]=0;e=Fb(a+40|0);f=qg(a+52|0);Nf(c);w[a+28>>1]=65472;x[31725]=0;x[b+12>>2]=1065353216;O(883,c|0,b+12|0);g=x[31725];x[31725]=0;if((g|0)!=1){x[a+32>>2]=0;w[a+30>>1]=0;Nf(d);fb=b+16|0;return a|0}a=N()|0;HZ(f);tb(e);uc(d);uc(c);Q(a|0);p()}function lga(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){a=x[a+20>>2];if(!a){break b}return Bg(a)|0}Y(T(0)|0)|0;x[31725]=0;V(989,12243,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();return 0}return Bg(22255)|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function B1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-512|0;fb=d;c=fb-16|0;fb=c;f=d+15|0;oF(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){nF(f)}c=-1;a:{if(!e){break a}c=0;if(!qF(d+15|0)){break a}c=ve(a,b,pF(y[d+125|0],y[d+126|0]),hb)}fb=d+512|0;return c|0}function tk(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function nv(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;c=D(a,b);ova(b,0,a,0);a=hb?0:c}else{a=0}a:{if(!a){break a}x[31725]=0;b=R(783,a|0)|0;c=x[31725];x[31725]=0;b:{c:{if((c|0)==1){Y(T(0)|0)|0;x[31725]=0;X(26);c=x[31725];x[31725]=0;b=0;if((c|0)==1){break c}}break b}T(0)|0;Sb();p()}if(!b){break a}d=Tb(b,0,a)- -64|0}return d}function Yea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[31725]=0;W(1002,a|0);f=x[31725];x[31725]=0;if((f|0)!=1){return fu(x[x[a+24>>2]+24>>2],b,c,d,e)|0}Y(T(0)|0)|0;x[31725]=0;V(989,12486,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function OT(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;i=x[d+20>>2];h=x[d+52>>2];g=!h|e;v[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}x[(D(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}x[d+24>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+48>>2]=h;w[d+72>>1]=z[d+74>>1];de(a,i>>>0>1&e&(b|0)==1,f+15|0);fb=f+16|0}function OG(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1129474426|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1634291279|(y[a+8|0]|y[a+9|0]<<8)!=14|(!(y[a+12|0]|y[a+13|0]<<8)|(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))<=0))){b=(y[a+18|0]|y[a+19|0]<<8|(y[a+20|0]<<16|y[a+21|0]<<24))>>>0>23}return b}function A2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;x[d>>2]=b;x[d+4>>2]=c;x[d+8>>2]=b;x[d+12>>2]=c;f=fb-16|0;fb=f;g=fb-16|0;fb=g;e=g+4|0;x[e+4>>2]=1;h=e,i=Ec(24),x[h+8>>2]=i;b=zm(x[e+8>>2]);x[b>>2]=78552;DG(nc(b),x[d>>2],x[d+4>>2]);c=f+8|0;b=Yn(e);Xn(c,nc(b),b);Am(e);fb=g+16|0;Ef(a,c);ke(c);fb=f+16|0;fb=d+16|0}function xra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=yb(b,c);d=fb-16|0;fb=d;e=Sd(b,c);a:{if(e>>>0<=Ug(a)>>>0){f=c;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;$C(d+12|0,h);f=x[d+12>>2]}b=Wg(b,f,g);if(!i){LY(a,f,c,e-oc(x[a>>2],x[a+4>>2])|0);break a}Ih(a,b);break a}wr(a);sm(a,Mf(a,e));LY(a,b,c,e)}fb=d+16|0}function x7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=fb-16|0;fb=g;k=Nh(g+12|0,x[a+8>>2]);i=yt(0,c,d-c|0,b?b:500204);Mh(k);fb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function jf(a,b,c){var d=0,e=0,f=0;e=Fb(a);d=y[b+11|0];f=x[b+4>>2];a=0;x[31725]=0;O(53,e|0,Yc(f,d)|0);d=x[31725];x[31725]=0;if((d|0)!=1){a:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=x[(y[cc(b,a)|0]<<2)+c>>2];x[31725]=0;O(35,e|0,d|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Qb(e);Q(a|0);p()}function QB(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function k2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;f=x[b+16>>2];a:{if(f>>>0<=c>>>0){bc(a,x[d>>2],0);break a}g=x[b+12>>2];b=x[b+4>>2];x[e+20>>2]=x[d+4>>2];x[e+16>>2]=f-c;bc(e+24|0,x[d>>2],x[Gb(e+20|0,e+16|0)>>2]);d=x[x[b>>2]+28>>2];f=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=f;ib[d|0](a,b,c+g|0,e+8|0)}fb=e+32|0}function Yaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=x[d+4>>2];oz(b,c,g);f=x[b+16>>2];a:{if(f>>>0<=c>>>0){bc(a,x[d>>2],0);break a}x[e+12>>2]=f-c;x[e+8>>2]=g;d=x[d>>2];f=x[Gb(e+12|0,e+8|0)>>2];Er(e,d,g,0,f);h=x[e>>2];i=x[e+4>>2];mp(Pe(wb(x[b+4>>2]),c),Pe(Pe(wb(x[b+4>>2]),c),i),h);Er(a,d,g,0,f)}fb=e+16|0}function VK(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;e=b+16|0;a:{while(1){d=x[a+36>>2];c=b+8|0;f=ib[x[x[d>>2]+20>>2]](d,x[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=x[b+4>>2]-c|0;if((Tk(g,1,c,x[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=iu(x[a+32>>2])?-1:0}fb=b+16|0;return d|0}function TJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=x[b>>2];h=x[a>>2];e=x[ec(a)>>2]==1238;f=x[c>>2];g=f-h|0;f=g>>>0>=2147483647?-1:(h|0)==(f|0)?4:g<<1;g=Fv(e?0:h,f);if(g){if(!e){le(a)}x[d+4>>2]=1205;e=Be(d+8|0,g,d+4|0);a=QJ(a,e);Lc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=x[a>>2]+(f&-4);fb=d+16|0;return}Ay();p()}function kra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;Or(e+8|0,c);x[31725]=0;O(598,e+20|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){vk(e,e+8|0);x[31725]=0;V(303,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function fT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=x[a+16>>2];e=d?y[(D(b,872)+a|0)+1429|0]:e;f=x[a+40>>2];b=D(b,872)+a|0;a=b+1467|0;v[a|0]=y[a|0]|64;a=b+1468|0;h=a;i=x[a>>2];g=(+(d>>>0)+1)*+(c|0)/+(f>>>0);a:{if(F(g)<2147483648){a=~~g;break a}a=-2147483648}x[h>>2]=i+(a+((c|0)<0?e:0-e|0)|0);c=(d+1|0)==(f|0)?c:a;a=c>>31;v[b+1429|0]=(a^c)-a}function CF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<5){if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==4){Rm(c+4|0,x[c+12>>2]);d=x[c+4>>2];break a}else{v[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){gh(a,c+11|0);e=y[c+11|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11235,9079,324,14199);p()}fb=c+16|0;return d}function v9(a){a=a|0;a:{x[31725]=0;R(1196,499224)|0;a=x[31725];x[31725]=0;b:{if((a|0)==1){break b}x[31725]=0;R(1196,499560)|0;a=x[31725];x[31725]=0;if((a|0)==1){break b}x[31725]=0;R(1197,499308)|0;a=x[31725];x[31725]=0;if((a|0)==1){break b}x[31725]=0;R(1197,499644)|0;a=x[31725];x[31725]=0;if((a|0)==1){break b}break a}T(0)|0;Sb();p()}}function fra(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(!b){break a}x[31725]=0;O(591,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;O(592,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;zY(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);zY(b);fb=c+16|0;return a|0}function t1(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(!b){break a}x[31725]=0;O(228,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)!=1){x[31725]=0;O(229,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){break a}}a=N()|0;VE(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);VE(b);fb=c+16|0;return a|0}function lta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;e_(e+8|0,c);x[31725]=0;O(93,e+20|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){vk(e,e+8|0);x[31725]=0;V(94,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function Qr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=wb(x[b>>2]);g=wb(x[b+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){a:{if(!Ib(d,g)){break a}f=fb-16|0;fb=f;xi(f+8|0,x[d>>2],x[d+4>>2]);h=$b(x[f+8>>2]);fb=f+16|0;if((c|0)==(h|0)){break a}d=x[nm(e+12|0)>>2];continue}break}fb=e+16|0;if(lc(d,wb(x[b+4>>2]))){bi(a);return}tp(a,d)}function pka(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;v[b+23|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;x[b+16>>2]=0;x[b+20>>2]=0;c=gc(b,b+16|0,15);kc(b+8|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);c=0;a:{if(x[b+12>>2]!=15){break a}if(kd(b+16|0,8525,15)){break a}Vb(a,15);c=1}fb=b+32|0;return c|0}function kua(a,b){a=a|0;b=b|0;var c=0;b=fb-32|0;fb=b;c=-1;a:{if(!$D(a,b+20|0)){break a}c=0;if(!w$(b+20|0)){break a}if((y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))==1179472708){c=-1;if(!gd(a,4)){break a}}c=-1;if(!rk(a,b+12|0)){break a}c=(y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24))==1196314451}fb=b+32|0;return c|0}function W4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;fo(e+8|0,c);x[31725]=0;O(93,e+20|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){vk(e,e+8|0);x[31725]=0;V(94,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function Jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,52)+f;b=x[d>>2];a:{while(1){if(x[d+4>>2]==(b|0)){break a}x[31725]=0;O(924,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){b=x[d>>2]+52|0;x[d>>2]=b;continue}break}a=N()|0;he(d);Q(a|0);p()}he(d);fb=e+16|0}function Foa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=fb-16|0;fb=c;x[c+12>>2]=4925421;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;if(A[e>>2]<b>>>0){dd();p()}if(b>>>0>=4925422){bk();p()}c=Ec(D(b,872));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=zb(a),g=b+D(x[d+12>>2],872)|0,x[f>>2]=g;fb=d+16|0}function CE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;xw(e+8|0,c);x[31725]=0;O(93,e+20|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){vk(e,e+8|0);x[31725]=0;V(94,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function $c(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;hl(b);e=a+8|0;f=yf(d+12|0,b);a:{b=x[a+8>>2];if(oc(b,x[a+12>>2])>>>0<=c>>>0){x[31725]=0;O(1292,e|0,c+1|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}b=x[e>>2]}a=yb(b,c);b=x[a>>2];if(b){Bm(b);a=yb(x[e>>2],c)}g=a,h=le(f),x[g>>2]=h;jJ(f);fb=d+16|0;return}a=N()|0;jJ(f);Q(a|0);p()}function uA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Id(d+24|0,a,b);b=fb-16|0;fb=b;f=x[d+28>>2];g=x[d+24>>2];h=f-g|0;i=b,j=nl(c,g,h)+D((h|0)/6|0,6)|0,x[i+12>>2]=j;Ac(d+16|0,f,b+12|0);fb=b+16|0;a=CR(a,x[d+16>>2]);i=d,j=tA(c,x[d+20>>2]),x[i+12>>2]=j;Ac(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function ld(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;vn(a);x[a+16>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0;x[a+4>>2]=0;w[a+32>>1]=64;x[a+24>>2]=8363;x[a+28>>2]=16777344;x[a+36>>2]=0;v[a+39|0]=0;v[a+40|0]=0;v[a+41|0]=0;v[a+42|0]=0;d=z[a+34>>1]&-25151;w[a+34>>1]=(b|0)==4?d|32:d;b=Dc(c+4|0,22255);ze(a+43|0,b);tb(b);rW(a);fb=c+16|0}function oia(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[x[a+20>>2]+148>>2]=-1;Rr(b+8|0,a+4228|0);c=x[a+20>>2];d=wb(x[b+8>>2]);e=Yk(x[b+8>>2],x[b+12>>2]);x[31725]=0;S(971,c+4|0,d|0,e|0);c=x[31725];x[31725]=0;a:{if((c|0)==1){c=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(c|0)|0;gp(x[a+20>>2]+4|0);Z()}fb=b+16|0;return}Q(c|0);p()}function Vua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,10);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0}return a|0}function E1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-784|0;fb=d;c=fb-16|0;fb=c;f=d+12|0;xF(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){wF(f)}c=-1;a:{if(!e){break a}c=0;if(!zF(d+12|0)){break a}c=ve(a,b,yF(y[d+527|0]),0)}fb=d+784|0;return c|0}function $sa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=1;a:{if(Ug(a)){d=x[a>>2];e=oc(d,x[a+4>>2]);x[c+8>>2]=e;f=x[Gb(c+12|0,c+8|0)>>2];while(1){if(f){w[d>>1]=z[b>>1];v[d+2|0]=y[b+2|0];f=f-1|0;d=d+4|0;continue}break}if(!e){l_(a,1-e|0,b);break a}Ih(a,x[a>>2]+4|0);break a}wr(a);sm(a,Mf(a,1));l_(a,1,b)}fb=c+16|0}function ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ri(a,b,c,d);x[a>>2]=43360;c=Nb(a+4208|0);x[a+4220>>2]=0;x[a+4224>>2]=1056964608;b=a+4228|0;v[b+4|0]=0;v[b+5|0]=4;v[b|0]=69;v[b+1|0]=99;v[b+2|0]=104;v[b+3|0]=111;v[b+6|0]=1;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){lu(a);return a|0}b=N()|0;uc(c);ag(a);Q(b|0);p()}function bma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=fb-32|0;fb=d;Rv(d+8|0,c);x[31725]=0;O(476,d+20|0,41676);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){vk(d,d+8|0);x[31725]=0;V(94,a|0,b|0,x[d>>2],x[d+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(d+8|0);fb=d+32|0;break a}a=N()|0;tb(d+8|0);break b}a=N()|0;Ag(d+8|0)}Q(a|0);p()}}function Uq(a){var b=0,c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;b=wb(x[a>>2]);f=wb(x[a+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=b;while(1){if(Ib(b,f)){c=c+C[b>>3];b=x[_u(e+12|0)>>2];continue}break}fb=e+16|0;b=wb(x[a>>2]);x[d+12>>2]=b;c=-c;a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){c=c+C[b>>3];C[b>>3]=c;b=x[_u(d+12|0)>>2];continue}else{fb=d+16|0}break}}function Cra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb+-64|0;fb=d;c=fb-16|0;fb=c;f=d+12|0;WY(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){VY(f)}c=-1;a:{if(!e){break a}c=0;if(!YY(d+12|0)){break a}c=ve(a,b,XY(d+12|0),hb)}fb=d- -64|0;return c|0}function z1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;c=fb-16|0;fb=c;f=d+10|0;hF(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){gF(f)}c=-1;a:{if(!e){break a}c=0;if(!jF(d+10|0)){break a}c=ve(a,b,iF(y[d+45|0]),hb)}fb=d+48|0;return c|0}function V7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=x[b>>2];h=x[a>>2];e=x[ec(a)>>2]==1238;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g>>>0<=1?1:g;g=Fv(e?0:h,f);if(g){if(!e){le(a)}x[d+4>>2]=1205;e=Be(d+8|0,g,d+4|0);a=QJ(a,e);Lc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=f+x[a>>2];fb=d+16|0;return}Ay();p()}function Ksa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{e=Mb(x[b>>2],x[b+8>>2],c<<2);if(!e){break a}wc(d+12|0,65535);xg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}f=d+8|0;if(!Un(b,f)){In(f)}w[c>>1]=x[d+8>>2];c=x[Md(d+4|0)>>2];continue}}fb=d+16|0;return e|0}function IP(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;a=Nb(a);x[31725]=0;W(992,b+4|0);c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){c=wb(x[b+4>>2]);d=wb(x[b+8>>2]);e=x[vb(b,a)>>2];x[31725]=0;S(993,c|0,d|0,e|0);c=x[31725];x[31725]=0;if((c|0)==1){break b}uc(b+4|0);fb=b+16|0;return}c=N()|0;break a}c=N()|0;uc(b+4|0)}Td(a);Q(c|0);p()}
function saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Xo(e,c);x[31725]=0;S(504,d+20|0,b|0,e|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;S(246,a|0,0,d+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function nQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+24620>>2]/5|0;b=Gc(b,b>>31);x[a+4272>>2]=b;x[31725]=0;x[c+12>>2]=0;S(953,a+4256|0,b<<1,c+12|0);b=x[31725];x[31725]=0;a:{if((b|0)==1){b=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;x[a+4272>>2]=0;Z()}x[a+4276>>2]=0;x[a+4268>>2]=0;fb=c+16|0;return}Q(b|0);p()}function SR(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{while(1){x[e+12>>2]=b;x[e+8>>2]=d;if(A[Gb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=Rq(v[xb(a,f)|0]);h=Rq(v[xb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}fb=e+16|0;return a}function J9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=x[a+44>>2];c=x[a+24>>2];if(e>>>0<c>>>0){x[a+44>>2]=c;e=c}g=x[a+8>>2];f=x[a+12>>2];d=-1;a:{if(g>>>0>=f>>>0){break a}if(lc(b,-1)){no(a,g,f-1|0,e);return My(b)|0}c=b<<24>>24;if(!(x[a+48>>2]&16)){d=-1;if(!lc(c,v[f-1|0])){break a}}no(a,g,f-1|0,e);v[x[a+12>>2]]=c;d=b}return d|0}function xja(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=Tg(c+4|0,a,1);Dk(x[a+4>>2],B[b>>2]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Dk(x[c+8>>2],B[b>>2]);x[c+8>>2]=x[c+8>>2]+4;mA(a,c);_f(c);fb=d+32|0}function _la(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=d;c=Hf(a,c);$d(e+8|0,x[a+36>>2]);f=a;a:{if(!c){Pc(e+8|0,a+32|0,5);d=0;if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}d=x[a+36>>2];a=0;ZE(b,x[e+28>>2]);while(1){if(A[e+28>>2]>a>>>0){ZU(d,_b(x[b>>2],a));a=a+1|0;continue}break}d=c}gf(f,d);fb=e+32|0}function Ms(a,b,c,d,e,f){var g=0;g=fb-16|0;fb=g;x[g+12>>2]=d;d=x[re(g+8|0,g+12|0)>>2];x[31725]=0;ha(f|0,a+8|0,b|0,c|0,d|0,e|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){a=Ez(a);b=Dz(a+88|0);c=Cz(a+92|0);d=Bz(a+96|0);x[a>>2]=47772;x[b>>2]=47888;x[c>>2]=47968;x[d>>2]=48008;Vc(g+12|0);fb=g+16|0;return a}a=N()|0;Vc(g+12|0);Q(a|0);p()}function JE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=Hk(b,zd(a));a:{f=Cb(x[a+4>>2],y[a+11|0]);if(b>>>0<=f>>>0){if(c){e=Mc(a);b:{if(e-f>>>0>=c>>>0){e=Kb(a);if((b|0)==(f|0)){break b}g=b+e|0;Vi(g+c|0,g,f-b|0);break b}Xm(a,e,(c+f|0)-e|0,f,b,0,c);e=x[a>>2]}im(b+e|0,c,d);b=c+f|0;ng(a,b);fd(b+e|0,0)}break a}ln();p()}zd(a)}function Dpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-608|0;fb=d;c=fb-16|0;fb=c;oX(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){nX(d)}c=-1;a:{if(!e){break a}c=0;if(!qX(d)){break a}c=ve(a,b,pX(y[d+34|0]|y[d+35|0]<<8),hb)}fb=d+608|0;return c|0}function zsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Sc(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;b=b-d|0;d=x[zb(a)>>2];f=x[a+4>>2];a:{if(b>>>0<=d-f>>>0){Hp(a,b,c);break a}d=zb(a);d=wn(e+12|0,cm(a,Sc(x[a>>2],f)+b|0),Sc(x[a>>2],x[a+4>>2]),d);uZ(d,b,c);ir(a,d);un(d)}fb=e+32|0;return}if(b>>>0<d>>>0){pr(a,b+e|0)}}function tra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Gp(e,b,c);x[31725]=0;S(125,d+20|0,28,e|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;O(12,a|0,d+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function M0(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=$h(c+4|0,a,1);gj(x[a+4>>2],z[b>>1]);x[a+4>>2]=x[a+4>>2]+2;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=ok(d+12|0,pk(a,Zc(x[a>>2],x[a+4>>2])+1|0),Zc(x[a>>2],x[a+4>>2]),c);gj(x[c+8>>2],z[b>>1]);x[c+8>>2]=x[c+8>>2]+2;Yr(a,c);kj(c);fb=d+32|0}function Eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;if((d|0)!=1){x[a+16>>2]=0;x[a+12>>2]=c;x[a+8>>2]=b;return}Y(T(0)|0)|0;x[31725]=0;V(989,13107,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Ata(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-208|0;fb=d;c=fb-16|0;fb=c;f=d+2|0;C_(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){B_(f)}c=-1;a:{if(!e){break a}c=0;if(!E_(d+2|0)){break a}c=ve(a,b,D_(d+2|0),hb)}fb=d+208|0;return c|0}function qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Xo(e,c);x[31725]=0;O(14,d+20|0,e|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){x[31725]=0;S(845,a|0,b|0,d+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function jo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=fb-16|0;fb=e;a:{f=Sd(b,c);if(f>>>0<1073741808){b:{if(lr(f)){Me(d,f);break b}Wj(e+8|0,zn(f)+1|0);g=x[e+8>>2];yd(d,g);pf(d,x[e+12>>2]);Yd(d,f);d=g}while(1){if((b|0)!=(c|0)){yd(d,x[b>>2]);d=d+4|0;b=b+4|0;continue}break}yd(d,0);fb=e+16|0;break a}qf();p()}return a|0}function Y3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{e=x[b>>2];if(Dd(e)){f=d+4|0;if(!Ad(x[c+4>>2],y[c+11|0])){HP(c,18382);e=x[b>>2]}b=x[b+4>>2];ib[x[x[b>>2]+24>>2]](f,b,e);x[31725]=0;P(842,c|0,f|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}tb(d+4|0)}_c(a,c);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function Hqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Xo(e,c);x[31725]=0;S(125,d+20|0,b|0,e|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;O(12,a|0,d+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function ti(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=fb-16|0;fb=e;a:{f=Yj(b,c);if(f>>>0<2147483632){b:{if(Uk(f)){Me(d,f);break b}sg(e+8|0,Eh(f)+1|0);g=x[e+8>>2];yd(d,g);pf(d,x[e+12>>2]);Yd(d,f);d=g}while(1){if((b|0)!=(c|0)){fd(d,y[b|0]);d=d+1|0;b=b+1|0;continue}break}fd(d,0);fb=e+16|0;break a}qf();p()}return a|0}function j0(a,b,c,d){var e=0,f=0,g=0,h=0;e=Cb(x[a+4>>2],y[a+11|0]);if(e>>>0>=b>>>0){f=Mc(a);a:{if(f-e>>>0>=d>>>0){if(!d){break a}f=Kb(a);h=f+b|0;if((b|0)!=(e|0)){g=b+f|0;Vi(g+d|0,g,e-b|0);c=(c>>>0>=g>>>0?e+f>>>0>c>>>0?d:0:0)+c|0}Vi(h,c,d);b=d+e|0;ng(a,b);fd(b+f|0,0);return a}fq(a,f,(d+e|0)-f|0,e,b,0,d,c)}return a}ln();p()}function b0(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){c=fb-16|0;fb=c;b=vb(c+12|0,x[x[a+8>>2]>>2]);e=x[vb(c+8|0,x[x[a+4>>2]>>2])>>2];d=fb-16|0;fb=d;a=x[b>>2];x[d+12>>2]=a;while(1){if(di(a,e)){b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+12>>2]=x[b+12>>2]+28;fb=b+16|0;Gd(kE(x[b+12>>2]));a=x[nm(d+12|0)>>2];continue}break}fb=d+16|0;fb=c+16|0}}function _ua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-1968|0;fb=e;c=fb-16|0;fb=c;f=e+14|0;E0(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){D0(f)}c=-1;a:{if(!d){break a}c=0;if(!G0(e+14|0)){break a}c=ve(a,b,1024,0)}fb=e+1968|0;return c|0}function Rj(a){var b=0,c=0,d=0,e=0,f=0;b=x[a+4>>2];if(lc(x[a>>2],b)){a=0}else{b=$i(b);e=$i(x[a>>2]);c=fb-16|0;fb=c;x[c+12>>2]=b;while(1){a:{if(!Zg(b,e)){break a}d=fb-16|0;fb=d;x[d+12>>2]=b;f=jj(d+12|0);fb=d+16|0;if(z[x[f>>2]>>1]!=65535){break a}b=x[jj(c+12|0)>>2];continue}break}fb=c+16|0;a=mE(wb(x[a>>2]),b)}return a&65535}function KZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Wf(e,c);x[31725]=0;S(504,d+20|0,b|0,e|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;O(12,a|0,d+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function Kka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(!Dd(x[a+1298300>>2])){d=x[a+24620>>2];e=fb-16|0;fb=e;b=Ec(536);x[31725]=0;d=P(878,b|0,d|0)|0;f=x[31725];x[31725]=0;a:{if((f|0)!=1){b=x[yf(e+12|0,d)>>2];fb=e+16|0;break a}a=N()|0;Db(b);Q(a|0);p()}x[c+12>>2]=b;b=a+1298300|0;a=c+12|0;xS(b,le(a));WA(a)}fb=c+16|0}function kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;b=b-c|0;c=x[zb(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){$q(a,b);break a}c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],e)+b|0),oc(x[a>>2],x[a+4>>2]),c);jA(c,b);_m(a,c);_f(c)}fb=d+32|0;return}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}function _F(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179340888|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1213419859){break a}b=$b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24));if(!b){break a}c=($b(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function Fra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=x[a+8>>2];e=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=D(b,20)+e;b=x[c>>2];a:{while(1){if(x[c+4>>2]==(b|0)){break a}x[31725]=0;W(230,b|0);a=x[31725];x[31725]=0;if((a|0)!=1){b=x[c>>2]+20|0;x[c>>2]=b;continue}break}a=N()|0;he(c);Q(a|0);p()}he(c);fb=d+16|0}function aY(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808604749|((y[a+8|0]|y[a+9|0]<<8)-768&65535)>>>0<65280|(((y[a+112|0]|y[a+113|0]<<8)-65&65535)>>>0<65472|(y[a+106|0]|y[a+107|0]<<8)>>>0>256)){break a}if((y[a+122|0]|y[a+123|0]<<8)>>>0>255){break a}b=(y[a+124|0]|y[a+125|0]<<8)>>>0<4e3}return b}function Js(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;x[f+12>>2]=c;c=x[re(f+8|0,f+12|0)>>2];x[31725]=0;ba(e|0,a+8|0,b|0,c|0,d|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){a=Ez(a);b=Dz(a+88|0);c=Cz(a+92|0);d=Bz(a+96|0);x[a>>2]=47772;x[b>>2]=47888;x[c>>2]=47968;x[d>>2]=48008;Vc(f+12|0);fb=f+16|0;return a}a=N()|0;Vc(f+12|0);Q(a|0);p()}function Gia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=33;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;hD(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);hD(e,b);Tb(x[d+8>>2]+c|0,0,33-c|0);Vb(a,x[d+28>>2]);fb=d+32|0;return c|0}function AA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=c>=.999?.999:c;h=c*3.141592653589793;i=av(b);while(1){if((e|0)!=32768){f=((e^-1)<<12&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=Xi(g)*av(M(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=qC(c*d*32768),w[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function yqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-128|0;fb=e;c=fb-16|0;fb=c;f=e+2|0;$X(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){_X(f)}c=-1;a:{if(!d){break a}c=0;if(!aY(e+2|0)){break a}c=ve(a,b,256,0)}fb=e+128|0;return c|0}function nS(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;lS(d,b+80|0);x[31725]=0;S(125,c+20|0,0,d|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;O(12,a|0,c+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function RU(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;if(y[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){v[a+534|0]=0}else{Oj(a,d,1);c=c+1|0;continue}break}}v[b+15|0]=0;Vh(a+8|0,18,b+15|0);Hv(a+26|0,18,27562);v[b+14|0]=255;Vh(a+62|0,256,b+14|0);Ah(x[a>>2],x[a+4>>2],65535,261,1);Ah(x[a>>2],x[a+4>>2],65535,260,0);fb=b+16|0}function M3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(oh(a,x[b+8>>2],e)){Ox(b,c,d);return}a:{if(!oh(a,x[b>>2],e)){break a}if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+20>>2]=c;x[b+32>>2]=d;x[b+40>>2]=x[b+40>>2]+1;if(!(x[b+36>>2]!=1|x[b+24>>2]!=2)){v[b+54|0]=1}x[b+44>>2]=4}}function BM(a){var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;if(!y[a+20|0]){while(1){if(!(ib[x[x[a>>2]+40>>2]](a)|0)){zM(a,65536);c=gc(b+16|0,xb(x[a+4>>2],x[a+16>>2]),65536);d=x[x[a>>2]+44>>2];e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;ib[d|0](b+24|0,a,b+8|0);x[a+16>>2]=x[a+16>>2]+x[b+28>>2];continue}break}v[a+20|0]=1}fb=b+32|0}function fua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;c=fb-16|0;fb=c;f=e+15|0;R0(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){FE(f)}c=-1;a:{if(!d){break a}c=0;if(!n$(e+15|0)){break a}c=ve(a,b,72,0)}fb=e+32|0;return c|0}function aha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ri(a,b,c,d);x[a+4272>>2]=1065353216;x[a>>2]=45504;b=a+4208|0;e=yb(b,0),f=1056880300,x[e>>2]=f;e=yb(b,1),f=1050733080,x[e>>2]=f;e=yb(b,2),f=1056964608,x[e>>2]=f;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;ag(a);Q(b|0);p()}function _Q(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=Ug(a);b=oc(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[31725]=0;b=ba(952,c+12|0,b|0,b|0,zb(a)|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){_m(a,b);_f(b);break b}Y(T(0)|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break a}}fb=c+32|0;return}T(0)|0;Sb();p()}function Uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ri(a,b,c,d);x[a>>2]=45740;b=a+4208|0;e=yb(b,0),f=1065353216,x[e>>2]=f;e=yb(b,1),f=1065353216,x[e>>2]=f;e=yb(b,2),f=1051372203,x[e>>2]=f;e=yb(b,3),f=0,x[e>>2]=f;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;ag(a);Q(b|0);p()}function $y(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-240|0;fb=g;x[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-x[(i<<2)+d>>2]|0;if((so(a,f,b)|0)>=0){if((so(a,e,b)|0)>=0){break a}}j=f;f=(so(f,e,b)|0)>=0;e=f?j:e;x[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}LL(g,h);fb=g+240|0}function $Q(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=cA(a);b=qk(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[31725]=0;b=ba(951,c+12|0,b|0,b|0,zb(a)|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){YQ(a,b);XQ(b);break b}Y(T(0)|0)|0;x[31725]=0;X(26);a=x[31725];x[31725]=0;if((a|0)==1){break a}}fb=c+32|0;return}T(0)|0;Sb();p()}function g3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;bd(a,x[b+28>>2]);x[31725]=0;S(110,d+12|0,b|0,c|0);e=x[31725];x[31725]=0;a:{if((e|0)==1){break a}Zb(d+12|0);b=x[b+24>>2];if(b){x[31725]=0;S(111,d+8|0,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)==1){break a}Zb(d+8|0)}fb=d+16|0;return}b=N()|0;Zb(a);Q(b|0);p()}function _pa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=zw(c+4|0,a,1);MX(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=QD(d+12|0,RD(a,Uf(x[a>>2],x[a+4>>2])+1|0),Uf(x[a>>2],x[a+4>>2]),c);MX(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;PD(a,c);Yv(c);fb=d+32|0}function zia(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;Wf(d,b);x[31725]=0;O(964,c+20|0,d|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;S(965,a|0,0,c+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function zfa(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return E(nP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31725]=0;V(989,9377,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function xfa(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return E(mP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31725]=0;V(989,6272,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function wfa(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return E(lP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31725]=0;V(989,6174,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function vfa(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return E(kP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31725]=0;V(989,6130,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function iE(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=H$(c+4|0,a,1);G$(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+40;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=E$(d+12|0,F$(a,Jr(x[a>>2],x[a+4>>2])+1|0),Jr(x[a>>2],x[a+4>>2]),c);G$(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+40;D$(a,c);C$(c);fb=d+32|0}function cma(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=jC(c+4|0,a,1);XB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+32;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=gv(d+12|0,ar(a,Lg(x[a>>2],x[a+4>>2])+1|0),Lg(x[a>>2],x[a+4>>2]),c);XB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;$U(a,c);YB(c);fb=d+32|0}function Lta(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=zw(c+4|0,a,1);SD(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=QD(d+12|0,RD(a,Uf(x[a>>2],x[a+4>>2])+1|0),Uf(x[a>>2],x[a+4>>2]),c);SD(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;PD(a,c);Yv(c);fb=d+32|0}function Fta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-224|0;fb=d;c=fb-16|0;fb=c;L_(c+8|0,d+6|0);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!N_(d+6|0)){break a}c=ve(a,b,M_(y[d+222|0],y[d+223|0]),hb)}fb=d+224|0;return c|0}function FM(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=x[a>>2];a:{if(!c){break a}d=x[a+8>>2];if(!d){break a}e=x[a+12>>2];if(!e){break a}a=ib[e|0](c)|0;f=hb;if((f|0)<0){break a}b=0;b:{if((ib[d|0](c,0,0,0)|0)<0){break b}b=0;if((ib[d|0](c,0,0,2)|0)<0){break b}ib[e|0](c)|0;b=hb;b=(b|0)>0|(b|0)>=0}ib[d|0](c,a,f,0)|0}return b|0}function Dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[31725]=0;W(1002,a|0);d=x[31725];x[31725]=0;if((d|0)!=1){x[a+4>>2]=c;x[a>>2]=b?b:983;return}Y(T(0)|0)|0;x[31725]=0;V(989,13137,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Afa(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return E(oP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31725]=0;V(989,6229,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function mka(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;Xo(d,b);x[31725]=0;O(14,c+20|0,d|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;S(246,a|0,0,c+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function ipa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=xx(c+4|0,a);uC(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=Em(d+12|0,Yp(a,Ud(x[a>>2],x[a+4>>2])+1|0),Ud(x[a>>2],x[a+4>>2]),c);uC(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;NW(a,c);MW(c);fb=d+32|0}function Xja(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;$k(d,b);x[31725]=0;O(14,c+20|0,d|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;S(246,a|0,0,c+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function U1(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;Wf(d,b);x[31725]=0;S(125,c+20|0,22,d|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;O(12,a|0,c+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Qb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function ME(a){var b=0,c=0,d=0,e=0;c=y[a+9|0]|y[a+10|0]<<8;d=ova(y[a+3|0],0,18,0);c=c+d|0;b=hb;e=d>>>0>c>>>0?b+1|0:b;d=y[a+6|0]|y[a+7|0]<<8;b=d>>>31|0;d=d<<1;c=d+c|0;b=b+e|0;d=d>>>0>c>>>0?b+1|0:b;a=y[a+4|0]|y[a+5|0]<<8;b=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+3|0;hb=b>>>0<3?a+1|0:a;return b}function sla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;b=lg(d+8|0,b);x[31725]=0;S(841,d+20|0,b|0,c|0);e=x[31725];x[31725]=0;a:{b:{if((e|0)!=1){x[31725]=0;S(73,a|0,d+20|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}tb(d+20|0);tb(b);fb=d+32|0;return}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(b);Q(c|0);p()}function ioa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=4896;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;kD(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);kD(e,b);Tb(x[d+8>>2]+c|0,0,4896-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function iA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;h=z[b>>1];c=ce(a);e=ec(a);f=fb-16|0;fb=f;while(1){if(c){g=cr(z[c+16>>1],h);e=g?e:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[vb(f+12|0,e)>>2];fb=f+16|0;a:{if(Ib(c,rg(a))){if(!cr(z[b>>1],z[td(c)>>1])){break a}}c=rg(a)}a=x[vb(d+12|0,c)>>2];fb=d+16|0;return a}function tH(a,b,c,d,e){var f=0;a:{f=fb-32|0;fb=f;Wp(f+8|0,c);x[31725]=0;O(e|0,f+20|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){vk(f,f+8|0);x[31725]=0;V(94,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(f+8|0);fb=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;Ag(f+8|0)}Q(a|0);p()}}function mH(a,b,c,d,e){var f=0;a:{f=fb-32|0;fb=f;Z_(f+8|0,c);x[31725]=0;O(e|0,f+20|0,d|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){vk(f,f+8|0);x[31725]=0;V(94,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[31725];x[31725]=0;if((a|0)==1){break c}Ag(f+8|0);fb=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;Ag(f+8|0)}Q(a|0);p()}}function T1(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=sG(c+4|0,a);bx(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+36;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=qG(d+12|0,rG(a,js(x[a>>2],x[a+4>>2])+1|0),js(x[a>>2],x[a+4>>2]),c);bx(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+36;oG(a,c);dx(c);fb=d+32|0}function Pua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c<<1)){break a}wc(d+12|0,65535);xg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}HE(b,d+10|0);e=c,f=Bb(z[d+10>>1]),w[e>>1]=f;c=x[Md(d+4|0)>>2];continue}}fb=d+16|0}function qoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=263;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;JV(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);JV(e,b);Tb(x[d+8>>2]+c|0,0,263-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function fta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=102;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;m_(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);m_(e,b);Tb(x[d+8>>2]+c|0,0,102-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function UX(a){var b=0,c=0,d=0,e=0,f=0;f=y[a+28|0]|y[a+29|0]<<8;c=ova(y[a+30|0],0,37,0);d=hb;b=ova(y[a+24|0]|y[a+25|0]<<8,0,192,0);c=b+c|0;d=hb+d|0;b=b>>>0>c>>>0?d+1|0:d;a=y[a+26|0];d=a>>>26|0;e=c;c=a<<6;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+f|0;a=b>>>0<e>>>0?a+1|0:a;b=b+192|0;hb=b>>>0<192?a+1|0:a;return b}function K2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;b=Cm(d+8|0,b);x[31725]=0;S(150,d+20|0,b|0,c|0);e=x[31725];x[31725]=0;a:{b:{if((e|0)!=1){x[31725]=0;S(4,a|0,d+20|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}tb(d+20|0);tb(b);fb=d+32|0;return}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(b);Q(c|0);p()}function pA(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+D(b,52);b=x[d+4>>2];f=x[d+8>>2];a:{while(1){if((b|0)==(f|0)){break a}x[31725]=0;O(924,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){b=b+52|0;x[d+4>>2]=b;continue}break}a=N()|0;hc(d);Q(a|0);p()}hc(d);fb=e+16|0}function yra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=22;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;Zv(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Zv(e,b);Tb(x[d+8>>2]+c|0,0,22-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function wra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=40;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;aD(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);aD(e,b);Tb(x[d+8>>2]+c|0,0,40-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function f8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=x[27991];x[g+24>>2]=x[27990];x[g+28>>2]=h;h=x[27989];x[g+16>>2]=x[27988];x[g+20>>2]=h;h=x[27987];x[g+8>>2]=x[27986];x[g+12>>2]=h;h=x[27985];x[g>>2]=x[27984];x[g+4>>2]=h;h=a;a=g+32|0;b=zk(h,b,c,d,e,f,g,a);fb=a;return b|0}function Z2(a){a=a|0;var b=0,c=0;a:{b=fb-32|0;fb=b;c=b+8|0;Dc(c,13576);x[31725]=0;S(125,b+20|0,1,c|0);c=x[31725];x[31725]=0;b:{c:{if((c|0)!=1){x[31725]=0;O(12,a|0,b+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(b+20|0);tb(b+8|0);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Qb(b+20|0)}tb(b+8|0);Q(a|0);p()}}function YZ(a){var b=0;a:{b:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1297108297){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=778924148){break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0<=255){break b}break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0>255){break a}}b=(y[a+36|0]|y[a+37|0]<<8)>>>0<4e3}return b}function zea(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){zO(x[x[a+24>>2]+24>>2],b);return 1}Y(T(0)|0)|0;x[31725]=0;V(989,5784,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function p1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=65;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;yw(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);yw(e,b);Tb(x[d+8>>2]+c|0,0,65-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function gQ(a){var b=0,c=E(0),d=0,e=0;e=x[x[a+16>>2]+24620>>2];b=fb-16|0;fb=b;x[b+12>>2]=0;x[b+8>>2]=1065353216;c=si(E(B[Nv(a+4208|0,b+12|0,b+8|0)>>2]*E(999)));a:{if(c<E(4294967296)&c>=E(0)){d=~~c>>>0;break a}d=0}fb=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0<=2?2:b;x[a+4216>>2]=b;x[a+4220>>2]=b>>>1;wc(a+4224|0,b)}function Zea(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return UO(x[x[a+24>>2]+24>>2],b)|0}Y(T(0)|0)|0;x[31725]=0;V(989,6659,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function S4(a,b,c){a=a|0;b=b|0;c=c|0;a=0;if(b&1){a=(vt(c)|0)!=0}if(b&2){a=(ut(c)|0)!=0|a}if(b&4){a=(tt(c)|0)!=0|a}if(b&8){a=(st(c)|0)!=0|a}if(b&16){a=(rt(c)|0)!=0|a}if(b&32){a=(qt(c)|0)!=0|a}if(b&64){a=(Oh(c)|0)!=0|a}if(b&128){a=(pt(c)|0)!=0|a}if(b&256){a=(ot(c)|0)!=0|a}if(b&512){a=(nt(c)|0)!=0|a}return a|0}function Ll(a,b){var c=0,d=0,e=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;b=b-c|0;c=x[zb(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){$q(a,b);break a}c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],e)+b|0),oc(x[a>>2],x[a+4>>2]),c);jA(c,b);mA(a,c);_f(c)}fb=d+32|0;return}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}function vta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=5;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;ik(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);ik(e,b);Tb(x[d+8>>2]+c|0,0,5-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function rH(a,b,c,d){var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;Cc(f,c);x[31725]=0;S(d|0,e+20|0,b|0,f|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;O(12,a|0,e+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(e+20|0);tb(e+8|0);fb=e+32|0;break a}a=N()|0;break b}a=N()|0;Qb(e+20|0)}tb(e+8|0);Q(a|0);p()}}function bR(a,b){var c=0,d=0,e=0,f=0,g=E(0);c=fb-16|0;fb=c;if(!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){w[c+14>>1]=0;pg(a,c+14|0);e=z[c+14>>1];Ll(b,e);while(1){if((d|0)!=(e|0)){x[c+8>>2]=0;Dq(a,c+8|0);f=yb(x[b>>2],d),g=B[c+8>>2],B[f>>2]=g;d=d+1|0;continue}break}d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}fb=c+16|0;return d}function xH(a,b,c){var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Dc(e,b);x[31725]=0;S(125,d+20|0,c|0,e|0);b=x[31725];x[31725]=0;b:{c:{if((b|0)!=1){x[31725]=0;O(12,a|0,d+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break c}Qb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Qb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function wm(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=D(c,872)+b|0;f=aT(x[d+720>>2],x[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return $S(a,b,c,e);case 1:break b;default:break a}}f=$S(a,b,c,e);if((f+5&255)>>>0>5){break a}a=D(c,872)+b|0;f=aT(x[a+720>>2],x[a+1272>>2],e)}return f}function qu(a){var b=0,c=0,d=0;b=Di(+B[a+4228>>2]*8)*.25+-.25;C[a+4248>>3]=b;if(y[a+4240|0]){if(b>45e-5){c=sq(b)/.6931471805599453;b=c-J(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Di(d+c)*.5}else{b=0}C[a+4248>>3]=b}pu(a)}function gV(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;e=x[b+4>>2];f=vb(d+12|0,c);g=vb(d+8|0,x[a>>2]);h=vb(d+4|0,x[b+4>>2]);i=b,j=OF(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=Cr(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=d+16|0;return e}function g$(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;e=x[b+4>>2];f=vb(d+12|0,c);g=vb(d+8|0,x[a>>2]);h=vb(d+4|0,x[b+4>>2]);i=b,j=XW(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=Cr(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=d+16|0;return e}function c2(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;d=c+8|0;$k(d,b);x[31725]=0;O(14,c+20|0,d|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){x[31725]=0;O(15,a|0,c+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Qb(c+20|0);tb(c+8|0);fb=c+32|0;return}b=N()|0;break a}b=N()|0;Qb(c+20|0)}tb(c+8|0);Q(b|0);p()}function ZQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=2097152){bk();p()}d=Ec(b<<11);x[e+12>>2]=b;x[e+8>>2]=d;d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<11)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<11)|0,x[f>>2]=g;fb=e+16|0;return a|0}function Psa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-192|0;fb=d;c=fb-16|0;fb=c;nw(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){WZ(d)}c=-1;a:{if(!e){break a}c=0;if(!YZ(d)){break a}c=ve(a,b,XZ(d),hb)}fb=d+192|0;return c|0}function gja(a,b){a=a|0;b=b|0;var c=0;c=x[a+20>>2];b=x[c+4>>2];a:{if(!((Sc(b,x[c+8>>2])|0)!=8|(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=1869112133)){c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;break a}aA(a,a)}ru(a)}function Rn(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(x[c>>2]|x[d>>2]){while(1){if((b|0)==(f|0)){break a}e=x[d>>2];g=x[c>>2];h=c,i=g-qd((qd(0-g|0,31)&255)+g|0,8)|0,x[h>>2]=i;h=d,i=x[d>>2]-qd(e+(qd(0-e|0,31)&255)|0,8)|0,x[h>>2]=i;e=(f<<3)+a|0;x[e>>2]=x[c>>2];x[e+4>>2]=x[d>>2];f=f+1|0;continue}}Tb(a,0,b<<3)}}function PQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[a+4232>>2];b=(b>>>1)+(b>>>6)|0;x[a+4220>>2]=b;x[31725]=0;x[c+12>>2]=0;S(953,a+4208|0,b<<1,c+12|0);b=x[31725];x[31725]=0;a:{if((b|0)==1){b=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;x[a+4220>>2]=0;Z()}x[a+4224>>2]=0;fb=c+16|0;return}Q(b|0);p()}function z7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;x[e>>2]=c;a=fy(f+12|0,0,x[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-x[e>>2]>>>0){break a}b=f+12|0;while(1){if(c){a=y[b|0];d=x[e>>2];x[e>>2]=d+1;v[d|0]=a;c=c-1|0;b=b+1|0;continue}break}b=0}fb=f+16|0;return b|0}function voa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=fb-16|0;fb=c;rZ(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){mD(d)}c=-1;a:{if(!e){break a}c=0;if(!NV(d)){break a}c=ve(a,b,MV(d),hb)}fb=d+80|0;return c|0}function ht(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}v[a|0]=43;a=a+1|0}if(d&512){v[a|0]=35;a=a+1|0}while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}v[a|0]=b}function gpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=fb-16|0;fb=c;x[c+12>>2]=477218588;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;if(A[e>>2]<b>>>0){dd();p()}c=Ec(D(b,9));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=zb(a),g=b+D(x[d+12>>2],9)|0,x[f>>2]=g;fb=d+16|0}function zU(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=xt(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);Xl(e,b,+n());return}a:{if(!zf(b)){break a}d=F(c)<Infinity;if(b<0){c=d?c:1;break a}if(d){break a}Xl(a,b,zf(c)?NaN:c);return}b=xt(b);g=Xi(c);Xl(a,b*kf(c),g*b)}function sv(a){var b=0,c=0;b=x[a+76>>2];a:{if(!((b|0)>=0&(!b|x[124213]!=(b&-1073741825)))){b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;a=y[b|0];break a}a=Ky(a);break a}b=a+76|0;c=x[b>>2];x[b>>2]=c?c:1073741823;c=x[a+4>>2];b:{if((c|0)!=x[a+8>>2]){x[a+4>>2]=c+1;a=y[c|0];break b}a=Ky(a)}le(b)}return a}function Zla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;c=Hf(a,c);$d(d,x[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(e+1|0){case 0:case 2:Li(f,b);break c;default:break d}}CZ(f,b,e)}f=c}gf(a,f);fb=d+16|0}function RI(a){a=a|0;var b=0,c=0,d=0;b=a+12|0;Qb(b+520|0);Qb(b+508|0);Qb(b+496|0);d=b+460|0;c=Qb(b+484|0);while(1){c=Qb(c-12|0);if((d|0)!=(c|0)){continue}break}c=b+172|0;while(1){d=Qb(d-12|0);if((d|0)!=(c|0)){continue}break}d=b+4|0;while(1){c=Qb(c-12|0);if((d|0)!=(c|0)){continue}break}Xs(b);return a|0}function GI(a){a=a|0;var b=0,c=0,d=0;b=a+12|0;tb(b+520|0);tb(b+508|0);tb(b+496|0);d=b+460|0;c=tb(b+484|0);while(1){c=tb(c-12|0);if((d|0)!=(c|0)){continue}break}c=b+172|0;while(1){d=tb(d-12|0);if((d|0)!=(c|0)){continue}break}d=b+4|0;while(1){c=tb(c-12|0);if((d|0)!=(c|0)){continue}break}Xs(b);return a|0}function ny(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;f=fb-16|0;fb=f;a:{if(b>>>0<1073741808){b:{if(lr(b)){Me(d,b);break b}Wj(f+8|0,zn(b)+1|0);e=x[f+8>>2];yd(d,e);pf(d,x[f+12>>2]);Yd(d,b);d=e}e=fb-16|0;fb=e;x[e+12>>2]=c;JF(d,b,e+12|0);fb=e+16|0;yd((b<<2)+d|0,0);fb=f+16|0;break a}qf();p()}return a|0}function GV(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;e=c+14|0;b=fb-16|0;fb=b;d=x[a+24>>2];a:{if(!d){zp(e);break a}dE(b+8|0,Yb(_i(sq(+(d>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);d=x[b+8>>2];v[b+7|0]=x[b+12>>2];de(e,d,b+7|0)}fb=b+16|0;b=c+4|0;VD(b,a+36|0,a+37|0);UD(b,e);fb=c+16|0}function I0(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;e=d+8|0;Wf(e,c);x[31725]=0;S(125,d+20|0,b|0,e|0);b=x[31725];x[31725]=0;a:{b:{if((b|0)!=1){x[31725]=0;O(12,a|0,d+20|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Qb(d+20|0);tb(d+8|0);fb=d+32|0;return}c=N()|0;break a}c=N()|0;Qb(d+20|0)}tb(d+8|0);Q(c|0);p()}function zha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Pd(c,E(0));a:{b:{switch(b-1|0){case 0:c=si(c);if(c==B[yb(a+4208|0,1)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 3:break b;default:break a}}c=E(si(E(c*E(4)))*E(.25))}d=yb(a+4208|0,b),e=c,B[d>>2]=e;Vz(a)}}function ofa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return fP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,12865,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function gia(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Pd(c,E(0));a:{b:{switch(b-3|0){case 0:c=si(c);if(c==B[yb(a+4208|0,3)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 1:break b;default:break a}}c=E(si(E(c*E(4)))*E(.25))}d=yb(a+4208|0,b),e=c,B[d>>2]=e;Vz(a)}}function gE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+8>>2]=c;g=f,h=lf(b),x[g+28>>2]=h;c=f+8|0;ug(c,b,x[Gb(c,f+28|0)>>2]);b=$e(c);x[31725]=0;aa(238,a|0,b|0,x[f+8>>2],d|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){Kc(f+8|0);fb=f+32|0;return}a=N()|0;Kc(f+8|0);Q(a|0);p()}function Rua(a){a=a|0;var b=0,c=0,d=0;c=fb-32|0;fb=c;b=255;a:{if(Qj(x[a>>2],x[a+4>>2])>>>0<=49){b=$B(c,x[a+12>>2]);x[31725]=0;O(293,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}Ik(b);ek(a,Qj(x[a>>2],x[a+4>>2])-1&255);b=Qj(x[a>>2],x[a+4>>2])-1|0}fb=c+32|0;return b&255}a=N()|0;Ik(b);Q(a|0);p()}function Naa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{if(!x[b+28>>2]){c=x[d>>2];break a}e=ib[x[b+32>>2]](x[b+24>>2],c,0,0)|0;c=x[d>>2];if((e|0)<0){break a}d=x[d+4>>2];e=c;while(1){if(!d){break a}f=ib[x[b+28>>2]](x[b+24>>2],e,d)|0;if(!f){break a}g=f+g|0;d=d-f|0;e=e+f|0;continue}}bc(a,c,g)}function J_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28490681|y[a+68|0]!=13|(y[a+69|0]!=10|y[a+70|0]!=26)){break a}if(y[a+76|0]|((y[a+71|0]|y[a+72|0]<<8|(y[a+73|0]<<16|y[a+74|0]<<24))!=1397116231|y[a+75|0]!=1)){break a}b=((y[a+116|0]|y[a+117|0]<<8)-1&65535)>>>0<9}return b}function $ea(a,b){a=a|0;b=b|0;var c=0;x[31725]=0;W(1002,a|0);c=x[31725];x[31725]=0;if((c|0)!=1){return WO(x[a+24>>2],b)|0}Y(T(0)|0)|0;x[31725]=0;V(989,9801,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function tfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return jP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,8796,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function qfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return hP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,7165,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function pfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return gP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,5319,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function nfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return eP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,9330,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function gfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return Co(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,7133,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function ffa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return Aq(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,6822,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function efa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return _O(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,6940,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function dfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return ZO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,7008,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function cfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return zq(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,7480,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Vea(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return SO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,5816,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function um(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;d=Kb(b);e=c,f=Yc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;x[c+8>>2]=x[a+4>>2]-1;Wg(d,d+x[Gb(c+12|0,c+8|0)>>2]|0,x[a>>2]);d=x[a>>2];e=c,f=Yc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;a=x[a+4>>2];x[c+8>>2]=a-1;Wm(d+x[Gb(c+12|0,c+8|0)>>2]|0,a+d|0,78784);fb=c+16|0}function ufa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return+PA(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[31725]=0;V(989,10149,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function sr(a){var b=0,c=0;b=fb-32|0;fb=b;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;c=a+288|0;gC(c,DV(c),b);x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;a=a+800|0;gC(a,sC(a),b);fb=b+32|0}function mfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return+dP(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[31725]=0;V(989,15142,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function O3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(oh(a,x[b+8>>2],0)){Nx(b,c,d);return}f=x[a+12>>2];rI(x[a+16>>2],x[a+20>>2],b,c,d);e=a+24|0;a=(a+16|0)+(f<<3)|0;a:{if(e>>>0>=a>>>0){break a}while(1){rI(x[e>>2],x[e+4>>2],b,c,d);if(y[b+54|0]){break a}e=e+8|0;if(a>>>0>e>>>0){continue}break}}}function yG(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;d=c+8|0;Rw(d,b);x[31725]=0;S(11,c+20|0,1,d|0);b=x[31725];x[31725]=0;a:{if((b|0)!=1){x[31725]=0;O(12,a|0,c+20|0);a=x[31725];x[31725]=0;if((a|0)==1){b=N()|0;Qb(c+20|0);break a}Qb(c+20|0);tb(c+8|0);fb=c+32|0;return}b=N()|0}tb(c+8|0);Q(b|0);p()}function cla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=yc(a,b,614);e=c+616|0;a=0;while(1){d=D(a,872);Mq(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=zC(c+223848|0,b+223848|0);x[31725]=0;P(847,c+223860|0,b+223860|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){return c|0}b=N()|0;dc(a);Q(b|0);p()}function HQ(a){a=a|0;var b=0,c=0,d=0;b=C[a+4264>>3]*+A[x[a+16>>2]+1074376>>2];a:{if(F(b)<0x8000000000000000){d=~~b>>>0;c=F(b)>=1?~~(b>0?H(J(b*2.3283064365386963e-10),4294967295):K((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}C[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function Cf(a){var b=0,c=0,d=0;a:{b:{b=a;if(!(b&3)){break b}if(!y[a|0]){return 0}while(1){b=b+1|0;if(!(b&3)){break b}if(y[b|0]){continue}break}break a}while(1){c=b;b=b+4|0;d=x[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(y[b|0]){continue}break}}return b-a|0}function nh(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=G(e);bg(d,e,0,0,0,c+81|0);e=0+x[d+8>>2]|0;c=(x[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=x[d+4>>2];b=x[d>>2]}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=e;x[a+12>>2]=f;fb=d+16|0}function d$(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){c=fb-16|0;fb=c;b=vb(c+12|0,x[x[a+8>>2]>>2]);e=x[vb(c+8|0,x[x[a+4>>2]>>2])>>2];d=fb-16|0;fb=d;a=x[b>>2];x[d+12>>2]=a;while(1){if(pd(a,e)){b=fb-16|0;fb=b;x[b+12>>2]=a;c$(b+12|0,-1);fb=b+16|0;a=x[tC(d+12|0)>>2];continue}break}fb=d+16|0;fb=c+16|0}}function UW(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=860902483){break a}if(Bb(y[a+4|0]|y[a+5|0]<<8)>>>0>2|y[a+6|0]>128){break a}if(Bb(y[a+200|0]|y[a+201|0]<<8)>>>0>3999){break a}if(!Bb(y[a+140|0]|y[a+141|0]<<8)){break a}b=(Bb(y[a+148|0]|y[a+149|0]<<8)|0)==50}return b}function Xea(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return+C[x[a+24>>2]+16>>3]}Y(T(0)|0)|0;x[31725]=0;V(989,7642,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Tea(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return x[x[a+24>>2]+8>>2]}Y(T(0)|0)|0;x[31725]=0;V(989,10930,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function K0(a,b,c){var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=192;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=lf(a)}e=d+8|0;nw(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);nw(e,b);Tb(x[d+8>>2]+c|0,0,192-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function $K(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a=Kt(a);x[a+32>>2]=b;x[a>>2]=94860;bd(d+12|0,x[a+4>>2]);x[31725]=0;b=R(1198,x[d+12>>2])|0;e=x[31725];x[31725]=0;if((e|0)!=1){Zb(d+12|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=lo(b),v[f+44|0]=g;fb=d+16|0;return}b=N()|0;Zb(d+12|0);mo(a);Q(b|0);p()}function tW(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;x[e+12>>2]=6553600;i=e,j=$b(b),x[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=Br(f*+A[Gb(g,b)>>2]);x[e+8>>2]=6553600;i=e,j=$b(c),x[i+4>>2]=j;i=e,j=Br(f*+A[Gb(b,e+4|0)>>2]),x[i+12>>2]=j;x[e+8>>2]=d-h;xn(a,h,Gb(b,g));fb=e+16|0}function nq(a,b){var c=0,d=0;c=fb-16|0;fb=c;bd(c+12|0,a);x[31725]=0;a=R(1217,x[c+12>>2])|0;d=x[31725];x[31725]=0;a:{b:{if((d|0)==1){break b}x[31725]=0;V(1228,a|0,111728,111754,b|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}Zb(c+12|0);fb=c+16|0;break a}a=N()|0;Zb(c+12|0);Q(a|0);p()}return b}function nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ri(a,b,c,d);x[a>>2]=42300;b=Nb(a+4208|0);x[a+4228>>2]=0;x[a+4220>>2]=0;x[a+4224>>2]=0;x[a+4232>>2]=x[c+24620>>2];r0(a+4260|0,80,150,80,255);x[31725]=0;O(947,a+44|0,2);c=x[31725];x[31725]=0;if((c|0)!=1){return a|0}c=N()|0;uc(b);ag(a);Q(c|0);p()}function d1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c<<1)){break a}wc(d+12|0,65535);xg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}HE(b,d+10|0);w[c>>1]=z[d+10>>1];c=x[Md(d+4|0)>>2];continue}}fb=d+16|0}function QZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb+-64|0;fb=c;d=c+44|0;ug(d,a,32);a=x[c+44>>2];e=c+20|0;wg(e,2,$e(d),a);x[31725]=0;O(220,c+32|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){a=c+12|0;Mn(a,b);b=a;a=c+32|0;um(b,a);tb(a);Kc(c+44|0);fb=c- -64|0;break a}a=N()|0;Kc(c+44|0);Q(a|0);p()}}function qx(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function a$(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function ZK(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a=mL(a);x[a+32>>2]=b;x[a>>2]=95228;bd(d+12|0,x[a+4>>2]);x[31725]=0;b=R(38,x[d+12>>2])|0;e=x[31725];x[31725]=0;if((e|0)!=1){Zb(d+12|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=lo(b),v[f+44|0]=g;fb=d+16|0;return}b=N()|0;Zb(d+12|0);Et(a);Q(b|0);p()}function Cy(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-160|0;fb=e;x[e+60>>2]=b;x[e+20>>2]=b;x[e+24>>2]=-1;f=e+16|0;Ji(f,0,0);PK(e,f,d,1);d=x[e+8>>2];g=x[e+12>>2];f=x[e>>2];h=x[e+4>>2];if(c){x[c>>2]=((x[e+20>>2]+x[e+136>>2]|0)-x[e+60>>2]|0)+b}x[a+8>>2]=d;x[a+12>>2]=g;x[a>>2]=f;x[a+4>>2]=h;fb=e+160|0}function rfa(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return iP(x[a+24>>2])|0}Y(T(0)|0)|0;x[31725]=0;V(989,9766,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function nB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Fk(a,b,b+700|0,c<<2,0)}}function kO(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;x[a+4>>2]=0;x[a>>2]=47652;a=ac(8);x[31725]=0;b=P(36,b+4|0,12133)|0;c=x[31725];x[31725]=0;a:{b:{if((c|0)!=1){pc(a,b);x[31725]=0;S(99,a|0,48492,1006);a=x[31725];x[31725]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0)}p()}function ZF(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=x[a+92>>2];e=x[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){x[a+96>>2]=e;x[a+92>>2]=d}else{f=(g<<3)+b|0;h=x[f>>2];d=d-qd((qd(0-d|0,31)&255)+d|0,8)|0;x[f>>2]=h+d;h=x[f+4>>2];e=e-qd((qd(0-e|0,31)&255)+e|0,8)|0;x[f+4>>2]=h+e;g=g+1|0;continue}break}}}function Xra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;tf(b);x[d+12>>2]=0;a:{if(!Ok(a,d+12|0)){break a}f=c;c=x[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}v[d+11|0]=0;if(ni(a,d+11|0)){Zp(b,v[d+11|0]);e=e+1|0;continue}break}e=0}fb=d+16|0;return e|0}function q_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=qg(a);b=b+236|0;e=Ar(b);a:{while(1){if((b|0)!=(e|0)){d=z[b>>1];w[c+14>>1]=d;if(d){x[31725]=0;S(403,c+4|0,a|0,c+14|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}fb=c+16|0;return}b=N()|0;Tv(a);Q(b|0);p()}function hQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[a+4256>>2];x[a+4240>>2]=b<<1;x[31725]=0;x[c+12>>2]=0;S(953,a+4208|0,b<<2,c+12|0);b=x[31725];x[31725]=0;a:{if((b|0)==1){b=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;x[a+4240>>2]=0;Z()}x[a+4244>>2]=0;fb=c+16|0;return}Q(b|0);p()}function oB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Fk(a,b,b+700|0,c,0)}}function ala(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(Ed(y[b+24|0])){a=qg(a);c=$i(x[b>>2]);d=Rf(b);x[31725]=0;S(850,a|0,c|0,d|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}x[31725]=0;P(849,a+12|0,b+12|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}v[a+24|0]=1}return}b=N()|0;iT(a);Q(b|0);p()}function _D(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;x[e+8>>2]=c;f=e,g=lf(b),x[f+28>>2]=g;c=e+8|0;ug(c,b,x[Gb(c,e+28|0)>>2]);b=$e(c);x[31725]=0;V(345,a|0,b|0,x[e+8>>2],d|0);a=x[31725];x[31725]=0;if((a|0)!=1){Kc(e+8|0);fb=e+32|0;return}a=N()|0;Kc(e+8|0);Q(a|0);p()}function wC(a,b,c,d,e){var f=0;a:{f=x[a>>2];if(!je(f,x[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}vn(b);b=bp(b,a);x[b+20>>2]=0;x[b>>2]=d;if(!Fh(b)){break a}if(x[a>>2]!=(d|0)){gs(b+68|0)}yc(x[b+20>>2],x[a+20>>2]+c|0,d);x[b+8>>2]=e?d:0;x[b+4>>2]=0;w[b+34>>1]=z[b+34>>1]&65533|(e?2:0)}}function pH(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;e=Fb(a+16|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[31725]=0;b=P(c|0,d+8|0,b+16|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){a=d+20|0;Sh(a,b);Ab(e,a);tb(a);tb(b);fb=d+32|0;return}b=N()|0;Hh(a);Q(b|0);p()}function dN(a){var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;b=a+120|0;$t(y[b+20|0]);c=fb-16|0;fb=c;x[c+12>>2]=d+15;a=fb-16|0;fb=a;e=x[18379];x[a+8>>2]=x[18378];x[a+12>>2]=e;e=x[18377];x[a>>2]=x[18376];x[a+4>>2]=e;b=ib[x[vq(a,Ck(y[b+20|0]))>>2]](c+12|0,b)|0;fb=a+16|0;fb=c+16|0;fb=d+16|0;return b}function sk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=x[a+4>>2];e=x[a+12>>2];i=x[a+8>>2];d=x[a>>2];while(1){if((b|0)!=(f|0)){if(!d){x[a>>2]=8;c=i;if((e|0)!=(c|0)){c=e-1|0;x[a+12>>2]=c}d=8;e=c;c=y[c|0]}g=c;d=d-1|0;x[a>>2]=d;c=g>>>1|0;x[a+4>>2]=c;h=g&1|h<<1;f=f+1|0;continue}break}return h}function iR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=b;a:{if(Ug(a)>>>0>=b>>>0){f=x[a>>2];e=oc(f,x[a+4>>2]);x[d+8>>2]=e;hR(f,x[Gb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){nA(a,b-e|0,c);break a}Ih(a,x[a>>2]+(b<<2)|0);break a}wr(a);sm(a,Mf(a,b));nA(a,b,c)}fb=d+16|0}function Nba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=d+4|0;Bo(c,a);if(x[b>>2]){DZ(b);a=x[b>>2];at(b);Db(a);e=zb(b),f=0,x[e>>2]=f;x[b>>2]=0;x[b+4>>2]=0}x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];a=zb(c);e=zb(b),f=x[a>>2],x[e>>2]=f;x[a>>2]=0;x[c>>2]=0;x[c+4>>2]=0;of(c);fb=d+16|0}function mga(a){a=a|0;var b=0;x[31725]=0;W(1002,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return x[a+16>>2]}Y(T(0)|0)|0;x[31725]=0;V(989,5690,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function bi(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=fb-16|0;fb=e;c=e+4|0;x[c+4>>2]=1;g=c,h=Ec(16),x[g+8>>2]=h;b=zm(x[c+8>>2]);x[b>>2]=41192;g=Wn(nc(b)),h=41324,x[g>>2]=h;b=d+8|0;f=Yn(c);Xn(b,nc(f),f);Am(c);fb=e+16|0;Ef(a,b);ke(b);fb=d+16|0;x[a+8>>2]=0;Nd(a+12|0);return a}function Ffa(a){a=a|0;var b=0;x[31725]=0;W(1027,a|0);b=x[31725];x[31725]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[31725]=0;V(989,11974,a|0,0,0);a=x[31725];x[31725]=0;if((a|0)==1){break a}Z();a=0}return a|0}a=N()|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function uqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31725]=0;O(642,a|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break a}Ap(a,b,c)}b=d+8|0;Qd(b);ak(b);fb=d+16|0;return a|0}a=N()|0;ak(d+8|0);Q(a|0);p()}function dn(a,b,c,d){var e=0,f=0;a:{f=x[(D(b,872)+a|0)+1075648>>2];if(!f){break a}if(!Tj(y[f+31|0])){break a}e=y[f+34|0]-1|0;if((e&255)>>>0>249){break a}e=x[vd(a+906300|0,e)>>2];if(!e){break a}ib[x[x[e>>2]+96>>2]](e,f,c,d,b);if(c>>>0>250){break a}w[(D(b,872)+a|0)+1075834>>1]=65535}}function Ex(a,b,c,d,e){var f=0,g=0;a:{f=fb+-64|0;fb=f;g=f+44|0;ug(g,a,e);a=x[f+44>>2];e=f+20|0;wg(e,d,$e(g),a);x[31725]=0;O(220,f+32|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){a=f+12|0;gc(a,b,c);b=a;a=f+32|0;um(b,a);tb(a);Kc(f+44|0);fb=f- -64|0;break a}a=N()|0;Kc(f+44|0);Q(a|0);p()}}function u1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31725]=0;O(227,a|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break a}XE(a,b,c)}b=d+8|0;Qd(b);dh(b);fb=d+16|0;return a|0}a=N()|0;dh(d+8|0);Q(a|0);p()}function jia(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=1869112133){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4228>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4232>>2]=c;lu(a)}}function _ia(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=1869112133){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;ru(a)}}function XP(a,b,c){v[a+12|0]=0;x[c>>2]=0;x[b>>2]=0;x[a+28>>2]=0;x[a+32>>2]=0;w[a+24>>1]=0;x[a+36>>2]=0;x[a+40>>2]=0;x[a+44>>2]=0;x[a+48>>2]=0;VP(a+60|0);VP(a+52|0);Jq(a+49956|0);Jq(a+58148|0);Jq(a+66340|0);Jq(a+74532|0);Tb(a+228|0,0,32768);Tb(a+32996|0,0,512);Tb(a+33508|0,0,16384)}function UZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31725]=0;O(462,a|0,b|0);e=x[31725];x[31725]=0;if((e|0)==1){break a}tD(a,b,c)}b=d+8|0;Qd(b);jm(b);fb=d+16|0;return a|0}a=N()|0;jm(d+8|0);Q(a|0);p()}function sj(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=d;g=Nh(e+8|0,b);b=fb-16|0;fb=b;d=x[e+12>>2];x[b+12>>2]=d;x[b+8>>2]=d;f=-1;d=wt(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Fd(d);x[h>>2]=a;if(!a){break a}f=wt(a,d,c,x[b+12>>2])}fb=b+16|0;Mh(g);fb=e+16|0;return f}function Rja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;c=Hf(a,c);$d(d,x[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{if(!((e|0)!=4&(e|0)!=-1)){Ok(f,b);break c}qN(f,b,e)}f=c}gf(a,f);fb=d+16|0}function Ku(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!b){break a}i=Ob(a+1074312|0,73)?c- -64|0:c;c=120;g=Jj(a);j=g^-1;e=1;while(1){if(!c){break a}k=c;c=c>>>1|0;h=e+c|0;f=yh(a,h,i,d);if(!(f>>>0>b>>>0&j)&(!(!f|g)|b>>>0<=f>>>0)){continue}e=h+1|0;c=(c^-1)+k|0;continue}}return e}function Jla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=b;a:{if(ep(a)>>>0>=b>>>0){f=x[a>>2];e=Sc(f,x[a+4>>2]);x[d+8>>2]=e;Vh(f,x[Gb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Hp(a,b-e|0,c);break a}pr(a,x[a>>2]+b|0);break a}_v(a);bl(a,cm(a,b));Hp(a,b,c)}fb=d+16|0}function $p(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=f>>>0){bk();p()}d=Ec(D(b,e));x[g+12>>2]=b;x[g+8>>2]=d;d=x[g+12>>2];b=x[g+8>>2]}x[a>>2]=b;c=b+D(c,e)|0;x[a+8>>2]=c;x[a+4>>2]=c;h=nc(a),i=b+D(d,e)|0,x[h>>2]=i;fb=g+16|0;return a}function si(a){var b=E(0),c=0,d=0;c=(q(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return E(a*E(0))}a=(c|0)>=0?a:E(-a);b=E(E(E(a+E(8388608))+E(-8388608))-a);a:{if(b>E(.5)){a=E(E(a+b)+E(-1));break a}a=E(a+b);if(!(b<=E(-.5))){break a}a=E(a+E(1))}a=(c|0)>=0?a:E(-a)}return a}function h3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=Ot(c);x[a>>2]=94320;x[d>>2]=94340;x[a+60>>2]=94380;x[a>>2]=94360;x[a+4>>2]=0;e=c;c=a+8|0;to(e,c);x[a>>2]=94320;x[d>>2]=94340;x[31725]=0;P(109,c|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}a=N()|0;Dl(d);Q(a|0);p()}function Ss(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=y[b|0];a:{if(!d){d=0;break a}b:{if(!y[b+1|0]){v[a|0]=d;break b}d=0;if(!gq(e+12|0,b,c)){break a}f=x[e+12>>2];b=Tx(f,c);c:{if((b|0)!=-1){break c}b=32;if((f|0)==8239){break c}if((f|0)!=160){break a}}v[a|0]=b}d=1}fb=e+16|0;return d}function r2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;x[e+24>>2]=d;x[e+28>>2]=c;x[31725]=0;V(169,e+8|0,b|0,e+28|0,e+24|0);c=x[31725];x[31725]=0;if((c|0)!=1){c=e+16|0;Rp(c,x[e+8>>2],x[e+12>>2]);Ef(a,c);ke(c);ke(e+8|0);ke(b);fb=e+32|0;return}a=N()|0;ke(b);Q(a|0);p()}function d8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;x[g+12>>2]=b;bd(g+8|0,x[d+28>>2]);x[31725]=0;b=R(1217,x[g+8>>2])|0;d=x[31725];x[31725]=0;if((d|0)!=1){Zb(g+8|0);gK(a,f+24|0,g+12|0,c,e,b);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function c8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;x[g+12>>2]=b;bd(g+8|0,x[d+28>>2]);x[31725]=0;b=R(1217,x[g+8>>2])|0;d=x[31725];x[31725]=0;if((d|0)!=1){Zb(g+8|0);fK(a,f+16|0,g+12|0,c,e,b);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function QF(a,b,c,d){var e=0,f=0,g=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;e=d;d=x[a+1068>>2];w[e+(d<<1)>>1]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;f=a,g=_d(z[x[a+1060>>2]+34>>1])+d|0,x[f+1068>>2]=g;x[a+1072>>2]=x[a+1072>>2]-1}function Gpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+14|0;sX(c+8|0,e);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){rX(e)}if(a){d=tX(b+14|0)}fb=b+160|0;return d|0}
function FP(a,b){var c=0,d=0,e=0,f=0;c=fb-96|0;fb=c;NQ(b,c,c+96|0);b=0;while(1){if((b|0)==12){x[a+104>>2]=0;x[a+96>>2]=!(x[a+88>>2]|x[a+92>>2]);x[a+100>>2]=0;fb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d&65535;b=b+1|0;continue}break}x[a+112>>2]=0}function zua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-624|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+14|0;$$(c+8|0,e);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){_$(e)}if(a){d=a0(b+14|0)}fb=b+624|0;return d|0}function PY(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;x[e+12>>2]=a;a:{if(!(!c|b)){a=_e(+(D(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){wc(e+12|0,10);a=D(y[x[e+12>>2]+25168|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=_e(733.8401379310345/f*1e4);break a}a=_e(f/.264*1e4)}fb=e+16|0;return a}function rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;tf(b);e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,1,$e(e),a);x[31725]=0;O(220,d+16|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){a=d+16|0;Ab(b,a);tb(a);Kc(d+28|0);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function o0(a){var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;e=xb(a,31),f=0,v[e|0]=f;d=Mi(a,Yo(a),0);v[c+15|0]=0;d=Yj(a,d);Wm(d+a|0,Yo(a),c+15|0);while(1){if((b|0)!=(d|0)){a:{if(v[xb(a,b)|0]>=32){if(y[xb(a,b)|0]!=127){break a}}e=xb(a,b),f=32,v[e|0]=f}b=b+1|0;continue}break}fb=c+16|0}function j8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;x[g+12>>2]=b;bd(g+8|0,x[d+28>>2]);x[31725]=0;b=R(28,x[g+8>>2])|0;d=x[31725];x[31725]=0;if((d|0)!=1){Zb(g+8|0);jK(a,f+24|0,g+12|0,c,e,b);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function i8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;x[g+12>>2]=b;bd(g+8|0,x[d+28>>2]);x[31725]=0;b=R(28,x[g+8>>2])|0;d=x[31725];x[31725]=0;if((d|0)!=1){Zb(g+8|0);iK(a,f+16|0,g+12|0,c,e,b);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function Xe(a){var b=0,c=0;b=fb-32|0;fb=b;v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;kF(b+9|0);x[a>>2]=x[b>>2];c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;c=x[b+24>>2];x[a+20>>2]=x[b+20>>2];x[a+24>>2]=c;v[a+28|0]=y[b+28|0];fb=b+32|0}function opa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-208|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+4|0;TW(c+8|0,e);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){SW(e)}if(a){d=UW(b+4|0)}fb=b+208|0;return d|0}function Wta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+10|0;Zv(c+8|0,e);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){a$(e)}if(a){d=b$(b+10|0)}fb=b+32|0;return d|0}function Sra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+11|0;ik(c+8|0,e);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){jZ(e)}if(a){d=kZ(b+11|0)}fb=b+16|0;return d|0}function Jt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=ac(16);if(!y[502193]){v[502193]=1}a=gc(c+8|0,a,126384);x[31725]=0;e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a=U(1178,d|0,c|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){da(a|0,124308,1179);p()}a=N()|0;jc(d);Q(a|0);p()}function Cta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+3|0;I_(c+8|0,e);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){H_(e)}if(a){d=J_(b+3|0)}fb=b+160|0;return d|0}function BH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;x[g+12>>2]=c;c=g+12|0;wc(c,f);wc(c,65535);h=z[g+12>>1];xg(a,h);c=0;while(1){if((c|0)==(h|0)){fb=g+16|0}else{f=y[b+c|0];i=Wr(x[a>>2],x[a+4>>2],c),j=(d|0)==(f|0)?-1:(e|0)==(f|0)?-2:f,w[i>>1]=j;c=c+1|0;continue}break}}function e0(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;x[d+12>>2]=b;c=fb-16|0;fb=c;x[c+12>>2]=153391689;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=rE(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[ad(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}dd();p()}function dma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=WV(d+4|0,a+8|0,b);b=x[a>>2];a:{while(1){if(x[a+4>>2]==(b|0)){break a}x[31725]=0;O(786,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){b=x[a>>2]+32|0;x[a>>2]=b;continue}break}b=N()|0;he(a);Q(b|0);p()}he(a);fb=d+16|0}function Goa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=ej(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=1;c=Wh(c);if((c|0)!=1){break b}}hy(a,d,1,d,d,0);c=d}d=x[a>>2];Yd(a,c+1|0);break a}Me(a,c+1|0);d=a}a=(c<<2)+d|0;yd(a,b);yd(a+4|0,0)}function F$(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;x[d+12>>2]=b;c=fb-16|0;fb=c;x[c+12>>2]=107374182;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=B$(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[ad(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}dd();p()}function v0(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function sM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;mf(e+24|0,b,c);b=Ef(e+16|0,d);x[31725]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;jg(165,a,x[e+24>>2],x[e+28>>2],e+8|0);a=x[31725];x[31725]=0;if((a|0)!=1){ke(d);fb=e+32|0;return}a=N()|0;ke(d);Q(a|0);p()}function rd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;g=x[b+8>>2];f=x[b>>2];mf(e+16|0,c,d);c=x[x[f>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,f,g,e+8|0);mf(a,x[e+24>>2],x[e+28>>2]);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];fb=e+32|0}function noa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[31725]=0;O(227,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}$q(a,b)}b=c+8|0;Qd(b);dh(b);fb=c+16|0;return a|0}a=N()|0;dh(c+8|0);Q(a|0);p()}function ira(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[31725]=0;O(590,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}jD(a,b)}b=c+8|0;Qd(b);dh(b);fb=c+16|0;return a|0}a=N()|0;dh(c+8|0);Q(a|0);p()}function HY(a,b){var c=0,d=0;a:{c=x[b>>2];d=x[b+20>>2];if(!je(c,d)){break a}if(x[a+20>>2]==(d|0)){x[a+20>>2]=0;c=x[b>>2]}wc(a,c);c=z[a+34>>1]&-2|w[b+34>>1]&1;w[a+34>>1]=c;w[a+34>>1]=c&65471|z[b+34>>1]&64;if(!Fh(a)){break a}yc(x[a+20>>2],x[b+20>>2],Xk(x[a>>2],z[a+34>>1]))}}function BQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+1074404>>2];x[31725]=0;x[c+12>>2]=0;S(953,a+4208|0,D(b,254)|0,c+12|0);b=x[31725];x[31725]=0;a:{if((b|0)==1){b=T(125e3)|0;if((gb|0)!=($(125e3)|0)){break a}Y(b|0)|0;Z()}x[a+4220>>2]=0;fb=c+16|0;return}Q(b|0);p()}function qo(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=qva(a,b,10,0);e=hb;a=ova(d,e,246,0)+a|0;c=c-1|0;v[c|0]=a|48;f=b>>>0>9;a=d;b=e;if(f){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;v[c|0]=D(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function d9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b|0];g=v[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function Zra(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a:{if(oc(x[a>>2],x[a+4>>2])>>>0>511){break a}if(!Dd(b)){break a}x[31725]=0;O(502,a|0,c+12|0);a=x[31725];x[31725]=0;d=b;if((a|0)!=1){break a}a=N()|0;og(c+12|0);Q(a|0);p()}og(c+12|0);fb=c+16|0;return d|0}function Zp(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=ej(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Wh(c);if((c|0)!=10){break b}}Xm(a,d,1,d,d,0,0);c=d}d=x[a>>2];Yd(a,c+1|0);break a}Me(a,c+1|0);d=a}a=c+d|0;fd(a,b);fd(a+1|0,0)}function Q0(a,b,c){var d=0,e=0,f=0;d=fb-48|0;fb=d;tf(b);e=d+28|0;ug(e,a,c);a=x[d+28>>2];f=d+4|0;wg(f,3,$e(e),a);x[31725]=0;O(220,d+16|0,f|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=b;b=d+16|0;Ab(e,b);tb(b);Kc(d+28|0);fb=d+48|0;return!c|(a|0)!=0}a=N()|0;Kc(d+28|0);Q(a|0);p()}function PF(a,b,c,d){var e=0,f=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;v[x[a+1068>>2]+d|0]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;e=a,f=x[a+1068>>2]+_d(z[x[a+1060>>2]+34>>1])|0,x[e+1068>>2]=f;x[a+1072>>2]=x[a+1072>>2]-1}function Oqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=CJ(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[31725]=0;W(599,b|0);e=x[31725];x[31725]=0;if((e|0)!=1){b=b+24|0;x[a+4>>2]=b;continue}break}b=N()|0;hc(a);Q(b|0);p()}hc(a);fb=c+16|0}function Dr(a,b,c){var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;d=fb-32|0;fb=d;Id(d+24|0,a,b);a=fb-16|0;fb=a;e=c;b=x[d+28>>2];c=x[d+24>>2];g=b-c|0;e=e-g|0;x[a+12>>2]=e;nl(e,c,g);Ac(d+16|0,b,a+12|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f+8|0,a,d+12|0);fb=d+32|0;fb=f+16|0}function nka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,1,$e(e),a);x[31725]=0;O(220,d+16|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){a=d+16|0;ze(b,a);tb(a);Kc(d+28|0);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function WE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=zw(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[31725]=0;W(230,b|0);e=x[31725];x[31725]=0;if((e|0)!=1){b=b+20|0;x[a+4>>2]=b;continue}break}b=N()|0;hc(a);Q(b|0);p()}hc(a);fb=c+16|0}function Q_(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=d+12|0;wc(c,256);wc(c,65535);f=z[d+12>>1];xg(a,f);c=0;while(1){if((c|0)==(f|0)){fb=d+16|0}else{e=y[b+c|0];g=Wr(x[a>>2],x[a+4>>2],c),h=(e|0)==255?-1:(e|0)==254?-2:e,w[g>>1]=h;c=c+1|0;continue}break}}function Nla(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=ej(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Wh(c);if((c|0)!=10){break b}}VB(a,d,1,d,d,0);c=d}d=x[a>>2];Yd(a,c+1|0);break a}Me(a,c+1|0);d=a}a=c+d|0;fd(a,b);fd(a+1|0,0)}function Gsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,2,$e(e),a);x[31725]=0;O(220,d+16|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){a=d+16|0;pm(b,a);tb(a);Kc(d+28|0);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function Ee(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function ZW(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=wb(x[a>>2]);x[c+12>>2]=b;e=wb(x[a+4>>2]);while(1){a:{d=Ib(b,e);if(!d){break a}a=z[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){w[b>>1]=65535;break b}if(a>>>0>63){break a}}b=x[Md(c+12|0)>>2];continue}break}fb=c+16|0;return d^1}function Y$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,2,$e(e),a);x[31725]=0;O(220,d+16|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){a=d+16|0;zc(b,a);tb(a);Kc(d+28|0);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function Fia(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=4104;a=0;d=x[b+8>>2];a:{if(d>>>0<4096){break a}c=x[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}x[b+12>>2]=e;x[b+8>>2]=d-c;a=e}if(!a){_(6053,9014,88,7400);p()}fb=b+16|0;return a|0}function ck(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=wb(x[b>>2]);f=wb(x[b+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){a:{if(!Ib(d,f)){break a}if(I$(c,x[d>>2],x[d+4>>2])){break a}d=x[nm(e+12|0)>>2];continue}break}fb=e+16|0;if(lc(d,wb(x[b+4>>2]))){bi(a);return}tp(a,d)}function b8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=fb-16|0;fb=a;x[a+12>>2]=b;bd(a+8|0,x[d+28>>2]);x[31725]=0;b=R(1217,x[a+8>>2])|0;d=x[31725];x[31725]=0;if((d|0)!=1){Zb(a+8|0);eK(f+20|0,a+12|0,c,e,b);fb=a+16|0;return x[a+12>>2]}b=N()|0;Zb(a+8|0);Q(b|0);p()}function tla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-48|0;fb=c;d=c+28|0;ug(d,a,32);a=x[c+28>>2];e=c+4|0;wg(e,1,$e(d),a);x[31725]=0;O(220,c+16|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){a=c+16|0;zc(b,a);tb(a);Kc(c+28|0);fb=c+48|0;break a}a=N()|0;Kc(c+28|0);Q(a|0);p()}}function lu(a){var b=0,c=0,d=E(0);c=y[a+4232|0];if(c>>>0>=5){v[a+4232|0]=0;c=0}if(v[a+4233|0]<0){v[a+4233|0]=127}b=v[a+4234|0];if((b|0)<0){v[a+4234|0]=127;b=127}a:{if((c|0)==3){d=E(E(1)-De(E(2),E(-E((b&255)+1|0))));break a}d=De(E(2),E(-E((b&255)>>>0)))}B[a+4224>>2]=d}function Uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(y[b+40|0]){break a}b:{if(!x[b+28>>2]){break b}d=x[c+4>>2];f=x[c>>2];while(1){if(!d){break a}e=ib[x[b+28>>2]](x[b+24>>2],f,d)|0;if(!e){break b}g=e+g|0;d=d-e|0;f=f+e|0;continue}}v[b+40|0]=1}bc(a,x[c>>2],g)}function LF(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=x[a+4>>2];f=e+b|0;x[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=x[a>>2];break a}a=x[a>>2];x[a+((f>>>0>=33?g>>>5|0:0)<<2)>>2]=0}Fp(d+8|0,a,e);Qw(x[d+8>>2],x[d+12>>2],b,c);fb=d+16|0}function Fja(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;x[c+12>>2]=-1;x[c+16>>2]=0;x[c+4>>2]=0;Fb(c+20|0);x[31725]=0;x[c+4>>2]=x[c+4>>2]&-1332|1058;x[c+8>>2]=1;S(81,a|0,b|0,c+4|0);a=x[31725];x[31725]=0;if((a|0)!=1){Hh(c+4|0);fb=c+32|0;return}a=N()|0;Hh(c+4|0);Q(a|0);p()}function uM(a){var b=0,c=0,d=0;b=fb-48|0;fb=b;kg(x[x[a>>2]-12>>2]+a|0,0);$d(b+32|0,a);a=Ii(a,0,0,2);$d(b+16|0,a);c=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=c;c=x[b+36>>2];x[b>>2]=x[b+32>>2];x[b+4>>2]=c;c=x[b+28>>2];d=x[b+24>>2];$m(a,b);a=Tu(d,c);fb=b+48|0;return a}function n$(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=320012546|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=184619540|y[a+8|0]>1|((y[a+9|0]-1&255)>>>0>7|(y[a+10|0]|y[a+11|0]<<8)>>>0>4096))){b=(y[a+12|0]|y[a+13|0]<<8)>>>0<4097}return b}function lF(a,b){var c=0,d=0;c=fb-16|0;fb=c;bd(c+12|0,a);x[31725]=0;a=R(28,x[c+12>>2])|0;d=x[31725];x[31725]=0;a:{if((d|0)==1){break a}x[31725]=0;a=P(29,a|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}Zb(c+12|0);fb=c+16|0;return a}a=N()|0;Zb(c+12|0);Q(a|0);p()}function l9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Pf(v[b|0]),e=x[x[a>>2]+52>>2],ib[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=Tk(b,1,c,x[a+32>>2])}return c|0}function h8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=fb-16|0;fb=a;x[a+12>>2]=b;bd(a+8|0,x[d+28>>2]);x[31725]=0;b=R(28,x[a+8>>2])|0;d=x[31725];x[31725]=0;if((d|0)!=1){Zb(a+8|0);hK(f+20|0,a+12|0,c,e,b);fb=a+16|0;return x[a+12>>2]}b=N()|0;Zb(a+8|0);Q(b|0);p()}function eq(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function P$(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;v[d+15|0]=1;v[d+14|0]=a>>>2;a=y[ef(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){v[d+13|0]=1;v[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=y[ef(d+13|0,d+12|0)|0]}fb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function DJ(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;d=sc(a+8|0),e=0,v[d+128|0]=e;Rd(b+8|0,x[vb(b+4|0,a)>>2]);x[31725]=0;O(1291,a|0,30);c=x[31725];x[31725]=0;if((c|0)!=1){$q(a,30);c=b+8|0;Qd(c);zJ(c);fb=b+16|0;return a}a=N()|0;zJ(b+8|0);Q(a|0);p()}function iH(a,b,c,d,e){var f=0,g=0;a:{f=fb-48|0;fb=f;tf(b);g=f+28|0;ug(g,a,d);a=x[f+28>>2];d=f+4|0;wg(d,e,$e(g),a);x[31725]=0;S(600,f+16|0,c|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){a=f+16|0;Ab(b,a);tb(a);Kc(f+28|0);fb=f+48|0;break a}a=N()|0;Kc(f+28|0);Q(a|0);p()}}function T0(a,b,c){var d=0,e=0,f=0;d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];f=d+4|0;wg(f,3,$e(e),a);x[31725]=0;O(220,d+16|0,f|0);e=x[31725];x[31725]=0;if((e|0)!=1){e=b;b=d+16|0;zc(e,b);tb(b);Kc(d+28|0);fb=d+48|0;return!c|(a|0)!=0}a=N()|0;Kc(d+28|0);Q(a|0);p()}function vv(a,b){a:{b:{if((b|0)!=31){if((b|0)!=15){break b}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1196314451){break b}break a}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=825446227){break a}}b=Bb(y[a+4|0]|y[a+5|0]<<8)>>>0>177}return b}function ZB(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a=jC(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}x[31725]=0;O(786,b|0,c|0);f=x[31725];x[31725]=0;if((f|0)!=1){b=b+32|0;x[a+4>>2]=b;continue}break}b=N()|0;hc(a);Q(b|0);p()}hc(a);fb=d+16|0}function Yh(a,b){var c=0,d=0,e=0;a:{if(!(v[a+480180|0]&1|b)){break a}e=x[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;w[c+480286>>1]=64;d=c+480280|0;x[d>>2]=x[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;w[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function K9(a){a=a|0;var b=0,c=0,d=0;c=x[a+44>>2];b=x[a+24>>2];if(c>>>0<b>>>0){x[a+44>>2]=b;c=b}d=-1;a:{if(!(y[a+48|0]&8)){break a}b=x[a+16>>2];if(b>>>0<c>>>0){no(a,x[a+8>>2],x[a+12>>2],c);b=x[a+16>>2]}a=x[a+12>>2];if(a>>>0>=b>>>0){break a}d=Pf(v[a|0])}return d|0}function At(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=x[b+76>>2]>=0;b:{c=x[b+4>>2];c:{if(!c){Wy(b);c=x[b+4>>2];if(!c){break c}}if(x[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;x[b+4>>2]=c;v[c|0]=a;x[b>>2]=x[b>>2]&-17;d=a&255}return d}function wP(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=126908;x[a+20>>2]=0;x[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;x[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;x[a+8>>2]=d;x[a+32>>2]=d>>>0>=31?-1:-1>>>31-d|0;x[a+28>>2]=b>>>0>=c>>>0?-1>>>32-d|0:0;x[a+16>>2]=(D(c,d)-b|0)+c;return a}function via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;x[a+4>>2]=b;x[a>>2]=0;b=mu(a+8|0,d);x[31725]=0;P(967,a+20|0,c|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){x[a+32>>2]=0;x[a+36>>2]=0;v[a+42|0]=0;v[a+40|0]=0;v[a+41|0]=y[a+41|0]&224|25;return a|0}a=N()|0;Eb(b);Q(a|0);p()}function WI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=vJ(a,c);x[a>>2]=113196;c=Bk(Kb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Tm(a,17927,b);x[31725]=0;W(1345,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(d+4|0);Q(a|0);p()}fb=d+16|0;return a|0}p()}function N5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=yJ(a,c);x[a>>2]=111996;c=Bk(Kb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Tm(a,17865,b);x[31725]=0;W(1345,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(d+4|0);Q(a|0);p()}fb=d+16|0;return a|0}p()}function L5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=xJ(a,c);x[a>>2]=112028;c=Bk(Kb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Tm(a,18046,b);x[31725]=0;W(1345,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(d+4|0);Q(a|0);p()}fb=d+16|0;return a|0}p()}function El(a){var b=0,c=0;a:{b=x[a+1396>>2];if((b|0)>24){break a}if(!b){x[a+1392>>2]=0}while(1){if(y[a+1376|0]?0:x[a+1384>>2]){break a}c=Qt(a);if((c|0)==-1){break a}b=x[a+1396>>2];x[a+1396>>2]=b+8;x[a+1392>>2]=x[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Bn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=a;c=IC(b);e=fb-16|0;fb=e;a:{if(c>>>0<1073741808){b:{if(lr(c)){Me(d,c);break b}Wj(e+8|0,zn(c)+1|0);f=x[e+8>>2];yd(d,f);pf(d,x[e+12>>2]);Yd(d,c);d=f}yd(Zi(d,b,c)+(c<<2)|0,0);fb=e+16|0;break a}qf();p()}return a|0}function yH(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);a:{if(b){x[31725]=0;O(d|0,a|0,b|0);d=x[31725];x[31725]=0;if((d|0)==1){break a}Hp(a,b,c)}b=e+8|0;Qd(b);dj(b);fb=e+16|0;return a}a=N()|0;dj(e+8|0);Q(a|0);p()}function j4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=jo(e+4|0,c,d);c=GK(0,Kb(b),0);x[31725]=0;a=U(1365,a|0,c|0,0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){GK(Kb(a),Kb(b),Cb(x[a+4>>2],y[a+11|0])+1|0);Qb(b);fb=e+16|0;return}a=N()|0;Qb(b);Q(a|0);p()}function XZ(a){var b=0,c=0,d=0,e=0;d=y[a+32|0]|y[a+33|0]<<8;e=y[a+38|0]|y[a+39|0]<<8;c=y[a+34|0]|y[a+35|0]<<8;b=c+(y[a+36|0]|y[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=(c>>>0>b>>>0?a+1|0:a)<<2|b>>>30;c=d;d=b<<2;b=c+d|0;hb=b>>>0<d>>>0?a+1|0:a;return b}function SC(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-1024|0;fb=e;d=fb-16|0;fb=d;PC(d+8|0,e);f=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Vb(a,x[d+12>>2])}fb=d+16|0;if((f|0)==(g|0)){h=QC(e,c)>>>0<=b>>>0}fb=e+1024|0;return h}function $n(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(!b){b=0;break a}d=b;b=G(b);bg(c,d,0,0,0,b+81|0);d=0+x[c+8>>2]|0;b=(x[c+12>>2]^65536)+(16414-b<<16)|0;f=e>>>0>d>>>0?b+1|0:b;e=x[c+4>>2];b=x[c>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+8>>2]=d;x[a+12>>2]=f;fb=c+16|0}function g4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=ti(e+4|0,c,d);c=IK(0,Kb(b),0);x[31725]=0;a=U(543,a|0,c|0,0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){IK(Kb(a),Kb(b),Cb(x[a+4>>2],y[a+11|0])+1|0);tb(b);fb=e+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function LB(a,b,c,d){var e=0,f=0,g=0;e=ce(a);a:{if(e){f=ec(a);while(1){a=e;e=z[a+16>>1];g=x[a+20>>2];if(Wl(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Wl(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=ec(a);f=a}x[b>>2]=a;return f}function eB(a,b,c,d){var e=0,f=0,g=0;e=ce(a);a:{if(e){f=ec(a);while(1){a=e;e=y[a+16|0];g=x[a+20>>2];if(Ho(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Ho(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=ec(a);f=a}x[b>>2]=a;return f}function Vq(a,b,c,d){var e=0,f=0,g=0;a:{e=Yl(a,b);if((e|0)==255){break a}g=x[a>>2];if(Pj(g)){break a}f=Hd(a+318|0,e);e=PU(e);if(v[xb(f,10)|0]&1|d){Ah(g,x[a+4>>2],b,e- -64|0,OU(c,y[xb(f,2)|0]))}if(d){break a}Ah(x[a>>2],x[a+4>>2],b,e+67|0,OU(c,y[xb(f,3)|0]))}}function Vra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;tf(b);v[c+15|0]=0;a:{if(!ni(a,c+15|0)){break a}f=y[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}v[c+14|0]=0;if(ni(a,c+14|0)){Zp(b,v[c+14|0]);e=e+1|0;continue}break}d=0}fb=c+16|0;return d|0}function Kh(a,b,c,d,e,f){var g=0;g=fb-32|0;fb=g;x[g+12>>2]=-1;x[g+16>>2]=0;x[g+4>>2]=0;Fb(g+20|0);x[g+8>>2]=f;x[31725]=0;x[g+4>>2]=x[g+4>>2]&e|d;S(c|0,a|0,b|0,g+4|0);a=x[31725];x[31725]=0;if((a|0)!=1){Hh(g+4|0);fb=g+32|0;return}a=N()|0;Hh(g+4|0);Q(a|0);p()}function nH(a,b,c){var d=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31725]=0;O(c|0,a|0,b|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}YX(a,b)}b=d+8|0;Qd(b);dj(b);fb=d+16|0;return a}a=N()|0;dj(d+8|0);Q(a|0);p()}function iP(a){var b=0,c=0;b=x[a+24>>2];c=z[b+1074448>>1];if(c>>>0>=Rj(Xb(x[b+484360>>2],y[b+484376|0]))>>>0){return z[x[a+24>>2]+1074446>>1]}a=x[a+24>>2];b=z[_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],c)>>1];return yp(x[a+484344>>2],x[a+484348>>2],b)?b:-1}function a9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=x[b>>2];g=x[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function Cx(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;x[f+12>>2]=-1;x[f+16>>2]=0;x[f+4>>2]=0;x[f+8>>2]=0;Fb(f+20|0);x[31725]=0;x[f+4>>2]=x[f+4>>2]&e|d;S(c|0,a|0,b|0,f+4|0);a=x[31725];x[31725]=0;if((a|0)!=1){Hh(f+4|0);fb=f+32|0;return}a=N()|0;Hh(f+4|0);Q(a|0);p()}function $la(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=b;d=fb-16|0;fb=d;b=Hf(a,c);$d(d,x[a+36>>2]);a:{b:{if(!b){Pc(d,a+32|0,5);c=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}WB(x[a+36>>2],e,c);f=1;g=b}gf(a,g);fb=d+16|0;return f|0}function qH(a,b,c,d){var e=0,f=0;a:{e=fb-48|0;fb=e;f=e+28|0;ug(f,a,d);a=x[e+28>>2];d=e+4|0;wg(d,c,$e(f),a);x[31725]=0;O(220,e+16|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){a=e+16|0;ze(b,a);tb(a);Kc(e+28|0);fb=e+48|0;break a}a=N()|0;Kc(e+28|0);Q(a|0);p()}}function Wy(a){var b=0,c=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;if(x[a+20>>2]!=x[a+28>>2]){ib[x[a+36>>2]](a,0,0)|0}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;b=x[a>>2];if(b&4){x[a>>2]=b|32;return-1}c=x[a+44>>2]+x[a+48>>2]|0;x[a+8>>2]=c;x[a+4>>2]=c;return b<<27>>31}function Tba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=d+4|0;Ax(e,c);c=d+16|0;x[c>>2]=b;_c(c+4|0,e);x[31725]=0;O(1131,a+4|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){Zj(d+16|0);tb(d+4|0);fb=d+32|0;return}a=N()|0;Zj(d+16|0);tb(d+4|0);Q(a|0);p()}function OH(a,b,c,d){var e=0,f=0,g=0,h=0;a:{f=fb-16|0;fb=f;e=f+4|0;x[e+4>>2]=1;g=e,h=Ec(d),x[g+8>>2]=h;d=x[e+8>>2];x[31725]=0;P(c|0,d|0,b|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){b=a;a=Yn(e);Xn(b,nc(a),a);Am(e);fb=f+16|0;break a}a=N()|0;Am(e);Q(a|0);p()}}function p0(a,b,c){var d=0,e=0;d=fb-48|0;fb=d;tf(b);e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,2,$e(e),a);x[31725]=0;O(220,d+16|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){a=d+16|0;Ab(b,a);tb(a);Kc(d+28|0);fb=d+48|0;return}a=N()|0;Kc(d+28|0);Q(a|0);p()}function R$(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}v[d+15|0]=1;v[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=y[ef(d+15|0,d+14|0)|0]}a=e;fb=d+16|0;return a&255}function xba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[b>>2];e=x[b+8>>2];f=x[b+4>>2];a=0;a:while(1){if((a|0)!=(f|0)){g=(a<<2)+d|0;b=0;while(1)if((b|0)==(e|0)){a=a+1|0;continue a}else{c=x[g>>2]+(b<<3)|0;x[c>>2]=0;x[c+4>>2]=0;b=b+1|0;continue}}break}}function tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ri(a,b,c,d);x[a>>2]=44976;b=a+4208|0;e=yb(b,0),f=1017370378,x[e>>2]=f;e=yb(b,1),f=0,x[e>>2]=f;x[31725]=0;O(947,a+44|0,2);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;ag(a);Q(b|0);p()}function rf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;e=fb-16|0;fb=e;a:{if(b>>>0<2147483632){b:{if(Uk(b)){Me(d,b);break b}sg(e+8|0,Eh(b)+1|0);f=x[e+8>>2];yd(d,f);pf(d,x[e+12>>2]);Yd(d,b);d=f}fd(im(d,b,c)+b|0,0);fb=e+16|0;break a}qf();p()}return a|0}function qM(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=fb-16|0;fb=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(pd(a,e)){Eb(Xp(a));a=x[uk(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}}function nN(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=fb-16|0;fb=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(pd(a,e)){Zj(Az(a));a=x[br(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}}function h4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-32|0;fb=a;b=ti(a+20|0,b,c);x[31725]=0;c=U(1366,a+8|0,d|0,e|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){d=oi(Kb(b),Kb(c));tb(c);tb(b);fb=a+32|0;return((d|0)<0?-1:(d|0)!=0)|0}a=N()|0;tb(b);Q(a|0);p()}function dD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;UY(a,b);cd(a,$b(y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))+504|0);TY(a,d);a:{b=$b(y[b+32|0]|y[b+33|0]<<8|(y[b+34|0]<<16|y[b+35|0]<<24));if(!b){break a}if(!cd(a,b)){break a}fD(a,c);return}Tb(c,0,80)}function WG(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Dc(b+4|0,15559);a:{if(!Yc(x[a+4>>2],y[a+11|0])){break a}c=1;if((Rg(a,14629)|0)!=-1){break a}if((Rg(a,16809)|0)!=-1){break a}if((Rg(a,13773)|0)!=-1){break a}c=(Rg(a,13816)|0)!=-1}tb(a);fb=b+16|0;return c|0}function S1(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=-1;a:{if(!$F(a,c+12|0)){break a}d=0;if(!_F(c+12|0)){break a}if(b){a=x[b>>2];if(!x[b+4>>2]&a>>>0<$b(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))-8>>>0){break a}}d=1}fb=c+48|0;return d|0}function Paa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;if(!y[a+8|0]){_j(a+12|0,x[a+4>>2]);oe(b+24|0,x[a+12>>2],x[a+16>>2]);c=x[x[a>>2]+40>>2];d=x[b+28>>2];x[b+8>>2]=x[b+24>>2];x[b+12>>2]=d;ib[c|0](b+16|0,a,0,b+8|0);v[a+8|0]=1}fb=b+32|0;return x[a+12>>2]}function $f(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}Wj(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<2)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<2)|0,x[f>>2]=g;fb=e+16|0;return a|0}function w5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=sJ(a,0);x[a>>2]=118104;c=Fb(a+12|0);d=Fb(a+24|0);e=Fb(a+36|0);f=Fb(a+48|0);b=Kb(b);x[31725]=0;O(1348,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}a=N()|0;tb(f);tb(e);tb(d);tb(c);Q(a|0);p()}function u5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=rJ(a,0);x[a>>2]=118208;c=Fb(a+12|0);d=Fb(a+24|0);e=Fb(a+36|0);f=Fb(a+48|0);b=Kb(b);x[31725]=0;O(1349,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}a=N()|0;tb(f);tb(e);tb(d);tb(c);Q(a|0);p()}function s5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=qJ(a,0);x[a>>2]=118312;c=Fb(a+16|0);d=Fb(a+28|0);e=Fb(a+40|0);f=Fb(a+52|0);b=Kb(b);x[31725]=0;O(1350,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}a=N()|0;Qb(f);Qb(e);Qb(d);tb(c);Q(a|0);p()}function q5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=pJ(a,0);x[a>>2]=118416;c=Fb(a+16|0);d=Fb(a+28|0);e=Fb(a+40|0);f=Fb(a+52|0);b=Kb(b);x[31725]=0;O(1351,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}a=N()|0;Qb(f);Qb(e);Qb(d);tb(c);Q(a|0);p()}function BK(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[b>>2]=0;v[c+15|0]=0;ni(a,c+15|0);d=y[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){x[b>>2]=e;if((d|0)==(f|0)){fb=c+16|0}else{v[c+15|0]=0;ni(a,c+15|0);d=d+1|0;e=x[b>>2]|y[c+15|0]<<(d<<3)-2;continue}break}}function oE(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=fb-16|0;fb=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(pd(a,e)){nE(a);a=x[jj(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}}function rT(a,b,c,d){var e=0;e=-2147483648;e=!c|!(v[c+15|0]&1)?e:x[c+8>>2];a:{b:{if(!(!d|!(y[d+34|0]&32))){e=z[d+28>>1];break b}if((e|0)==-2147483648){break a}}Yq(b,e,a);if(!Ob(a+1074312|0,10)|y[a+480209|0]&64){break a}x[b+88>>2]=x[b+88>>2]&-257}}function V0(a,b,c){var d=0,e=0;d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,3,$e(e),a);x[31725]=0;O(220,d+16|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){a=d+16|0;pm(b,a);tb(a);Kc(d+28|0);fb=d+48|0;return}a=N()|0;Kc(d+28|0);Q(a|0);p()}function HL(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=HL(a*0x10000000000000000,b);c=x[b>>2]+-64|0}x[b>>2]=c;return a}x[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function $ra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{c=x[a>>2];if(oc(c,x[a+4>>2])>>>0>d>>>0){f=e+4|0;Cm(f,x[yb(c,d)>>2]+40|0);c=or(f,b);tb(f);if(!c){break a}g=x[yb(x[a>>2],d)>>2]}fb=e+16|0;return g|0}d=d+1|0;continue}}function Tja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);a:{b:{if(!c){Pc(e,a+32|0,5);f=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}f=x[c+16>>2]}ib[d|0](x[a+36>>2],b,f);g=c}gf(a,g);fb=e+16|0}function kW(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+D(b,872);b=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)==(b|0)){hc(c);fb=d+16|0}else{hW(Tb(b,0,872));b=b+872|0;x[c+4>>2]=b;continue}break}}function RC(a,b,c){var d=0;d=fb-16|0;fb=d;w[d+12>>1]=c;w[d+14>>1]=b;b=wb(x[a>>2]);c=wb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=b;while(1){if(Ib(b,c)){if(z[b>>1]==z[d+14>>1]){w[b>>1]=z[d+12>>1]}b=x[Md(a+12|0)>>2];continue}break}fb=a+16|0;fb=d+16|0}function yda(a,b){a=a|0;b=b|0;var c=0;a:{if((a|0)==(b|0)){break a}c=x[a+4>>2];if(c){Db(c);x[a+4>>2]=0}if(ib[x[x[b>>2]+8>>2]](b)|0){b=ib[x[x[b>>2]+8>>2]](b)|0}else{b=22255}c=Fd(Cf(b)+1|0);x[a+4>>2]=c;if(!c){break a}yc(c,b,Cf(b)+1|0)}return a|0}function ir(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=XW(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function hO(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=d,f=rO(c),x[e+8>>2]=f;c=x[re(d+12|0,d+8|0)>>2];x[31725]=0;b=+pa(1120,a|0,+b,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){Vc(d+8|0);fb=d+16|0;return+b}a=N()|0;Vc(d+8|0);Q(a|0);p()}function fx(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function bs(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=NF(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function Yr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=OF(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Ub(a,b+4|0);Ub(a+4|0,b+8|0);Ub(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function Hl(a,b,c){var d=0,e=0,f=0,g=0,h=0;while(1){a:{if((a|0)!=(b|0)){e=x[c>>2];g=x[c+4>>2];d=fb-16|0;fb=d;f=qc(d+8|0,x[a>>2]);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;e=Ic(e,g,d);fb=d+16|0;if(!e){break a}}else{a=b}return a}a=a+8|0;continue}}function dq(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function Sb(){var a=0;a=x[31597];x[31725]=0;X(a|0);a=x[31725];x[31725]=0;a:{if((a|0)!=1){x[31725]=0;X(1367);a=x[31725];x[31725]=0;if((a|0)!=1){break a}}Y(T(0)|0)|0;x[31725]=0;X(1367);a=x[31725];x[31725]=0;if((a|0)!=1){break a}T(0)|0;Sb()}p()}function wn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}sg(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+c|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+d|0,x[f>>2]=g;fb=e+16|0;return a|0}function tqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;jr(e,c);Dj(d+12|0,e);x[31725]=0;V(303,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Jua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Or(e,c);Dj(d+12|0,e);x[31725]=0;V(303,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function IS(a,b){a=DS(a);DS(a+368680|0);if(b){CS(a,1);return}if(!y[495776]){IS(127072,1);v[495776]=1}Nk(258184,323720,a+131112|0);Nk(323720,389256,a+196648|0);Nk(389256,454792,a+262184|0);Nk(127096,258184,a+24|0);yc(a+327720|0,454792,40960)}function FT(a,b){var c=0,d=0;d=fb-16|0;fb=d;c=x[a+104>>2];a:{if(!c){break a}c=x[c>>2];if(!c){break a}x[a+76>>2]=c;x[a+88>>2]=x[a+88>>2]&-131|128;x[d+12>>2]=b<<8;x[d+8>>2]=c-1;b=c+(x[Gb(d+12|0,d+8|0)>>2]^-1)|0;x[a>>2]=0;x[a+4>>2]=b}fb=d+16|0}function yaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;d=uv(e+4|0,a,d);f=x[d+4>>2];x[31725]=0;a=ba(1165,zb(a)|0,b|0,c|0,f|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){x[d+4>>2]=a;hc(d);fb=e+16|0;return}a=N()|0;hc(d);Q(a|0);p()}function wsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Rv(e,c);Dj(d+12|0,e);x[31725]=0;V(94,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function sh(a,b){var c=0,d=0,e=0;d=y[a+11|0];c=Cb(x[a+4>>2],d);a:{if((c|0)!=(Cb(x[b+4>>2],y[b+11|0])|0)){break a}a=Kb(a);b=Kb(b);if(!Cd(d)){while(1){e=!c;if(!c|y[a|0]!=y[b|0]){break a}b=b+1|0;a=a+1|0;c=c-1|0;continue}}e=!py(a,b,c)}return e}function rsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Wp(e,c);Dj(d+12|0,e);x[31725]=0;V(94,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function oQ(a,b,c){var d=0,e=0;if(E(F(a))<E(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return E((e?b^-1|e:b)|0)}function mpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;e_(e,c);Dj(d+12|0,e);x[31725]=0;V(94,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;d=hv(e+4|0,a,d);f=x[d+4>>2];x[31725]=0;a=ba(1129,zb(a)|0,b|0,c|0,f|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){x[d+4>>2]=a;hc(d);fb=e+16|0;return}a=N()|0;hc(d);Q(a|0);p()}function ue(a,b){var c=0,d=0;c=x[a+4>>2];d=c+b|0;x[a+4>>2]=d;if(x[a+8>>2]>=(d|0)){d=x[a>>2]+(c>>3)|0;a=c&7;c=y[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=y[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function sH(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=c;c=e+12|0;wc(c,d);wc(c,65535);d=z[e+12>>1];xg(a,d);c=0;while(1){if((c|0)==(d|0)){fb=e+16|0}else{f=y[b+c|0];g=Wr(x[a>>2],x[a+4>>2],c),h=f,w[g>>1]=h;c=c+1|0;continue}break}}function rD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Nb(a+8|0);x[31725]=0;d=R(204,b|0)|0;e=x[31725];x[31725]=0;b:{if((e|0)==1){break b}x[31725]=0;S(171,a|0,b|0,d|0);a=x[31725];x[31725]=0;if((a|0)==1){break b}break a}a=N()|0;dc(c);Q(a|0);p()}}function k$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;EE(e,c);Dj(d+12|0,e);x[31725]=0;V(94,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function aX(a){var b=0,c=0;a:{if(y[a+29|0]!=2){break a}b=y[a+28|0];if((b|0)!=26&(b|0)!=2|y[a+30|0]!=2){break a}b=y[a+31|0];if(b>>>0>21|!(1<<b&3146753)|y[a+33|0]>64){break a}b=y[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=_W(a+20|0)}return c}function _E(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;xw(e,c);Dj(d+12|0,e);x[31725]=0;V(94,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function WT(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+3|0]|y[b+4|0]<<8|(y[b+5|0]<<16|y[b+6|0]<<24);v[a+3|0]=b;v[a+4|0]=b>>>8;v[a+5|0]=b>>>16;v[a+6|0]=b>>>24}function RG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;fo(e,c);Dj(d+12|0,e);x[31725]=0;V(94,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31725];x[31725]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Lsa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;v[b+30|0]=0;w[b+28>>1]=0;c=gc(b+8|0,b+28|0,3);kc(b+20|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+24>>2]!=3){break a}if(kd(b+28|0,14733,3)){break a}Vb(a,3);d=1}fb=b+32|0;return d|0}function Koa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;w[b+28>>1]=0;x[b+24>>2]=0;c=gc(b+8|0,b+24|0,6);kc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=6){break a}if(kd(b+24|0,3856,6)){break a}Vb(a,6);d=1}fb=b+32|0;return d|0}function yy(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;w[b>>1]=0;v[c+15|0]=0;ni(a,c+15|0);d=y[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){w[b>>1]=e;if(d>>>0>=f>>>0){fb=c+16|0}else{v[c+15|0]=0;ni(a,c+15|0);e=z[b>>1]|y[c+15|0]<<7;d=1;continue}break}}function ix(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;mf(e+8|0,b,c);x[31725]=0;Ma(167,a|0,x[e+8>>2],x[e+12>>2]);b=x[31725];x[31725]=0;if((b|0)!=1){x[a+8>>2]=0;Ef(a+12|0,d);ke(d);fb=e+16|0;return a|0}a=N()|0;ke(d);Q(a|0);p()}function VC(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=x[b+12>>2];mf(e+16|0,c,d);c=x[x[b>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,b,f,e+8|0);mf(a,x[e+24>>2],x[e+28>>2]);x[b+12>>2]=x[b+12>>2]+x[a+4>>2];fb=e+32|0}function sA(a,b){var c=0,d=0,e=0,f=0;c=a&16711680;d=c>>>8|0;e=c<<24;c=a&-16777216;f=c>>>24|0;c=e|c<<8;e=d|f|(a<<24|(a&65280)<<8);d=0;hb=e|(d|d);return((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|c}function nT(a,b){var c=0,d=0;a:{if(!(y[a+89|0]&16)){break a}c=x[a+656>>2];if(!c){break a}c=x[c>>2];b:{if(c){d=a;a=x[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;x[d+696>>2]=a;a=(D(a,x[b>>2])|0)/65536|0;break b}if(x[a+696>>2]){break a}a=0}x[b>>2]=a}}function O0(a){var b=0,c=0,d=0,e=0;c=y[a+2|0];b=c+(y[a+5|0]|y[a+6|0]<<8)|0;c=(b>>>0<c>>>0?1:d)<<1|b>>>31;d=b<<1;b=c;a=y[a+3|0]|y[a+4|0]<<8;c=a>>>30|0;e=d;d=a<<2;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e+47|0;hb=b>>>0<47?a+1|0:a;return b}function AU(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=x[a>>2];e=Lk(b,x[a+4>>2]);b=wb(b);x[c+12>>2]=b;d=+(e>>>0);a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){C[b>>3]=C[b>>3]/d;C[b+8>>3]=C[b+8>>3]/d;b=x[$o(c+12|0)>>2];continue}else{fb=c+16|0}break}}function rua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;$w(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b+2|0]=0;v[b|0]=0;v[b+1|0]=0}}function ov(a){var b=0;a:{if(y[a+4|0]|(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1414687062){break a}if(Bb(y[a+6|0]|y[a+7|0]<<8)>>>0>1){break a}if(Bb(y[a+12|0]|y[a+13|0]<<8)){break a}b=(Bb(y[a+16|0]|y[a+17|0]<<8)|0)==20}return b}function Ji(a,b,c){var d=0,e=0,f=0,g=0;x[a+112>>2]=b;x[a+116>>2]=c;e=x[a+4>>2];d=x[a+44>>2]-e|0;x[a+120>>2]=d;x[a+124>>2]=d>>31;d=a;a=x[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}x[d+104>>2]=a}function ET(a,b){var c=0,d=0;a:{if(!(v[a+851|0]&1)){break a}c=x[a+104>>2];if(!c){break a}d=x[c>>2];if(!d){break a}x[a+76>>2]=d;x[a>>2]=0;x[a+4>>2]=d-1;c=x[a+88>>2];x[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}x[a+84>>2]=d;x[a+80>>2]=0}}function Aja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=b;d=fb-16|0;fb=d;b=Hf(a,c);$d(d,x[a+36>>2]);a:{b:{if(!b){Pc(d,a+32|0,5);c=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}WB(x[a+36>>2],e,c);f=b}gf(a,f);fb=d+16|0}function hV(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=$h(e+4|0,a,c-f>>1);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){hc(g);Dr(b,f,h);fb=e+16|0}else{gj(d,z[a>>1]);d=d+2|0;x[g+4>>2]=d;a=a+2|0;continue}break}}function CV(a){var b=0,c=0,d=0;d=Yo(a);while(1){if((a|0)!=(d|0)){b=y[a|0];a:{b:{if((b-97&255)>>>0<=5){c=b-32|0;break b}if(!(b-88>>>0<2|b-120>>>0<2)){c=99;if((b|0)==75|(b|0)==107){break b}break a}c=122}v[a|0]=c}a=a+1|0;continue}break}}function ug(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Nb(a+8|0);x[31725]=0;S(171,a|0,b|0,c|0);c=x[31725];x[31725]=0;a:{if((c|0)!=1){a=x[a>>2];x[31725]=0;P(185,b|0,a|0)|0;a=x[31725];x[31725]=0;if((a|0)!=1){break a}}a=N()|0;dc(d);Q(a|0);p()}}function NT(a,b,c){var d=0;d=x[b+48>>2]+1|0;x[b+52>>2]=d;a:{if(A[Wb(x[a+484344>>2],z[b+70>>1])+12>>2]>d>>>0){break a}if(!c){w[b+74>>1]=z[b+72>>1]+1}x[b+52>>2]=0;if(!Ob(a+1074312|0,63)){break a}a=x[b+56>>2];x[b+56>>2]=0;x[b+52>>2]=a}}function Hsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;kD(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,4896)}return a|0}function s9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=Tk(b,4,c,x[a+32>>2])}return c|0}function pZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=An(a);e=Cb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Kb(a);Zi(d+(e<<2)|0,b,c);b=c+e|0;ng(a,b);yd(d+(b<<2)|0,0);return a|0}wI(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a|0}function h$(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=am(e+4|0,a,c-f|0);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){hc(g);Dr(b,f,h);fb=e+16|0}else{Fl(d,y[a|0]);d=d+1|0;x[g+4>>2]=d;a=a+1|0;continue}break}}function Zf(a,b,c){var d=0;a:{if(A[b+8>>2]<c>>>0){x[31725]=0;V(1150,17408,9110,435,6381);a=x[31725];x[31725]=0;if((a|0)==1){break a}p()}d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;return}T(0)|0;Sb();p()}function D_(a){var b=0,c=0,d=0,e=0;b=y[a+3|0];c=ova(b>>>0<3?48:64,0,Bb(y[a+196|0]|y[a+197|0]<<8),0);d=hb;e=c;c=ova(ova(Bb(y[a+198|0]|y[a+199|0]<<8),0,b>>>0<4?4:5,0),hb,Bb(y[a+200|0]|y[a+201|0]<<8),0);b=e+c|0;b=b+512|0;hb=0;return b}function nC(a,b){var c=0,d=0,e=0,f=0;w[a+24>>1]=0;x[a+20>>2]=0;x[a>>2]=0;x[a+4>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(F(d)<2147483648){b=~~d;break a}b=-2147483648}x[a+16>>2]=b;e=a,f=wW(c-+(b<<2)),x[e+8>>2]=f;x[a+12>>2]=hb;return a}function gS(a){var b=0,c=0,d=0;c=fb-544|0;fb=c;a:{if(!(y[a+480210|0]&128)|!x[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=nC(c,x[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}yc(b+112|0,a,538);b=b+872|0;continue}}fb=c+544|0}function fB(a,b,c){var d=0,e=0;d=ce(a);a:{if(d){e=ec(a);while(1){a=d;d=y[a+16|0];if(Io(c,d)){e=a;d=x[a>>2];if(d){continue}break a}if(!Io(d,c)){break a}e=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(a);e=a}x[b>>2]=a;return e}function Gra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;hD(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,33)}return a|0}function yba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=x[b>>2];d=x[b+8>>2];e=x[b+4>>2];a=0;a:while(1){if((a|0)!=(e|0)){f=(a<<2)+c|0;b=0;while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{x[x[f>>2]+(b<<2)>>2]=0;b=b+1|0;continue}}break}}function v1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;yw(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,65)}return a|0}function gva(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){fh(a+b|0);a=a+1|0;continue}break}break a}bc(c+8|0,b,120);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function wR(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=e>>>8|0;g=(e&255)<<24|d>>>8;d=(((y[b|0]^d)&255)<<3)+22288|0;e=x[d>>2];d=x[d+4>>2]^f;x[a>>2]=e^g;x[a+4>>2]=d;b=b+1|0;continue}break}return a}function Tta(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){zp((a<<1)+b|0);a=a+1|0;continue}break}break a}hw(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Si(a){var b=0,c=0,d=0,e=0;b=Zd(a);c=b&63;e=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){d=Zd(a);c=(d&127)<<b|c;if(d<<24>>24>=0){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}return(e|0)<0?(c|0)<0?-2147483648:0-c|0:c}function Eg(a,b){var c=0,d=0,e=0,f=0;d=z[a+22>>1];e=d+z[a+20>>1]|0;c=z[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-D(x[yb(b,z[c+28>>1])>>2],w[c+26>>1])|0;d=d+1|0;continue}break}return a}function x2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=x[d>>2];g=x[b+8>>2];if(g>>>0>c>>>0){x[e+12>>2]=g-c;x[e+8>>2]=x[d+4>>2];b=x[b+4>>2]+c|0;h=x[Gb(e+12|0,e+8|0)>>2];Wg(b,b+h|0,f)}bc(a,f,h);fb=e+16|0}function eE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=x[a>>2];f=qm(e,x[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=hj(e,c);if(!Ib(x[c>>2],x[c+4>>2])){break a}d=d+1|0;continue}break}return(Ng(a,d&65535,b)?d:-1)&65535}function UR(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Gc(pva(ova(d,d>>31,g,h),hb,256,0),hb);x[a+4>>2]=f-d;x[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function Sr(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=fb-16|0;fb=b;Zr(b+8|0,c+15|0);d=x[b+12>>2];od(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(d|0)){gd(a,x[b+12>>2])}fb=b+16|0;fb=c+16|0;return((d|0)==(e|0)?y[c+15|0]:0)&255}function QD(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}RE(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,20)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+D(d,20)|0,x[f>>2]=g;fb=e+16|0;return a}function Em(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}$G(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,12)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+D(d,12)|0,x[f>>2]=g;fb=e+16|0;return a}function pva(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=qva(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;hb=(g^hb)-((a>>>0<f>>>0)+g|0)|0;return b}function Tla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;JU(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){QB(b)}return a|0}function Pqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(Lh(178956970)>>>0<b>>>0){dd();p()}d=Ec(D(b,24));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=zb(a),f=b+D(x[c+12>>2],24)|0,x[e>>2]=f;fb=c+16|0}function LT(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!c){break a}x[b+40>>2]=c;if(!c|x[a+480180>>2]!=256){break a}x[d+12>>2]=c>>>4;x[d+8>>2]=1;e=b,f=x[ad(d+12|0,d+8|0)>>2],x[e+40>>2]=f;e=b,f=xC(c&255),x[e+44>>2]=f}fb=d+16|0}function Ioa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(Lh(119304647)>>>0<b>>>0){dd();p()}d=Ec(D(b,36));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=zb(a),f=b+D(x[c+12>>2],36)|0,x[e>>2]=f;fb=c+16|0}function vw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Hw(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){LE(b)}return a|0}function tj(a,b,c){c=c&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=y[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(y[a+1|0]|32)!=120){break a}a=a+2|0}return a}function ok(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}Uw(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<1)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<1)|0,x[f>>2]=g;fb=e+16|0;return a}function ms(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}tG(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<3)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<3)|0,x[f>>2]=g;fb=e+16|0;return a}function gv(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}XV(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<5)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<5)|0,x[f>>2]=g;fb=e+16|0;return a}function Tq(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(C[Qp(b)>>3]-C[a>>3]);b=0;while(1){if((b|0)!=2048){d=-Ee(f*C[Ve(a,b)>>3]);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}g=yb(c,b),h=e,x[g>>2]=h;b=b+1|0;continue}break}}function Jaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=e+4|0;x[c+4>>2]=1;f=c,g=Ec(40),x[f+8>>2]=g;d=zm(x[c+8>>2]);x[d>>2]=78280;d=EM(nc(d));x[d+24>>2]=b;x[d>>2]=78428;b=a;a=Yn(c);Xn(b,nc(a),a);Am(c);fb=e+16|0}function Av(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;HX(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){IX(b)}return a|0}function AZ(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}xZ(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,6)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+D(d,6)|0,x[f>>2]=g;fb=e+16|0;return a}function $V(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}_V(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<4)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<4)|0,x[f>>2]=g;fb=e+16|0;return a}function zZ(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,6)+f;b=x[d>>2];while(1){if(x[d+4>>2]!=(b|0)){Pv(b,c);b=x[d>>2]+6|0;x[d>>2]=b;continue}break}he(d);fb=e+16|0}function w$(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179011410|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1179472708)){return 1}return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179472708}function mua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(Lh(715827882)>>>0<b>>>0){dd();p()}d=Ec(D(b,6));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=zb(a),f=b+D(x[c+12>>2],6)|0,x[e>>2]=f;fb=c+16|0}function lla(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],16);a:{if(!d){a=0;while(1){if((a|0)!=16){fh(a+b|0);a=a+1|0;continue}break}break a}bE(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function ae(a,b){var c=0,d=0,e=0,f=0,g=0;d=z[a+22>>1];g=d+z[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=z[e+28>>1]+b|0;w[e+28>>1]=f;if((f&65535)>>>0<2048){break a}w[a+20>>1]=c-d}return}c=c+1|0;continue}}function Nsa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a+480180>>2]=b;yr(c,zr(a));d=x[c+12>>2];b=a+1074320|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=d;b=x[c+4>>2];x[a+1074312>>2]=x[c>>2];x[a+1074316>>2]=b;Bu(a+8|0,zr(a));fb=c+16|0}
function Bu(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=42284;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=42136;break a;case 2:c=42132;break a;case 1:break b;case 0:break c}}c=42128;break a}c=42124}x[a>>2]=x[c>>2]}function tta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(Lh(2147483647)>>>0<b>>>0){dd();p()}d=Ec(b<<1);x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=zb(a),f=b+(x[c+12>>2]<<1)|0,x[e>>2]=f;fb=c+16|0}function or(a,b){var c=0,d=0;c=fb-32|0;fb=c;ee(c+24|0,a);ee(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=x[c+24>>2];b=x[c+28>>2];d=x[c+12>>2];if((b|0)==(d|0)){a=GZ(a,b,x[c+8>>2],d)}else{a=1}fb=c+32|0;return!a}function Tpa(a,b){a=a|0;b=b|0;var c=0;b=fb-32|0;fb=b;c=-1;a:{if(!$D(a,b+20|0)){break a}c=0;if(!GX(b+20|0)){break a}c=-1;if(!rk(a,b+12|0)){break a}c=0;if(!x[b+16>>2]){break a}c=!(x[b+12>>2]&-2139062144)}fb=b+32|0;return c|0}function SV(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!(c&32)){break a}c=zd(b);x[d+12>>2]=c;f=Df(b);while(1){if(!Ib(c,f)){break a}e=y[c|0];if((e-97&255)>>>0<=25){v[c|0]=e-32}c=x[me(d+12|0)>>2];continue}}_c(a,b);fb=d+16|0}function lqa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){fh(a+b|0);a=a+1|0;continue}break}break a}TD(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Zja(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;d=-1;a:{if(!PG(a,c+8|0)){break a}d=0;if(!FR(c+8|0)|(x[b>>2]!=(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))|x[b+4>>2]?b:0)){break a}d=1}fb=c+32|0;return d|0}function Gt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Mc(a);e=Cb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Kb(a);Cg(d+e|0,b,c);b=c+e|0;ng(a,b);fd(b+d|0,0);return a|0}fq(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a|0}function AH(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;x[f+24>>2]=a;x[f+28>>2]=b;x[f+16>>2]=d;x[f+20>>2]=e;x[f+8>>2]=c;x[f+12>>2]=0;a=J0(f+24|0,f+8|0);b=f+16|0;a=iq(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?a:b;fb=f+32|0;return x[a>>2]}function zv(a,b){var c=0,d=0,e=0;if(x[a>>2]){n0(a);c=x[a>>2];rE(a);Db(c);d=zb(a),e=0,x[d>>2]=e;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=zb(b);d=zb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0}function _t(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=x[b>>2];b=oc(d,x[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){fb=c+16|0}else{x[c+12>>2]=0;e=sc(c+12|0);f=yb(d,a),g=x[e>>2],x[f>>2]=g;a=a+1|0;continue}break}}function gT(a,b){var c=0,d=0,e=0,f=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];d=zb(a);c=ec(a);a:{if(!x[d>>2]){x[a>>2]=c;break a}x[x[c>>2]+8>>2]=c;c=ec(b);x[b>>2]=c;x[c>>2]=0;e=zb(b),f=0,x[e>>2]=f}return a}function dia(a){a=a|0;var b=0;ib[x[x[a>>2]+132>>2]](a);Vz(a);x[a+4236>>2]=0;v[a+4202|0]=1;b=ib[x[x[a>>2]+196>>2]](a)|0;x[a+4328>>2]=0;x[a+4312>>2]=0;B[a+4240>>2]=b?E(.5):E(1);b=x[a+4256>>2];x[a+4324>>2]=b;x[a+4320>>2]=b}function cX(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){v[d+14|0]=(z[(b<<1)+31054>>1]-z[(c<<1)+31054>>1]|0)/5;a=y[Rb(d+15|0,d+14|0)|0]}fb=d+16|0;return a&255}function Rba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;e=d+4|0;mN(e,c);a=x[a+1298472>>2];x[31725]=0;S(387,a|0,b|0,e|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(d+4|0);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function MA(a,b){var c=0;c=x[b+24>>2];c=c>>>0<=1?1:c;x[a+24628>>2]=c>>>0>=512?512:c;a:{if(!(x[b+16>>2]!=x[a+24620>>2]|x[b+20>>2]!=x[a+24624>>2])){c=0;if(x[b+12>>2]==x[a+24616>>2]){break a}}c=1}yc(a+24604|0,b,40);bS(a,c)}function Jx(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;g=Ef(f+8|0,d);x[31725]=0;h=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=h;a=jg(e,a,b,c,f);b=x[31725];x[31725]=0;if((b|0)!=1){ke(d);fb=f+16|0;return a}a=N()|0;ke(d);Q(a|0);p()}function pea(a,b){a=a|0;b=b|0;var c=0;a=x[a+8>>2];a:{if(Ad(x[b+4>>2],y[b+11|0])){c=0}else{c=a;if(Ld(b,47360)){break a}c=a+88|0;if(Ld(b,47372)){break a}c=a+92|0;if(Ld(b,47384)){break a}c=Ld(b,47397)?a+96|0:0}}return c|0}function fZ(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function ei(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;bc(d+8|0,b,c);e=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Vb(a,x[d+12>>2])}fb=d+16|0;a=(e|0)==(f|0);if(!a){Tb(b,0,c)}return a}function b$(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=777268804){break a}if($b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Bb(y[a+8|0]|y[a+9|0]<<8)}return b}function Xta(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if(Lh(1073741823)>>>0<=8191){dd();p()}c=Ec(32768);x[b+12>>2]=8192;x[b+8>>2]=c;c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=zb(a),e=c+(x[b+12>>2]<<2)|0,x[d>>2]=e;fb=b+16|0}function Tra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=-1;a:{if(!rk(a,d+8|0)){break a}e=x[d+12>>2];c=0;if(!(x[d+8>>2]==(Ln(8978)|0)&e>>>0>255&e>>>0<260)){break a}c=ve(a,b,e>>>0<259?80:76,0)}fb=d+16|0;return c|0}function Qt(a){var b=0;a:{b=y[a+1376|0];b:{if(!b){b=-1;if(x[a+1384>>2]){break b}if(!ez(a)){break b}b=y[a+1376|0];if(!b){break a}}v[a+1376|0]=b-1;x[a+1400>>2]=x[a+1400>>2]+1;b=hf(a)}return b}_(15751,13258,1578,5429);p()}function DX(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;d=vb(c+12|0,a);a=x[d>>2];if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(e|0)){b=b-56|0;hr(b);continue}break}x[a+4>>2]=e;a=x[d>>2];b=x[a>>2];AX(a);Db(b)}fb=c+16|0}function $S(a,b,c,d){var e=0,f=0;e=x[(D(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=z[(D(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=y[((b<<5)+a|0)+480288|0]}return f}function vB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=x[b+480180>>2];if(f&64671904){b=y[(d&15)+42208|0];v[a+2|0]=0;w[a>>1]=b;return}g=a;a=(c&255)==4&(f|0)==4;c=(d&255)<<a<<4;fm(g,(h=Ob(b+1074312|0,66)?0:c,i=c,j=e,j?h:i),a)}function UU(a,b){a:{if(y[a+76|0]==(b|0)){break a}v[a+76|0]=b;if(b){b=0;if(z[a+24>>1]==15){w[a+20>>1]=0;b=1}x[a+8>>2]=0;x[a+16>>2]=b;return}b:{switch(x[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}x[a+16>>2]=3}}function TI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=a;a=Bk(Kb(b));x[d>>2]=a;a:{if(!a){a=c+4|0;Tm(a,17609,b);x[31725]=0;W(1345,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c+4|0);Q(a|0);p()}fb=c+16|0;return}p()}function EF(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Mb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;gh(a,c+15|0);d=v[c+15|0]}fb=c+16|0;a=d<<24>>24;break a}_(11235,9079,324,14199);p()}return a}function xr(a,b,c){var d=0,e=0;e=z[a+480192>>1];a:{if(e){if(!Tc(b)|c>>>0>e>>>0){break a}c=x[((c<<2)+a|0)+900380>>2];if(!c){break a}d=z[_b(c+236|0,b-1|0)>>1];break a}d=c}return(z[a+480190>>1]>=(d&65535)>>>0?d:0)&65535}function ova(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=D(e,f);g=c&65535;h=a&65535;i=D(g,h);f=(i>>>16|0)+D(f,g)|0;e=(f&65535)+D(e,h)|0;hb=(D(b,c)+j|0)+D(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function cz(a){var b=0;a:{b:{while(1){if(x[a+1380>>2]!=-1){break b}b=0;if(!Pt(a)){break a}if(!(v[a+1375|0]&1)){continue}break}fc(a,32);return 0}x[a+1396>>2]=0;x[a+1400>>2]=0;x[a+1384>>2]=0;v[a+1376|0]=0;b=1}return b}function Vga(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;a:{if(!Ld(a,10265)){c=b+4|0;Tm(c,18196,a);a=Kb(c);x[31725]=0;O(68,44,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(b+4|0);Q(a|0);p()}fb=b+16|0;return}p()}function SI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Bk(Kb(b));x[a>>2]=d;a:{if(!d){a=c+4|0;Tm(a,17650,b);x[31725]=0;W(1345,a|0);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;tb(c+4|0);Q(a|0);p()}fb=c+16|0;return a}p()}function LL(a,b){var c=0,d=0,e=0;c=fb-256|0;fb=c;if((b|0)>=2){x[(b<<2)+a>>2]=c;yc(c,x[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;yc(x[e>>2],x[(d<<2)+a>>2],4);x[e>>2]=x[e>>2]+4;if((b|0)!=(d|0)){continue}break}}fb=c+256|0}function vU(a,b){var c=0,d=0,e=0,f=0;e=C[a+48>>3];c=C[a+40>>3];C[a+48>>3]=c;f=C[a+64>>3];d=C[a+56>>3];C[a+64>>3]=d;C[a+40>>3]=b;b=e*C[a+16>>3]+(C[a>>3]*b+c*C[a+8>>3])-d*C[a+24>>3]-f*C[a+32>>3];C[a+56>>3]=b;return b}function WB(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:ZU(a,b);return;default:break a}}d=fb-32|0;fb=d;x[d+28>>2]=c;w[d+26>>1]=0;x[d+12>>2]=2;nz(d+16|0,a,d+26|0,x[Gb(d+28|0,d+12|0)>>2]);ij(b,z[d+26>>1]);fb=d+32|0}function wV(a){var b=0;b=w[a+784>>1];if(b){x[a+692>>2]=(b&32767)-1;if((b|0)<0){x[a+88>>2]=x[a+88>>2]|256}w[a+784>>1]=0}b=y[a+795|0];if(b){v[a+795|0]=0;v[a+838|0]=b-1}b=y[a+796|0];if(b){v[a+796|0]=0;v[a+837|0]=b-1}}function ro(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return E(b?-1/a:a)}function Mq(a,b){a=yc(a,b,88);x[a+88>>2]=x[b+88>>2];yc(a+92|0,b+92|0,576);x[a+668>>2]=x[b+668>>2];yc(a+672|0,b+672|0,52);jB(a+724|0,b+724|0);jB(a+732|0,b+732|0);jB(a+740|0,b+740|0);yc(a+748|0,b+748|0,123);return a}function hsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);a:{if(!c){Pc(e,a+32|0,5);f=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}MZ(x[a+36>>2],b,d,0);f=c}gf(a,f);fb=e+16|0}function vka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Ug(a)>>>0<b>>>0){if(Lh(1073741823)>>>0<b>>>0){break a}d=zb(a);e=a;a=$f(c+12|0,b,oc(x[a>>2],x[a+4>>2]),d);_m(e,a);_f(a)}fb=c+32|0;return}dd();p()}function _T(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;d=vb(c+12|0,a);a=x[d>>2];if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(e|0)){b=b-7|0;continue}break}x[a+4>>2]=e;a=x[d>>2];b=x[a>>2];GB(a);Db(b)}fb=c+16|0}function xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(ll(a)>>>0<b>>>0){if(Lh(357913941)>>>0<b>>>0){break a}d=zb(a);e=a;a=Em(c+12|0,b,Ud(x[a>>2],x[a+4>>2]),d);vx(e,a);zs(a)}fb=c+32|0;return}dd();p()}function jpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(ll(a)>>>0<b>>>0){if(Lh(357913941)>>>0<b>>>0){break a}d=zb(a);e=a;a=Em(c+12|0,b,Ud(x[a>>2],x[a+4>>2]),d);NW(e,a);MW(a)}fb=c+32|0;return}dd();p()}function fG(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;if(c>>>0<2147483632){a:{if(Uk(c)){Me(a,c);break a}sg(d+8|0,Eh(c)+1|0);e=x[d+8>>2];yd(a,e);pf(a,x[d+12>>2]);Yd(a,c);a=e}fd(Xg(a,b,c)+c|0,0);fb=d+16|0;return}qf();p()}function bn(a,b){var c=E(0),d=0,e=0;c=E(1);d=w[a+28>>1];a:{if((d|0)>(b|0)){break a}e=x[a+4>>2];if((oc(e,x[a+8>>2])+d|0)-1<<16>>16<(b|0)){break a}c=B[yb(e,b-d|0)>>2];c=c<=E(10000000036274937e-31)?E(1):c}return c}function al(a){wc(a+16|0,x[a>>2]);wc(a+8|0,x[a>>2]);if(A[a+12>>2]>=A[a+16>>2]){x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=z[a+34>>1]&65511}if(A[a+4>>2]>=A[a+8>>2]){x[a+4>>2]=0;x[a+8>>2]=0;w[a+34>>1]=z[a+34>>1]&65529}}function UY(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;WY(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){VY(b)}return a}function QY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Pn(a)>>>0<b>>>0){if(Lh(2147483647)>>>0<b>>>0){break a}d=zb(a);e=a;a=ok(c+12|0,b,Zc(x[a>>2],x[a+4>>2]),d);Yr(e,a);kj(a)}fb=c+32|0;return}dd();p()}function OD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;O_(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){P_(b)}return a}function Lla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Zn(a)>>>0<b>>>0){if(Lh(536870911)>>>0<b>>>0){break a}d=zb(a);e=a;a=ms(c+12|0,b,kh(x[a>>2],x[a+4>>2]),d);NB(e,a);ls(a)}fb=c+32|0;return}dd();p()}function Hu(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;if(c>>>0<2147483632){a:{if(Uk(c)){Me(a,c);break a}sg(d+8|0,Eh(c)+1|0);e=x[d+8>>2];yd(a,e);pf(a,x[d+12>>2]);Yd(a,c);a=e}fd(Cg(a,b,c)+c|0,0);fb=d+16|0;return}qf();p()}function Dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);a:{if(!c){Pc(e,a+32|0,5);f=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}eR(d,x[a+36>>2],b);f=c}gf(a,f);fb=e+16|0}function Bla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(GB(a)>>>0<b>>>0){if(Lh(613566756)>>>0<b>>>0){break a}d=zb(a);e=a;a=ZT(c+12|0,b,FB(x[a>>2],x[a+4>>2]),d);YT(e,a);XT(a)}fb=c+32|0;return}dd();p()}function vea(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;mN(d,b);a=x[a+1298472>>2];x[31725]=0;S(387,a|0,1,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(c+4|0);fb=c+16|0;return}a=N()|0;tb(c+4|0);Q(a|0);p()}function gL(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];a:{if(!c){break a}d=x[c+24>>2];b:{if((d|0)==x[c+28>>2]){b=ib[x[x[c>>2]+52>>2]](c,b)|0;break b}x[c+24>>2]=d+4;x[d>>2]=b}if(!po(b)){break a}x[a>>2]=0}return a|0}function WM(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=e+8|0;tz(f,b);while(1){if(d){b=x[f+4>>2];h=vh(d);Ej(b,c+g|0,h);b=x[x[f+4>>2]+4>>2];d=d-b|0;g=b+g|0;if((b|0)==(h|0)){continue}}break}bc(a,c,g);fb=e+16|0}function Pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Fj(a);if(d){e=x[b+4>>2];b=x[b>>2];x[c+8>>2]=b;x[c+12>>2]=e;a=x[x[d>>2]+72>>2];x[c>>2]=b;x[c+4>>2]=e;a=ib[a|0](d,c)|0}else{a=1}fb=c+16|0;return a|0}function KA(a,b){var c=0,d=0;c=x[b+4>>2];x[a+24648>>2]=x[b>>2];x[a+24652>>2]=c;d=x[b+20>>2];c=a+24664|0;x[c>>2]=x[b+16>>2];x[c+4>>2]=d;d=x[b+12>>2];c=a+24656|0;x[c>>2]=x[b+8>>2];x[c+4>>2]=d;aS(a+24648|0);gS(a)}function Haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=x[c>>2];c=x[c+4>>2];while(1){if(c){d=x[b+24>>2];g=vh(c);Ej(d,e+f|0,g);d=x[x[b+24>>2]+4>>2];c=c-d|0;e=e+d|0;if((d|0)==(g|0)){continue}}break}bc(a,f,e)}function mp(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Id(d+24|0,a,b);yn(d+16|0,x[d+24>>2],x[d+28>>2],c);a=e$(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];Ac(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function Nx(a,b,c){var d=0;d=x[a+16>>2];if(!d){x[a+36>>2]=1;x[a+24>>2]=c;x[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(x[a+24>>2]!=2){break a}x[a+24>>2]=c;return}v[a+54|0]=1;x[a+24>>2]=2;x[a+36>>2]=x[a+36>>2]+1}}function IJ(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Id(d+24|0,a,b);yn(d+16|0,x[d+24>>2],x[d+28>>2],c);a=kA(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];Ac(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function wW(a){a=a*4294967296;if(F(a)<0x8000000000000000){hb=F(a)>=1?~~(a>0?H(J(a*2.3283064365386963e-10),4294967295):K((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}hb=-2147483648;return 0}function QC(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=CG(a);a:while(1){if((a|0)!=(e|0)){f=td(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((y[xb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function HA(a,b,c){var d=0,e=0;d=x[b+656>>2];if(!d){return 0}d=Jw(d,c);a=a+1074312|0;if(!Ob(a,31)){e=Ob(a,93)^1}a:{if(!(v[XR(b,c)+6|0]&1)){a=0;if(!(v[d+12|0]&1)|e){break a}}a=lc(x[d>>2],x[d+4>>2])^1}return a}function pv(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Id(d+24|0,a,b);yn(d+16|0,x[d+24>>2],x[d+28>>2],c);a=x[d+16>>2];f=d,g=WD(c,x[d+20>>2]),x[f+12>>2]=g;Ac(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0}function cpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;qn(a,b);b=wb(x[a>>2]);x[c+12>>2]=b;a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){d=y[b|0]+(d&255)|0;v[b|0]=d;b=x[me(c+12|0)>>2];continue}else{fb=c+16|0}break}}function YS(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function FE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function od(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=x[b+12>>2];mf(e+16|0,c,d);c=x[x[b>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,b,f,e+8|0);mf(a,x[e+24>>2],x[e+28>>2]);fb=e+32|0}function Mla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Nb(a);d=qg(a+12|0);v[a+32|0]=c;x[a+28>>2]=0;x[a+24>>2]=b;x[31725]=0;O(805,a|0,1);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;nU(d);sU(a);Q(b|0);p()}function Jd(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Mb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;gh(a,c+15|0);d=y[c+15|0]}fb=c+16|0;break a}_(11235,9079,324,14199);p()}return d}function Ei(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;bc(d+8|0,b,c);e=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Vb(a,x[d+12>>2])}fb=d+16|0;if((e|0)!=(f|0)){Tb(b,0,c)}}function Aqa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;w[b+30>>1]=0;c=gc(b+8|0,b+30|0,2);kc(b+20|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);if(!(x[b+24>>2]!=2|z[b+30>>1]!=21584)){Vb(a,2);d=1}fb=b+32|0;return d|0}function wua(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],64)){a=0;while(1){if((a|0)!=64){fh(a+b|0);a=a+1|0;continue}break}break a}hw(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function WU(a){var b=0,c=0,d=0;b=z[a+20>>1];w[a+28>>1]=z[a+22>>1]<<1|(y[x[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=x[c>>2];if(d){Vo(d);VU(x[c>>2])}b=b+1|0;continue}break}}function WO(a,b){var c=0,d=0;c=-1;a:{if((b|0)<0){break a}d=x[a+24>>2];if(Rj(Xb(x[d+484360>>2],y[d+484376|0]))>>>0<=b>>>0){break a}a=x[a+24>>2];c=z[_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],b)>>1]}return c}function Sla(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],27)){a=0;while(1){if((a|0)!=27){fh(a+b|0);a=a+1|0;continue}break}break a}JU(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function mha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;b=Gc(pva(ova(d,d>>31,b,0),hb,1e3,0),hb);x[a+16>>2]=0;x[a+12>>2]=b+c;fQ(a,e);b=x[a+12>>2];x[f+12>>2]=0;iR(a,b,f+12|0);fb=f+16|0}function iG(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808603728|(y[a+4|0]-16&255)>>>0<249|((y[a+5|0]-16&255)>>>0<249|(y[a+6|0]-16&255)>>>0<249))){b=(y[a+7|0]-9&255)>>>0<7}return b}function Yf(a,b,c,d,e){var f=0;f=fb-256|0;fb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Tb(f,b&255,c?d:256);if(!c){while(1){Lf(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}Lf(a,f,d)}fb=f+256|0}function V3(a){a=a|0;var b=0;a:{b:{if(!a){break b}b=ql(a);if(uI(b,-1)|y[b+13|0]){break b}b=x[b+8>>2];if(b){x[31725]=0;R(b|0,a|0)|0;b=x[31725];x[31725]=0;if((b|0)==1){break a}}jc(a)}return}T(0)|0;Sb();p()}function Cw(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],32)){a=0;while(1){if((a|0)!=32){fh(a+b|0);a=a+1|0;continue}break}break a}PE(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function yoa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if((b|0)>=0){d=2147483647;a=fv(a);if(a>>>0<=1073741822){x[c+12>>2]=a<<1;x[c+8>>2]=b+31&-32;d=x[ad(c+12|0,c+8|0)>>2]}fb=c+16|0;return d|0}dd();p()}function xo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(ep(a)>>>0<b>>>0){if(Lh(-1)>>>0<b>>>0){break a}d=zb(a);e=a;a=wn(c+12|0,b,Sc(x[a>>2],x[a+4>>2]),d);ir(e,a);un(a)}fb=c+32|0;return}dd();p()}function te(a,b){var c=0,d=0,e=0;b=b+7&-8;x[a+8>>2]=b+x[a+8>>2];d=x[a+80>>2];a:{if(d){c=b;b=x[a+88>>2];e=c+b|0;c=0;if((e|0)>x[a+92>>2]){break a}x[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Fd(b)}return c}function ai(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;fl(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function _Y(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;TD(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function Z9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=x[b+52>>2];if(c&16){d=x[b+48>>2];c=x[b+28>>2];if(d>>>0<c>>>0){x[b+48>>2]=c;d=c}ti(a,x[b+24>>2],d);break a}if(c&8){ti(a,x[b+12>>2],x[b+20>>2]);break a}Fb(a)}}function VN(a,b){a=a|0;b=b|0;var c=0;a=Nj(a);x[a+4>>2]=0;x[a>>2]=47632;if(ib[x[x[b>>2]+8>>2]](b)|0){b=ib[x[x[b>>2]+8>>2]](b)|0}else{b=22255}c=Fd(Cf(b)+1|0);x[a+4>>2]=c;if(c){yc(c,b,Cf(b)+1|0)}return a|0}function Qja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;c=Hf(a,c);$d(d,x[a+36>>2]);a:{if(!c){Pc(d,a+32|0,5);e=0;if(Hb(x[x[d>>2]>>2],x[d+4>>2])){break a}}RZ(x[a+36>>2],b,a);e=c}gf(a,e);fb=d+16|0}function Hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=x[a+4>>2];b=lg(d+4|0,b);x[31725]=0;V(1018,a|0,b|0,c|0,1);a=x[31725];x[31725]=0;if((a|0)!=1){tb(b);fb=d+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function u0(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],8)){a=0;while(1){if((a|0)!=8){fh(a+b|0);a=a+1|0;continue}break}break a}fl(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function ri(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;c=2;if(a>>>0>=2){x[b+12>>2]=a>>>1;x[b+8>>2]=a^-1;d=b,e=x[Gb(b+12|0,b+8|0)>>2]+a|0,x[d+12>>2]=e;x[b+8>>2]=-1;c=x[Gb(b+12|0,b+8|0)>>2]}fb=b+16|0;return c}function dK(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;v[g+15|0]=0;v[g+14|0]=f;v[g+13|0]=e;v[g+12|0]=37;if(f){tg(g+13|0,g+14|0)}h=c,i=(fa(b|0,Sc(b,x[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,x[h>>2]=i;fb=g+16|0}function xia(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{if(Ug(a)>>>0<=12){if(Lh(1073741823)>>>0<=12){break a}c=zb(a);d=a;a=$f(b+12|0,13,oc(x[a>>2],x[a+4>>2]),c);_m(d,a);_f(a)}fb=b+32|0;return}dd();p()}function e3(a,b){a=a|0;b=b|0;var c=0;a=Kt(a);x[a>>2]=93640;c=Fb(a+32|0);x[a+44>>2]=0;x[a+48>>2]=8;x[31725]=0;O(114,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;tb(c);mo(a);Q(b|0);p()}function Hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;b=x[b+4>>2];c=lg(d+4|0,c);x[31725]=0;S(1004,a|0,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){tb(c);fb=d+16|0;return}a=N()|0;tb(c);Q(a|0);p()}function XX(a,b){a=a|0;b=b|0;var c=0,d=0;d=x[a>>2];c=65535;a:{if(!He(d,x[a+4>>2],b)){break a}d=eE(a,x[hj(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=x[a>>2];a=hj(c,b);AR(hj(c,d),a);c=d}return c|0}function T9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;f=x[x[b>>2]+20>>2];e=x[c+12>>2];x[d+8>>2]=x[c+8>>2];x[d+12>>2]=e;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;ib[f|0](a,b,d,8);fb=d+16|0}function HS(a,b,c){var d=0,e=0;d=Mc(a);e=Cb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Kb(a);Xg(d+e|0,b,c);b=c+e|0;ng(a,b);fd(b+d|0,0);return a}Zq(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a}function Dl(a){a=a|0;var b=0;x[a>>2]=94836;x[31725]=0;O(115,a|0,0);b=x[31725];x[31725]=0;if((b|0)!=1){Zb(a+28|0);Db(x[a+32>>2]);Db(x[a+36>>2]);Db(x[a+48>>2]);Db(x[a+60>>2]);return a|0}T(0)|0;Sb();p()}function AJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Lh(1073741823)>>>0<b>>>0){dd();p()}iJ(c+8|0,jq(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function tx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;d=Cb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){ln();p()}b=Kb(b);x[e+8>>2]=d-c;Hu(a,b+c|0,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function q$(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=443372356|y[a+4|0]!=32|(!y[a+46|0]|(y[a+45|0]-17&255)>>>0<240)){break a}if(!y[a+47|0]){break a}b=y[a+49|0]<101}return b}function k3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;d=Cb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){ln();p()}b=Kb(b);x[e+8>>2]=d-c;fG(a,b+c|0,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function C0(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],512)){a=0;while(1){if((a|0)!=128){In((a<<2)+b|0);a=a+1|0;continue}break}break a}xE(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Dw(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],256)){a=0;while(1){if((a|0)!=256){fh(a+b|0);a=a+1|0;continue}break}break a}bc(c+8|0,b,256);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function yU(a,b,c,d,e,f){x[a+40>>2]=0;x[a+44>>2]=0;C[a+32>>3]=f;C[a+24>>3]=e;C[a+16>>3]=d;C[a+8>>3]=c;C[a>>3]=b;x[a+48>>2]=0;x[a+52>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;a=a- -64|0;x[a>>2]=0;x[a+4>>2]=0}function l_(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Tg(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{ip(b,z[c>>1]|z[c+2>>1]<<16);b=b+4|0;x[a+4>>2]=b;continue}break}}function be(a,b){var c=0,d=0,e=0;d=z[a+24>>1];if((d|0)!=(b&65535)){c=z[a+22>>1]-1&127;w[a+22>>1]=c;e=z[a+20>>1];if(e>>>0<=127){w[a+20>>1]=e+1}c=(c<<2)+a|0;w[c+26>>1]=b-d;w[c+28>>1]=0;w[a+24>>1]=b}}function N_(a){var b=0,c=0,d=0;a:{if(kd(a,22244,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|y[a+16|0]>3|y[a+17|0]>3){break a}d=a;a=a+19|0;if(y[d+18|0]<16){continue}break}}return b}function Cj(a){var b=0;b=32767;a:{if(a>=E(32766.5)){break a}b=32768;if(a<=E(-32767.5)){break a}a=E(a+E(.5));b:{if(E(F(a))<E(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Bs(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(b){d=Mc(a);e=Cb(x[a+4>>2],y[a+11|0]);if(d-e>>>0<b>>>0){Xm(a,d,(b-d|0)+e|0,e,e,0,0)}d=Kb(a);im(d+e|0,b,c);b=b+e|0;ng(a,b);fd(b+d|0,0)}return a|0}function $da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=x[a+4>>2];a=x[b+4>>2];b=x[b>>2];x[d+8>>2]=b;x[d+12>>2]=a;f=x[c>>2];c=x[c+4>>2];x[d>>2]=b;x[d+4>>2]=a;Mz(e,d,f,c,1);fb=d+16|0}function zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Lh(357913941)>>>0<b>>>0){dd();p()}$G(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+D(x[c+12>>2],12)|0,x[d>>2]=e;fb=c+16|0}function rk(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;fl(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){gl(b)}return a}function r$(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;hw(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){aw(b)}return a}function pY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(!Un(b,a)|!c){break a}ph(d+8|0,a);a=0;while(1){if(a>>>0>=4){break a}b=x[d+8>>2];tg(xb(b,a),xb(b,a|1));a=a+2|0;continue}}fb=d+16|0}function nP(a,b){var c=E(0),d=E(0);if(!((b|0)<0|z[a+480188>>1]<=b>>>0)){a=D(b,872)+a|0;c=E(E(y[a+1075834|0])*E(.0078125));d=E(c*c);c=E(E(y[a+1075835|0])*E(.0078125));c=E(M(E(d+E(c*c))))}return c}function lka(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;a:{if(!rk(a,b+8|0)){break a}c=0;if(!JR(x[b+8>>2],x[b+12>>2])){break a}c=-1;if(!eF(a,b+4|0)){break a}c=IR(x[b+4>>2])}fb=b+16|0;return c|0}function jS(a){var b=0,c=0;a=a+906300|0;c=Ij(a);while(1){if((a|0)!=(c|0)){b=x[a>>2];a:{if(!b){break a}if(!(ib[x[x[b>>2]+120>>2]](b)|0)){break a}ib[x[x[b>>2]+100>>2]](b)}a=a+160|0;continue}break}}function gX(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;ex(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){fx(b)}return a}function bX(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;O_(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){P_(b)}return a}function W$(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;gw(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){jE(b)}return a}function Qqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Lh(1073741823)>>>0<b>>>0){dd();p()}KF(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function PG(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;NG(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){qx(b)}return a}function Lr(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function LX(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;HX(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){IX(b)}return a}function $F(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;fs(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){gs(b)}return a}function $D(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Hr(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){v$(b)}return a}function sm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Lh(1073741823)>>>0<b>>>0){dd();p()}Wj(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function m1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Lh(214748364)>>>0<b>>>0){dd();p()}RE(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+D(x[c+12>>2],20)|0,x[d>>2]=e;fb=c+16|0}function eja(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);d=fb-16|0;fb=d;e=d,f=E(E(ib[x[x[a>>2]+48>>2]](a,b))+c),B[e+12>>2]=f;QT(d+12|0,E(0),E(1));ib[x[x[a>>2]+44>>2]](a,b,B[d+12>>2]);fb=d+16|0}function cE(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=1;x[c+8>>2]=a>>>4;b=Yb(128/(D(x[Ze(c+12|0,c+8|0)>>2],b)|0)|0,1,15);v[c+7|0]=1;v[c+6|0]=a&15;a=y[ef(c+7|0,c+6|0)|0];fb=c+16|0;return a|b<<4&240}function GC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Lh(2147483647)>>>0<b>>>0){dd();p()}Uw(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<1)|0,x[d>>2]=e;fb=c+16|0}function Fla(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if(Lh(2147483647)>>>0<=2303){dd();p()}Uw(b+8|0,2304);c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=zb(a),e=(x[b+12>>2]<<1)+c|0,x[d>>2]=e;fb=b+16|0}function AE(a,b,c){var d=0;a=(a&65535)>>>D(c,3)|0;d=a>>>2&1|y[b+12|0]&-8;v[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=y[b+13|0]|y[b+14|0]<<8;v[b+15|0]=a;v[b+16|0]=a>>>8;v[b+12|0]=d|4}}function xU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Lh(536870911)>>>0<b>>>0){dd();p()}tG(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<3)|0,x[d>>2]=e;fb=c+16|0}function uU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Lh(268435455)>>>0<b>>>0){dd();p()}_V(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<4)|0,x[d>>2]=e;fb=c+16|0}function gq(a,b,c){var d=0;d=fb-16|0;fb=d;if(y[b|0]){x[d+8>>2]=0;x[d+12>>2]=0;b=ey(d+4|0,b,Cf(b),d+8|0,c);if(b>>>0<=4294967293){x[a>>2]=x[d+4>>2]}a=b>>>0<4294967294}else{a=0}fb=d+16|0;return a}function gM(a,b){var c=0,d=0,e=0,f=E(0),g=E(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=B[e>>2];c=c+h|0;g=B[c>>2];B[e>>2]=f+g;B[c>>2]=f-g;d=d+1|0;continue}break}}function _S(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=ks(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{ZS(b,x[c>>2],x[c+4>>2]);b=b+8|0;x[a+4>>2]=b;continue}break}}function RZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;pg(a,d+14|0);e=z[d+14>>1];pS(b,e);c=0;while(1){if((c|0)==(e|0)){QA(b);fb=d+16|0}else{Ok(a,yb(x[b>>2],c));c=c+1|0;continue}break}}function OZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Lh(715827882)>>>0<b>>>0){dd();p()}xZ(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+D(x[c+12>>2],6)|0,x[d>>2]=e;fb=c+16|0}function EL(a){var b=0,c=0,d=0;d=x[a>>2];while(1){c=v[d|0];if(Oh(c)){d=d+1|0;x[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=D(b,10);b=(c|0)>(b^2147483647)?-1:c+b|0}else{b=-1}continue}break}return b}function kN(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=Ec(1298480);x[31725]=0;c=R(1133,b|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){b=x[yf(a+12|0,c)>>2];fb=a+16|0;return b|0}a=N()|0;Db(b);Q(a|0);p()}function YI(a){a=a|0;var b=0,c=0,d=0;x[a>>2]=111976;d=a+8|0;while(1){b=x[a+8>>2];if(oc(b,x[a+12>>2])>>>0>c>>>0){b=x[yb(b,c)>>2];if(b){Bm(b)}c=c+1|0;continue}break}tb(a+152|0);dy(d);return a|0}function NA(a,b){var c=0;a=DW(a,b);v[a+12|0]=y[b+12|0];c=y[b+13|0]|y[b+14|0]<<8|(y[b+15|0]<<16|y[b+16|0]<<24);v[a+13|0]=c;v[a+14|0]=c>>>8;v[a+15|0]=c>>>16;v[a+16|0]=c>>>24;v[a+17|0]=y[b+17|0]}function Fka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=z[a+28>>1];w[d+12>>1]=e;f=d,g=(oc(x[a+4>>2],x[a+8>>2])+e|0)-1|0,w[f+14>>1]=g;a=kR(a,b,c,d+12|0);fb=d+16|0;return a|0}function pk(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Lh(2147483647);if(d>>>0<=b>>>0){a=Pn(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function kc(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;mf(f+16|0,d,e);d=x[x[b>>2]+28>>2];e=x[f+20>>2];x[f+8>>2]=x[f+16>>2];x[f+12>>2]=e;ib[d|0](f+24|0,b,c,f+8|0);mf(a,x[f+24>>2],x[f+28>>2]);fb=f+32|0}function Oj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Yl(a,b);if((d|0)==255){break a}Gk(a,b);Vq(a,b,0,0);if(!c){break a}e=_b(a+26|0,d),f=65535,w[e>>1]=f;a=xb(a+62|0,b);v[a|0]=y[a|0]|128}}function Mf(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Lh(1073741823);if(d>>>0<=b>>>0){a=Ug(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function rG(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Lh(119304647);if(d>>>0<=b>>>0){a=cx(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function oD(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Lh(715827882);if(d>>>0<=b>>>0){a=cw(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function ns(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Lh(536870911);if(d>>>0<=b>>>0){a=Zn(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function ar(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Lh(134217727);if(d>>>0<=b>>>0){a=cp(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function aW(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Lh(268435455);if(d>>>0<=b>>>0){a=iv(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function Yp(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Lh(357913941);if(d>>>0<=b>>>0){a=ll(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function RD(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Lh(214748364);if(d>>>0<=b>>>0){a=TE(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function OJ(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Lh(178956970);if(d>>>0<=b>>>0){a=at(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function GD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=(sq(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),C[d+8>>3]=e;RT(c+8|0,127);a=gm(C[c+8>>3]);fb=c+16|0;return a}function zu(a){var b=0;x[31725]=0;a=R(856,a|0)|0;b=x[31725];x[31725]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[31725]=0;X(26);b=x[31725];x[31725]=0;a=0;if((b|0)==1){break a}}return a}T(0)|0;Sb();p()}function zE(a,b){var c=0,d=0;c=fb-16|0;fb=c;ik(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function yE(a,b){var c=0,d=0;c=fb-16|0;fb=c;Rr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function y$(a,b){var c=0,d=0;c=fb-16|0;fb=c;gw(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function uR(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Lh(82595524);if(d>>>0<=b>>>0){a=Cu(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function t$(a,b){var c=0,d=0;c=fb-16|0;fb=c;hw(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function sZ(a,b){var c=0,d=0;c=fb-16|0;fb=c;rZ(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function s$(a,b){var c=0,d=0;c=fb-16|0;fb=c;Hr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function oA(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Eo(x[c+8>>2],x[b>>2]);x[c+8>>2]=x[c+8>>2]+4;_m(a,c);_f(c);fb=d+32|0}function lX(a){var b=0,c=0,d=0;c=y[a+32|0]|y[a+33|0]<<8;b=y[a+36|0]|y[a+37|0]<<8;a=y[a+34|0]|y[a+35|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<1|b>>>31;b=b<<1;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function jG(a,b){var c=0,d=0;c=fb-16|0;fb=c;NG(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function iY(a,b){var c=0,d=0;c=fb-16|0;fb=c;Ev(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function gx(a,b){var c=0,d=0;c=fb-16|0;fb=c;ex(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function gh(a,b){var c=0,d=0;c=fb-16|0;fb=c;Zr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function aG(a,b){var c=0,d=0;c=fb-16|0;fb=c;fs(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function Y0(a){var b=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;b=x[a>>2];if(b&8){x[a>>2]=b|32;return-1}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];return 0}function Un(a,b){var c=0,d=0;c=fb-16|0;fb=c;ph(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function S0(a,b){var c=0,d=0;c=fb-16|0;fb=c;R0(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function PX(a,b){var c=0,d=0;c=fb-16|0;fb=c;aD(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function OC(a,b){var c=0,d=0;c=fb-16|0;fb=c;TC(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function NK(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:v[a|0]=c;return;case 1:w[a>>1]=c;return;case 2:case 3:x[a>>2]=c;return;case 5:break b;default:break a}}x[a>>2]=c;x[a+4>>2]=d}}function N$(a,b){var c=0,d=0;c=fb-16|0;fb=c;bE(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function MV(a){var b=0,c=0,d=0;c=y[a+64|0]|y[a+65|0]<<8;b=y[a+72|0]|y[a+73|0]<<8;a=y[a+70|0]|y[a+71|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<2|b>>>30;b=b<<2;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function Kp(a,b){var c=0,d=0;c=fb-16|0;fb=c;Jp(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function HB(a,b,c,d){var e=0,f=0,g=0;e=c-b|0;a:{if((e|0)<=9){g=e;e=D(32-G(d|1)|0,1233)>>>12|0;f=61;if((g|0)<(e+(A[(e<<2)+123776>>2]<=d>>>0)|0)){break a}}c=EB(b,d);f=0}x[a+4>>2]=f;x[a>>2]=c}function Dx(a,b,c){var d=0;d=fb-16|0;fb=d;bc(d+8|0,b,c);b=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);c=x[d+4>>2];if((b|0)==(c|0)){Vb(a,x[d+12>>2])}fb=d+16|0;return(b|0)==(c|0)}function qz(a,b,c,d,e,f,g,h,i){var j=0;j=fb-16|0;fb=j;Sg(j,b,c,d,e,f,g,h,i^-2147483648);d=x[j>>2];c=x[j+4>>2];b=x[j+12>>2];x[a+8>>2]=x[j+8>>2];x[a+12>>2]=b;x[a>>2]=d;x[a+4>>2]=c;fb=j+16|0}function fV(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;v[a+16|0]=0;c=$B(b,x[a+12>>2]);x[31725]=0;O(785,a|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){Ik(c);fb=b+32|0;return}a=N()|0;Ik(c);Q(a|0);p()}function fM(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=zb(a);c=wn(d+12|0,cm(a,Sc(x[a>>2],x[a+4>>2])+1|0),Sc(x[a>>2],x[a+4>>2]),c);Fl(x[c+8>>2],y[b|0]);x[c+8>>2]=x[c+8>>2]+1;ir(a,c);un(c);fb=d+32|0}function Vf(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb+-64|0;fb=c;d=qA(c+12|0,a);x[31725]=0;S(201,a|0,b|0,d|0);a=x[31725];x[31725]=0;if((a|0)!=1){Ek(d);fb=c- -64|0;return}a=N()|0;Ek(d);Q(a|0);p()}function FV(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function oi(a,b){var c=0,d=0;c=y[a|0];d=y[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=y[b+1|0];c=y[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function f9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a+84>>2];d=c+256|0;f=Kz(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;yc(b,e,c);b=e+d|0;x[a+84>>2]=b;x[a+8>>2]=b;x[a+4>>2]=c+e;return c|0}function Re(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;x[a+8>>2]=x[c+8>>2];v[a+12|0]=0;fb=c+16|0}function GZ(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+8>>2]=d;c=ZG(a,c,x[Gb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}fb=e+16|0;return c}function F_(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+8>>2]=d;c=py(a,c,x[Gb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}fb=e+16|0;return c}function Cga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;a=EP(f,b,c,d,0,0,0,0,e);fb=f+16|0;return a|0}function zo(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(!bN(y[a+20|0])){x[31725]=0;O(1140,b+15|0,a|0);c=x[31725];x[31725]=0;if((c|0)==1){break a}}v[a+20|0]=255;fb=b+16|0;return}T(0)|0;Sb();p()}function l8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+8>>2]=624576549;x[g+12>>2]=1394948685;h=a;a=g+16|0;b=Ak(h,b,c,d,e,f,g+8|0,a);fb=a;return b|0}function Gk(a,b){var c=0,d=0,e=0;a:{c=Yl(a,b);if((c|0)==255){break a}if(Pj(x[a>>2])){break a}e=a+8|0;d=xb(e,c);v[d|0]=y[d|0]&223;d=cv(c);c=xb(e,c);Ah(x[a>>2],x[a+4>>2],b,d|176,y[c|0])}}function Eba(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=x[18387];x[c+8>>2]=x[18386];x[c+12>>2]=d;d=x[18385];x[c>>2]=x[18384];x[c+4>>2]=d;ib[x[vq(c,Ck(y[b+20|0]))>>2]](a,b);fb=c+16|0}function aH(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=zb(a);c=Em(d+12|0,Yp(a,Ud(x[a>>2],x[a+4>>2])+1|0),Ud(x[a>>2],x[a+4>>2]),c);As(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;vx(a,c);zs(c);fb=d+32|0}function Xt(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=x[a+4>>2];d=((b<<2)+(Ow(x[a>>2],1)^270549120)|0)+2019860093|0;x[a>>2]=d;b=b+D(Ow(d,16),5)|0;x[a+4>>2]=b;continue}break}return b}function Esa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],12);a:{if(!d){v[c|0]=0;Vh(b,12,c);break a}Hr(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function nA(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Tg(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{Dk(b,B[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function e8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Kb(a);return zk(g,h,c,d,e,f,b,b+(Cb(x[a+4>>2],y[a+11|0])<<2)|0)|0}function cm(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Lh(-1);if(d>>>0<=b>>>0){a=ep(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function Xh(a,b){var c=0;b=Uc(b);c=x[a+8>>2];if(oc(c,x[a+12>>2])>>>0>b>>>0){a=x[yb(c,b)>>2]!=0}else{a=0}if(!a){a=Nj(ac(4));x[a>>2]=125456;da(a|0,125592,1190);p()}return x[yb(c,b)>>2]}function XE(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Tg(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{Eo(b,x[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function UP(a){var b=0,c=0;if(!a){return 1}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(F(c)<2147483648){a=~~c;break a}a=-2147483648}b=Di(b-+(a|0))}else{b=0}return b}function Sl(a){var b=0;a=si(a);b=2147483647;a:{if(a>=E(2147483648)){break a}b=-2147483648;if(a<=E(-2147483648)){break a}b=~~a;if(E(F(a))<E(2147483648)){break a}b=-2147483648}return b}function Ap(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=$h(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{gj(b,z[c>>1]);b=b+2|0;x[a+4>>2]=b;continue}break}}function RP(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;c=QP(f,b,c,d,e,0,0,0,0);fb=f+16|0;return+c}function Qm(a,b){x[a+28>>2]=0;w[a+24>>1]=65535;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;v[a|0]=0;x[a+32>>2]=11;x[a+36>>2]=b;Nb(a+40|0);Nb(a+52|0);Tb(a- -64|0,0,48);return a}function Jsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;nZ(b,c);c=Mb(x[a>>2],x[a+8>>2],c<<2);if(c){mZ(d+8|0,x[b>>2],x[b+4>>2]);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0;return c|0}function Joa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],4);a:{if(!d){v[c|0]=0;l$(b,4,c);break a}ph(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Hp(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=am(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{Fl(b,y[c|0]);b=b+1|0;x[a+4>>2]=b;continue}break}}function $r(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if((b|0)<0){dd();p()}KF(c+8|0,(b-1>>>5|0)+1|0);b=x[c+8>>2];x[a+4>>2]=0;x[a>>2]=b;d=zb(a),e=x[c+12>>2],x[d>>2]=e;fb=c+16|0}function t2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=ib[x[x[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function bl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Lh(-1)>>>0<b>>>0){dd();p()}sg(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+x[c+12>>2]|0,x[d>>2]=e;fb=c+16|0}function Yt(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+12>>2]=12;while(1){x[b+8>>2]=32;if(A[Gb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0;a=d&4095}else{c=c+15|0;d=Jo(a);continue}break}return a}function MB(a){var b=0,c=0;b=x[a>>2];c=x[b>>2];a:{if(!c){while(1){c=Uh(b);b=x[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=x[b+4>>2];if(c){continue}break}}x[a>>2]=b;return a}function Gu(a,b){var c=0;a=MS(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c}function E2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;wG(b,c);c=Mb(x[a>>2],x[a+8>>2],c<<3);if(c){vG(d+8|0,x[b>>2],x[b+4>>2]);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0;return c|0}function Moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;CW(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<8)){c=x[b>>2];bc(d+8|0,c,Th(c,x[b+4>>2])<<8);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function HT(a,b,c,d){a:{if((a|0)!=67108864){break a}a=D(d,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=D(a,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129}}function D2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(Sc(x[c>>2],x[c+4>>2])>>>0>=a>>>0){break a}_j(c,a)}return!d|0}function h6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[(a<<2)+112112>>2]}else{a=0}x[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function YR(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;while(1){x[b+12>>2]=7;x[b+8>>2]=32;if(A[Gb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0;a=d&127}else{c=c+15|0;d=Jo(a);continue}break}return a}function Xz(a){var b=0,c=0,d=0;C[a+4272>>3]=C[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=Jo(d)|b<<15;continue}break}C[c+4280>>3]=+(b|0)*-4.656612873077393e-10}function Pv(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+4|0]|y[b+5|0]<<8;v[a+4|0]=b;v[a+5|0]=b>>>8}function Jh(a,b,c){a:{if(b>>>0<=c>>>0){a=ac(8);x[31725]=0;b=R(190,a|0)|0;c=x[31725];x[31725]=0;if((c|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}return y[a+c|0]}da(b|0,24440,164);p()}function vsa(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;x[c>>2]=0;x[c+4>>2]=0;QZ(b,c);PZ(a,c);fb=c+32|0}function k8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Kb(a);return Ak(g,h,c,d,e,f,b,Cb(x[a+4>>2],y[a+11|0])+b|0)|0}function gU(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;while(1){if(c){f=Wl(z[c+16>>1],x[c+20>>2],a,b);d=f?d:c;c=x[(f?c+4|0:c)>>2];continue}break}a=x[vb(e+12|0,d)>>2];fb=e+16|0;return a}function fha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=12){c=Pd(c,E(0));d=a+4208|0;if((b|0)==12){c=E(si(E(c*E(3)))/E(3));b=12}e=yb(d,b),f=c,B[e>>2]=f;v[a+5046|0]=1}}function $l(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=zb(b);d=zb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function uja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;f=x[c>>2];if(f>>>0<Sc(a,b)>>>0){a=yl(e+4|0,xb(a,f),z[c+20>>1]);g=Fy(d,a);Eb(a)}fb=e+16|0;return g|0}function u3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;a=x[a+4>>2];f=x[b+4>>2];b=x[b>>2];x[e>>2]=b;x[e+4>>2]=f;x[e+8>>2]=b;x[e+12>>2]=f;Nz(a,e,c,d,1);fb=e+16|0}function tD(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Kr(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{Pv(b,c);b=b+6|0;x[a+4>>2]=b;continue}break}}function kp(a){var b=0,c=0;b=x[31480];c=a+7&-8;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>jb()<<16>>>0){if(!(eb(a|0)|0)){break a}}x[31480]=a;return b}x[31600]=48;return-1}function Waa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;oz(a,b,c);c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+8|0,d+12|0)>>2]}fb=d+16|0;return c|0}function vY(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-24|0;ub(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];at(a);Db(b)}}function v3(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b>>2];b=x[b+4>>2];x[c>>2]=d;x[c+4>>2]=b;x[c+8>>2]=d;x[c+12>>2]=b;a=xP(a,c,1);fb=c+16|0;gb=hb;return a|0}function oN(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-16|0;Zj(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];iv(a);Db(b)}}function Sta(a,b){a=a|0;b=b|0;if(!s$(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0}}function QH(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-12|0;Eb(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];ll(a);Db(b)}}function Bq(a){var b=0;b=x[a+24>>2];x[31725]=0;W(857,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){Td(a+68|0);of(a+36|0);Jl(a+32|0);xh(a+24|0);wh(a+4|0);return Vc(a)}T(0)|0;Sb();p()}function fpa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;b=-1;a:{if(!rk(a,c+8|0)){break a}b=0;if(!EW(c+8|0)){break a}b=-1;if(!mh(a,4)){break a}b=eX(a)>>>31|0}fb=c+16|0;return b|0}function c4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;ib[x[x[a>>2]+12>>2]](d+8|0,a,b);a=x[d+8>>2];b=x[c>>2];a=lc(x[d+12>>2],x[c+4>>2])&(a|0)==(b|0);fb=d+16|0;return a|0}function JX(a){var b=0,c=0,d=0,e=0;d=y[a+4|0];e=y[a+92|0];c=y[a+94|0]|y[a+95|0]<<8;b=c+y[a+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=d;d=b<<2;b=a+d|0;b=b-96|0;hb=0;return b}function Gja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if(Ib(b,c)){x[d+8>>2]=x[b>>2];BA(a,d+8|0);b=x[Je(d+12|0)>>2];continue}else{fb=d+16|0}break}}function pc(a,b){a=a|0;b=b|0;var c=0;a=Nj(a);x[a+4>>2]=0;x[a>>2]=47632;c=Fd(Yc(x[b+4>>2],y[b+11|0])+1|0);x[a+4>>2]=c;if(c){yc(c,Kb(b),Yc(x[b+4>>2],y[b+11|0])+1|0)}return a|0}function H4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;while(1){if((b|0)!=(c|0)){f=Tx(x[b>>2],x[a+8>>2]);v[e|0]=(f|0)==-1?d:f;e=e+1|0;b=b+4|0;continue}break}return c|0}function uw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;_j(b,c);if(Mb(x[a>>2],x[a+8>>2],c)){c=x[b>>2];bc(d+8|0,c,Sc(c,x[b+4>>2]));rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function rY(a,b){var c=0,d=0;c=fb-16|0;fb=c;Ev(c+8|0,b);b=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function jD(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=Tg(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{In(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function YX(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=am(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{FX(b);b=b+1|0;x[a+4>>2]=b;continue}break}}function Uka(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Ec(1);x[31725]=0;X(59);c=x[31725];x[31725]=0;if((c|0)!=1){b=x[yf(a+12|0,b)>>2];fb=a+16|0;return b|0}a=N()|0;Db(b);Q(a|0);p()}function Uca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=d;x[c+8>>2]=b;x[c+12>>2]=d;e=yP(a,c,1);fb=c+16|0;return+e}function QE(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=$h(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{Vw(b);b=b+2|0;x[a+4>>2]=b;continue}break}}function Og(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Jh(x[d>>2],x[d+4>>2],a);return((Jh(x[d>>2],x[d+4>>2],a+1|0)<<8|e<<16|Jh(x[d>>2],x[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function Fz(a,b){var c=0,d=0;if(b>>>0<2147483632){if(Uk(b)){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;Me(a,b);return a}c=Eh(b)+1|0;d=Ec(c);pf(a,c);yd(a,d);Yd(a,b);return a}qf();p()}function $q(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=Tg(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{KV(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function $E(a,b){var c=0,d=0;c=fb-16|0;fb=c;ph(c+8|0,b);b=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function ni(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;v[c+31|0]=0;Dj(c+8|0,c+31|0);Sm(c+20|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];v[b|0]=y[c+31|0];fb=c+32|0;return(a|0)==1|0}function f6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];if(!(a>>>0>127|!(x[(a<<2)+112112>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function YG(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&255)!=0}return b}function W_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28163770){break a}if(kd(a+44|0,18439,3)){break a}b=(y[a+47|0]|y[a+48|0]<<8)>>>0>97}return b}function uda(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=d;x[c+8>>2]=b;x[c+12>>2]=d;a=zP(a,c,1);fb=c+16|0;return a|0}function sua(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;fl(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);if((b|0)==x[c+4>>2]){Vb(a,x[c+12>>2])}fb=c+16|0}function sf(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+8>>2]=c;x[d+4>>2]=31;e=d,f=m0(b,c),x[e+12>>2]=f;c=b;b=sE(d+4|0);Wg(c,c+b|0,a);e=xb(a,b),f=0,v[e|0]=f;o0(a);fb=d+16|0}function rF(a,b,c){var d=0;d=fb-16|0;fb=d;a=Ip(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){gj(b,z[c>>1]);b=x[a>>2]+2|0;x[a>>2]=b;continue}break}he(a);fb=d+16|0}function hH(a,b){var c=0,d=0,e=0;c=x[a>>2];if(x[c>>2]){e=x[c>>2];d=x[c+4>>2];while(1){if((d|0)!=(e|0)){d=d-b|0;continue}break}x[c+4>>2]=e;a=x[a>>2];b=x[a>>2];zb(a);Db(b)}}function uZ(a,b,c){var d=0;d=fb-16|0;fb=d;a=yC(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){Fl(b,y[c|0]);b=x[a>>2]+1|0;x[a>>2]=b;continue}break}he(a);fb=d+16|0}function u2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=ib[x[x[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function pW(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-36|0;continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];cx(a);Db(b)}}function kta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(a){ib[x[x[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}sS(d,9153,10891,171,42);MG(d,b,c)}fb=d+16|0}function g6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=x[c>>2];if(a>>>0>127|!(x[(a<<2)+112112>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function Ix(a,b,c,d,e){var f=0;a:{f=zu(4332);if(f){x[31725]=0;ha(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break a}}return f}a=N()|0;Db(f);Q(a|0);p()}function zT(a,b,c){var d=0;d=c&15;if(d){v[b+824|0]=d}c=c&240;if(c){v[b+823|0]=c>>>4}x[b+88>>2]=x[b+88>>2]|131072;if(!(!d|!Ob(a+1074312|0,80))){v[b+824|0]=y[b+824|0]<<2}}function lT(a,b){a=a|0;b=b|0;var c=0,d=0;c=Mc(a);d=Cb(x[a+4>>2],y[a+11|0]);if((c|0)==(d|0)){VB(a,c,1,c,c,0)}c=Kb(a);im(c+d|0,1,b);b=d+1|0;ng(a,b);fd(b+c|0,0);return a|0}function Nm(a){a=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function LV(a,b,c,d){a=gc(a,b,c);b=x[a+4>>2];a:{if((d|0)>=0){b=b+d|0;c=x[a>>2]+(b>>>3&536870908)|0;break a}b=b+d|0;c=x[a>>2]+((b-31|0)/32<<2)|0}x[a>>2]=c;x[a+4>>2]=b&31}function BA(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=Tg(c+4|0,a,1);Eo(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}oA(a,b)}function $ka(a,b){a=a|0;b=b|0;var c=0;a=qg(a);c=$i(x[b>>2]);b=Rf(b);x[31725]=0;S(851,a|0,c|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;jT(a);Q(b|0);p()}function y5(a,b,c){a=a|0;b=b|0;c=c|0;a=tJ(a,c);x[a>>2]=113476;b=Kb(b);x[31725]=0;O(1347,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;ay(a);Q(b|0);p()}function xda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;b=x[b+4>>2];e=x[c+4>>2];c=x[c>>2];x[d>>2]=c;x[d+4>>2]=e;x[d+8>>2]=c;x[d+12>>2]=e;vP(a,b,d,1);fb=d+16|0}function rr(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],4);a:{if(!d){lD(b);break a}ph(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function hM(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&240)!=240&(b&254)!=226){break a}a=y[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function Zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a=x[a+4>>2];e=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=e;x[d+8>>2]=b;x[d+12>>2]=e;Pz(a,d,c,1);fb=d+16|0}function Dka(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Dc(a+4|0,10265);x[31725]=0;W(63,b|0);c=x[31725];x[31725]=0;if((c|0)!=1){tb(b);fb=a+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function Bv(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=y[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function A5(a,b,c){a=a|0;b=b|0;c=c|0;a=uJ(a,c);x[a>>2]=113436;b=Kb(b);x[31725]=0;O(1346,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;$x(a);Q(b|0);p()}function spa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=-1;a:{if(!bX(a,c)){break a}d=0;if(!aX(c)){break a}d=ve(a,b,$W(y[c+31|0],y[c+33|0]),hb)}fb=c+48|0;return d|0}function pqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;wG(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<3)){vG(d+8|0,x[b>>2],x[b+4>>2]);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function kd(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=y[a|0];e=y[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function dI(a,b,c){var d=0;a:{if(!a){a=ac(8);x[31725]=0;c=R(c|0,a|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}return}da(c|0,b|0,1006);p()}function _M(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=am(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{b=b+1|0;x[a+4>>2]=b;continue}break}}function Vda(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=fb-16|0;fb=d;a=x[a+4>>2];e=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=e;x[d+8>>2]=b;x[d+12>>2]=e;Oz(a,d,c,1);fb=d+16|0}function haa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a=Zy(Pa(x[a+60>>2],b|0,c|0,d&255,e+8|0)|0);fb=e+16|0;hb=a?-1:x[e+12>>2];return(a?-1:x[e+8>>2])|0}function h2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function eD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;nZ(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<2)){mZ(d+8|0,x[b>>2],x[b+4>>2]);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Cb(x[b+4>>2],y[b+11|0]);e=a;a=Cb(x[c+4>>2],y[c+11|0]);b=Xg(Kb(Fz(e,d+a|0)),Kb(b),d)+d|0;im(Xg(b,Kb(c),a)+a|0,1,0)}function dX(a,b){var c=0;c=fb-32|0;fb=c;OX(c+24|0,a);ee(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=Ic(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;return a}function ci(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=is(b);d=Mc(a);if(c>>>0<=d>>>0){Yu(a,Vi(Kb(a),b,c),c);break a}e=a;a=Cb(x[a+4>>2],y[a+11|0]);Zq(e,d,c-d|0,a,0,a,c,b)}}function Xaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;oz(a,b,c);a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function v2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=x[a+8>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function pta(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],12)){w[c>>1]=0;d_(a,6,c);break a}Hr(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function kV(a,b,c,d){var e=0;e=fb-32|0;fb=e;Id(e+24|0,b,c);yn(e+16|0,x[e+24>>2],x[e+28>>2],d);b=jV(b,x[e+16>>2]-b>>1);x[e+12>>2]=x[e+20>>2];Ac(a,b,e+12|0);fb=e+32|0}function GX(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=541938512|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1162627398)){return 1}return 0}function FZ(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;b=ec(b);a=Dh(a,Ec(32),Mg(d+8|0,b));b=x[a>>2]+16|0;w[b>>1]=z[x[c>>2]>>1];Fb(b+4|0);e=ec(a),f=1,v[e+4|0]=f;fb=d+16|0}function BV(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&224)!=224|(b&24)==8){break a}a=y[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function rL(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>2];if((c|0)==x[a+28>>2]){return e=a,f=Pf(b),d=x[x[a>>2]+52>>2],ib[d](e|0,f|0)|0}x[a+24>>2]=c+1;v[c|0]=b;return Pf(b)}function kqa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-80|0;fb=d;c=-1;a:{if(!W$(a,d+14|0)){break a}c=0;if(!VX(d+14|0)){break a}c=ve(a,b,UX(d+14|0),hb)}fb=d+80|0;return c|0}function aqa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],8)){w[c>>1]=0;d_(a,4,c);break a}fl(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function ST(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=uv(c+4|0,a,1);As(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;return}aH(a,b)}function Ld(a,b){var c=0;c=fb-32|0;fb=c;ee(c+24|0,a);a=qc(c+16|0,b);b=x[a+4>>2];x[c+8>>2]=x[a>>2];x[c+12>>2]=b;a=Ic(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;return a}function HI(a,b,c){var d=0,e=0;d=An(a);if(d>>>0>=c>>>0){e=b;b=c<<2;d=nl(Kb(a),e,b);ng(a,c);yd(b+d|0,0);return}e=a;a=Cb(x[a+4>>2],y[a+11|0]);wI(e,d,c-d|0,a,0,a,c,b)}function hW(a){x[a>>2]=0;x[a+4>>2]=0;x[a+88>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;nC(a+112|0,48e3);x[a+668>>2]=0;mC(a+724|0);mC(a+732|0);mC(a+740|0);ch(a+788|0);return a}function Upa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],5)){v[c|0]=0;Vh(a,5,c);break a}ik(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function zM(a,b){var c=0,d=0;c=Sc(x[a+4>>2],x[a+8>>2]);b=x[a+16>>2]+b|0;if(c>>>0<b>>>0){d=a+4|0;a:{if(c){a=ri(c);if(b>>>0<=a>>>0){break a}}a=AM(b,65536)}_j(d,a)}}function y9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e>>2]=c;x[e+4>>2]=d;x[e+8>>2]=c;x[e+12>>2]=d;a=bL(a,e,b);x[a>>2]=94516;fb=e+16|0;return a|0}function tm(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],4)){v[c|0]=0;Vh(a,4,c);break a}ph(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function sE(a){var b=0,c=0;a:{c=yb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=pE(x[b>>2],x[a>>2])?b:a;continue}}return x[a>>2]}function j3(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=xx(c+4|0,a);As(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;return}aH(a,b)}function fea(a,b){a=a|0;b=b|0;var c=0;a=ac(8);x[31725]=0;b=P(1057,a|0,12097)|0;c=x[31725];x[31725]=0;if((c|0)!=1){da(b|0,125360,164);p()}b=N()|0;jc(a);Q(b|0);p()}function _q(a){x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=128;x[a+4>>2]=256;x[a+32>>2]=363;x[a+36>>2]=952;x[a+16>>2]=48e3;x[a+20>>2]=2;x[a+24>>2]=128;x[a+28>>2]=0;return a}function __(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],6)){v[c|0]=0;Vh(a,6,c);break a}TD(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function J4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;while(1){if((b|0)!=(c|0)){e=d,f=II(v[b|0],x[a+8>>2]),x[e>>2]=f;d=d+4|0;b=b+1|0;continue}break}return c|0}function J3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=x[c>>2];a=ib[x[x[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){x[c>>2]=x[d+12>>2]}fb=d+16|0;return a|0}function Eka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=vh(b),x[d+12>>2]=e;x[c+8>>2]=0;d=a,e=x[hk(c+12|0,c+8|0,42288)>>2],x[d+36>>2]=e;Eq(a);fb=c+16|0}function vr(a){var b=0,c=0,d=0,e=0;b=x[a+4>>2];c=x[b>>2];x[a+4>>2]=c;if(c){Dn(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(Uh(a)?0:4)|0,e=b,x[d>>2]=e;x[b>>2]=a;Dn(a,b)}function ur(a){var b=0,c=0,d=0,e=0;b=x[a>>2];c=x[b+4>>2];x[a>>2]=c;if(c){Dn(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(Uh(a)?0:4)|0,e=b,x[d>>2]=e;x[b+4>>2]=a;Dn(a,b)}function uS(a){var b=0,c=0,d=0;b=x[a+112>>2];if((b|0)>=11){b=378;while(1){if(b|c){tS(a);d=b;b=b-1|0;c=c-!d|0;continue}break}b=0}x[a+112>>2]=b+1;a=tS(a);return a}function jA(a,b){var c=0;c=fb-16|0;fb=c;a=Nn(c+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){KV(b);b=x[a>>2]+4|0;x[a>>2]=b;continue}break}he(a);fb=c+16|0}function b1(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(gh(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=T0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function Tia(a){a=a|0;var b=0;b=fb-16|0;fb=b;KQ(b+8|0,a,0);if(x[b+12>>2]){a=x[a+20>>2];x[a+148>>2]=-1;JQ(a+4|0,wb(x[b+8>>2]),Yk(x[b+8>>2],x[b+12>>2]))}fb=b+16|0}function KE(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(gh(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=Q0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function ID(a){var b=0,c=0;b=fb-16|0;fb=b;w[b+14>>1]=a;Gf(b+14|0,4095);a=z[b+14>>1];c=HD(Di(+((a&255)>>>0)*.00390625)*32768);fb=b+16|0;return c>>>15-(a>>>8|0)|0}function Ec(a){a=a|0;var b=0;a=a>>>0<=1?1:a;a:{while(1){b=Fd(a);if(b){break a}b=x[125549];if(b){ib[b|0]();continue}break}da(Ym(ac(4))|0,125e3,34);p()}return b|0}function wja(a){a=a|0;var b=0;b=fb-16|0;fb=b;Pc(b+4|0,a+32|0,4);if(!Hb(x[x[b+4>>2]>>2],x[b+8>>2])){oy(a)}a=x[vb(b+12|0,wb(x[a+52>>2]))>>2];fb=b+16|0;return a|0}function vja(a){a=a|0;var b=0;b=fb-16|0;fb=b;Pc(b+4|0,a+32|0,4);if(!Hb(x[x[b+4>>2]>>2],x[b+8>>2])){oy(a)}a=x[vb(b+12|0,wb(x[a+56>>2]))>>2];fb=b+16|0;return a|0}function nl(a,b,c){var d=0;if(a>>>0<b>>>0){return yc(a,b,c)}if(c){d=a+c|0;b=b+c|0;while(1){d=d-1|0;b=b-1|0;v[d|0]=y[b|0];c=c-1|0;if(c){continue}break}}return a}function _H(a,b,c){var d=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=D(b,872)+a|0;if(!(v[a+1075081|0]&1)){break a}d=E(E(y[a+c|0])*E(.0078125))}return d}function Wla(a,b){a=a|0;b=b|0;a=sc(a);v[a+534|0]=0;x[a+4>>2]=0;x[31725]=0;O(791,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;Hj(a);Q(b|0);p()}function Pt(a){var b=0;a:{if((hf(a)|0)!=79){break a}if((hf(a)|0)!=103){break a}if((hf(a)|0)!=103){break a}b=(hf(a)|0)==83}if(!b){fc(a,30);return 0}return $L(a)}function OS(a,b){var c=0;c=fb-32|0;fb=c;a=we(c+8|0,a,b);a=Eu(c+16|0,x[a>>2],x[a+4>>2]);a=we(c+24|0,x[a>>2],x[a+4>>2]);b=x[a>>2];fb=c+32|0;hb=x[a+4>>2];return b}function Iw(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],2)){v[c|0]=0;sF(a,c);break a}Jp(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function EW(a){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1299020115){a=($b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))|0)==1}else{a=0}return a}function lN(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function hG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Nb(a+8|0);x[31725]=0;S(171,a|0,b|0,c|0);a=x[31725];x[31725]=0;if((a|0)!=1){break a}a=N()|0;dc(d);Q(a|0);p()}}function Pd(a,b){var c=0,d=0,e=E(0);c=fb-16|0;fb=c;x[c+8>>2]=1065353216;B[c+12>>2]=b;d=c,e=cg(a),B[d+4>>2]=e;a=B[Nv(c+4|0,c+12|0,c+8|0)>>2];fb=c+16|0;return a}function Ok(a,b){var c=0;c=fb-32|0;fb=c;x[c+28>>2]=0;Ux(c+8|0,c+28|0);Sm(c+20|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];Rm(b,x[c+28>>2]);fb=c+32|0;return(a|0)==4}function Cn(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(F(a)<2147483648){return~~a}b=-2147483648}return b}function qC(a){var b=0;a=Ee(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(F(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function q9(a,b){a=a|0;b=b|0;var c=0,d=0;b=FD(x[b>>2]);x[a+36>>2]=b;c=a,d=lh(b),x[c+44>>2]=d;c=a,d=lo(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){ko(5563);p()}}function j9(a,b){a=a|0;b=b|0;var c=0,d=0;b=Ly(x[b>>2]);x[a+36>>2]=b;c=a,d=lh(b),x[c+44>>2]=d;c=a,d=lo(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){ko(5563);p()}}function _8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=x[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function N6(a){a=a|0;if(y[500528]){return x[125131]}if(!y[501688]){v[501688]=1}wd(501664,121012);wd(501676,121024);v[500528]=1;x[125131]=501664;return 501664}function LC(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=a;c=c&65535;while(1){if(!(!Ib(a,b)|(c|0)==z[a>>1])){a=x[Md(d+12|0)>>2];continue}break}fb=d+16|0;return a}function AS(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=a+12|0;while(1){if(c>>>0<32){c=c+48|0;d=TA(126944);continue}break}x[b>>2]=d;Jo(b);fb=a+16|0;return x[b>>2]}function $P(a){a=a|0;var b=0;x[a+4240>>2]=0;x[a+4244>>2]=0;b=a+4264|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4256|0;x[b>>2]=0;x[b+4>>2]=0;a=a+4248|0;x[a>>2]=0;x[a+4>>2]=0}function dR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;while(1){if((b|0)==(c|0)){fb=d+16|0}else{x[d+12>>2]=x[b>>2];BA(a,d+12|0);b=b+4|0;continue}break}}function b9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function Vb(a,b){a=a|0;b=b|0;var c=0;c=Mb(x[a>>2],x[a+8>>2],b);a:{if(c){b=x[a+8>>2]+b|0;break a}b=x[a>>2];b=ib[x[x[b>>2]+24>>2]](b)|0}x[a+8>>2]=b;return c|0}function Te(a,b){var c=0;c=x[a>>2];x[a>>2]=b;a:{if(c){a=x[ec(a)>>2];x[31725]=0;W(a|0,c|0);a=x[31725];x[31725]=0;if((a|0)==1){break a}}return}T(0)|0;Sb();p()}function Doa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-48|0;fb=d;c=-1;a:{if(!bX(a,d)){break a}c=0;if(!UV(d)){break a}c=ve(a,b,TV(y[d+47|0]),hb)}fb=d+48|0;return c|0}function $H(a,b,c){var d=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=D(b,872)+a|0;if(v[a+1075081|0]&1){break a}d=E(E(y[a+c|0])*E(.0078125))}return d}function z6(a){a=a|0;if(y[500520]){return x[125129]}if(!y[501656]){v[501656]=1}id(501632,13897);id(501644,13876);v[500520]=1;x[125129]=501632;return 501632}function ima(a,b){a=a|0;b=b|0;a=Nb(a);v[a+16|0]=0;x[a+12>>2]=b;x[31725]=0;W(784,a|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a|0}b=N()|0;_B(a);Q(b|0);p()}function Iu(a,b){var c=0,d=0,e=E(0);c=fb-16|0;fb=c;B[c+12>>2]=b;x[c+8>>2]=0;x[c+4>>2]=1065353216;d=a,e=B[Nv(c+12|0,c+8|0,c+4|0)>>2],B[d+144>>2]=e;fb=c+16|0}function s0(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=x[c>>2];v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function oj(a,b,c,d,e){a:{e=zu(e);if(e){x[31725]=0;ba(d|0,e|0,a|0,b|0,c|0)|0;a=x[31725];x[31725]=0;if((a|0)==1){break a}}return e}a=N()|0;Db(e);Q(a|0);p()}function i2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function hz(a,b){var c=0;while(1){c=(b|0)>=120?120:b;a=E(a*E(B[((c&3)<<2)+82240>>2]*E(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function gr(a,b){var c=0,d=0;a:{if(!a){break a}c=ova(a,0,b,0);d=hb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Fd(c);if(!(!a|!(y[a-4|0]&3))){Tb(a,0,c)}return a}function b_(a,b){var c=0;c=ova(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;hb=b>>>0<256?a+1|0:a;return b}function Gj(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;C[a>>3]=C[a>>3]-c;C[a+8>>3]=C[a+8>>3]-d}function Gi(a){var b=0,c=0;b=a*a;c=b*a;return E(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function w2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function d3(a,b,c){a=a|0;b=b|0;c=c|0;a=Ds(a,x[b+28>>2]);bH(b+28|0,c);x[31725]=0;O(115,b|0,1);b=x[31725];x[31725]=0;if((b|0)==1){b=N()|0;Zb(a);Q(b|0);p()}}function Xga(a){a=a|0;var b=0,c=E(0);v[a+4202|0]=1;b=a,c=BB(E(E(E(E(A[x[a+16>>2]+24620>>2])/E(3))+E(-80))/E(15920)),E(0),E(1)),B[b+4272>>2]=c;aQ(a);$P(a)}function BY(a,b,c,d){var e=0;e=fb-32|0;fb=e;Id(e+24|0,b,c);yn(e+16|0,x[e+24>>2],x[e+28>>2],d);b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(a,b,e+12|0);fb=e+32|0}function uo(a,b){var c=0,d=0;b=b+7&-8;d=x[a+80>>2];a:{if(d){b=x[a+92>>2]-b|0;c=0;if((b|0)<x[a+88>>2]){break a}x[a+92>>2]=b;return b+d|0}c=Fd(b)}return c}function mX(a){var b=0;return(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1297236819|y[a+29|0]!=16?b:((y[a+42|0]|y[a+43|0]<<8)-1&65535)>>>0<2}function ah(a){var b=0,c=0;b=x[a>>2];c=x[b+4>>2];a:{if(!c){while(1){if(!Uh(b)){b=x[b+8>>2];continue}break}b=x[b+8>>2];break a}b=h_(c)}x[a>>2]=b;return a}function KX(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=441273424|y[a+5|0]!=16|(y[a+54|0]-33&255)>>>0<224)){b=y[a+4|0]>95}return b}function qpa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb+-64|0;fb=d;c=-1;a:{if(!r$(a,d)){break a}c=0;if(!WW(d)){break a}c=ve(a,b,VW(d),hb)}fb=d- -64|0;return c|0}function qN(a,b,c){var d=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+24>>2]=0;x[d+12>>2]=4;nz(d+16|0,a,d+24|0,x[Gb(d+28|0,d+12|0)>>2]);Rm(b,x[d+24>>2]);fb=d+32|0}function _5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];v[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function Fn(a,b){var c=0,d=0,e=0;_v(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=zb(b);d=zb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function DW(a,b){var c=0,d=0,e=0;wr(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=zb(b);d=zb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function to(a,b){x[a+20>>2]=0;x[a+24>>2]=b;x[a+12>>2]=0;x[a+4>>2]=4098;x[a+8>>2]=6;x[a+16>>2]=!b;Tb(a+32|0,0,40);wL(a+28|0);x[a+72>>2]=0;x[a+76>>2]=-1}function hua(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb+-64|0;fb=d;c=-1;a:{if(!r$(a,d)){break a}c=0;if(!q$(d)){break a}c=ve(a,b,p$(d),0)}fb=d- -64|0;return c|0}function cd(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(A[a+8>>2]<b>>>0){d=x[a>>2];c=0;if(!(ib[x[x[d>>2]+32>>2]](d,0,b)|0)){break a}}x[a+8>>2]=b;c=1}return c|0}function PO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;nM(i,b,c,d,e,f,g);_c(a,h+20|0);hn(i);fb=h+32|0}function Kq(a,b,c){var d=0;a:{if(b&134218752){break a}if(!Lj(c)){break a}b=y[c+34|0];if((b+5&255)>>>0<6){break a}d=x[vd(a+906300|0,b-1|0)>>2]}return d}function CZ(a,b,c){var d=0;d=fb-32|0;fb=d;x[d+28>>2]=c;v[d+27|0]=0;x[d+12>>2]=1;nz(d+16|0,a,d+27|0,x[Gb(d+28|0,d+12|0)>>2]);v[b|0]=y[d+27|0];fb=d+32|0}function wu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;d=Tg(e+4|0,a,d);f=d,g=yR(zb(a),b,c,x[d+4>>2]),x[f+4>>2]=g;hc(d);fb=e+16|0}function oaa(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=lg(a,b);x[31725]=0;P(72,a+12|0,c|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}}function o$(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],8)){v[c|0]=0;Vh(a,8,c);break a}fl(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function ax(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],3)){v[c|0]=0;Vh(a,3,c);break a}$w(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function BT(a,b,c){var d=0,e=0;x[b+56>>2]=0;d=b,e=Mo(a,z[b+70>>1],x[b+48>>2],c,0),w[d+68>>1]=e;if(!(!(y[a+480180|0]&5)|x[b+60>>2]==-1)){x[b+60>>2]=0}}function BJ(a){x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;w[a+20>>1]=0;x[a+16>>2]=-1;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0}function zpa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!LX(a,d)){break a}c=0;if(!mX(d)){break a}c=ve(a,b,lX(d),hb)}fb=d+96|0;return c|0}function qh(a,b){var c=0;if(Cd(y[a+11|0])){c=x[a>>2];ej(x[a+8>>2]);Db(c)}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Me(b,0);yd(b,0)}function Ypa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!LX(a,d)){break a}c=0;if(!KX(d)){break a}c=ve(a,b,JX(d),hb)}fb=d+96|0;return c|0}function XG(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Dc(b+4|0,15559);if(Yc(x[a+4>>2],y[a+11|0])){c=(Rg(a,13898)|0)!=-1}else{c=0}tb(a);fb=b+16|0;return c|0}function Ww(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){B[b>>2]=E(x[a>>2])*e;B[c>>2]=E(x[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function R5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b|0];v[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function PP(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=eu(Ec(12));x[c+8>>2]=b;x[c+4>>2]=a;x[c>>2]=47532;a=x[yf(d+12|0,c)>>2];fb=d+16|0;return a|0}function II(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Nh(c+12|0,b);b=a&255;if(b>>>0>=128){b=(a|0)==-1?-1:x[x[124231]>>2]?-1:a&57343}Mh(d);fb=c+16|0;return b}function zs(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;Eb(b);continue}break}c=x[a>>2];if(c){ys(a);Db(c)}}function zX(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;x[a+8>>2]=b;hr(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function qR(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;x[a+8>>2]=b;Ek(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function dx(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;x[a+8>>2]=b;Op(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function c0(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;x[a+8>>2]=b;Gd(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function Yv(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;x[a+8>>2]=b;ub(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function Yq(a,b,c){a:{if(!Ob(c+1074312|0,102)){break a}c=z[a+692>>1]+1|0;w[a+784>>1]=c;if(!(v[a+89|0]&1)){break a}w[a+784>>1]=c|32768}x[a+692>>2]=b}function YB(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;Ik(b);continue}break}c=x[a>>2];if(c){ys(a);Db(c)}}function S3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(oh(a,x[b+8>>2],f)){Px(b,c,d,e);return}a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)}function PA(a){if(y[a+480224|0]==2){return+A[a+1074420>>2]/1e4}return+A[a+24620>>2]/(+A[a+1074404>>2]*+(D(x[a+1074408>>2],x[a+1074416>>2])>>>0))*60}function KS(a,b){var c=0,d=0;c=fb-16|0;fb=c;b=we(c+8|0,ova(b,b>>31,500654080,20),hb);d=x[b>>2];b=x[b+4>>2];fb=c+16|0;x[a>>2]=d;x[a+4>>2]=b;return a}function GK(a,b,c){var d=0,e=0,f=0,g=0;d=IC(b);if(d>>>0<c>>>0){HK(a,b,d+1|0);return d}if(c){e=a;a=c-1|0;f=HK(e,b,a)+(a<<2)|0,g=0,x[f>>2]=g}return d}function x9(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;ib[x[x[a+32>>2]+d>>2]](b,a,x[d+x[a+36>>2]>>2]);continue}break}}function v$(a){v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function rha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=1){c=Pd(c,E(0));if((b|0)==1){d=1;c=si(c)}e=yb(a+4208|0,d),f=c,B[e>>2]=f;gQ(a)}}function nI(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function gf(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!b){Pc(c+8|0,a+32|0,5);if(Hb(x[x[c+8>>2]>>2],x[c+12>>2])){break a}}x[a+28>>2]=x[a+28>>2]+1}fb=c+16|0}function bY(a){return(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))==1279545165&(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1297239878}function TB(a,b,c){var d=0,e=0,f=0;d=Yl(a,b);if((d|0)!=255){e=_b(a+26|0,d),f=c,w[e>>1]=f;a=a+62|0;e=xb(a,b),f=255,v[e|0]=f;e=xb(a,c),f=d,v[e|0]=f}}function NU(a){var b=0,c=0,d=0;d=y[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=y[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function M_(a,b){var c=0;c=ova(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;hb=b>>>0<11?a+1|0:a;return b}function Ija(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;w[c+30>>1]=b;b=c+30|0;Jp(c+20|0,b);d=x[c+20>>2];Jp(c+12|0,b);yl(a,d,x[c+16>>2]);fb=c+32|0}function Gs(a,b,c,d){var e=0;e=ac(8);x[31725]=0;a=P(d|0,e|0,a|0)|0;d=x[31725];x[31725]=0;if((d|0)!=1){da(a|0,c|0,b|0);p()}a=N()|0;jc(e);Q(a|0);p()}function vt(a){var b=0,c=0,d=0;if(!a){return 0}d=98960;while(1){b=d;c=x[b>>2];if(c){d=b+4|0;if((a|0)!=(c|0)){continue}}break}return((c?b:0)|0)!=0}function sP(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;nM(i,b,c,d,e,f,g);_c(a,i);hn(i);fb=h+32|0}function lG(a){a=a|0;var b=0;a=Fb(a);x[31725]=0;R(170,a+12|0)|0;b=x[31725];x[31725]=0;if((b|0)!=1){sc(a+32|0);return a|0}b=N()|0;tb(a);Q(b|0);p()}function cj(a,b){var c=0;c=x[a>>2];if(Zc(c,x[a+4>>2])>>>0>b>>>0){a=x[a+24>>2];a=He(x[a+484344>>2],x[a+484348>>2],z[_b(c,b)>>1])}else{a=0}return a}function Yla(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;v[c+31|0]=b;b=c+31|0;Zr(c+20|0,b);d=x[c+20>>2];Zr(c+12|0,b);yl(a,d,x[c+16>>2]);fb=c+32|0}function LE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0}function KB(a){var b=0,c=0;b=fb-16|0;fb=b;x[b+12>>2]=a;c=b+12|0;a=1;while(1){if((a|0)>0){ah(c);a=a-1|0;continue}break}fb=b+16|0;return x[b+12>>2]}function DQ(a,b){var c=0;c=x[b+4>>2];if(x[a>>2]==(b|0)){x[a>>2]=c}if(c){x[c+8>>2]=x[b+8>>2]}a=x[b+8>>2];if(a){x[a+4>>2]=c}x[b+4>>2]=0;x[b+8>>2]=0}function uq(a,b){var c=0;a:{if(!hM(b)|(y[b+1|0]^y[a+1|0])>>>0>1){break a}b=y[b+2|0];a=y[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function fR(a){var b=0;b=fb-16|0;fb=b;B[b+12>>2]=F(a);x[b+8>>2]=646978941;x[b+4>>2]=1259902592;a=B[Nv(b+12|0,b+8|0,b+4|0)>>2];fb=b+16|0;return a}function TP(a,b){var c=0;if(a>.999999){c=0}else{a=a*a;b=kf(31415.926535897932/b);c=_i(32768/(1-a)*(1-(a*b+M((a+a)*(1-b)-a*a*(1-b*b)))))}return c}function Nua(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(gh(a,c+11|0)){x[c+4>>2]=y[c+11|0];p0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0}function Ky(a){var b=0,c=0;b=fb-16|0;fb=b;c=-1;a:{if(Wy(a)){break a}if((ib[x[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=y[b+15|0]}fb=b+16|0;return c}function uT(a,b){v[a+840|0]=b;v[a+812|0]=b;v[a+811|0]=b;v[a+809|0]=b;v[a+807|0]=b;v[a+806|0]=b;v[a+833|0]=b;v[a+826|0]=b>>>4;v[a+827|0]=b<<2&60}function h1(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(gh(a,c+11|0)){x[c+4>>2]=y[c+11|0];V0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0}function Tk(a,b,c,d){var e=0;e=D(b,c);a:{if(x[d+76>>2]<0){a=uE(a,e,d);break a}a=uE(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function Fga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){Gz(a,0,0,0,0,0,0,c,d);return}Gz(a,x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2],x[b+24>>2],b,c,d)}function sqa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Pg(b);Pg(b);break a}a=ih(b);ih(b)}while(1){if(a){if(a&1){Vb(b,260)}a=a>>>1|0;continue}break}}function pg(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;w[c+30>>1]=0;vk(c+8|0,c+30|0);Sm(c+20|0,a,x[c+8>>2],x[c+12>>2]);ij(b,z[c+30>>1]);fb=c+32|0}function iX(a,b,c,d){var e=0;e=c&4;a:{b:{if(!(e|(b&255)!=4)){if(c&2){break b}Xc(a,8,1,0,10);return}b=16;if(e){break a}}b=8}Xc(a,b,c&2|1,0,d^1)}function aF(a,b){var c=0;a:{if(!(y[a+2|0]|y[a+3|0]<<8)|(!y[a|0]|!y[a+1|0])){break a}c=1;if(b>>>0<9){break a}c=(y[a+4|0]-1&255)>>>0<32}return c}function Tm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Cf(b);e=a;a=Cb(x[c+4>>2],y[c+11|0]);b=Cg(Kb(Fz(e,d+a|0)),b,d)+d|0;im(Cg(b,Kb(c),a)+a|0,1,0)}function QL(a,b,c,d,e,f){var g=0,h=0;g=x[a+32>>2];if(!y[a+23|0]){x[(c<<2)+g>>2]=b;return}h=g;g=d<<2;x[h+g>>2]=b;v[x[a+8>>2]+d|0]=e;x[f+g>>2]=c}function JY(a){var b=0;if(!(kd(a,15009,3)|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-2147483647>>>0<2147484072)){b=y[a+3|0]<6}return b}function Fm(a,b){var c=0,d=0;d=x[a+4>>2];c=x[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;x[a+8>>2]=c;continue}break}b=x[a>>2];if(b){nc(a);Db(b)}}function ag(a){a=a|0;var b=0;x[a>>2]=42776;x[x[a+20>>2]>>2]=0;b=x[a+16>>2];x[b+946300>>2]=x[b+946300>>2]-1;x[a+20>>2]=0;GQ(a+44|0);return a|0}function Zu(a,b){var c=0,d=0;d=gk(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!He(a,b,d&65535)){continue}}break}return c&65535}function YV(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){ys(a);Db(b)}}function X$(a,b,c){var d=0;d=fb-16|0;fb=d;tm(d+12|0,b);x[d+8>>2]=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);lp(a,d+8|0,c);fb=d+16|0}function Uu(a,b){var c=0;c=fb-16|0;fb=c;ee(c+8|0,a);ee(c,b);b=x[c>>2];a=F_(x[c+8>>2],x[c+12>>2],b,x[c+4>>2]);fb=c+16|0;return Cd(a?a>>31|1:0)}function Sn(a,b){var c=0;a=Wn(a);x[a>>2]=78688;c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function QR(a,b){var c=0;c=fb-16|0;fb=c;ee(c+8|0,a);ee(c,b);b=x[c>>2];a=GZ(x[c+8>>2],x[c+12>>2],b,x[c+4>>2]);fb=c+16|0;return Cd(a?a>>31|1:0)}function MW(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){ys(a);Db(b)}}function Fi(a){var b=0;a=a*a;b=a*a;return E(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function hE(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;w[c+14>>1]=1;d=c,e=mm(a,b),w[d+12>>1]=e;a=z[qe(c+14|0,c+12|0)>>1];fb=c+16|0;return a-1&65535}function OO(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;oM(h,b,c,d,e,f);_c(a,g+20|0);hn(h);fb=g+32|0}function x_(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=b,d=$b(a),x[c+12>>2]=d;x[b+8>>2]=236;a=x[ad(b+12|0,b+8|0)>>2];fb=b+16|0;hb=0;return a-216|0}function of(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=vb(d+12|0,a);c=x[b>>2];if(x[c>>2]){DZ(c);b=x[b>>2];c=x[b>>2];at(b);Db(c)}fb=d+16|0;return a}function Ne(a,b,c){v[a+11|0]=c;v[a+10|0]=b;v[a+12|0]=y[a+12|0]&251;w[a+8>>1]=65535;x[a>>2]=0;x[a+4>>2]=0;v[a+12|0]=y[a+12|0]&252|1;return a}function Lb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;if(b>>>0>=121){Wq(12210);p()}e=d+8|0;Jb(e,a,b);Jf(e,c);fb=d+16|0;return a|0}function Kw(a,b){var c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=1){c=BF(a,1);break a}c=ih(a);Vb(a,b-2|0)}return c}function Cp(a,b){var c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=CF(a,b);break a}c=Pg(a);Vb(a,b-4|0)}return c}function Ab(a,b){var c=0;if(Cd(y[a+11|0])){Db(x[a>>2])}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Me(b,0);fd(b,0);return a}function wL(a){var b=0,c=0;x[31725]=0;c=ca(1180)|0;b=x[31725];x[31725]=0;if((b|0)!=1){b=a;a=x[c>>2];x[b>>2]=a;hl(a);return}T(0)|0;Sb();p()}function rI(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=Mx(x[d>>2],c)}ib[x[x[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function j6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-16|0;fb=a;x[a+12>>2]=e;x[a+8>>2]=d-c;b=Gb(a+12|0,a+8|0);fb=a+16|0;return x[b>>2]}function Tx(a,b){var c=0;c=fb-16|0;fb=c;b=Nh(c+12|0,b);a=a>>>0>=128?(a&-128)!=57216?-1:x[x[124231]>>2]?-1:a&255:a;Mh(b);fb=c+16|0;return a}function Ql(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=x[a+24>>2];d=x[a+40>>2];x[b+12>>2]=1;a=x[ad(a+20|0,b+12|0)>>2];fb=b+16|0;return D(a,c+d|0)}function LO(a,b,c){var d=0,e=0;d=Mc(a);if(d>>>0>=c>>>0){Yu(a,Vi(Kb(a),b,c),c);return}e=a;a=Cb(x[a+4>>2],y[a+11|0]);fq(e,d,c-d|0,a,0,a,c,b)}function xla(a){a=a|0;var b=0;b=x[a>>2];if(ib[x[x[b>>2]+32>>2]](b,0,32)|0){a=x[a>>2];a=ib[x[x[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function xC(a){a=50-(D(y[(a>>>4|0)+29904|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Gc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function mk(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Rb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+21|0]=f;fb=d+16|0}function lk(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Rb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+22|0]=f;fb=d+16|0}function j$(a){var b=0,c=0,d=0;c=fb-16|0;fb=c;b=c+13|0;ax(b,a);a=y[xb(b,0)|0];d=y[xb(b,1)|0];b=y[xb(b,2)|0];fb=c+16|0;return a|d<<8|b<<16}function ed(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=-32768;x[b+4>>2]=32767;a=w[Ze(b+8|0,ud(b+12|0,b+4|0))>>1];fb=b+16|0;return a}function UO(a,b){var c=0,d=0;a:{if(!St(b)){break a}c=x[a+484344>>2];if(!He(c,x[a+484348>>2],b&65535)){break a}d=x[Wb(c,b)+12>>2]}return d}function Sia(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=x[a+20>>2];oe(b,x[c+4>>2],x[c+8>>2]);IQ(a,gc(b+8|0,x[b>>2],x[b+4>>2]),0);fb=b+16|0}function AC(a,b){var c=0,d=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[b>>2]=0;x[b+4>>2]=0;c=zb(b),d=0,x[c>>2]=d;return a}function faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=x[b>>2]+7&-8;x[c>>2]=b+16;d=a,e=wx(x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2]),C[d>>3]=e}function N4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=Dy(x[b>>2]),x[d>>2]=e;b=b+4|0;continue}break}return c|0}function L4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=Ey(x[b>>2]),x[d>>2]=e;b=b+4|0;continue}break}return c|0}function JH(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=x[a>>2];if(d>>>0<=127){d=x[(d<<2)+c>>2]}x[a>>2]=d;a=a+4|0;continue}break}return b}function tY(a){w[a+10>>1]=0;w[a+12>>1]=0;w[a+8>>1]=1084;x[a>>2]=0;x[a+4>>2]=40;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;return a}function rP(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;oM(h,b,c,d,e,f);_c(a,h);hn(h);fb=g+32|0}function gd(a,b){var c=0,d=0,e=0;c=mh(a,b);if(c){x[a+12>>2]=x[a+12>>2]+b;return c}d=a,e=ib[x[x[a>>2]+24>>2]](a)|0,x[d+12>>2]=e;return c}function WC(a){var b=0;b=Bb(y[a+26|0]|y[a+27|0]<<8);return((y[a+24|0]>15)+(y[a+25|0]>64)|0)+(Bb(y[a+22|0]|y[a+23|0]<<8)<<1>>>0<b>>>0)|0}function SS(a,b,c,d){var e=0;e=a+1074376|0;pB(a,e,b,c,d);e=0-y[(D(b,872)+e|0)+1428|0]|0;if(d){c=0}else{c=Ju(x[a+480180>>2])}Go(a,b,e,c)}function x4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=Al(y[b|0]),v[d|0]=e;b=b+1|0;continue}break}return c|0}function v4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=zt(y[b|0]),v[d|0]=e;b=b+1|0;continue}break}return c|0}function un(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;x[a+8>>2]=b;continue}break}a=x[a>>2];if(a){Db(a)}}function mva(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){Jn(b)}v[a|0]=1}return a|0}function dp(a){var b=0,c=0;c=fb-16|0;fb=c;b=vb(c+12|0,a);a=x[b>>2];if(x[a>>2]){cZ(a,x[a>>2]);a=x[b>>2];b=x[a>>2];dZ(a);Db(b)}fb=c+16|0}function bla(a,b){a=a|0;b=b|0;a=iB(a);x[31725]=0;O(848,a|0,b|0);b=x[31725];x[31725]=0;if((b|0)==1){b=N()|0;Nq(a);Q(b|0);p()}return a|0}function PW(a){var b=0,c=0;c=fb-16|0;fb=c;b=vb(c+12|0,a);a=x[b>>2];if(x[a>>2]){JW(a,x[a>>2]);a=x[b>>2];b=x[a>>2];ll(a);Db(b)}fb=c+16|0}function Kia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Tc(c&255))){LQ(a,8,E(0))}a=Fj(a);if(a){ib[x[x[a>>2]+96>>2]](a,b,c,d,e)}}function Eu(a,b,c){var d=0;d=fb-16|0;fb=d;b=we(d+8|0,ova(b,c,1e6,0),hb);c=x[b>>2];b=x[b+4>>2];fb=d+16|0;x[a>>2]=c;x[a+4>>2]=b;return a}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=fu(x[a+32>>2],b,c,d,2);if(a>>>0<=15){a=y[a+42192|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function Dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=fu(x[a+32>>2],b,c,d,3);if(a>>>0<=46){a=y[a+42144|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function zda(a,b){a=a|0;b=b|0;var c=0;if((a|0)!=(b|0)){c=x[a+4>>2];if(c){Db(c);x[a+4>>2]=0}x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0}return a|0}function ut(a){return a>>>0<=254?(a+1&127)>>>0>32:(a&65534)!=65534&a-65532>>>0<1048580|(a-57344>>>0<8185|a>>>0<8232|a-8234>>>0<47062)}function N9(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){lL(b)}v[a|0]=1}return a|0}function xi(a,b,c){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24;v[a+4|0]=c;v[a+5|0]=c>>>8;v[a+6|0]=c>>>16;v[a+7|0]=c>>>24}function wY(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=-128;x[b+4>>2]=127;a=v[Ze(b+8|0,ud(b+12|0,b+4|0))|0];fb=b+16|0;return a}function IH(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a|0];if((d|0)>=0){d=x[(d<<2)+c>>2]}v[a|0]=d;a=a+1|0;continue}break}return b}function Gha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;if(b>>>0<=4){c=Pd(c,E(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=si(c)}B[d>>2]=c;jQ(a)}}function Ala(a,b){a=a|0;b=b|0;a=yE(a,b);if(!a){v[b+6|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0}return a|0}function pi(a,b){var c=0,d=0;c=x[a>>2];d=x[a+4>>2];b=x[a+16>>2]+b|0;a=x[a+12>>2];b=(b|0)%(a|0)|0;return B[Oc(c,d,(b>>31&a)+b|0)>>2]}function dg(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=121){Wq(12175);p()}d=c+8|0;Jb(d,a,b);Jf(d,0);fb=c+16|0;return a|0}function aaa(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+1;a=Pf(v[a|0])}else{a=-1}return a|0}function TS(a,b,c,d){var e=0;e=a+1074376|0;qB(a,e,b,c,d);e=y[(D(b,872)+e|0)+1427|0];if(d){c=0}else{c=Ju(x[a+480180>>2])}Go(a,b,e,c)}function Ry(a){a=a|0;var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+1;return Pf(v[b|0])|0}function Lt(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=x[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=x[c>>2];x[a>>2]=d<<b;x[a+4>>2]=c<<b|d>>>32-b}function Fj(a){var b=0,c=0;b=vm(x[x[a+20>>2]+28>>2]);if(!(b>>>0>249|y[a+4200|0]>=b>>>0)){c=x[vd(x[a+16>>2]+906300|0,b)>>2]}return c}function qi(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;o(+b);e=j(1)|0;j(0)|0;l(0,d|0);l(1,c&2147483647|e&-2147483648);return+n()}function fla(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=250){Wq(12210);p()}d=c+8|0;Jb(d,a,b);hp(d);fb=c+16|0;return a|0}function Nt(a,b){var c=0,d=0;c=x[a+4>>2];a:{if(b>>>0<=31){d=x[a>>2];break a}b=b-32|0;d=c;c=0}x[a+4>>2]=c>>>b;x[a>>2]=c<<32-b|d>>>b}function eZ(a,b){var c=0;c=fb-16|0;fb=c;a=Tg(c+4|0,a,1);ip(x[a+4>>2],z[b>>1]|z[b+2>>1]<<16);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0}function bh(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=0;x[b+4>>2]=255;a=y[Ze(b+8|0,ud(b+12|0,b+4|0))|0];fb=b+16|0;return a}function PL(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}_(14218,13258,1180,5734);p()}if((b|0)==255){return 0}a=b>>>0>10}return a}function rO(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=eu(Ec(8));x[c+4>>2]=a;x[c>>2]=48480;a=x[yf(b+12|0,c)>>2];fb=b+16|0;return a|0}function ke(a){var b=0;a=x[a+4>>2];if(a){if(Bm(a)){a:{b=a+8|0;if(x[b>>2]){if((hx(b)|0)!=-1){break a}}ib[x[x[a>>2]+16>>2]](a)}}}}function jN(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=XM(Ec(8));x[c+4>>2]=a;x[c>>2]=73560;a=x[yf(b+12|0,c)>>2];fb=b+16|0;return a|0}function jH(a,b,c,d){a=Nb(a);x[31725]=0;S(d|0,a|0,b|0,c|0);b=x[31725];x[31725]=0;if((b|0)!=1){return a}b=N()|0;uc(a);Q(b|0);p()}function iK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=mt(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function fK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=it(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function dz(a,b,c){var d=0;d=x[a+32>>2];if(A[a+40>>2]<d+c>>>0){x[a+96>>2]=1;return 0}yc(b,d,c);x[a+32>>2]=x[a+32>>2]+c;return 1}function a6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){x[d>>2]=v[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function P9(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+4;a=x[a>>2]}else{a=-1}return a|0}function OB(a,b){var c=0;c=x[a+484360>>2];b=b&255;if(Qj(c,x[a+484364>>2])>>>0<=b>>>0){return Xb(c,y[a+484376|0])}return Xj(c,b)}function CH(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+8>>2]=a;x[d+12>>2]=b;x[d>>2]=c;x[d+4>>2]=0;a=_r(d+8|0,d);fb=d+16|0;return x[a>>2]}function BC(a,b){var c=0;c=fb-16|0;fb=c;a=gc(c+8|0,(b>>>3&536870908)+a|0,1<<b);a=Hb(x[x[a>>2]>>2],x[a+4>>2]);fb=c+16|0;return a}function AT(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(y[a+480180|0]&2){break a}}x[b+56>>2]=0;d=Mo(a,z[b+70>>1],x[b+48>>2],c,0)}return d}function wS(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Du(b);a=x[a>>2];b=x[a>>2];Cu(a);Db(b)}fb=c+16|0}function vC(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){OW(b);a=x[a>>2];b=x[a>>2];ll(a);Db(b)}fb=c+16|0}function tv(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){ZV(b);a=x[a>>2];b=x[a>>2];lC(a);Db(b)}fb=c+16|0}function sU(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){mU(b);a=x[a>>2];b=x[a>>2];ll(a);Db(b)}fb=c+16|0}function qS(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Tp(b);a=x[a>>2];b=x[a>>2];cx(a);Db(b)}fb=c+16|0}function pu(a){var b=0;b=C[a+4248>>3]/+A[x[a+16>>2]+24620>>2];C[a+4264>>3]=b;if(y[a+4240|0]){C[a+4264>>3]=b*(C[a+4288>>3]/60)}}function nu(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){dA(b);a=x[a>>2];b=x[a>>2];cA(a);Db(b)}fb=c+16|0}function ie(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){n0(b);a=x[a>>2];b=x[a>>2];rE(a);Db(b)}fb=c+16|0}function gG(a,b){var c=0;c=x[b+4>>2];if(c){bc(a,c,x[b>>2]);return}c=x[b+8>>2];b=x[b+12>>2];if(!lc(c,b)){oe(a,c,b);return}Nd(a)}function fH(a,b,c){a=si(a);a:{if(a>=b){break a}c=0;if(a<=E(0)){break a}if(a<E(4294967296)&a>=E(0)){c=~~a>>>0;break a}}return c}function _B(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){eV(b);a=x[a>>2];b=x[a>>2];cp(a);Db(b)}fb=c+16|0}function Yi(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){kY(b);a=x[a>>2];b=x[a>>2];cp(a);Db(b)}fb=c+16|0}function YU(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(b){Yd(b,a)}if(c){Yd(c,a)}if(d){Yd(d,a)}if(e){Yd(e,a)}}function T5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function FS(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){fw(b);a=x[a>>2];b=x[a>>2];B$(a);Db(b)}fb=c+16|0}function Br(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function yn(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=b;b=c-b|0;g=e,h=nl(d,f,b)+b|0,x[g+12>>2]=h;Ac(a,c,e+12|0);fb=e+16|0}function xI(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;d=Tg(e+4|0,a,d);f=d,g=yR(jq(a),b,c,x[d+4>>2]),x[f+4>>2]=g;hc(d);fb=e+16|0}function tw(a,b){return nr(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24),y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))?b:a}function Sx(a,b){var c=0,d=0,e=0,f=0;c=Cf(b);d=Ec(c+13|0);x[d+8>>2]=0;x[d+4>>2]=c;x[d>>2]=c;e=a,f=yc(nc(d),b,c+1|0),x[e>>2]=f}function SG(a){a=a|0;var b=0;a=Fb(a);x[31725]=0;O(132,a|0,13724);b=x[31725];x[31725]=0;if((b|0)==1){b=N()|0;tb(a);Q(b|0);p()}}function Q3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(oh(a,x[b+8>>2],0)){Nx(b,c,d);return}a=x[a+8>>2];ib[x[x[a>>2]+28>>2]](a,b,c,d)}function jK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=mt(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function gK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=it(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function dm(a,b){var c=0;a:{if(A[a+12>>2]<b>>>0){c=0;if(!(ib[x[x[a>>2]+32>>2]](a,0,b)|0)){break a}}x[a+12>>2]=b;c=1}return c}function Rc(a,b,c){var d=0;d=a;a=c&31;if((c&63)>>>0>=32){c=b>>31;a=b>>a}else{c=b>>a;a=((1<<a)-1&b)<<32-a|d>>>a}hb=c;return a}function RY(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;w[c+14>>1]=b;if((mm(x[a>>2],x[a+4>>2])|0)!=65535){M0(a,c+14|0)}fb=c+16|0}function PT(a){tB(a);x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;a=qg(a);qg(a+12|0);v[a+24|0]=1}function Ml(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;yA(a,c,d)}function Fg(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return To(a,d)}function tr(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return ib[x[x[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function qia(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=Bh(E(Pd(c,E(0))*E(127))),v[d|0]=e;lu(a)}}function jja(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=Bh(E(Pd(c,E(0))*E(255))),v[d|0]=e;ru(a)}}function eQ(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=uc(b-24|0);if((c|0)!=(b|0)){continue}break}return ag(a)|0}function rp(a){x[a+32>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function dH(a,b){x[a>>2]=b;wL(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function OR(a,b){var c=0;if(!(y[a|0]!=y[b|0]|C[a+8>>3]!=C[b+8>>3]|y[a+16|0]!=y[b+16|0])){c=x[a+20>>2]==x[b+20>>2]}return c}function Fu(a,b,c){c=c&255;while(1){a:{if(!b){a=0;break a}if(lc(y[a|0],c)){break a}b=b-1|0;a=a+1|0;continue}break}return a}function FC(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function qt(a){if(a>>>0<=131071){a=y[(a>>>3&31|y[(a>>>8|0)+103616|0]<<5)+103616|0]>>>(a&7)&1}else{a=a>>>0<196606}return a}function ne(a,b){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))}function Mp(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=x[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}x[a>>2]=b}}function Fe(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=x[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}x[a>>2]=b}}function uY(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!mh(a,4)){lD(b);break a}ph(c+8|0,b);VC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function rh(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;x[f+12>>2]=e;c=Nh(f+8|0,c);a=wt(a,b,d,x[f+12>>2]);Mh(c);fb=f+16|0;return a}function rW(a){var b=0;if(!(y[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){x[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function qV(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){nV(a,1);nV(a,0)}}function pV(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){oV(a,1);oV(a,0)}}function pF(a,b){var c=0;c=ova(b&255,0,1536,0);b=hb;a=ova(a&255,0,25,0);c=a+c|0;b=hb+b|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function hL(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+4;return x[b>>2]}function _W(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((y[a+b|0]-32&255)>>>0<95){continue}}break}return(b|0)==8}function LY(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a=Tg(e+4|0,a,d);f=a,g=Cr(b,c,x[a+4>>2]),x[f+4>>2]=g;hc(a);fb=e+16|0}function qT(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Yb(x[a>>2]+((D(c<<24>>24,(d^-1|-256)+b|0)|0)/2|0)|0,0,256),x[e>>2]=f}}function o3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return ib[a|0](h|b,c,d,e,b|f,g)|0}function hf(a){var b=0;b=x[a+32>>2];a:{if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1;a=0;break a}x[a+32>>2]=b+1;a=y[b|0]}return a}function du(a){a=a|0;var b=0;x[a>>2]=47692;Yd(a,0);b=x[a+8>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+8>>2]=0;return Vm(a)|0}function d_(a,b,c){var d=0;while(1){if(b){d=y[c|0]|y[c+1|0]<<8;v[a|0]=d;v[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}}function dF(a){var b=0;b=0;a:{if(kd(a,14188,3)){break a}a=y[a+3|0];b=1;if((a|0)==1){break a}b=(a-8&255)>>>0<7}return b}function av(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function VX(a){var b=0;if(!(kd(a,13865,3)|y[a+3|0]>31|(v[a+27|0]<0|y[a+32|0]>64))){b=(y[a+33|0]-1&255)>>>0<32}return b}function Mi(a,b,c){c=c&255;while(1){a:{if((a|0)!=(b|0)){if((c|0)!=y[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function Ila(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=yf(b+12|0,Tb(Ec(6668),0,6668));fb=b+16|0;x[a>>2]=x[c>>2];return a|0}function Dga(a){a=a|0;var b=0;b=fb-16|0;fb=b;if(a){a=qc(b+8|0,a);a=Rz(x[a>>2],x[a+4>>2])}else{a=0}fb=b+16|0;return a|0}function yi(a){var b=0;while(1){a:{if((b|0)!=47){if(y[b+42224|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function t9(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=FD(x[b>>2]);x[a+36>>2]=b;c=a,d=lo(b),v[c+44|0]=d}function nK(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;b=Nh(d+8|0,b);a=MK(a,9262,x[d+12>>2]);Mh(b);fb=d+16|0;return a}function m9(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=Ly(x[b>>2]);x[a+36>>2]=b;c=a,d=lo(b),v[c+44|0]=d}function lH(a,b,c){a=Ee(a);a:{if(a>=b){break a}c=0;if(a<=0){break a}if(a<4294967296&a>=0){c=~~a>>>0;break a}}return c}function _ga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=2){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;aQ(a)}}function Vha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=5){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;pQ(a)}}function Sga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=3){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;_P(a)}}function Nha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=4){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;lQ(a)}}function xV(a){x[a+700>>2]=0;w[a+842>>1]=0;x[a+688>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0}function n0(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Gd(b);continue}break}x[a+4>>2]=c}function Yl(a,b){a=a+62|0;if(v[xb(a,b)|0]<0){return 255}if(y[xb(a,b)|0]!=255){a=y[xb(a,b)|0]&127}else{a=255}return a}function X8(a){a=a|0;var b=0,c=0;c=x[a+4>>2];b=x[a>>2];a=x[a+8>>2];b=b+(a>>1)|0;if(a&1){c=x[c+x[b>>2]>>2]}ib[c|0](b)}function Tp(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;Op(b);continue}break}x[a+4>>2]=c}function HK(a,b,c){var d=0;if(c){d=a;while(1){x[d>>2]=x[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a}function Fh(a){var b=0;vn(a);b=nv(x[a>>2],el(z[a+34>>1]));x[a+20>>2]=b;if(!b){return 0}return Xk(x[a>>2],z[a+34>>1])}function wr(a){var b=0,c=0,d=0;if(x[a>>2]){Nf(a);b=x[a>>2];Ug(a);Db(b);c=zb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function vh(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=x[Gb(b+12|0,b+8|0)>>2];fb=b+16|0;return a}function lV(a){var b=0,c=0,d=0;if(x[a>>2]){lj(a);b=x[a>>2];Pn(a);Db(b);c=zb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function iU(a){var b=0,c=0,d=0;if(x[a>>2]){IG(a);b=x[a>>2];Zn(a);Db(b);c=zb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function RK(a,b,c,d,e,f,g,h,i){x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function Lh(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=Gb(b+12|0,b+8|0);fb=b+16|0;return x[a>>2]}function BR(a){var b=0,c=0,d=0;if(x[a>>2]){L$(a);b=x[a>>2];cw(a);Db(b);c=zb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function yc(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function r0(a,b,c,d,e){v[a+4|0]=b;v[a|0]=69;v[a+1|0]=99;v[a+2|0]=104;v[a+3|0]=111;v[a+7|0]=e;v[a+6|0]=d;v[a+5|0]=c}function lM(a,b){var c=0;c=fb-16|0;fb=c;a=am(c+4|0,a,1);Fl(x[a+4>>2],y[b|0]);x[a+4>>2]=x[a+4>>2]+1;hc(a);fb=c+16|0}function NL(a,b,c){var d=0,e=0,f=0;e=c*c;C[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;C[b>>3]=d*d+((c+c)*d+(c*c-e))}function yT(a,b){var c=0;c=b&15;if(c){v[a+827|0]=c<<2}b=b&240;if(b){v[a+826|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|262144}function uea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=ib[x[x[b>>2]+8>>2]](b)|0;d=c,e=Bg(a?a:22255),x[d>>2]=e}}function nL(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];a:{if(!c){break a}if(!lc(rL(c,b),-1)){break a}x[a>>2]=0}return a|0}function mS(a,b){var c=0;c=fb-16|0;fb=c;a=hC(c+4|0,a);Eo(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0}function kQ(a){a=a|0;x[a+4244>>2]=0;x[a+4248>>2]=0;x[a+4228>>2]=0;x[a+4232>>2]=0;a=a+4252|0;x[a>>2]=0;x[a+4>>2]=0}function jt(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}Ub(a,b);a=a+4|0;continue}}}function TR(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];if((c|0)==(d|0)){a=SR(x[a>>2],c,x[b>>2],d)}else{a=1}return!a}function Pl(a,b){var c=0;c=b&15;if(c){v[a+824|0]=c<<2}b=b&240;if(b){v[a+823|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|131072}function Im(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}tg(a,b);a=a+1|0;continue}}}function iQ(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;x[a+8>>2]=b;continue}break}}function ty(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(x[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function fN(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(!Ld(c,x[a>>2])){break a}}else{a=b}return a}a=a+8|0;continue}}function _A(a,b){var c=0;c=fb-16|0;fb=c;a=we(c+8|0,pva(a,b,1e6,0),hb);b=x[a>>2];fb=c+16|0;hb=x[a+4>>2];return b}function Rl(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function KJ(a,b){var c=0;c=Kb(a);if(c>>>0<=b>>>0){a=(Cb(x[a+4>>2],y[a+11|0])<<2)+c>>>0>=b>>>0}else{a=0}return a}function oh(a,b,c){if(!c){return x[a+4>>2]==x[b+4>>2]}if((a|0)==(b|0)){return 1}return!oi(x[a+4>>2],x[b+4>>2])}function mR(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=32767;a=w[Gb(b+12|0,b+8|0)>>1];fb=b+16|0;return a}function lm(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=65535;a=z[Gb(b+12|0,b+8|0)>>1];fb=b+16|0;return a}function dw(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=(D(a,b)>>>0)/255;Fe(c+12|0,0,15);fb=c+16|0;return y[c+12|0]}function OW(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;continue}break}x[a+4>>2]=c}function Ln(a){a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function Jf(a,b){var c=0;c=x[a+4>>2];if(b){a=x[a>>2];x[a>>2]=x[a>>2]|c;return}a=x[a>>2];x[a>>2]=x[a>>2]&(c^-1)}function DH(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=yb(c,a);a=a+1|0;x[d>>2]=a<<b;continue}break}}function f4(){if(y[500396]){return x[125098]}Ds(500388,x[vH()>>2]);v[500396]=1;x[125098]=500388;return 500388}function XR(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function Ul(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+8>>2]=c;gc(a,b,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function Mk(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=c+12|0;x[a>>2]=x[a>>2]+(b<<2);fb=c+16|0;return x[a>>2]}function MS(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function Lx(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=Mx(x[e>>2],h)}ib[x[x[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function Dq(a,b){var c=0;c=fb-32|0;fb=c;ph(c+16|0,b);Sm(c+24|0,a,x[c+16>>2],x[c+20>>2]);ph(c+8|0,b);fb=c+32|0}function $v(a){var b=0;b=fb-16|0;fb=b;w[b+14>>1]=a;w[b+12>>1]=255;a=y[Nc(b+14|0,b+12|0)|0];fb=b+16|0;return a}function uua(a,b){a=a|0;b=b|0;var c=0;b=fb-80|0;fb=b;c=-1;if(W$(a,b+14|0)){c=V$(b+14|0)}fb=b+80|0;return c|0}function tL(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return Pf(v[b|0])}function hK(a,b,c,d,e){b=rj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function eK(a,b,c,d,e){b=qj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function VU(a){var b=0;b=x[a+4>>2];w[a+70>>1]=y[((z[b+20>>1]>>>6|z[b+22>>1]<<4)&65535)+27424|0]>>>z[a+68>>1]}function zra(a,b){a=a|0;b=b|0;if(!_Y(a,b)){v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0}}function zi(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=255;a=y[Gb(b+12|0,b+8|0)|0];fb=b+16|0;return a}function zV(a,b){a=a|0;b=b|0;var c=0;c=Cb(x[a+4>>2],y[a+11|0]);if(c>>>0<b>>>0){Bs(a,b-c|0,0);return}qU(a,b)}function ux(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+12>>2]=x[b+12>>2]+12;fb=b+16|0;return Xp(x[b+12>>2])}function qA(a,b){a=Nb(a);x[a+20>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;Nb(a+24|0);Fb(a+36|0);x[a+48>>2]=b;return a}function mY(a,b){v[a+6|0]=255;x[a+16>>2]=0;w[a+4>>1]=0;x[a>>2]=0;if(b>=0){C[a+8>>3]=b;x[a+16>>2]=3}return a}function fga(){var a=0;a=fb-16|0;fb=a;if($a(a+12|0,4)|0){Jt(x[31600],12710);p()}fb=a+16|0;return x[a+12>>2]}function cM(a,b,c,d){B[d+4>>2]=a+c;a=E(a+E(c*E(-.5)));b=E(b*E(.8660253882408142));B[d+8>>2]=a-b;B[d>>2]=b+a}function Wl(a,b,c,d){a=a&65535;c=c&65535;a=(a|0)!=(c|0)?a>>>0<c>>>0?-1:1:0;if(Vj(a)){a=hU(b,d)}return Cd(a)}function Oea(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return ZH(a,b,c,d,e,f,g,12977,1084)|0}function Hea(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return ZH(a,b,c,d,e,f,g,13045,1091)|0}function qra(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(rk(a,b+8|0)){c=JY(b+8|0)}fb=b+16|0;return c|0}function Yua(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(rk(a,b+8|0)){c=z0(b+8|0)}fb=b+16|0;return c|0}function Pu(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=Jo(a);continue}break}return a}function Lz(a,b){var c=0;c=Kb(a);if(c>>>0<=b>>>0){a=Cb(x[a+4>>2],y[a+11|0])+c>>>0>=b>>>0}else{a=0}return a}function Jw(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function Cqa(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if($D(a,b+4|0)){c=bY(b+4|0)}fb=b+16|0;return c|0}function $W(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function mI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=0;return Hz(g|a,b,c,d,a|e,f)|0}function hva(a){a=a|0;var b=0;b=x[a+76>>2];if(lc(-1,b)){b=lF(x[a+28>>2],32);x[a+76>>2]=b}return b<<24>>24}function ZI(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;x[e>>2]=c;x[h>>2]=f;return 3}function WN(a,b){a=a|0;b=b|0;a=Nj(a);x[a+4>>2]=0;x[a>>2]=47632;x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0;return a|0}function V$(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179468868&(y[a+4|0]-1&255)>>>0<10}function Rs(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=Mx(x[d>>2],g)}ib[x[x[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function Ob(a,b){var c=0;c=fb-16|0;fb=c;XF(c+8|0,a,b);a=Hb(x[x[c+8>>2]>>2],x[c+12>>2]);fb=c+16|0;return a}function Mda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return MO(x[a+4>>2],b,c,d,e,f,g)|0}
function Bl(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return x[b>>2]}function vS(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;Ek(c);continue}break}x[a+4>>2]=b}function q0(a,b){a=xm(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];xm(a+12|0,x[b+12>>2],x[b+16>>2]);return a}function ol(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;x[c+12>>2]=x[c+12>>2]-b;fb=c+16|0;return x[c+12>>2]}function lU(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;uf(c);continue}break}x[a+4>>2]=b}function kz(a,b,c){b=(D(D(iz(a),jz(a,b)),125)>>>0)/(kM(a,b)>>>0)|0;a=(a&6)==6?b&134217724:b;return a?a:c}function dV(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;Ik(c);continue}break}x[a+4>>2]=b}function cea(a){a=a|0;var b=0;b=fb-16|0;fb=b;ee(b+8|0,a);a=Rz(x[b+8>>2],x[b+12>>2]);fb=b+16|0;return a|0}function SE(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;ub(c);continue}break}x[a+4>>2]=b}function QT(a,b,c){var d=E(0);a:{if(b>c){break a}d=B[a>>2];if(!(d<b)){b=c;if(!(d>b)){break a}}B[a>>2]=b}}function Pb(a,b,c){var d=0;c=c+x[a+4>>2]|0;d=b;b=x[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;x[a>>2]=b;x[a+4>>2]=c}function JW(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;vC(c);continue}break}x[a+4>>2]=b}function Ida(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return EO(x[a+4>>2],b,c,d,e,f,g)|0}function xj(a){a:{a=a&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function ev(a,b){b=ova(a,a>>31,b,b>>31);a=hb;b=b+5e5|0;a=b>>>0<5e5?a+1|0:a;return Gc(pva(b,a,1e6,0),hb)}function RT(a,b){var c=0,d=0;a:{if(b<0){break a}c=C[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}C[a>>3]=d}}function EJ(a){var b=0,c=0;b=fb-16|0;fb=b;a=Nh(b+12|0,a);c=x[x[124231]>>2];Mh(a);fb=b+16|0;return c?4:1}function vp(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(Un(a,b+12|0)){c=$b(x[b+12>>2])}fb=b+16|0;return c|0}function Wk(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(Kp(a,b+14|0)){c=Bb(z[b+14>>1])}fb=b+16|0;return c|0}function raa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;U0(c+8|0,b);Gp(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function e_(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=Bb(b&65535),w[d+14>>1]=e;Rv(a,c+14|0);fb=c+16|0}function _v(a){var b=0,c=0;if(x[a>>2]){gp(a);Db(x[a>>2]);b=zb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function ZD(a,b){if(b>>>0<=126){Xe(((b<<5)+a|0)+480280|0);Wo((D(b,872)+a|0)+1074992|0,a,b,134217728)}}function Vv(a){a=a|0;var b=0;w[a+34>>1]=0;b=a+43|0;Wm(b,b+22|0,78784);x[a+20>>2]=0;ld(a,0);return a|0}function Tb(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function NV(a){if(((y[a+68|0]|y[a+69|0]<<8)-128&65535)>>>0>=65409){a=kd(a,18296,17)}else{a=1}return!a}function H2(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;c=-1;if(PG(a,b+8|0)){c=OG(b+8|0)}fb=b+32|0;return c|0}function GS(a){a=Fb(a);Fb(a+12|0);Fb(a+24|0);Fb(a+36|0);Fb(a+48|0);Fc(a+60|0,0);x[a+64>>2]=0;return a}function $1(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=-1;if(rk(a,b+8|0)){c=iG(b+8|0)}fb=b+16|0;return c|0}function uf(a){var b=0,c=0;b=fb-16|0;fb=b;a=x[vb(b+12|0,a)>>2];c=x[a>>2];if(c){zb(a);Db(c)}fb=b+16|0}function gl(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function cra(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Kp(a,b+14|0);fb=b+16|0;return(a?z[b+14>>1]:0)<<16>>16}function VH(a,b,c){var d=0;d=fb-16|0;fb=d;c=Dc(d+4|0,c);a=pc(a,c);tb(c);x[a>>2]=b;fb=d+16|0;return a}function PV(a){ie(a+140|0);ub(a+120|0);ub(a+100|0);ub(a+80|0);ub(a+60|0);ub(a+40|0);ub(a+20|0);ub(a)}function Mia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=Fj(a);if(a){ib[x[x[a>>2]+88>>2]](a,b,c,d,e)}}function L1(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;Mn(c+8|0,b);Gp(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function K1(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;Fc(a+8|0,0);$r(a,127);LF(a,127,y[b|0]);return a|0}function IZ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){HZ(c+52|0);tb(c+40|0);uc(c+16|0);uc(c+4|0);Db(c)}}function Hg(a,b,c){var d=0;d=x[a>>2];c=x[a+4>>2]-(c+(d>>>0<b>>>0)|0)|0;b=d-b|0;x[a>>2]=b;x[a+4>>2]=c}function DS(a){x[a+20>>2]=0;v[a+16|0]=7;x[a+8>>2]=1889785610;x[a+12>>2]=1072630333;v[a|0]=3;return a}function DE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0}function qea(a,b){a=a|0;b=b|0;var c=0;b=Kb(b);c=x[a+4>>2];if(c){ib[c|0](b,x[a+8>>2]);return}ju(b,a)}function oU(a,b,c){var d=0;d=fb-16|0;fb=d;a=x[vb(d+12|0,gU(b,c,ce(a),ec(a)))>>2];fb=d+16|0;return a}function iJ(a,b,c){a:{if(!(y[b+120|0]|c>>>0>30)){v[b+120|0]=1;break a}b=IY(c)}x[a+4>>2]=c;x[a>>2]=b}function hS(a,b){if(b>>>0<=255){a=x[((b<<2)+a|0)+900380>>2];a=a?a+492|0:22255}else{a=22255}return a}function fi(a,b,c){var d=0;d=x[a+4>>2];while(1){if((b|0)!=(d|0)){d=d-c|0;continue}break}x[a+4>>2]=b}function ey(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=Nh(f+12|0,e);a=yt(a,b,c,d);Mh(e);fb=f+16|0;return a}function _c(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];QG(b);return a}function Iia(a,b,c){a=a|0;b=b|0;c=c|0;a=Fj(a);if(!a){return 0}return ib[x[x[a>>2]+104>>2]](a,b,c)|0}function Hi(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=Nh(f+12|0,e);a=DK(a,b,c,d);Mh(e);fb=f+16|0;return a}function HF(a,b,c,d,e,f,g){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e);vb(a+16|0,f);vb(a+20|0,g)}function Lw(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=gh(a,b+15|0);fb=b+16|0;return(a?y[b+15|0]:0)<<24>>24}function sR(a,b){var c=0;c=fb-16|0;fb=c;a=we(c+8|0,a,b);b=x[a>>2];fb=c+16|0;hb=x[a+4>>2];return b}function lw(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=Dc(c+4|0,b);_c(d,a);tb(a);fb=c+16|0}function ig(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=tc(c+4|0,b);_c(d,a);tb(a);fb=c+16|0}function ct(a,b){a=a|0;b=b|0;b=x[b+68>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function ZJ(a,b){a=a|0;b=b|0;b=x[b+64>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function Ura(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Un(a,b+12|0);fb=b+16|0;return E(a?B[b+12>>2]:E(0))}function UJ(a,b){a=a|0;b=b|0;b=x[b+72>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function Rea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return cI(a,b,c,d,e,f,10648,1081)|0}function Od(){var a=0;if(y[500372]){return x[125092]}a=Bk(14276);v[500372]=1;x[125092]=a;return a}function Fba(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=x[yf(b+12|0,$l(Ec(12),a))>>2];fb=b+16|0;return a|0}function Efa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return cI(a,b,c,d,e,f,10693,1054)|0}function nz(a,b,c,d){var e=0;e=fb-16|0;fb=e;bc(e+8|0,c,d);WM(a,b,x[e+8>>2],x[e+12>>2]);fb=e+16|0}function eva(a,b){a=a|0;b=b|0;if(!zE(a,b)){v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b|0]=0}}function Yz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Y9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+24>>2]](a,b,c,d,e,f)|0}function X9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f)|0}function W9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+28>>2]](a,b,c,d,e,f)|0}function V9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0}function U9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+44>>2]](a,b,c,d,e,f)|0}function Sm(a,b,c,d){var e=0;e=fb-16|0;fb=e;mf(e+8|0,c,d);WM(a,b,x[e+8>>2],x[e+12>>2]);fb=e+16|0}function MD(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=x[K_(c+12|0,0-b|0)>>2];fb=c+16|0;return a}function wka(a,b){a=a|0;b=b|0;Si(a);Si(a);a:{if(b>>>0>=60){Vb(a,4);break a}Si(a)}return Si(a)|0}function Xw(a,b){a=bG(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];bG(a+12|0,x[b+12>>2],x[b+16>>2])}function WX(a){var b=0,c=0;b=1;c=x[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}x[a>>2]=b}}function Sca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;sP(a,x[b+4>>2],c,d,e,f,g)}function S2(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;VI(d,b);Sh(a,d);tb(d);fb=c+16|0}function Nca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;PO(a,x[b+4>>2],c,d,e,f,g)}function L0(a,b){a=a|0;b=b|0;if(!zE(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0}}function K3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(oh(a,x[b+8>>2],f)){Px(b,c,d,e)}}function F9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[b>>2]+16>>2]](a,b,x[c+8>>2],x[c+12>>2],0,d)}function eX(a){var b=0,c=0;b=fb-16|0;fb=b;if($E(a,b+12|0)){c=$b(x[b+12>>2])}fb=b+16|0;return c}function a0(a){var b=0;if(!(kd(a,24692,20)|(y[a+25|0]-9&255)>>>0<248)){b=v[a+47|0]>=0}return b}function Zd(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=gh(a,b+15|0);fb=b+16|0;return(a?y[b+15|0]:0)&255}function RL(a){var b=0;b=+((a&2097151)>>>0);return E(tk(+E((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function Q$(a,b){return(Yb((D(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Yb((D(a&15,b)>>>0)/15|0,1,15))&255}function Jca(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;rP(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function JD(a){var b=0,c=0;b=fb-16|0;fb=b;if(Kp(a,b+14|0)){c=xe(w[b+14>>1])}fb=b+16|0;return c}function Ica(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;OO(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function Fx(a,b,c,d){var e=0;x[a>>2]=x[b>>2];e=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<d)+e;return a}function EK(a){var b=0;b=x[124231];if(a){x[124231]=(a|0)==-1?500180:a}return(b|0)==500180?-1:b}function pt(a){return y[(a>>>3&31|y[(a>>>8|0)+107520|0]<<5)+107520|0]>>>(a&7)&1&a>>>0<=131071}function kZ(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1279544644&y[a+4|0]<32}function Zs(a){a=a|0;var b=0;x[a>>2]=112060;b=x[a+8>>2];if(!(!b|!y[a+12|0])){Db(b)}return a|0}function Wm(a,b,c){b=b-a|0;while(1){if((b|0)>0){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function Vm(a){a=a|0;var b=0;x[a>>2]=47652;b=x[a+4>>2];if(b){Db(Bq(b))}x[a+4>>2]=0;return a|0}function Mqa(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;c=a;a=bi(b+12|0);GY(c,a,0,0);ub(a);fb=b+32|0}function Mca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fu(x[x[a+4>>2]+24>>2],b,c,d,e)|0}function Ic(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=F_(a,b,x[c>>2],d)}else{a=1}return!a}function GW(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=D(c,12)+d;return a}function rA(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;KY(b+12|0,-1);fb=b+16|0;return x[b+12>>2]}function nE(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;i0(b+12|0,-1);fb=b+16|0;return x[b+12>>2]}function jV(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=x[iV(c+12|0,b)>>2];fb=c+16|0;return a}function R9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return ib[x[x[a>>2]+32>>2]](a,b,c,d,e)|0}function Pe(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=x[TU(c+12|0,b)>>2];fb=c+16|0;return a}function IC(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(x[b>>2]){continue}break}return b-a>>2}function z0(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==810369604&y[a+4|0]<4}function wJ(a,b){a=xd(a,b);v[a+12|0]=0;x[a+8>>2]=0;x[a>>2]=112060;x[a+8>>2]=112112;return a}function sB(a){var b=0;x[a+84>>2]=0;x[a+88>>2]=0;b=x[a+80>>2];x[a+92>>2]=b;x[a+96>>2]=b<<12}function mqa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=ai(a,b+8|0);fb=b+16|0;return+(a?C[b+8>>3]:0)}function j5(a,b){a=a|0;b=b|0;a=xd(a,0);TI(a+8|0,b);x[a>>2]=117092;x[a>>2]=117376;return a|0}function ih(a){var b=0;b=fb-16|0;fb=b;a=Kp(a,b+14|0);fb=b+16|0;return(a?z[b+14>>1]:0)&65535}function h5(a,b){a=a|0;b=b|0;a=xd(a,0);TI(a+8|0,b);x[a>>2]=117248;x[a>>2]=117492;return a|0}function gg(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){ZD(a,c);b=b+1|0;continue}break}}function fy(a,b,c){var d=0;d=fb-16|0;fb=d;c=Nh(d+12|0,c);a=Xy(a,b);Mh(c);fb=d+16|0;return a}function UE(a){var b=0;b=x[a>>2];if(x[b>>2]){SE(b,x[b>>2]);a=x[a>>2];b=x[a>>2];TE(a);Db(b)}}function ON(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=DN(d);b=b+1|0}QU(a,b,c,d,e)}function Nga(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;Gz(a,b,c,d,e,0,0,f,g)}function LD(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=0;Bu(b+12|0,a);fb=b+16|0;return x[b+12>>2]}function GF(a,b){if((a&4088)>>>0>=520){b=Ow(0-rva(b^1230262859,25)|0,4)^1247037516}return b}function sL(a){var b=0;b=x[a>>2];if(b){if(!lc(tL(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function mx(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=x[(b<<2)+22264>>2]}else{b=9742}tc(a,b)}function fQ(a,b){var c=0;c=x[a+12>>2];if((c|0)>0){x[a+20>>2]=(x[a+16>>2]+(b+c|0)|0)%(c|0)}}function bG(a,b,c){var d=0;d=fb-16|0;fb=d;b=xm(d+8|0,b,c);FG(b,a);ke(b);fb=d+16|0;return a}function Oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Fj(a);if(a){ib[x[x[a>>2]+76>>2]](a,b,c,d)}}function Nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Fj(a);if(a){ib[x[x[a>>2]+84>>2]](a,b,c,d)}}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Fj(a);if(a){ib[x[x[a>>2]+92>>2]](a,b,c,d)}}function Gm(a,b,c){var d=E(0);if(b>>>0<=c>>>0){d=B[yb(a+4208|0,b)>>2]}else{d=E(0)}return d}function Eh(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function xq(a){a=a|0;var b=0;x[a>>2]=47632;b=x[a+4>>2];if(b){Db(b);x[a+4>>2]=0}return a|0}function rva(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function ox(){var a=0,b=0;a=fb-16|0;fb=a;b=yf(a+12|0,Nb(Ec(12)));fb=a+16|0;return x[b>>2]}function lA(a,b){if((a|0)>=0){return(a>>>0)%(b>>>0)|0}return(((a^-1)>>>0)%(b>>>0)^-1)+b|0}function is(a){var b=0;while(1){if(!lc(y[a|0],0)){a=a+1|0;b=b+1|0;continue}break}return b}function iF(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;hb=b>>>0<2624?a+1|0:a;return b}function c3(a,b,c){a=a|0;b=b|0;c=c|0;ib[x[x[b>>2]+8>>2]](b,c);Ds(a,x[b+4>>2]);bH(b+4|0,c)}function Nl(a,b,c){a=a+1074992|0;return x[(a+D(b,872)|0)+680>>2]>x[(a+D(c,872)|0)+680>>2]}function KU(a,b,c){while(1){if((b|0)!=(c|0)){IU(a,y[b|0]);b=b+1|0;continue}break}return a}function I$(a,b,c){var d=0;d=fb-16|0;fb=d;xi(d+8|0,b,c);fb=d+16|0;return x[d+8>>2]==(a|0)}function Hy(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;a=wt(a,b,c,d);fb=e+16|0;return a}function zn(a){var b=0;if(a>>>0>=2){b=OY(a+1|0);a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function tJ(a,b){a=xd(a,b);x[a+8>>2]=46;x[a+12>>2]=44;x[a>>2]=113352;Fb(a+16|0);return a}function on(a,b){var c=0;c=fb-16|0;fb=c;a=x[vb(c+12|0,(b<<1)+a|0)>>2];fb=c+16|0;return a}function oJ(a,b){a=xd(a,b);b=a+8|0;x[b>>2]=121044;x[a>>2]=116028;x[b>>2]=116076;return a}function nJ(a,b){a=xd(a,b);b=a+8|0;x[b>>2]=121080;x[a>>2]=116292;x[b>>2]=116340;return a}function iw(a,b){var c=0;c=fb-16|0;fb=c;a=x[vb(c+12|0,D(b,6)+a|0)>>2];fb=c+16|0;return a}function eT(a,b){var c=0;c=y[a+851|0];if(c&1){v[a+851|0]=c|64;x[a+852>>2]=x[a+852>>2]+b}}function XB(a,b){a=$l(a,b);_c(a+12|0,b+12|0);w[a+28>>1]=z[b+28>>1];x[a+24>>2]=x[b+24>>2]}function Qia(a,b){a=a|0;b=b|0;a=Fj(a);if(!a){return 1}return ib[x[x[a>>2]+68>>2]](a,b)|0}function OX(a,b){var c=0;c=fb-16|0;fb=c;Mn(c+8|0,b);BZ(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function ES(a){var b=0;b=a+4e4|0;while(1){b=UA(b-160|0);if((b|0)!=(a|0)){continue}break}}function $t(a){if(bN(a)){a=ac(4);x[a>>2]=0;a=Nj(a);x[a>>2]=124524;da(a|0,124560,34);p()}}function zD(a){var b=0;b=EV(a);while(1){if((a|0)!=(b|0)){o0(a);a=a+32|0;continue}break}}function yC(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=c+d;return a}function ws(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=DN(d);b=b+1|0}HB(a,b,c,d)}function m2(a){a=a|0;var b=0;b=x[a+4>>2];return(ib[x[x[b>>2]+20>>2]](b)|0)+x[a+12>>2]|0}function im(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+15|0]=c;Vh(a,b,d+15|0);fb=d+16|0;return a}function iL(a){var b=0;b=x[a>>2];if(b){if(!po(Bl(b))){return!x[a>>2]}x[a>>2]=0}return 1}function ch(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;return a}function Qea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return bI(a,b,c,d,e,12433,1082)|0}function Nv(a,b,c){var d=E(0);d=B[a>>2];if(!Mv(d,B[b>>2])){b=Mv(B[c>>2],d)?c:a}return b}function Lq(a,b,c){a=Ql(a)-x[a+16>>2]|0;if(a>>>0>=2){c=E(E(E(c-b)/E(a>>>0))+b)}return c}function LK(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a=MK(a,11188,b);fb=c+16|0;return a}function Dfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return bI(a,b,c,d,e,12533,1055)|0}function Bm(a){var b=0;b=hx(a+4|0);if((b|0)==-1){ib[x[x[a>>2]+8>>2]](a)}return(b|0)==-1}function zc(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;Mn(d,a);um(d,b);fb=c+16|0;return a}function laa(a,b){a=a|0;b=b|0;a=z[a>>1];b=z[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function kaa(a,b){a=a|0;b=b|0;a=x[a>>2];b=x[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function ju(a,b){a=a|0;b=b|0;b=fb-16|0;fb=b;x[b>>2]=a;GP(18447,b);iu(125936);fb=b+16|0}function X5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[x[x[b>>2]+16>>2]](a,b,c,d,e,8)}function TV(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;hb=b>>>0<259?a+1|0:a;return b}function R2(){var a=0;a:{if(YG(19989250)){break a}if(XG()){break a}a=WG()^1}return a|0}function OU(a,b){return(a>>>0<=62?63-(D((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function Nea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return YH(a,b,c,d,e,9626,1085)|0}function Gea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return YH(a,b,c,d,e,9698,1092)|0}function GG(a,b){var c=0;c=fb-16|0;fb=c;b=Ef(c+8|0,b);FG(b,a);ke(b);fb=c+16|0;return a}function EE(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;v[c+15|0]=b;xw(a,c+15|0);fb=c+16|0}function A0(a,b,c){v[a+2|0]=1;b=b&15;if(c){b=y[b+24640|0]}else{b=(b<<2)+4|0}v[a+4|0]=b}function xv(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function s8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return KH(b,c,d,e,f,1)|0}function q8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return KH(b,c,d,e,f,0)|0}function q6(a){a=a|0;a=501656;while(1){a=tb(a-12|0);if((a|0)!=501632){continue}break}}function p6(a){a=a|0;a=501312;while(1){a=tb(a-12|0);if((a|0)!=501024){continue}break}}function o6(a){a=a|0;a=500840;while(1){a=tb(a-12|0);if((a|0)!=500672){continue}break}}function kJ(a){var b=0;b=x[a>>2];if(x[b>>2]){Nf(b);a=x[a>>2];cy(jq(a),x[a>>2],Ug(a))}}function Y5(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+97936>>2]}return b<<24>>24}function Wg(a,b,c){var d=0;d=fb-16|0;fb=d;BY(d+8|0,a,b,c);fb=d+16|0;return x[d+12>>2]}function V5(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+96400>>2]}return b<<24>>24}function QJ(a,b){var c=0,d=0;Te(a,le(b));b=ec(b);c=ec(a),d=x[b>>2],x[c>>2]=d;return a}function Nu(a,b){if(!(v[b+851|0]&1&x[a+480180>>2]==8)){IA(a,b,0);IA(a,b,1);IA(a,b,2)}}function Kv(a,b){var c=0;c=fb-16|0;fb=c;w[c+14>>1]=b;Hv(a+236|0,128,c+14|0);fb=c+16|0}function JK(a){return(a|0)!=0&(a|0)!=121484&(a|0)!=121508&(a|0)!=500096&(a|0)!=500120}function E6(a){a=a|0;a=501688;while(1){a=Qb(a-12|0);if((a|0)!=501664){continue}break}}function D6(a){a=a|0;a=501616;while(1){a=Qb(a-12|0);if((a|0)!=501328){continue}break}}function C8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return MH(b,c,d,e,f,1)|0}function C6(a){a=a|0;a=501016;while(1){a=Qb(a-12|0);if((a|0)!=500848){continue}break}}function A8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return MH(b,c,d,e,f,0)|0}function zga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return DP(a,b,c,d,0,0,0,0,e)|0}function uC(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function pia(a,b){a=a|0;b=b|0;return E(b>>>0<=2?E(E(y[(a+b|0)+4232|0])/E(127)):E(0))}function lf(a){a=a|0;var b=0;b=x[a>>2];return(ib[x[x[b>>2]+24>>2]](b)|0)-x[a+8>>2]|0}function lW(a,b,c,d,e,f){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e);vb(a+16|0,f)}function ija(a,b){a=a|0;b=b|0;return E(b>>>0<=3?E(E(y[(a+b|0)+4264|0])/E(255)):E(0))}function hk(a,b,c){var d=0;d=x[a>>2];if(!dr(d,x[b>>2])){b=dr(x[c>>2],d)?c:a}return b}function gy(a){a=a|0;x[a>>2]=113264;if(x[a+8>>2]!=(Od()|0)){xl(x[a+8>>2])}return a|0}function Yg(a,b,c){var d=0;d=C[a>>3];if(!OV(d,C[b>>3])){b=OV(C[c>>3],d)?c:a}return b}function Pg(a){var b=0;b=fb-16|0;fb=b;a=Un(a,b+12|0);fb=b+16|0;return a?x[b+12>>2]:0}function Nda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return KO(x[a+4>>2],b,c,d,e)|0}function Kda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return DO(x[a+4>>2],b,c,d,e)|0}function Jo(a){var b=0;b=a;a=x[a>>2];x[b>>2]=D(a,214013)+2531011;return a>>>16&32767}function I4(a,b,c){a=a|0;b=b|0;c=c|0;a=Tx(b,x[a+8>>2]);return((a|0)==-1?c:a)<<24>>24}function He(a,b,c){if(yp(a,b,c)){a=hj(a,c);a=Ib(x[a>>2],x[a+4>>2])}else{a=0}return a}function zW(a){var b=0;b=x[a>>2];if(x[b>>2]){cW(b);a=x[a>>2];b=x[a>>2];iv(a);Db(b)}}function y7(a){a=a|0;kq(x[a+8>>2]);a=x[a+8>>2];if(!a){return 1}return(EJ(a)|0)==1|0}function pq(a){a=a|0;x[a+56>>2]=94176;x[a>>2]=94156;Dt(a+4|0);Dl(a+56|0);return a|0}function k0(a,b,c){a=a|0;b=b|0;c=c|0;return j0(a,b,Kb(c),Cb(x[c+4>>2],y[c+11|0]))|0}function jz(a,b){return y[(D(a>>>1&3,15)+D(a>>>3&1,45)+((b&240)>>>4)|0)+81137|0]<<1}function jU(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ec(a)+4|0]){kU(b+16|0)}Db(b)}}function hm(a,b){var c=0,d=0,e=0;c=x[a+24>>2];d=a,e=_e(Di(b)*+(c>>>0)),x[d+24>>2]=e}function ge(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=48616;Ac(a,48512,b+12|0);fb=b+16|0}function gR(a){var b=0;b=x[a>>2];if(x[b>>2]){Nf(b);a=x[a>>2];b=x[a>>2];Ug(a);Db(b)}}function aja(a){a=a|0;v[a+4202|0]=1;x[a+4232>>2]=x[x[a+16>>2]+24620>>2];ru(a);PQ(a)}function Yk(a,b){var c=0;c=fb-16|0;fb=c;a=x[vb(c+12|0,a+b|0)>>2];fb=c+16|0;return a}function TF(a){var b=0;b=x[a>>2];if(x[b>>2]){lj(b);a=x[a>>2];b=x[a>>2];Pn(a);Db(b)}}function TA(a){var b=0;b=fb-16|0;fb=b;vb(b+12|0,a+116|0);a=uS(a);fb=b+16|0;return a}function PR(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ec(a)+4|0]){Eb(b+16|0)}Db(b)}}function M$(a){var b=0;b=x[a>>2];if(x[b>>2]){L$(b);a=x[a>>2];b=x[a>>2];cw(a);Db(b)}}function JG(a){var b=0;b=x[a>>2];if(x[b>>2]){IG(b);a=x[a>>2];b=x[a>>2];Zn(a);Db(b)}}function Ff(a){a=a|0;x[a+60>>2]=94340;x[a>>2]=94320;Dt(a+8|0);Dl(a+60|0);return a|0}function Ef(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0;return a}function EZ(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ec(a)+4|0]){Zj(b+16|0)}Db(b)}}function Dha(a){a=a|0;v[a+4202|0]=1;x[a+4256>>2]=x[x[a+16>>2]+24620>>2];jQ(a);hQ(a)}function xT(a,b){var c=0;c=b&15;if(c){v[a+830|0]=c}b=b&240;if(b){v[a+829|0]=b>>>4}}function q7(){var a=0,b=0,c=0;a=xd(501744,1);x[a>>2]=113264;b=a,c=Od(),x[b+8>>2]=c}function jv(a,b){a=Bb(a&65535);b=Bb(b&65535);return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function aq(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<d);return a}function _p(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,d);return a}function VL(a,b){b=x[a+32>>2]+b|0;x[a+32>>2]=b;if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1}}function xM(a,b){a=Wn(a);v[a+8|0]=0;x[a+4>>2]=b;x[a>>2]=77372;Nb(a+12|0);return a}function rg(a){var b=0;b=fb-16|0;fb=b;a=x[vb(b+12|0,ec(a))>>2];fb=b+16|0;return a}function oea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ms(a,b,c,d,e,1107)|0}function mea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ms(a,b,c,d,e,1109)|0}function lea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ms(a,b,c,d,e,1111)|0}function hR(a,b,c){while(1){if(b){B[a>>2]=B[c>>2];b=b-1|0;a=a+4|0;continue}break}}function bp(a,b){a=yc(a,b,34);w[a+34>>1]=z[b+34>>1];yc(a+36|0,b+36|0,68);return a}function UV(a){if((y[a+14|0]-53&255)>>>0>=252){a=kd(a,15612,14)}else{a=1}return!a}function Rf(a){var b=0;b=fb-16|0;fb=b;a=x[vb(b+12|0,rg(a))>>2];fb=b+16|0;return a}function Ns(a,b,c,d){if(b>>>0>=d>>>0){bk();p()}c=Ec(D(b,c));x[a+4>>2]=b;x[a>>2]=c}function JF(a,b,c){while(1){if(b){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Hv(a,b,c){while(1){if(b){w[a>>1]=z[c>>1];b=b-1|0;a=a+2|0;continue}break}}function GP(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;GL(125936,a,b,0,0);fb=c+16|0}function Fda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fI(a,b,c,d,e,1122)|0}function $i(a){var b=0;b=fb-16|0;fb=b;a=x[vb(b+12|0,wb(a))>>2];fb=b+16|0;return a}function tO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ls(a,b,c,d,e,1106)|0}function qO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ls(a,b,c,d,e,1108)|0}function pO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ls(a,b,c,d,e,1110)|0}function p3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ib[a|0](b,c,d)|0;gb=hb;return a|0}function oO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ls(a,b,c,d,e,1026)|0}function i6(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<2)+112112>>2]&b)!=0&c>>>0<=127}function gga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ms(a,b,c,d,e,1e3)|0}function gO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Hx(a,b,c,d,e,1107)|0}function fO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Is(a,b,c,d,e,1107)|0}function eO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Hx(a,b,c,d,e,1109)|0}function dO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Is(a,b,c,d,e,1109)|0}function cY(a){var b=0;while(1){if((b|0)!=512){fh(a+b|0);b=b+1|0;continue}break}}function cO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Hx(a,b,c,d,e,1111)|0}function bO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Is(a,b,c,d,e,1111)|0}function Vk(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;ic(a+8|0,b+8|0)}function EM(a){a=Wn(a);x[a>>2]=77836;Nb(a+4|0);v[a+20|0]=0;x[a+16>>2]=0;return a}function BP(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fI(a,b,c,d,e,1001)|0}function s3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[a|0](b,c,d,e,f)}function qg(a){var b=0,c=0;sc(a+4|0);Fc(a+8|0,0);b=a,c=ec(a),x[b>>2]=c;return a}function mca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return AN(a-88|0,b,c,d,e)|0}function lS(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;HC(d,1,b);Cc(a,d);fb=c+16|0}function l$(a,b,c){while(1){if(b){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function eg(a){var b=0;b=xb(a,2);return y[xb(a,1)|0]<<8|y[b|0]<<16|y[xb(a,0)|0]}function aO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Is(a,b,c,d,e,1e3)|0}function Qb(a){var b=0;if(Cd(y[a+11|0])){b=x[a>>2];ej(x[a+8>>2]);Db(b)}return a}function PJ(){var a=0;a=fb-16|0;x[a+8>>2]=0;x[a+12>>2]=1048576;return C[a+8>>3]}function Msa(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,pZ(b,Kb(c),Cb(x[c+4>>2],y[c+11|0])))}function M6(a){a=a|0;if(!y[500624]){Bn(500612,113580);v[500624]=1}return 500612}function K6(a){a=a|0;if(!y[500656]){Bn(500644,113664);v[500656]=1}return 500644}function Id(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;xn(a,b,d+12|0);fb=d+16|0}function Iaa(a){a=a|0;a=x[a+24>>2];return vM(x[(x[x[a>>2]-12>>2]+a|0)+16>>2])^1}function IU(a,b){var c=0;c=a;a=x[a>>2];x[c>>2]=a<<8^x[((a>>>24^b)<<2)+27564>>2]}function I6(a){a=a|0;if(!y[500560]){Bn(500548,113508);v[500560]=1}return 500548}function Gx(a,b,c,d){if(b>>>0>=d>>>0){bk();p()}c=Ec(b<<c);x[a+4>>2]=b;x[a>>2]=c}function G6(a){a=a|0;if(!y[500592]){Bn(500580,113544);v[500592]=1}return 500580}function FH(a,b){x[a>>2]=b;Qb(a+52|0);Qb(a+40|0);Qb(a+28|0);tb(a+16|0);return a}function EH(a,b){x[a>>2]=b;tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);return a}function Bx(a,b){b=a+b|0;while(1){b=tb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Ai(a){return(qk(x[a>>2],x[a+4>>2])|0)!=(0-qk(x[a+12>>2],x[a+16>>2])|0)}function y6(a){a=a|0;if(!y[500608]){Dc(500596,13617);v[500608]=1}return 500596}function s6(a){a=a|0;if(!y[500576]){Dc(500564,13766);v[500576]=1}return 500564}function mda(a,b){a=a|0;b=b|0;a=x[a+4>>2];return TO(x[a+24>>2],B[a+48>>2],b)|0}function m3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ib[a|0](b,c,d,e)|0}function lD(a){var b=0;while(1){if((b|0)!=4){fh(a+b|0);b=b+1|0;continue}break}}function f$(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[zb(a)>>2]){lM(a,b);return}fM(a,b)}function ap(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0}function Z4(a,b){a=a|0;b=b|0;a=Nj(a);x[a>>2]=125052;Sx(a+4|0,Kb(b));return a|0}function Z3(a,b,c){a=a|0;b=b|0;c=c|0;if(!y[502192]){v[502192]=1}gc(a,c,126380)}function Uw(a,b){var c=0;if((b|0)<0){bk();p()}c=Ec(b<<1);x[a+4>>2]=b;x[a>>2]=c}function IE(a,b){return _e(Di((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function DA(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[zb(a)>>2]){mS(a,b);return}oA(a,b)}function ze(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;Pw(d,a);um(d,b);fb=c+16|0}function zB(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Tl(Tl(c,a),D(a,-100)+b|0)}function yB(a){var b=0;if(!(y[a+2|0]|(y[a|0]|y[a+1|0]))){b=!y[a+3|0]}return b}function xB(a,b){var c=0;c=a;a=(b>>>0)/1e4|0;return zB(Tl(c,a),D(a,-1e4)+b|0)}function wb(a){var b=0;b=fb-16|0;fb=b;a=x[vb(b+12|0,a)>>2];fb=b+16|0;return a}function w6(a){a=a|0;if(!y[500640]){Dc(500628,9253);v[500640]=1}return 500628}function uJ(a,b){a=xd(a,b);w[a+8>>1]=11310;x[a>>2]=113312;Fb(a+12|0);return a}function u6(a){a=a|0;if(!y[500544]){Dc(500532,5265);v[500544]=1}return 500532}function tf(a){if(Cd(y[a+11|0])){fd(x[a>>2],0);Yd(a,0);return}fd(a,0);Me(a,0)}function pm(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;U0(d,a);um(d,b);fb=c+16|0}function oS(a,b){a=a|0;b=b|0;if(A[a+4>>2]<A[zb(a)>>2]){mS(a,b);return}oA(a,b)}function hA(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function gA(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function bU(a){x[a>>2]=0;x[a+4>>2]=0;x[a>>2]=-2078137563;x[a+4>>2]=-873292572}function Yba(a,b){a=a|0;b=b|0;Jn(x[a+4>>2]);kG(pG(x[a+4>>2],b));Jn(x[a+4>>2])}function Ru(a,b){var c=0;c=a;a=(b>>>0)/1e6|0;return xB(Tl(c,a),D(a,-1e6)+b|0)}function P3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(oh(a,x[b+8>>2],0)){Nx(b,c,d)}}function Mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ao(a,b,c,d,12934,1086)|0}function Kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ao(a,b,c,d,13008,1088)|0}function Jj(a){if(Ob(a+1074312|0,7)){a=En(x[a+480180>>2])^1}else{a=0}return a}function Fha(a,b){a=a|0;b=b|0;return E(b>>>0<=4?B[((b<<2)+a|0)+4220>>2]:E(0))}function Aj(a,b,c){if(x[a+80>>2]){x[a+92>>2]=x[a+92>>2]+(c+7&-8);return}Db(b)}function $j(a){var b=0;b=fb-16|0;fb=b;a=x[yf(b+12|0,a)>>2];fb=b+16|0;return a}function rK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+32>>2]](a,b,c,d)|0}function mK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+48>>2]](a,b,c,d)|0}function fe(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+8>>2];Vb(b,c);kx(a,b,d,c)}function aT(a,b,c){var d=0;return!b|!(y[a+35|0]&4?!a|(c|0)!=1:1)?d:y[b+34|0]}function Pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ao(a,b,c,d,9420,1083)|0}function Lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ao(a,b,c,d,9581,1087)|0}function Jea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ao(a,b,c,d,9659,1089)|0}function Iea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ao(a,b,c,d,9451,1090)|0}function $e(a){var b=0;b=fb-16|0;fb=b;Tn(b+8|0,a);fb=b+16|0;return x[b+8>>2]}function zQ(a){a=a|0;x[a>>2]=44748;uc(a+4276|0);uc(a+4264|0);return ag(a)|0}function z9(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){cL(a,c);return}Dc(a,7920)}function u8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return LH(b,c,d,e,1)|0}function rC(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function r8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return LH(b,c,d,e,0)|0}function kM(a,b){a=a^-1;return x[(b&12)+81140>>2]>>>(a>>>3&1)>>>(a>>>4&1)|0}function h_(a){var b=0;while(1){b=a;a=x[a>>2];if(a){continue}break}return b}function fL(a,b,c,d,e,f,g,h){return ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function e6(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+97936>>2]}return b|0}function c6(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+96400>>2]}return b|0}function am(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+c;return a}function Gh(a,b){var c=0;c=a;a=x[a+8>>2];b=a-b|0;x[c+8>>2]=a>>>0>=b>>>0?b:0}function FU(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);yU(a,b,0,0,b+-1,0)}function E8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return NH(b,c,d,e,1)|0}function B8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return NH(b,c,d,e,0)|0}function hi(a,b,c){x[a+8>>2]=b;x[a+12>>2]=c;x[a>>2]=0;x[a+4>>2]=0;return a}function a4(a,b,c){a=a|0;b=b|0;c=c|0;return lc(a,x[b+4>>2])&x[b>>2]==(c|0)}function Tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return JO(x[a+4>>2],b,c,d)|0}function Sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return HO(x[a+4>>2],b,c,d)|0}function Qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return IO(x[a+4>>2],b,c,d)|0}function Pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return GO(x[a+4>>2],b,c,d)|0}function Oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return NO(x[a+4>>2],b,c,d)|0}function Lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return FO(x[a+4>>2],b,c,d)|0}function Kk(a){var b=0;b=z[a+172>>1];a=z[a+156>>1];return(QV(a)?b:a)&65535}function Cia(a,b){a=a|0;b=b|0;a=x[a+20>>2];v[a+24|0]=y[a+24|0]&253|(b?2:0)}function AG(a,b){a=a|0;b=b|0;a=Nj(a);x[a>>2]=125052;Sx(a+4|0,b);return a|0}function zj(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+12>>2]](a,b,c)|0}function zG(a,b){a=Ef(a,b);x[a+8>>2]=x[b+8>>2];Ef(a+12|0,b+12|0);return a}function up(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+48>>2]](a,b,c)|0}function uc(a){var b=0;b=fb-16|0;fb=b;gR(vb(b+12|0,a));fb=b+16|0;return a}function tz(a,b){var c=0,d=0;c=vb(a,x[x[b>>2]-12>>2]+b|0),d=b,x[c+4>>2]=d}function pG(a,b){a=a|0;b=b|0;return AF(a,Kb(b),Cb(x[b+4>>2],y[b+11|0]))|0}function osa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Cp(a,b),x[d>>2]=e}function nsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Kw(a,b),w[d>>1]=e}function nY(a,b){v[a+6|0]=255;x[a+16>>2]=b;w[a+4>>1]=0;x[a>>2]=0;return a}function hd(a,b){a=GG(a,b);x[a+8>>2]=x[b+8>>2];GG(a+12|0,b+12|0);return a}function dc(a){var b=0;b=fb-16|0;fb=b;NZ(vb(b+12|0,a));fb=b+16|0;return a}function Xc(a,b,c,d,e){v[a+3|0]=e;v[a+2|0]=d;v[a+1|0]=c;v[a|0]=b;return a}function Mb(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+32>>2]](a,b,c)|0}function Kb(a){var b=0,c=0,d=0;return b=x[a>>2],c=a,d=Cd(y[a+11|0]),d?b:c}function IF(a,b){while(1){if(b){x[a>>2]=0;b=b-1|0;a=a+4|0;continue}break}}function zL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;hi(a,-1,-1)}function Rm(a,b){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function Jy(a,b){var c=0;c=Ot(a+4|0);x[a>>2]=94968;x[c>>2]=94988;to(c,b)}function Iy(a,b){var c=0;c=WK(a+4|0);x[a>>2]=95336;x[c>>2]=95356;to(c,b)}function wpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;kH(a,b,c,d,e,135)}function uQ(a){a=a|0;return E(E(E(B[yb(a+4208|0,5)>>2]*E(198))+E(-99)))}function qc(a,b){var c=0,d=0;x[a>>2]=b;c=a,d=Cf(b),x[c+4>>2]=d;return a}function kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Js(a,b,c,d,1113)|0}function jea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Js(a,b,c,d,1115)|0}function hq(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[e>>2]=c;return 3}function hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Js(a,b,c,d,1117)|0}function gea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Js(a,b,c,d,1119)|0}function dE(a,b,c){var d=0;d=(b|0)/(c|0)|0;x[a>>2]=d;x[a+4>>2]=b-D(c,d)}function az(a){return((Ph(a)+(Ph(a)<<8)|0)+(Ph(a)<<16)|0)+(Ph(a)<<24)|0}function XU(a,b){x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=b?b:49716;x[a+12>>2]=0}function Uua(a){a=a|0;x[a+16>>2]=x[a+16>>2]|1;if(v[a+20|0]&1){ua();p()}}function PU(a){if(a>>>0<=8){return y[a+27552|0]}return y[a+27543|0]|256}function Mc(a){if(Cd(y[a+11|0])){a=ej(x[a+8>>2])-1|0}else{a=10}return a}function KN(a){a=a|0;return+(+A[x[a+32>>2]+480240>>2]*152587890625e-16)}function J$(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function IK(a,b,c){var d=0;d=c;c=Cf(b);if(d>>>0>c>>>0){wO(a,b)}return c}function I3(a){a=a|0;if(!a){return 0}return(gB(a,124608,124752)|0)!=0|0}function Eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return UH(a,b,c,d,1001)|0}function Cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return UH(a,b,c,d,1122)|0}function tt(a){return a>>>0<32|a-127>>>0<33|(a&-2)==8232|a-65529>>>0<3}function qD(a,b){if(b){qD(a,x[b>>2]);qD(a,x[b+4>>2]);Zj(b+16|0);Db(b)}}function pD(a,b){if(b){pD(a,x[b>>2]);pD(a,x[b+4>>2]);Zj(b+16|0);Db(b)}}function nra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Jx(a,b,c,d,587)|0}function nO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ks(a,b,c,d,1112)|0}function mO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ks(a,b,c,d,1114)|0}function lv(a,b){a=a&255;b=b&255;return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function lO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ks(a,b,c,d,1116)|0}function jO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ks(a,b,c,d,1118)|0}function jB(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];v[a+6|0]=y[b+6|0]}function ii(a,b){a=a|0;b=b|0;v[a|0]=2;v[a+1|0]=3;v[a+2|0]=0;v[a+3|0]=4}function hs(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function bk(){var a=0;a=Ym(ac(4));x[a>>2]=124936;da(a|0,125012,34);p()}function _N(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Hs(a,b,c,d,1115)|0}function ZN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Hs(a,b,c,d,1117)|0}function YN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Hs(a,b,c,d,1119)|0}function Tsa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;kH(a,b,c,d,e,93)}function Sq(a,b){if(b){Sq(a,x[b>>2]);Sq(a,x[b+4>>2]);kU(b+16|0);Db(b)}}function Ox(a,b,c){if(!(x[a+28>>2]==1|x[a+4>>2]!=(b|0))){x[a+28>>2]=c}}function DB(a,b){if(b){DB(a,x[b>>2]);DB(a,x[b+4>>2]);hn(b+16|0);Db(b)}}function CA(a,b){if(b){CA(a,x[b>>2]);CA(a,x[b+4>>2]);Eb(b+16|0);Db(b)}}function An(a){if(Cd(y[a+11|0])){a=ej(x[a+8>>2])-1|0}else{a=1}return a}function $N(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Hs(a,b,c,d,1113)|0}function $B(a,b){a=Nb(a);Fb(a+12|0);w[a+28>>1]=0;x[a+24>>2]=b;return a}function sS(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b}function rU(a,b,c){if(He(a,b,c)){a=x[Wb(a,c)+12>>2]}else{a=1}return a}function q3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[a|0](b,c,d,e)}function mW(a,b,c,d,e){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e)}function m$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Jx(a,b,c,d,341)|0}function lx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Jx(a,b,c,d,165)|0}function hN(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){zo(c+120|0);Db(c)}}function by(a){a=a|0;if(x[a+8>>2]!=(Od()|0)){xl(x[a+8>>2])}return a|0}function NZ(a){var b=0;b=x[a>>2];if(x[b>>2]){gp(b);Db(x[x[a>>2]>>2])}}function n3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ib[a|0](b,c,d)|0}function ZY(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];ic(a+8|0,b+8|0)}function Y8(a){a=a|0;var b=0;b=x[125100]+1|0;x[125100]=b;x[a+4>>2]=b}function E7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lg(a,f)}function D7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lq(a,f)}function jZ(a){v[a+4|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function jI(a,b,c,d,e,f,g){return Ja(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function dT(a,b){x[a+852>>2]=x[a+852>>2]+b;v[a+851|0]=y[a+851|0]|64}function _r(a,b){return Nw(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function Wr(a,b,c){if(Zc(a,b)>>>0<=c>>>0){Ew();p()}return(c<<1)+a|0}function Oc(a,b,c){if(oc(a,b)>>>0<=c>>>0){Ew();p()}return(c<<2)+a|0}function Nk(a,b,c){var d=0;d=fb-16|0;fb=d;BY(d+8|0,a,b,c);fb=d+16|0}function Jm(a,b){return b?a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24):a}function JO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return XH(a,b,c,d,4)|0}function J0(a,b){return iq(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function IO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return XH(a,b,c,d,2)|0}function HO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return WH(a,b,c,d,4)|0}function GO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return WH(a,b,c,d,2)|0}function sg(a,b){a=a|0;b=b|0;var c=0;c=Ec(b);x[a+4>>2]=b;x[a>>2]=c}function sV(a,b){var c=0,d=0;c=vb(a,x[b>>2]),d=y[b+4|0],v[c+4|0]=d}function nd(a){a=(a|0)>=32767?32767:a;return(a|0)<=-32768?-32768:a}function cy(a,b,c){a:{if((a|0)==(b|0)){v[b+120|0]=0;break a}Db(b)}}function Y4(a,b){a=a|0;b=b|0;a=WI(a,b,1);x[a>>2]=121212;return a|0}function Wj(a,b){a=a|0;b=b|0;var c=0;c=IY(b);x[a+4>>2]=b;x[a>>2]=c}function Wga(a,b,c){a=a|0;b=b|0;c=c|0;return oj(a,b,c,981,86224)|0}function Rha(a,b){a=a|0;b=b|0;if(!x[31725]){x[31725]=a;x[31726]=b}}function D4(a,b){a=a|0;b=b|0;a=XI(a,b,1);x[a>>2]=121116;return a|0}function $5(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function yk(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+52>>2]](a,b,0)|0}function xp(a,b){x[a>>2]=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];return a}function vo(a,b){if(A[a+4>>2]<A[zb(a)>>2]){lM(a,b);return}fM(a,b)}function uha(a,b,c){a=a|0;b=b|0;c=c|0;return oj(a,b,c,977,4228)|0}function sia(a,b,c){a=a|0;b=b|0;c=c|0;return oj(a,b,c,970,4236)|0}function oja(a,b,c){a=a|0;b=b|0;c=c|0;return oj(a,b,c,946,4268)|0}function n2(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+16>>2]](a)|0}function lha(a,b,c){a=a|0;b=b|0;c=c|0;return oj(a,b,c,978,5048)|0}function lI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return xO(a,b,c,d)|0}function gma(a,b){a=a|0;b=b|0;a=Xv(a,b);x[a>>2]=125260;return a|0}function ek(a,b){if(Lg(x[a>>2],x[a+4>>2])>>>0>b>>>0){v[a+16|0]=b}}function bha(a,b,c){a=a|0;b=b|0;c=c|0;return oj(a,b,c,980,4276)|0}function _ha(a,b,c){a=a|0;b=b|0;c=c|0;return oj(a,b,c,973,4280)|0}function Zia(a,b,c){a=a|0;b=b|0;c=c|0;return oj(a,b,c,954,4304)|0}function Vs(a){a=a|0;x[a>>2]=113144;xl(x[a+16>>2]);return Zs(a)|0}function Sp(a,b,c){a=Ef(a,b);x[a+8>>2]=0;Ef(a+12|0,c);ke(c);ke(b)}function Qha(a,b,c){a=a|0;b=b|0;c=c|0;return oj(a,b,c,974,4276)|0}function ML(a,b){a=KL(a-1|0);if(!a){a=KL(b);a=a?a+32|0:0}return a}function Jta(a,b){a=a|0;b=b|0;a=Xv(a,b);x[a>>2]=125208;return a|0}function Jha(a,b,c){a=a|0;b=b|0;c=c|0;return oj(a,b,c,975,4268)|0}function IN(a){a=a|0;return+(+x[x[a+32>>2]+1074456>>2]*.00390625)}function GY(a,b,c,d){a=Ge(a,b);w[a+22>>1]=d;w[a+20>>1]=c;return a}function Dm(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+32>>2]](a,0,b)|0}function Dh(a,b,c){a=vb(a,b);j_(a+4|0,x[c>>2],x[c+4>>2]);return a}function vz(a){var b=0;b=fb-16|0;fb=b;oN(vb(b+12|0,a));fb=b+16|0}function vW(a){var b=0;b=fb-16|0;fb=b;iW(vb(b+12|0,a));fb=b+16|0}function u_(a,b){a=a|0;b=b|0;a=Xv(a,b);x[a>>2]=125072;return a|0}function rn(a){var b=0;b=fb-16|0;fb=b;zW(vb(b+12|0,a));fb=b+16|0}function o2(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+8>>2]](a)|0}function md(a){var b=0;b=fb-16|0;fb=b;TF(vb(b+12|0,a));fb=b+16|0}function kr(a,b,c){a=Bb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function kq(a){var b=0;b=fb-16|0;fb=b;Mh(Nh(b+12|0,a));fb=b+16|0}function iq(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function dy(a){var b=0;b=fb-16|0;fb=b;kJ(vb(b+12|0,a));fb=b+16|0}function bQ(a){return E(E(B[yb(a+4208|0,11)>>2]*E(19980))+E(20))}function YA(a){tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);tb(a)}function Td(a){var b=0;b=fb-16|0;fb=b;QH(vb(b+12|0,a));fb=b+16|0}function Sk(a){var b=0;b=fb-16|0;fb=b;M$(vb(b+12|0,a));fb=b+16|0}function Rca(a,b){a=a|0;b=b|0;return E(oP(x[x[a+4>>2]+24>>2],b))}function Qca(a,b){a=a|0;b=b|0;return E(nP(x[x[a+4>>2]+24>>2],b))}function Qc(a){var b=0;b=fb-16|0;fb=b;UE(vb(b+12|0,a));fb=b+16|0}function QW(a){var b=0;b=fb-16|0;fb=b;KW(vb(b+12|0,a));fb=b+16|0}function Pca(a,b){a=a|0;b=b|0;return E(kP(x[x[a+4>>2]+24>>2],b))}function Lga(a,b){a=a|0;b=b|0;if(!b){return 3}x[b>>2]=a;return 0}function Lca(a,b){a=a|0;b=b|0;return E(mP(x[x[a+4>>2]+24>>2],b))}function Kca(a,b){a=a|0;b=b|0;return E(lP(x[x[a+4>>2]+24>>2],b))}function DG(a,b,c){a=Wn(a);x[a+8>>2]=c;x[a+4>>2]=b;x[a>>2]=78688}function CY(a){var b=0;b=fb-16|0;fb=b;vY(vb(b+12|0,a));fb=b+16|0}function Ae(a){var b=0;b=fb-16|0;fb=b;JG(vb(b+12|0,a));fb=b+16|0}function AW(a){var b=0;b=fb-16|0;fb=b;pW(vb(b+12|0,a));fb=b+16|0}function zy(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+12>>2]](a,b)|0}function zx(a){var b=0;b=fb-16|0;B[b+12>>2]=a;return B[b+12>>2]}function w7(a){a=a|0;a=x[a+8>>2];if(!a){return 1}return EJ(a)|0}function rm(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+28>>2]](a,b)|0}function jta(a,b){a=a|0;b=b|0;a=g_(a,b);if(!a){f_(b)}return a|0}function cu(a,b){var c=0;c=G(a)+32|0;a=G(b);return(a|0)==32?c:a}function cQ(a){return E(E(B[yb(a+4208|0,0)>>2]*E(1e4))+E(-1e4))}function Xca(a,b){a=a|0;b=b|0;return UO(x[x[a+4>>2]+24>>2],b)|0}function Vc(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){su(b)}return a}function Se(a,b,c,d){x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function Qs(a){var b=0;b=fb-16|0;C[b+8>>3]=a;return C[b+8>>3]*a}function Nw(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function Ho(a,b,c,d){a=lv(a,c);if(Vj(a)){a=hU(b,d)}return Cd(a)}function Cla(a,b){a=a|0;b=b|0;a=gZ(a,b);if(!a){fZ(b)}return a|0}function Bt(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+44>>2]](a,b)|0}function Bg(a){var b=0;b=gr(Cf(a)+1|0,1);if(b){wO(b,a)}return b}function yD(a,b){a=a|0;b=b|0;a=sZ(a,b);if(!a){mD(b)}return a|0}function vha(a,b,c){a=a|0;b=b|0;c=c|0;return Ix(a,b,c,1,976)|0}function ul(a){return wb(Kb(a)+(Cb(x[a+4>>2],y[a+11|0])<<2)|0)}function ss(a,b){a=a|0;b=b|0;a=jG(a,b);if(!a){qx(b)}return a|0}function sQ(a){a=a|0;return Jk(E(B[yb(a+4208|0,4)>>2]*E(4)))|0}function op(a,b){a=a|0;b=b|0;a=s$(a,b);if(!a){v$(b)}return a|0}function mh(a,b){return ib[x[x[a>>2]+32>>2]](a,x[a+12>>2],b)|0}function m0(a,b){if(!b){return-1}b=yq(a,b,0);return b?b-a|0:-1}function jX(a){return y[a+15|0]<<12|y[a+14|0]<<4|y[a+13|0]<<20}function iia(a,b,c){a=a|0;b=b|0;c=c|0;return Ix(a,b,c,0,972)|0}function iS(a,b){return b>>>0>=4e3?22255:((b<<5)+a|0)+946304|0}function ds(a,b){var c=0;c=b+1|0;x[a>>2]=x[a>>2]>(c|0)?c:b+2|0}function dS(a,b,c,d){w[a+4>>1]=c;v[a+6|0]=b;x[a>>2]=d;return a}function bx(a,b){a=_c(a,b);ic(a+12|0,b+12|0);re(a+32|0,b+32|0)}function _w(a,b){a=a|0;b=b|0;a=aG(a,b);if(!a){gs(b)}return a|0}function W7(a,b){a=a|0;b=b|0;bT(a,Ry(x[b>>2])<<24>>24,x[b>>2])}function Ur(a,b){a=a|0;b=b|0;a=Un(a,b);if(!a){In(b)}return a|0}function Up(a,b){a=a|0;b=b|0;a=gx(a,b);if(!a){fx(b)}return a|0}function TT(a,b){a=a|0;b=b|0;a=N$(a,b);if(!a){Lr(b)}return a|0}function Rda(a,b,c){a=a|0;b=b|0;c=c|0;return+BO(x[a+4>>2],b,c)}function N0(a,b){a=a|0;b=b|0;a=yE(a,b);if(!a){DE(b)}return a|0}function JS(a,b,c,d){w[a>>1]=b;v[a+2|0]=y[c|0];v[a+3|0]=y[d|0]}function Gr(a,b){a=a|0;b=b|0;a=t$(a,b);if(!a){aw(b)}return a|0}function Ci(a,b){a=a|0;b=b|0;a=ai(a,b);if(!a){gl(b)}return a|0}function Cha(a,b,c){a=a|0;b=b|0;c=c|0;return Ix(a,b,c,0,976)|0}function xua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;tH(a,b,c,d,135)}function xm(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){hl(c)}return a}function xS(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(Hj(c))}}function uI(a,b){var c=0;c=a;a=x[a>>2]+b|0;x[c>>2]=a;return a}function p$(a){return(y[a+47|0]+y[a+45|0]|0)+(y[a+46|0]<<5)|0}function em(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){ec(a);Db(b)}}function Uba(a,b){a=a|0;b=b|0;x[a>>2]=x[b>>2];lg(a+4|0,b+4|0)}function Ska(a){a=a|0;a=Xv(a,22255);x[a>>2]=125152;return a|0}function Mta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mH(a,b,c,d,365)}function LG(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(dc(c))}}function Kf(a,b,c){return(x[((c&255)<<2)+a>>2]&b)!=0&(c|0)>=0}function Jia(a){a=a|0;a=Fj(a);if(a){ib[x[x[a>>2]+100>>2]](a)}}function IY(a){if(a>>>0>=1073741824){bk();p()}return Ec(a<<2)}function Asa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mH(a,b,c,d,476)}function AM(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function $ha(a){a=a|0;return E(E(B[yb(a+4208|0,6)>>2]*E(20)))}function $b(a){return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function zm(a){a=EG(a,0);x[a+8>>2]=0;x[a>>2]=121352;return a}function zI(a){a=a|0;x[a>>2]=112028;xl(x[a+8>>2]);return a|0}function yI(a){a=a|0;x[a>>2]=111996;xl(x[a+8>>2]);return a|0}function wha(a){a=a|0;return E(E(B[yb(a+4208|0,6)>>2]*E(4)))}function uj(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function tQ(a){a=a|0;return E(E(B[yb(a+4208|0,2)>>2]*E(10)))}function tM(a){a=a|0;x[a>>2]=78224;dc(a+24|0);return Tt(a)|0}function jh(a,b,c,d){hb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function f2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bc(a,x[d>>2],0)}function Zz(a){a=a|0;x[a+32>>2]=0;x[a+28>>2]=x[a+28>>2]&-7|2}function Ys(a){a=a|0;x[a>>2]=113196;xl(x[a+8>>2]);return a|0}function Xv(a,b){a=Nj(a);x[a>>2]=125032;Sx(a+4|0,b);return a}function VR(a,b){var c=0;c=z[a>>1];w[a>>1]=z[b>>1];w[b>>1]=c}function Ub(a,b){var c=0;c=x[a>>2];x[a>>2]=x[b>>2];x[b>>2]=c}function MN(a){a=a|0;return+(65536/+A[x[a+32>>2]+480244>>2])}function KL(a){var b=0,c=0,d=0;return b=nva(a),c=0,d=a,d?b:c}function EY(a){var b=0;b=x[a+100>>2];x[a+100>>2]=0;return b}
function Dt(a){a=a|0;x[a>>2]=93640;tb(a+32|0);return mo(a)|0}function Csa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;tH(a,b,c,d,93)}function BS(a){x[a>>2]=0;Nb(a+4|0);Tb(a+16|0,0,144);return a}function zqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;iH(a,b,c,d,2)}function zka(a,b,c){a=a|0;b=b|0;c=c|0;return jH(a,b,c,64)|0}function yq(a,b,c){if(!b){return 0}return gu(a,c<<24>>24,b)}function uz(a,b,c,d,e,f){return RH(a,b,c,d,e,f,73620,74416)}function sz(a,b,c,d,e,f){return RH(a,b,c,d,e,f,74496,75260)}function rN(a,b){a=a|0;b=+b;TH(a,b,1e4,1074420,9363,512,32)}function r3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[a|0](b,c,d)}function pC(a,b){if(b){pC(a,x[b>>2]);pC(a,x[b+4>>2]);Db(b)}}function oC(a,b){if(b){oC(a,x[b>>2]);oC(a,x[b+4>>2]);Db(b)}}function kT(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(kB(b))}}function hx(a){var b=0;b=a;a=x[a>>2]-1|0;x[b>>2]=a;return a}function ew(a,b,c){a=a|0;b=b|0;c=c|0;return yH(a,b,c,324)|0}function d6(a,b,c){a=a|0;b=b|0;c=c|0;return JH(b,c,97936)|0}function cF(a){return!kd(a,14184,3)&(y[a+3|0]-10&255)>>>0<5}function bD(a,b){if(b){bD(a,x[b>>2]);bD(a,x[b+4>>2]);Db(b)}}function b6(a,b,c){a=a|0;b=b|0;c=c|0;return JH(b,c,96400)|0}function ZM(a,b){a=a|0;b=b|0;return Yj(x[b>>2],x[b+4>>2])|0}function Yw(a,b){return HS(a,Kb(b),Cb(x[b+4>>2],y[b+11|0]))}function YM(a,b){a=a|0;b=b|0;return Sd(x[b>>2],x[b+4>>2])|0}function W5(a,b,c){a=a|0;b=b|0;c=c|0;return IH(b,c,97936)|0}function Vqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;iH(a,b,c,d,3)}function U5(a,b,c){a=a|0;b=b|0;c=c|0;return IH(b,c,96400)|0}function Ty(a,b){return Gt(a,Kb(b),Cb(x[b+4>>2],y[b+11|0]))}function Ts(a,b){var c=0,d=0;c=a,d=Bk(b),x[c>>2]=d;return a}function Pba(a){a=a|0;Iz(a,2,100);ek(x[a+24>>2]+484360|0,0)}function P1(a){a=a|0;a=BG(a,13422);x[a>>2]=24460;return a|0}function Nh(a,b){var c=0,d=0;c=a,d=EK(b),x[c>>2]=d;return a}function Mu(a,b){if(b){Mu(a,x[b>>2]);Mu(a,x[b+4>>2]);Db(b)}}function Lu(a,b){if(b){Lu(a,x[b>>2]);Lu(a,x[b+4>>2]);Db(b)}}function Ir(a){return x[a+20>>2]+(x[a+8>>2]-x[a+24>>2]|0)|0}function H0(a,b,c){a=a|0;b=b|0;c=c|0;return yH(a,b,c,264)|0}function Gl(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(of(b))}}function ED(a,b){if(b){ED(a,x[b>>2]);ED(a,x[b+4>>2]);Db(b)}}function Do(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function DD(a,b){if(b){DD(a,x[b>>2]);DD(a,x[b+4>>2]);Db(b)}}function $ba(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,j0(c,0,b,Cf(b)))}function yA(a,b,c){C[a>>3]=C[a>>3]+b;C[a+8>>3]=C[a+8>>3]+c}function xz(a){return(Kb(a)+Cb(x[a+4>>2],y[a+11|0])|0)-1|0}function w9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hb=0;return 0}function no(a,b,c,d){x[a+16>>2]=d;x[a+12>>2]=c;x[a+8>>2]=b}function kI(a,b,c){b=La(1011,a|0,b|0,c|0)|0;hb=gb;return b}function hp(a){var b=0;b=x[a>>2];x[b>>2]=x[b>>2]|x[a+4>>2]}function b4(a){a=a|0;a=u_(a,7956);x[a>>2]=40264;return a|0}function _O(a){return Rj(Xb(x[a+484360>>2],y[a+484376|0]))}function S5(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function Gp(a,b,c){a=a|0;b=b|0;c=c|0;ti(a,b,Mi(b,b+c|0,0))}function B2(a){a=a|0;a=BG(a,8704);x[a>>2]=28868;return a|0}function qK(a,b,c){a=a|0;b=b|0;c=c|0;Hu(a,b,c);return a|0}function ng(a,b){if(Cd(y[a+11|0])){Yd(a,b);return}Me(a,b)}function naa(a,b,c){a=a|0;b=b|0;c=c|0;return Fd(D(b,c))|0}function lsa(a,b,c){a=a|0;b=b|0;c=c|0;ti(a,b,Sc(b,c)+b|0)}function kfa(a,b){a=a|0;b=b|0;return bo(a,b,11782,1063)|0}function jfa(a,b){a=a|0;b=b|0;return eI(a,b,13394,1064)|0}function jd(a,b,c,d){return Wc(a,D(z[b+480188>>1],c)+d|0)}function h0(a,b){v[a|0]=y[b|0];v[a+1|0]=y[b+1|0];return a}function gN(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){su(c)}}function fz(a,b){return x[((a>>>24^b)<<2)+495792>>2]^a<<8}function ay(a){a=a|0;x[a>>2]=113352;tb(a+16|0);return a|0}function afa(a,b){a=a|0;b=b|0;return bo(a,b,11817,1071)|0}function _f(a){var b=0;iQ(a);b=x[a>>2];if(b){Tz(a);Db(b)}}function _ea(a,b){a=a|0;b=b|0;return bo(a,b,11847,1073)|0}function _L(a){while(1){if((Qt(a)|0)!=-1){continue}break}}function Zo(a){x[a>>2]=0;x[a+4>>2]=0;Fc(a+8|0,0);return a}function Uea(a,b){a=a|0;b=b|0;return bo(a,b,11943,1076)|0}function Sea(a,b){a=a|0;b=b|0;return bo(a,b,11911,1077)|0}function Rq(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function OA(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(c)}}function Ny(a,b,c){x[a+28>>2]=c;x[a+20>>2]=b;x[a+24>>2]=b}function KF(a,b){var c=0;c=Ec(b<<2);x[a+4>>2]=b;x[a>>2]=c}function JN(a,b){a=a|0;b=+b;TH(a,b,256,1074456,11752,1,0)}function Gc(a,b){return AH(a,b,2147483647,-2147483648,-1)}function Df(a){return wb(Kb(a)+Cb(x[a+4>>2],y[a+11|0])|0)}function Cfa(a,b){a=a|0;b=b|0;return bo(a,b,11879,1056)|0}function $x(a){a=a|0;x[a>>2]=113312;tb(a+12|0);return a|0}function yha(a){a=a|0;return B[yb(a+4208|0,1)>>2]<E(1)|0}function yga(a,b){a=a|0;b=b|0;return eI(a,b,6432,1004)|0}function yL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hi(a,-1,-1)}function tg(a,b){var c=0;c=y[a|0];v[a|0]=y[b|0];v[b|0]=c}function oha(a){a=a|0;gQ(a);v[a+4202|0]=1;x[a+4224>>2]=0}function jx(a){a=a|0;x[a>>2]=125052;qI(a+4|0);return a|0}function iC(a,b){Ub(a,b);Ub(a+4|0,b+4|0);Ub(zb(a),zb(b))}function hT(a,b){a=gT(a,b);gT(a+12|0,b+12|0);v[a+24|0]=1}function bia(a){a=a|0;return B[yb(a+4208|0,3)>>2]<E(1)|0}function bH(a,b){hl(x[b>>2]);Bm(x[a>>2]);x[a>>2]=x[b>>2]}function Vla(a,b,c){a=a|0;b=b|0;c=c|0;return Mb(a,b,c)|0}function UD(a,b){v[x[a>>2]]=y[b|0];v[x[a+4>>2]]=y[b+1|0]}function Tt(a){a=a|0;x[a>>2]=77372;dc(a+12|0);return a|0}function S_(a){a=a|0;x[a>>2]=125032;qI(a+4|0);return a|0}function Qh(a,b,c){v[a|0]=y[a|0]|b;x[a+4>>2]=x[a+4>>2]|c}function PB(a,b){C[a>>3]=C[a>>3]*b;C[a+8>>3]=C[a+8>>3]*b}function Jv(a){uc(a+88|0);uc(a+68|0);uc(a+48|0);return a}function In(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function C2(a,b,c){a=a|0;b=b|0;c=c|0;kx(a,b,x[b+8>>2],c)}function Bj(a){return hf(a)|hf(a)<<8|hf(a)<<16|hf(a)<<24}function xn(a,b,c){x[a>>2]=b;x[a+4>>2]=x[c>>2];return a}function xG(a){a=a|0;x[a>>2]=41568;ke(a+4|0);return a|0}function wda(a,b,c){a=a|0;b=b|0;c=c|0;aP(a,x[b+4>>2],c)}function vla(a,b,c){a=a|0;b=b|0;c=c|0;cH(a,b,c,838,837)}function qI(a){a=kl(x[a>>2]);if((hx(a+8|0)|0)<0){Db(a)}}function pla(a,b,c){a=a|0;b=b|0;c=c|0;hI(a,b,c,842,843)}function mo(a){a=a|0;x[a>>2]=93512;Zb(a+4|0);return a|0}function jg(a,b,c,d,e){return Na(a|0,b|0,c|0,d|0,e|0)|0}function jM(a,b,c){x[a+4>>2]=0;x[a>>2]=b;x[a+8>>2]=c<<3}function jJ(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Bm(b)}}function ika(a,b,c){a=a|0;b=b|0;c=c|0;cH(a,b,c,914,913)}function aU(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(b)}}function Zt(a){a=a|0;x[a>>2]=48700;vz(a+4|0);return a|0}function ZO(a){return Zu(x[a+484344>>2],x[a+484348>>2])}function Yn(a){var b=0;b=x[a+8>>2];x[a+8>>2]=0;return b}function Yda(a,b,c){a=a|0;b=b|0;c=c|0;Iz(x[a+4>>2],b,c)}function Nb(a){x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);return a}function Kd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function KD(a){a=a&255;return Tc(a)^1|(a-49&255)>>>0<36}function IR(a){return(a|0)==1179012417|(a|0)==538987841}function Et(a){a=a|0;x[a>>2]=93576;Zb(a+4|0);return a|0}function DM(a){a=a|0;x[a>>2]=77836;dc(a+4|0);return a|0}function AK(a,b,c){a=vb(a,b);vb(a+4|0,x[c>>2]);return a}function xd(a,b){a=EG(a,b-1|0);x[a>>2]=113720;return a}function vL(a){a=a|0;return Ht(x[x[a>>2]-12>>2]+a|0)|0}function tq(a){return y[a+2|0]&2?(y[a+1|0]&6)==6?4:1:0}function th(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+20>>2]](a,b)}function pL(a){a=a|0;return Ft(x[x[a>>2]-12>>2]+a|0)|0}function loa(a,b){a=a|0;b=b|0;if(!PX(a,b)){Tb(b,0,40)}}function li(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+24>>2]](a,b)}function ksa(a,b){a=a|0;b=b|0;return Dc(a,b?b:22255)|0}function kia(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,b+4228|0,7)}function ki(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+28>>2]](a,b)}function iz(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function iva(a,b){a=a|0;b=b|0;Kh(a,b,262,1025,-1284,2)}function hU(a,b){return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function eda(a,b){a=a|0;b=b|0;return WO(x[a+4>>2],b)|0}function dba(a,b){a=a|0;b=b|0;ST(x[a>>2],b);return a|0}function coa(a,b){a=a|0;b=b|0;Kh(a,b,588,1058,-1332,3)}function c9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ti(a,c,d)}function Yb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function Xda(a,b){a=a|0;b=b|0;zO(x[x[a+4>>2]+24>>2],b)}function W6(){xd(501976,1);hJ(501984);x[125494]=117092}function Vka(a){a=a|0;Hj(126932);Hj(126924);tb(126912)}function Ssa(a,b){a=a|0;b=b|0;Kh(a,b,417,1042,-1332,2)}function Ph(a){var b=0;b=Qt(a);x[a+1396>>2]=0;return b}function P7(a,b){a=a|0;b=b|0;gc(a,hL(x[b>>2]),x[b>>2])}function MR(a,b){return D(b&65535,a&65535)+7>>>3&65535}function Kua(a,b){a=a|0;b=b|0;Kh(a,b,297,1058,-1332,2)}function Km(a,b){x[a+16>>2]=!x[a+24>>2]|(x[a+16>>2]|b)}function E9(a){a=a|0;return pq(x[x[a>>2]-12>>2]+a|0)|0}function C9(a){a=a|0;return Ff(x[x[a>>2]-12>>2]+a|0)|0}function Bpa(a,b){a=a|0;b=b|0;Kh(a,b,262,1042,-1332,2)}function $ia(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,b+4260|0,8)}function $8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jo(a,c,d)}function yK(a,b,c){a=CK(a,b,c,0,-2147483648);return a}function y4(a,b){a=a|0;b=b|0;return Al(b&255)<<24>>24}function xea(a,b){a=a|0;b=b|0;Kh(a,b,81,1025,-1284,4)}function wj(a){a=a|0;return ib[x[x[a>>2]+16>>2]](a)|0}function w4(a,b){a=a|0;b=b|0;return zt(b&255)<<24>>24}function vj(a){a=a|0;return ib[x[x[a>>2]+12>>2]](a)|0}function vda(a){a=a|0;return _O(x[x[a+4>>2]+24>>2])|0}function tl(a,b){return ib[x[x[a>>2]+36>>2]](a,b,0)|0}function tda(a){a=a|0;return gP(x[x[a+4>>2]+24>>2])|0}function tc(a,b){a=a|0;b=b|0;fG(a,b,is(b));return a|0}function tb(a){if(Cd(y[a+11|0])){Db(x[a>>2])}return a}function ssa(a,b){a=a|0;b=b|0;Kh(a,b,81,1042,-1332,2)}function rra(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,k0(c,0,b))}function rda(a){a=a|0;return zq(x[x[a+4>>2]+24>>2])|0}function qs(a,b){a=ic(a,b);Tb(a+20|0,0,1040);return a}function pda(a){a=a|0;return Co(x[x[a+4>>2]+24>>2])|0}function oda(a){a=a|0;return ZO(x[x[a+4>>2]+24>>2])|0}function nea(a,b){a=a|0;b=b|0;Kh(a,b,13,1025,-1284,2)}function lh(a){a=a|0;return ib[x[x[a>>2]+24>>2]](a)|0}function lda(a){a=a|0;return SO(x[x[a+4>>2]+24>>2])|0}function kB(a){Nq(a+223860|0);dc(a+223848|0);return a}function iea(a,b){a=a|0;b=b|0;Kh(a,b,81,1025,-1284,2)}function ida(a){a=a|0;return jP(x[x[a+4>>2]+24>>2])|0}function hg(a,b,c,d){b=b+d|0;hb=a+c>>>0<c>>>0?b+1|0:b}function hda(a){a=a|0;return fP(x[x[a+4>>2]+24>>2])|0}function gda(a){a=a|0;return eP(x[x[a+4>>2]+24>>2])|0}function df(a,b,c,d){v[a+8|0]=d;x[a+4>>2]=c;x[a>>2]=b}function cf(a,b,c,d){bc(a,jd(b,c,d,0),z[c+480188>>1])}function aE(a,b){a=Ge(a,b);Tb(a+20|0,0,1040);return a}function _C(a,b){a=a|0;b=b|0;Kh(a,b,588,1058,-1332,2)}function Uda(a,b){a=a|0;b=b|0;Kh(a,b,82,1025,-1284,2)}function U6(){xd(501992,1);hJ(502e3);x[125498]=117248}function TN(a,b){hb=0-(((a|0)!=0)+b|0)|0;return 0-a|0}function Rp(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){hl(c)}}function Oca(a){a=a|0;return hP(x[x[a+4>>2]+24>>2])|0}function M2(a,b,c){a=a|0;b=b|0;c=c|0;hI(a,b,c,76,149)}function K4(a,b){a=a|0;b=b|0;return II(b,x[a+8>>2])|0}function Hia(a){a=a|0;v[a+4202|0]=1;pu(a);Xz(a);HQ(a)}function Gv(a,b){a=a|0;b=b|0;Kh(a,b,589,1058,-1332,2)}function GQ(a){uc(a+36|0);uc(a+24|0);nu(a+12|0);nu(a)}function ER(a,b){return(b>>>0>15?63:v[a+b|0])<<24>>24}function Dc(a,b){a=a|0;b=b|0;Hu(a,b,Cf(b));return a|0}function DT(a,b,c,d){return ed(Mo(a,b,c,d,0)-32768|0)}function DR(a,b){return(b>>>0>46?63:v[a+b|0])<<24>>24}function $ca(a){a=a|0;return Aq(x[x[a+4>>2]+24>>2])|0}function yu(a){a=a|0;a=bi(a);x[a+20>>2]=0;return a|0}function xha(a){a=a|0;return E(B[yb(a+4208|0,3)>>2])}function sw(a,b,c){if(b){tP(a+36|0,b,Mi(b,b+c|0,0))}}function qca(a,b,c){a=a|0;b=b|0;c=c|0;FN(a-88|0,b,c)}function qaa(a,b,c){a=a|0;b=b|0;c=c|0;Fs(a,b,c,1168)}function qG(a,b,c,d){return $p(a,b,c,d,36,119304648)}function oca(a,b,c){a=a|0;b=b|0;c=c|0;CN(a-88|0,b,c)}function nva(a){if(a){return 31-G(a-1^a)|0}return 32}function km(a){a=(a|0)>=120?120:a;return(a|0)<=1?1:a}function go(a,b,c,d){return(a|0)==(c|0)&(b|0)==(d|0)}function ee(a,b){gc(a,Kb(b),Cb(x[b+4>>2],y[b+11|0]))}function de(a,b,c){v[a|0]=b;v[a+1|0]=y[c|0];return a}function d0(a,b,c,d){return $p(a,b,c,d,28,153391690)}function cC(a){a=Nb(a);x[a+12>>2]=0;w[a+16>>1]=65280}function bea(a){a=a|0;return Rz(x[a>>2],x[a+4>>2])|0}function aia(a){a=a|0;return E(B[yb(a+4208|0,1)>>2])}function a5(a,b){a=a|0;b=b|0;Kh(a,b,13,1058,-1332,2)}function Zw(a){a=a|0;return ib[x[x[a>>2]+8>>2]](a)|0}function WF(a,b){return(y[b+34|0]&8)>>>3&(a&2050)==2}function SX(a){var b=0;a=a+8|0;hb=a>>>0<8|b;return a}function QQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function Ps(a,b,c,d,e,f){Ka(a|0,b|0,c|0,d|0,e|0,f|0)}function LJ(a,b,c,d){return $p(a,b,c,d,24,178956971)}function Er(a,b,c,d,e){gc(a,b+d|0,(e|0)==-1?c-d|0:e)}function EG(a,b){x[a+4>>2]=b;x[a>>2]=124504;return a}function E$(a,b,c,d){return $p(a,b,c,d,40,107374183)}function yta(a,b,c){a=a|0;b=b|0;c=c|0;z_(a,c,b,0,0)}function yo(a,b,c){x[a>>2]=b;x[a+4>>2]=c-b;return a}function ym(a){a=a|0;a=nc(a);ib[x[x[a>>2]>>2]](a)|0}function vra(a,b,c){a=a|0;b=b|0;c=c|0;sH(a,b,c,256)}function vQ(a){a=a|0;return E(B[yb(a+4208|0,0)>>2])}function t3(a){a=a|0;a=ib[a|0]()|0;gb=hb;return a|0}function sx(a,b){a=a|0;b=b|0;return HS(a,b,is(b))|0}function sca(a,b,c){a=a|0;b=b|0;c=+c;HN(a-88|0,b,c)}function py(a,b,c){if(!c){return 0}return kK(a,b,c)}function pca(a,b){a=a|0;b=b|0;return EN(a-88|0,b)|0}function nqa(a,b){a=a|0;b=b|0;return ei(a,b,1030)|0}function nca(a,b){a=a|0;b=b|0;return BN(a-88|0,b)|0}function mC(a){v[a+6|0]=0;w[a+4>>1]=65535;x[a>>2]=0}function le(a){var b=0;b=x[a>>2];x[a>>2]=0;return b}function gca(a,b,c){a=a|0;b=b|0;c=+c;wN(a-92|0,b,c)}function eqa(a,b){a=a|0;b=b|0;return Dx(a,b,1100)|0}function eca(a,b,c){a=a|0;b=b|0;c=+c;uN(a-92|0,b,c)}function d2(a,b){a=a|0;b=b|0;return AF(a,b,Cf(b))|0}function cG(a){return JL(a,E(15845632502852868e13))}function bva(a,b,c){a=a|0;b=b|0;c=c|0;cq(a,b,c,263)}function bda(a){a=a|0;return+dP(x[x[a+4>>2]+24>>2])}function Zsa(a,b){a=a|0;b=b|0;return Es(a,b,1186)|0}function ZT(a,b,c,d){return $p(a,b,c,d,7,613566757)}function ZA(a,b){x[a>>2]=b;x[a+4>>2]=b>>31;return a}function XF(a,b,c){gc(a,(c>>>3&536870908)+b|0,1<<c)}function Wda(a,b){a=a|0;b=+b;return+AO(x[a+4>>2],b)}function Uj(a){if(!a){return 0}return x[a+44>>2]!=0}function Tua(a,b){a=a|0;b=b|0;Cx(a,b,262,274,-1332)}function Tca(a){a=a|0;return+PA(x[x[a+4>>2]+24>>2])}function Sqa(a,b,c){a=a|0;b=b|0;c=c|0;Fs(a,b,c,596)}function Rsa(a,b,c){a=a|0;b=b|0;c=c|0;cq(a,b,c,418)}function Rqa(a,b,c){a=a|0;b=b|0;c=c|0;Fs(a,b,c,597)}function RN(a){a=a|0;a=x[a+4>>2];return(a?a:5011)|0}function Nqa(a,b,c){a=a|0;b=b|0;c=c|0;rH(a,b,c,504)}function MF(a){return JL(a,E(2524354896707238e-44))}function Lqa(a,b,c){a=a|0;b=b|0;c=c|0;zH(a,b,c,305)}function Lj(a){if(!a){return 0}return Tj(y[a+31|0])}function Kqa(a,b,c){a=a|0;b=b|0;c=c|0;eH(a,b,c,305)}function Ipa(a,b){a=a|0;b=b|0;return Es(a,b,1182)|0}function Gua(a,b,c){a=a|0;b=b|0;c=c|0;Fs(a,b,c,300)}function Fp(a,b,c){gc(a,(c>>>3&536870908)+b|0,c&31)}function Dua(a,b,c){a=a|0;b=b|0;c=c|0;oH(a,b,c,305)}function Dba(a,b){a=a|0;b=b|0;return Es(a,b,1185)|0}function DU(a,b){x[a+8>>2]=0;x[a+12>>2]=0;C[a>>3]=b}function Boa(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,sx(b,c))}function yJ(a,b){a=xd(a,b);x[a>>2]=115076;return a}function xJ(a,b){a=xd(a,b);x[a>>2]=115108;return a}function vJ(a,b){a=xd(a,b);x[a>>2]=113776;return a}function sJ(a,b){a=xd(a,b);x[a>>2]=117608;return a}function rJ(a,b){a=xd(a,b);x[a>>2]=117756;return a}function qJ(a,b){a=xd(a,b);x[a>>2]=117872;return a}function pJ(a,b){a=xd(a,b);x[a>>2]=117988;return a}function mra(a,b){a=a|0;b=b|0;return ei(a,b,422)|0}function mJ(a,b){a=xd(a,b);x[a>>2]=119176;return a}function lJ(a,b){a=xd(a,b);x[a>>2]=119296;return a}function hta(a,b){a=a|0;b=b|0;return ei(a,b,308)|0}function hra(a,b){a=a|0;b=b|0;return ei(a,b,826)|0}function fka(a,b){a=a|0;b=b|0;return ei(a,b,225)|0}function f3(a,b){a=a|0;b=b|0;return Es(a,b,1184)|0}function en(a){Kj(a+724|0);Kj(a+732|0);Kj(a+740|0)}function eha(a,b){a=a|0;b=b|0;return E(Gm(a,b,12))}function dl(a,b){return(a&65535)>>>0<(b&65535)>>>0}function cka(a,b){a=a|0;b=b|0;return ei(a,b,326)|0}function ava(a,b,c){a=a|0;b=b|0;c=c|0;zH(a,b,c,47)}function Zy(a){if(!a){return 0}x[31600]=a;return-1}function Zba(a){a=a|0;x[a>>2]=48480;return eu(a)|0}function Yta(a,b){a=a|0;b=b|0;return nH(a,b,347)|0}function NY(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,Ty(b,c))}function Mr(a,b,c){a=a|0;b=b|0;c=c|0;rH(a,b,c,125)}function KG(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,Yw(b,c))}function Jda(a,b,c){a=a|0;b=b|0;c=c|0;cq(a,b,c,83)}function Fca(a,b,c){a=a|0;b=b|0;c=c|0;eH(a,b,c,47)}function Eoa(a,b,c){a=a|0;b=b|0;c=c|0;oH(a,b,c,47)}function BG(a,b){a=AG(a,b);x[a>>2]=125312;return a}function Ada(a,b,c){a=a|0;b=b|0;c=c|0;cq(a,b,c,84)}function wqa(a,b){a=a|0;b=b|0;if(!yE(a,b)){DE(b)}}function we(a,b,c){x[a>>2]=b;x[a+4>>2]=c;return a}function uh(a,b){a=a|0;b=b|0;return sL(a)^sL(b)^1}function sO(a){x[a+4>>2]=0;x[a>>2]=47652;return a}function rca(a,b){a=a|0;b=b|0;return+GN(a-88|0,b)}function rE(a){return(x[zb(a)>>2]-x[a>>2]|0)/28|0}function qha(a,b){a=a|0;b=b|0;return E(Gm(a,b,1))}function ota(a,b){a=a|0;b=b|0;if(!g_(a,b)){f_(b)}}function ot(a){return a-48>>>0<10|(a|32)-97>>>0<6}function oka(a,b){a=a|0;b=b|0;if(!jG(a,b)){qx(b)}}function oI(a){return(a<<1)+16777216>>>0<16777217}function nta(a,b){a=a|0;b=b|0;return ei(a,b,78)|0}function mi(a,b){a=a|0;b=b|0;return iL(a)^iL(b)^1}function ll(a){return(x[zb(a)>>2]-x[a>>2]|0)/12|0}function l5(a,b){a=a|0;b=b|0;Cx(a,b,13,290,-1332)}function kn(a,b,c){x[a+4>>2]=c;w[a>>1]=b;return a}function jF(a){return!kd(a,24544,25)&y[a+34|0]<65}function j2(a,b){a=a|0;b=b|0;Cx(a,b,13,257,-1284)}function hka(a,b){a=a|0;b=b|0;return ei(a,b,73)|0}function gc(a,b,c){x[a+4>>2]=c;x[a>>2]=b;return a}function fia(a,b){a=a|0;b=b|0;return E(Gm(a,b,6))}function fca(a,b){a=a|0;b=b|0;return+vN(a-92|0,b)}function era(a,b){a=a|0;b=b|0;return ei(a,b,41)|0}function dca(a,b){a=a|0;b=b|0;return+tN(a-92|0,b)}function dZ(a){return(x[zb(a)>>2]-x[a>>2]|0)/33|0}function cx(a){return(x[zb(a)>>2]-x[a>>2]|0)/36|0}function at(a){return(x[zb(a)>>2]-x[a>>2]|0)/24|0}function aka(a,b){a=a|0;b=b|0;return ei(a,b,60)|0}function _Z(a){if(!(a&255)){return 1}return Tc(a)}function Zga(a,b){a=a|0;b=b|0;return E(Gm(a,b,2))}function Xl(a,b,c){C[a+8>>3]=c;C[a>>3]=b;return a}function Wpa(a,b){a=a|0;b=b|0;return ei(a,b,71)|0}function VZ(a,b){a=a|0;b=b|0;return nH(a,b,324)|0}function Uha(a,b){a=a|0;b=b|0;return E(Gm(a,b,5))}function TE(a){return(x[zb(a)>>2]-x[a>>2]|0)/20|0}function SK(a){return(Oh(a)|0)!=0|(a|32)-97>>>0<6}function Rga(a,b){a=a|0;b=b|0;return E(Gm(a,b,3))}function Ora(a,b){a=a|0;b=b|0;return ei(a,b,91)|0}function Oq(a,b){x[a+4>>2]=256;x[a>>2]=b;return a}function Mha(a,b){a=a|0;b=b|0;return E(Gm(a,b,4))}function Jra(a,b){a=a|0;b=b|0;if(!gZ(a,b)){fZ(b)}}function JR(a,b){return(a|0)==1179011410&b>>>0>80}function H1(a,b,c){a=a|0;b=b|0;c=c|0;cq(a,b,c,18)}function Cu(a){return(x[zb(a)>>2]-x[a>>2]|0)/52|0}function B$(a){return(x[zb(a)>>2]-x[a>>2]|0)/40|0}function AX(a){return(x[zb(a)>>2]-x[a>>2]|0)/56|0}function zz(a,b){x[a>>2]=x[b>>2];_c(a+4|0,b+4|0)}function u$(a,b){a=a|0;b=b|0;if(!t$(a,b)){aw(b)}}function tu(a){a=a|0;uc(a+4208|0);return ag(a)|0}function tea(a){a=a|0;return VH(a,47592,12589)|0}function qp(a,b){a=a|0;b=b|0;if(!ai(a,b)){gl(b)}}function qQ(a){a=a|0;uc(a+4256|0);return ag(a)|0}function o_(a,b){a=a|0;b=b|0;if(!aG(a,b)){gs(b)}}function iV(a,b){x[a>>2]=x[a>>2]+(b<<1);return a}function gi(a,b,c){return Fa(1016,a|0,b|0,c|0)|0}function fm(a,b,c){v[a+2|0]=c;w[a>>1]=b;return a}function fE(a,b){a=a|0;b=b|0;if(!N$(a,b)){Lr(b)}}function fD(a,b){a=a|0;b=b|0;if(!sZ(a,b)){mD(b)}}function eF(a,b){a=$E(a,b);if(!a){In(b)}return a}function cw(a){return(x[zb(a)>>2]-x[a>>2]|0)/6|0}function bT(a,b,c){x[a+4>>2]=c;v[a|0]=b;return a}function a1(a,b){a=a|0;b=b|0;if(!S0(a,b)){FE(b)}}function Xn(a,b,c){a=Nd(a);x[a+4>>2]=c;x[a>>2]=b}function UB(a){x[a+24>>2]=z[a+20>>1]<<z[a+22>>1]}function U$(a,b){a=y$(a,b);if(!a){jE(b)}return a}function RM(a,b){a=a|0;b=b|0;ml(a,b,74456,74464)}function QM(a,b){a=a|0;b=b|0;ml(a,b,74472,74480)}function QG(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0}function NM(a,b){a=a|0;b=b|0;ml(a,b,75276,75284)}function MQ(a){a=a|0;dc(a+4208|0);return ag(a)|0}function MM(a,b){a=a|0;b=b|0;ml(a,b,75292,75300)}function LM(a,b){a=a|0;b=b|0;ml(a,b,76104,76112)}function K_(a,b){x[a>>2]=x[a>>2]+D(b,6);return a}function KM(a,b){a=a|0;b=b|0;ml(a,b,76120,76128)}function HM(a,b){a=a|0;b=b|0;ml(a,b,76932,76940)}function HE(a,b){a=a|0;b=b|0;if(!Kp(a,b)){zp(b)}}function GM(a,b){a=a|0;b=b|0;ml(a,b,76948,76956)}function GB(a){return(x[zb(a)>>2]-x[a>>2]|0)/7|0}function CL(a,b){if(!a){return 0}return Xy(a,b)}
function Bw(a,b){a=a|0;b=b|0;if(!gx(a,b)){fx(b)}}function z5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500468))}function x5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500476))}function v5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500288))}function ud(a,b){return dr(x[b>>2],x[a>>2])?b:a}function tB(a){if(y[a+24|0]){mT(a);v[a+24|0]=0}}function t5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500296))}function rea(a){a=a|0;return VH(a,47612,8191)|0}function r5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500304))}function qe(a,b){return dl(z[a>>1],z[b>>1])?b:a}function p5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500312))}function n5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500256))}function lo(a){return ib[x[x[a>>2]+28>>2]](a)|0}function k5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500264))}function i5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500272))}function hfa(a,b,c){a=a|0;b=b|0;c=c|0;LO(a,b,c)}function hJ(a){var b=0,c=0;b=a,c=Od(),x[b>>2]=c}function gqa(a,b){a=a|0;b=b|0;bq(a,b,650,649,8)}function g5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500280))}function f5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500352))}function e5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500360))}function cva(a,b,c){a=a|0;b=b|0;c=c|0;I0(a,b,c)}function cha(a){a=a|0;dQ(a);Sz(a);v[a+4202|0]=1}function ad(a,b){return nr(x[a>>2],x[b>>2])?b:a}function Zm(a,b){return Mv(B[b>>2],B[a>>2])?b:a}function Ze(a,b){return dr(x[a>>2],x[b>>2])?b:a}function Wz(a,b){return Mv(B[a>>2],B[b>>2])?b:a}function Wua(a,b){a=a|0;b=b|0;bq(a,b,299,298,8)}function Wca(a){a=a|0;return+C[x[a+4>>2]+16>>3]}function Uta(a,b){a=a|0;b=b|0;bq(a,b,364,363,8)}function Tl(a,b){return jn((b<<1)+123824|0,2,a)}function Sha(a){a=a|0;v[a+4202|0]=1;nQ(a);pQ(a)}function Rla(a,b,c){a=a|0;b=b|0;c=c|0;fe(a,b,c)}function Qra(a,b){a=a|0;b=b|0;bq(a,b,521,520,6)}function Qpa(a,b){a=a|0;b=b|0;bq(a,b,683,682,8)}function Qk(a){return ib[x[x[a>>2]+36>>2]](a)|0}function P0(a,b){return(b&255)==2&(a&255)>>>0<3}function Ov(a,b){a=a|0;b=b|0;return Mb(a,b,1)^1}function Nc(a,b){return dl(z[b>>1],z[a>>1])?b:a}function M5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500208))}function Kha(a){a=a|0;v[a+4202|0]=1;lQ(a);kQ(a)}function Kba(a,b){a=a|0;b=b|0;_c(a,vO(b,18256))}function K5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500216))}function J5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500412))}function I5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500404))}function H5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500420))}function Gb(a,b){return nr(x[b>>2],x[a>>2])?b:a}function G1(a,b){a=a|0;b=b|0;Zp(a,b);return a|0}function F5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500428))}function E5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500436))}function D5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500452))}function C5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500444))}function B5(a,b){a=a|0;b=b|0;$c(a,b,Uc(500460))}function AY(a){var b=0;b=x[a>>2];me(a);return b}function AL(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function wE(a,b,c){a=a|0;b=b|0;c=c|0;p0(a,b,c)}function vm(a){return(a>>>0<=127?-1:a^128)&255}function ui(a,b){return(D(b,104)+a|0)+484380|0}function sea(a,b){a=a|0;b=b|0;return Yw(a,b)|0}function ola(a,b){a=a|0;b=b|0;return Ty(a,b)|0}function nf(a,b){v[a+4|0]=1;x[a>>2]=b;return a}function ifa(a){a=a|0;return aI(a,6626,1068)|0}function fqa(a,b){a=a|0;b=b|0;return PX(a,b)|0}function d4(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,c,b)}function cv(a){return(a>>>0<9?a:a-9|256)&65535}function co(a,b,c,d,e){Oa(a|0,b|0,c|0,d|0,e|0)}function aj(a,b){return y[a+b|0]!=63&b>>>0<=46}function Ym(a){a=Nj(a);x[a>>2]=124916;return a}function Wv(a,b){return y[a+b|0]!=63&b>>>0<=15}function Vca(a){a=a|0;return x[x[a+4>>2]+8>>2]}function Ut(a,b){return(a&255)>>>0<(b&255)>>>0}function Taa(a){a=a|0;x[a>>2]=77472;return a|0}function TZ(a,b,c){a=a|0;b=b|0;c=c|0;Q0(a,b,c)}function T$(a,b,c){a=a|0;b=b|0;c=c|0;T0(a,b,c)}function Pja(a,b){a=a|0;b=b|0;QA(zR(a+24|0,b))}function Os(a,b,c,d,e){Ea(a|0,b|0,c|0,d|0,e|0)}function Mg(a,b){v[a+4|0]=0;x[a>>2]=b;return a}function Maa(a){a=a|0;x[a>>2]=76972;return a|0}function Lf(a,b,c){if(!(y[a|0]&32)){uE(b,c,a)}}function LU(a){QB(a);Tb(a+27|0,0,255);return a}function Kaa(a,b){a=a|0;b=b|0;OH(a,b,1162,308)}function Gg(a,b,c){a=pva(a,b,c,c>>31);return a}function Gaa(a){a=a|0;x[a>>2]=78280;return a|0}function G4(a,b,c){a=a|0;b=b|0;c=c|0;HI(a,b,c)}function CP(a){x[a>>2]=0;x[a+4>>2]=-1;return a}function Bfa(a){a=a|0;return aI(a,7109,1060)|0}function Baa(a){a=a|0;x[a>>2]=77892;return a|0}function xy(a,b,c){a=CK(a,b,c,-1,-1);return a}function wc(a,b){if(A[a>>2]>b>>>0){x[a>>2]=b}}function uL(a){a=a|0;Sy(x[x[a>>2]-12>>2]+a|0)}function sn(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function s2(a){a=a|0;x[a>>2]=78552;return a|0}function qda(a,b){a=a|0;b=b|0;XO(a,x[b+4>>2])}function pX(a){a=ova(a&65535,0,80,0);return a}function oL(a){a=a|0;Qy(x[x[a>>2]-12>>2]+a|0)}function mu(a,b){a=a|0;b=b|0;return lg(a,b)|0}function kda(a,b){a=a|0;b=b|0;RO(a,x[b+4>>2])}function jda(a,b){a=a|0;b=b|0;qP(a,x[b+4>>2])}function jaa(a){a=a|0;return Ba(x[a+60>>2])|0}function g2(a){a=a|0;x[a>>2]=41432;return a|0}function eu(a){a=a|0;x[a>>2]=48460;return a|0}function eta(a,b){a=a|0;b=b|0;Ex(a,b,17,3,16)}function ef(a,b){return Ut(y[a|0],y[b|0])?b:a}function e2(a){a=a|0;x[a>>2]=41192;return a|0}function dda(a,b){a=a|0;b=b|0;VO(a,x[b+4>>2])}function cda(a,b){a=a|0;b=b|0;QO(a,x[b+4>>2])}function cA(a){return x[zb(a)>>2]-x[a>>2]>>11}function aba(a,b){a=a|0;b=b|0;OH(a,b,1158,52)}function _da(a,b){a=a|0;b=b|0;Jz(x[a+4>>2],b)}function Zaa(a){a=a|0;BM(a);return x[a+16>>2]}function Z0(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function Yca(a,b){a=a|0;b=b|0;bP(a,x[b+4>>2])}function WK(a){a=SL(a);x[a>>2]=95200;return a}function V_(a){a=(a&65535)-98|0;hb=0;return a}function T2(a,b){a=a|0;b=b|0;return sx(a,b)|0}function Sua(a,b){a=a|0;b=b|0;Ex(a,b,44,2,44)}function S$(a){v[a+12|0]=y[a+12|0]|2;return a}function Rb(a,b){return Ut(y[b|0],y[a|0])?b:a}function RW(a){return _e(443250/+(a>>>0)*1e4)}function Ot(a){a=SL(a);x[a>>2]=94808;return a}function Nd(a){x[a>>2]=0;x[a+4>>2]=0;return a}function Ita(a,b){a=a|0;b=b|0;uH(a,b,368,367)}function HP(a,b){a=a|0;b=b|0;return vO(a,b)|0}function HJ(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Gf(a,b){if(z[a>>1]>b>>>0){w[a>>1]=b}}function D9(a){a=a|0;eL(x[x[a>>2]-12>>2]+a|0)}function Bi(a,b){if(x[a>>2]>(b|0)){x[a>>2]=b}}function B9(a){a=a|0;dL(x[x[a>>2]-12>>2]+a|0)}function Aua(a,b){a=a|0;b=b|0;uH(a,b,308,307)}function vI(a,b,c){a=a|0;b=b|0;c=c|0;cL(a,c)}function v7(a){a=a|0;$c(a,501696,Uc(500208))}function u7(a){a=a|0;$c(a,501704,Uc(500216))}function tA(a,b){return D((b-a|0)/6|0,6)+a|0}function t7(a){a=a|0;$c(a,501712,Uc(500412))}function s7(a){a=a|0;$c(a,501728,Uc(500404))}function r7(a){a=a|0;$c(a,501736,Uc(500420))}function p7(a){a=a|0;$c(a,501744,Uc(500428))}function o7(a){a=a|0;$c(a,501760,Uc(500436))}function nda(a){a=a|0;return YO(x[a+4>>2])|0}function n7(a){a=a|0;$c(a,501768,Uc(500452))}function m7(a){a=a|0;$c(a,501776,Uc(500444))}function lC(a){return x[zb(a)>>2]-x[a>>2]>>8}function l7(a){a=a|0;$c(a,501784,Uc(500460))}function k7(a){a=a|0;$c(a,501792,Uc(500468))}function j7(a){a=a|0;$c(a,501816,Uc(500476))}function iv(a){return x[zb(a)>>2]-x[a>>2]>>4}function iB(a){v[a+24|0]=0;v[a|0]=0;return a}function i7(a){a=a|0;$c(a,501848,Uc(500224))}function h7(a){a=a|0;$c(a,501856,Uc(500232))}function g7(a){a=a|0;$c(a,501864,Uc(500240))}function f7(a){a=a|0;$c(a,501872,Uc(500248))}function e7(a){a=a|0;$c(a,501880,Uc(500288))}function d7(a){a=a|0;$c(a,501888,Uc(500296))}function cp(a){return x[zb(a)>>2]-x[a>>2]>>5}function c7(a){a=a|0;$c(a,501896,Uc(500304))}function b7(a){a=a|0;$c(a,501904,Uc(500312))}function ada(a){a=a|0;return iP(x[a+4>>2])|0}function a7(a){a=a|0;$c(a,501912,Uc(500320))}function _z(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function _aa(a){a=a|0;BM(a);return x[a+4>>2]}function _6(a){a=a|0;$c(a,501928,Uc(500336))}function Zn(a){return x[zb(a)>>2]-x[a>>2]>>3}function Z6(a){a=a|0;$c(a,501936,Uc(500344))}function Y6(a){a=a|0;$c(a,501944,Uc(500256))}function X6(a){a=a|0;$c(a,501960,Uc(500264))}function V6(a){a=a|0;$c(a,501976,Uc(500272))}function Uz(a){return E(E(a*E(7900))+E(100))}function Uh(a){return x[x[a+8>>2]>>2]==(a|0)}function Ug(a){return x[zb(a)>>2]-x[a>>2]>>2}function UQ(a){x[a>>2]=x[a>>2]-2048;return a}function Tz(a){return x[nc(a)>>2]-x[a>>2]>>2}function T6(a){a=a|0;$c(a,501992,Uc(500280))}function S6(a){a=a|0;$c(a,502008,Uc(500352))}function R6(a){a=a|0;$c(a,502016,Uc(500360))}function Pn(a){return x[zb(a)>>2]-x[a>>2]>>1}function Np(a,b,c,d){a=pva(a,b,c,d);return a}function MY(a,b,c){w[a>>1]=b;v[a+2|0]=y[c|0]}function Jk(a){return fH(a,E(4294967296),-1)}function Ck(a){a=a&255;return(a|0)==255?-1:a}function Cb(a,b){if(!Cd(b)){a=Wh(b)}return a}function BZ(a,b,c){gc(a,b,Mi(b,b+c|0,0)-b|0)}function $6(a){a=a|0;$c(a,501920,Uc(500328))}function yp(a,b,c){return gk(a,b)>>>0>c>>>0}function su(a){a=a|0;ib[x[x[a>>2]+4>>2]](a)}function oo(a){a=a|0;hL(x[a>>2]);return a|0}function ip(a,b){w[a>>1]=b;w[a+2>>1]=b>>>16}function ep(a){return x[zb(a)>>2]-x[a>>2]|0}function eW(a){x[a>>2]=x[a>>2]-256;return a}function eP(a){return A[a+1074420>>2]/1e4|0}function dja(a,b){a=a|0;b=b|0;v[a+4201|0]=b}function cr(a,b){return a<<16>>16<b<<16>>16}function Zl(a,b){return cr(z[a>>1],z[b>>1])}function TU(a,b){x[a>>2]=x[a>>2]+b;return a}function Rw(a,b){if(b){Dc(a,b);return}Fb(a)}function Qf(a,b){if(y[a|0]>b>>>0){v[a|0]=b}}function Pi(a,b){a=a|0;b=b|0;return E(E(0))}function O4(a,b){a=a|0;b=b|0;return Dy(b)|0}function M4(a,b){a=a|0;b=b|0;return Ey(b)|0}function Lm(a){a=a|0;Ry(x[a>>2]);return a|0}function CB(a){v[a+4|0]=0;v[a|0]=0;return a}function Bia(a,b,c){a=a|0;b=b|0;c=c|0;Nd(a)}function zca(a,b){a=a|0;b=b|0;PN(a-88|0,b)}function yX(a){x[a>>2]=x[a>>2]-56;return a}function yW(a,b,c,d){gc(a,b,(d|0)==-1?c:d)}function y2(a){a=a|0;return x[a+4>>2]!=0|0}function vn(a){aC(x[a+20>>2]);x[a+20>>2]=0}function vf(a,b,c){a=ova(c,0,a,b);return a}function uy(a){a=a|0;return Xh(a,500476)|0}function uk(a){x[a>>2]=x[a>>2]-12;return a}function taa(a,b){a=a|0;b=b|0;Cm(a,b+12|0)}function sl(a,b){ib[x[x[b>>2]+44>>2]](a,b)}function rl(a,b){ib[x[x[b>>2]+32>>2]](a,b)}function pR(a){x[a>>2]=x[a>>2]-52;return a}function nm(a){x[a>>2]=x[a>>2]+28;return a}function nG(a){x[a>>2]=x[a>>2]-36;return a}function lpa(a,b){a=a|0;b=b|0;qH(a,b,2,31)}function lca(a,b){a=a|0;b=b|0;zN(a-88|0,b)}function kw(a){x[a>>2]=x[a>>2]-28;return a}function ko(a){a=a|0;Gs(a,164,125360,1057)}function jl(a){x[a>>2]=x[a>>2]+12;return a}function id(a,b){a=a|0;b=b|0;LO(a,b,Cf(b))}function ica(a,b){a=a|0;b=b|0;yN(a-92|0,b)}function hr(a){uf(a+24|0);dc(a+12|0);dc(a)}function hca(a,b){a=a|0;b=b|0;xN(a-92|0,b)}function er(a){x[a>>2]=x[a>>2]+32;return a}function cT(a,b){return CH(a,b,2147483647)}function bt(a,b){ib[x[x[b>>2]+40>>2]](a,b)}function br(a){x[a>>2]=x[a>>2]-16;return a}function bm(a){x[a>>2]=x[a>>2]+52;return a}function aZ(a){x[a>>2]=x[a>>2]-33;return a}function _o(a){x[a>>2]=x[a>>2]-32;return a}function _ca(a){a=a|0;return+cP(x[a+4>>2])}function _9(a){a=a|0;return Xh(a,500224)|0}function _4(a){a=a|0;Gs(a,164,125360,1192)}function Y_(a){x[a>>2]=x[a>>2]-20;return a}function YP(a){return E(E(a*E(96))+E(-96))}function St(a){return(a|0)<=65535&(a|0)>=0}function Sf(a){x[a>>2]=x[a>>2]+20;return a}function S9(a){a=a|0;return Xh(a,500240)|0}function Oy(a){a=a|0;return Xh(a,500404)|0}function Op(a){rs(a+32|0);ub(a+12|0);tb(a)}function Mua(a,b){a=a|0;b=b|0;pw(a+36|0,b)}function Ly(a){a=a|0;return Xh(a,500420)|0}function Jg(a){return E(F(a))==E(Infinity)}function JL(a,b){return E(zx(a?E(-b):b)*b)}function Gka(a,b){a=a|0;b=b|0;us(a+40|0,b)}function FD(a){a=a|0;return Xh(a,500428)|0}function Ek(a){tb(a+36|0);uc(a+24|0);Sk(a)}function DI(a){a=a|0;return FH(a,118416)|0}function CI(a){a=a|0;return FH(a,118312)|0}function By(a){a=a|0;return Xh(a,500468)|0}function BI(a){a=a|0;return EH(a,118208)|0}function Ay(){da(Ym(ac(4))|0,125e3,34);p()}function Aw(a){a=a|0;return Xh(a,500412)|0}function Aca(a,b){a=a|0;b=b|0;QN(a-88|0,b)}function AI(a){a=a|0;return EH(a,118104)|0}function A$(a){x[a>>2]=x[a>>2]-40;return a}function $s(a){x[a>>2]=x[a>>2]-24;return a}function $o(a){x[a>>2]=x[a>>2]+16;return a}function yca(a,b){a=a|0;b=+b;NN(a-88|0,b)}function yN(a,b){a=a|0;b=b|0;SH(a,b,2048)}function xe(a){return Bb(a&65535)<<16>>16}function xN(a,b){a=a|0;b=b|0;SH(a,b,4096)}function wq(a){a=a|0;Bq(a+8|0);return a|0}function wca(a,b){a=a|0;b=+b;LN(a-88|0,b)}function vqa(a,b){a=a|0;b=b|0;Ei(a,b,274)}function vg(a){x[a>>2]=x[a>>2]+6;return a}function uca(a,b){a=a|0;b=+b;JN(a-88|0,b)}function tC(a){x[a>>2]=x[a>>2]-1;return a}function qqa(a,b){a=a|0;b=b|0;Ei(a,b,106)}function nua(a,b){a=a|0;b=b|0;qH(a,b,3,8)}function nD(a){x[a>>2]=x[a>>2]-6;return a}function n6(a,b){a=a|0;b=b|0;Bn(a,113384)}function mz(a,b,c){gc(a,(c<<12)+b|0,4096)}function me(a){x[a>>2]=x[a>>2]+1;return a}function m6(a,b){a=a|0;b=b|0;Bn(a,113404)}function lz(a,b){a=a|0;b=b|0;lg(a,b+36|0)}function lia(a){a=a|0;v[a+4202|0]=1;BQ(a)}function ky(a,b){a=a|0;b=b|0;lg(a,b+12|0)}function kca(a){a=a|0;return wq(a-92|0)|0}function jj(a){x[a>>2]=x[a>>2]-2;return a}function iy(a,b){a=a|0;b=b|0;lg(a,b+16|0)}function iI(a){a=Da(a|0)|0;hb=gb;return a}function hha(a){a=a|0;return x[a+4260>>2]}function dv(a){Wm(a,Yo(a),78784);return a}function dP(a){return+A[a+1074420>>2]/1e4}function cta(a,b){a=a|0;b=b|0;Ei(a,b,282)}function cca(a){a=a|0;return wq(a-96|0)|0}function an(a){return E(F(a))<E(Infinity)}function aca(a,b){a=a|0;b=+b;rN(a-96|0,b)}function aK(a,b){a=a|0;b=b|0;lg(a,b+24|0)}function _u(a){x[a>>2]=x[a>>2]+8;return a}function ZP(a){a=a|0;Tb(a+4296|0,0,81928)}function YJ(a,b){a=a|0;b=b|0;lq(a,b+28|0)}function Xg(a,b,c){Nk(b,b+c|0,a);return a}function XJ(a,b){a=a|0;b=b|0;lq(a,b+40|0)}function WJ(a,b){a=a|0;b=b|0;lq(a,b+52|0)}function UT(a){x[a>>2]=x[a>>2]-7;return a}function Tf(a){a=a|0;bi(a+8|0);return a|0}function Qq(a,b){v[a|0]=b+48;return a+1|0}function Pp(a){x[a>>2]=x[a>>2]-8;return a}function Ni(a){x[a>>2]=x[a>>2]-4;return a}function Md(a){x[a>>2]=x[a>>2]+2;return a}function Je(a){x[a>>2]=x[a>>2]+4;return a}function Iua(a,b){a=a|0;b=b|0;Ei(a,b,136)}function Ht(a){a=a|0;Dl(a+8|0);return a|0}function Ft(a){a=a|0;Dl(a+4|0);return a|0}function Ds(a,b){x[a>>2]=b;hl(b);return a}function Cl(a){a=a|0;return tL(a)<<24>>24}function Cg(a,b,c){Wg(b,b+c|0,a);return a}function Cca(a){a=a|0;return wq(a-88|0)|0}function AB(a,b){if(B[a>>2]>b){B[a>>2]=b}}function $J(a,b){a=a|0;b=b|0;lg(a,b+48|0)}function zt(a){return a-65>>>0<26?a|32:a}function zl(a){return(a|0)==32|a-9>>>0<5}function ura(a,b){a=a|0;b=b|0;Ei(a,b,42)}function so(a,b,c){return ib[c|0](a,b)|0}function pf(a,b){x[a+8>>2]=b|-2147483648}function oqa(a,b){a=a|0;b=b|0;Ei(a,b,72)}function mg(a,b){a=pva(0,a,b,0);return a}function l6(a,b){a=a|0;b=b|0;Dc(a,11280)}function k6(a,b){a=a|0;b=b|0;Dc(a,11397)}function je(a,b){return(b|0)!=0&(a|0)!=0}function j_(a,b,c){x[a>>2]=b;x[a+4>>2]=c}function ij(a,b){v[a|0]=b;v[a+1|0]=b>>>8}function hc(a){x[x[a>>2]+4>>2]=x[a+4>>2]}function el(a){return D(Qn(a),_d(a))&255}function dta(a,b){a=a|0;b=b|0;sw(a,b,17)}function cja(a){a=a|0;return y[a+4201|0]}function bja(a){a=a|0;return y[a+4202|0]}function Vr(a,b,c,d,e){BH(a,b,c,d,e,256)}function TY(a,b){a=a|0;b=b|0;Ei(a,b,284)}function Qx(a){return a-502208>>>2&65535}function Qua(a,b){a=a|0;b=b|0;xH(a,b,28)}function Ota(a,b){a=a|0;b=b|0;Ei(a,b,34)}function Kj(a){w[a+4>>1]=65535;x[a>>2]=0}function Jga(a){a=a|0;return(a|0)==277|0}function Fw(a,b,c,d,e){BH(a,b,c,d,e,128)}function FG(a,b){Ub(a,b);Ub(a+4|0,b+4|0)}function Ct(a,b){x[a+24>>2]=x[a+24>>2]+b}function Al(a){return a-97>>>0<26?a&95:a}function xca(a){a=a|0;return+MN(a-88|0)}function xR(a,b){x[a>>2]=x[a>>2]+D(b,6)}function x0(a,b){a=a|0;b=b|0;Ei(a,b,50)}function vi(a){return(a&65535)>>>0<3999}function vca(a){a=a|0;return+KN(a-88|0)}function uX(a,b,c,d){return sn(c,d,a,b)}function tca(a){a=a|0;return+IN(a-88|0)}function sI(a){return(z[a+2>>1]<<2)+a|0}function s1(a,b){a=a|0;b=b|0;Ei(a,b,59)}function oP(a,b){return $H(a,b,1075834)}function nt(a){return(a|0)==32|(a|0)==9}function mP(a,b){return _H(a,b,1075834)}function lY(a,b){a=a|0;b=b|0;return b|0}function lP(a,b){return _H(a,b,1075835)}function kP(a,b){return $H(a,b,1075835)}function jn(a,b,c){return Wg(a,a+b|0,c)}function i0(a,b){x[a>>2]=x[a>>2]+(b<<1)}function f1(a,b){a=a|0;b=b|0;sw(a,b,11)}function cK(a,b){a=a|0;b=b|0;rf(a,1,45)}function bK(a,b){a=a|0;b=b|0;ny(a,1,45)}function _y(a){return(q(a),j(2))>>>20|0}function _g(a,b,c){v[a+4|0]=c;x[a>>2]=b}function XS(a,b){return(Yl(a,b)|0)!=255}function XK(a){x[a+4>>2]=x[a+4>>2]|8192}function W3(a){a=a|0;if(a){uI(ql(a),1)}}function Uv(a,b,c){return a<b?b:a>c?c:a}function Tga(a){a=a|0;return-2013527448}function QI(a){a=a|0;return td(a-8|0)|0}function PZ(a,b){a=a|0;b=b|0;sw(a,b,32)}function PI(a){a=a|0;return _x(a-8|0)|0}function OI(a){a=a|0;return Zx(a-8|0)|0}function NI(a){a=a|0;return Yx(a-8|0)|0}function Mj(a,b){return rB(a&255,b&255)}function MI(a){a=a|0;return Xx(a-8|0)|0}function LS(a,b,c,d){return iq(a,b,c,d)}function LI(a){a=a|0;return Wx(a-8|0)|0}function KY(a,b){x[a>>2]=x[a>>2]+(b<<2)}function KI(a){a=a|0;return Vx(a-8|0)|0}function Ira(a,b){a=a|0;b=b|0;V0(a,b,8)}function HD(a){return lH(a,65535,65535)}function F0(a,b){return(a&255)==(b&255)}function Bb(a){return(a<<8|a>>>8)&65535}function BB(a,b,c){return a<b?b:a>c?c:a}function Am(a){a=x[a+8>>2];if(a){Db(a)}}function zw(a,b,c){return _p(a,b,c,20)}function vk(a,b){x[a+4>>2]=2;x[a>>2]=b}function uv(a,b,c){return _p(a,b,c,12)}function sha(a){a=a|0;return-620920304}function rx(a,b){x[a+4>>2]=3;x[a>>2]=b}function oe(a,b,c){yo(a,b,Sc(b,c)+b|0)}function l2(a){a=a|0;return x[a+16>>2]}function jy(a){a=a|0;return x[a+12>>2]}function iha(a){a=a|0;return-275227023}function i_(a,b,c){fm(a,b&65535,c&255)}function hia(a){a=a|0;return-270114148}function he(a){x[x[a+8>>2]>>2]=x[a>>2]}function eN(a){return a?(a|0)==2?3:2:1}function dt(a){a=a|0;return 2147483647}function d5(a,b){a=a|0;b=b|0;HH(a,b,0)}function c5(a,b){a=a|0;b=b|0;HH(a,b,1)}function boa(a){a=a|0;kX(a);return a|0}function b5(a,b){a=a|0;b=b|0;GH(a,b,0)}function _J(a){a=a|0;return x[a+60>>2]}function Yu(a,b,c){ng(a,c);fd(b+c|0,0)}function Xha(a){a=a|0;return-285139079}function Wia(a){a=a|0;return 542066252}function Wd(a,b){return Kb(a)+(b<<2)|0}function Vaa(a){a=a|0;return y[a+40|0]}function VJ(a){a=a|0;return x[a+64>>2]}function Ux(a,b){x[a+4>>2]=4;x[a>>2]=b}function Tu(a,b){return AH(a,b,-1,0,0)}function SQ(a){a=a|0;return 1869112133}function QX(a,b){a=a|0;b=b|0;xH(a,b,4)}function Oha(a){a=a|0;return-284078960}function Nj(a){x[a>>2]=125612;return a}function Mga(a,b){a=a|0;b=b|0;return 3}function LP(a,b,c){return jH(a,b,c,69)}function Kga(a,b){a=a|0;b=b|0;return 2}function Hha(a){a=a|0;return-281111764}function H$(a,b,c){return _p(a,b,c,40)}function Dj(a,b){x[a+4>>2]=1;x[a>>2]=b}function CJ(a,b,c){return _p(a,b,c,24)}function Bh(a){return fH(a,E(255),255)}function Aha(a){a=a|0;return-271958638}function $ga(a){a=a|0;return 302837129}function $4(a,b){a=a|0;b=b|0;GH(a,b,1)}function $2(a,b){a=a|0;b=b|0;Bs(a,1,b)}function yia(a,b){a=a|0;b=b|0;uF(a,b)}function waa(a,b){a=a|0;b=b|0;mu(a,b)}function vO(a,b){return Gt(a,b,Cf(b))}function vG(a,b,c){bc(a,b,kh(b,c)<<3)}function st(a){return(Ey(a)|0)!=(a|0)}function rt(a){return(Dy(a)|0)!=(a|0)}function ps(a){a=a|0;return x[a+4>>2]}function pp(a,b){w[a+8>>1]=b;return a}function pl(a){a=x[a>>2];if(a){xl(a)}}function p9(a){a=a|0;return UK(a,0)|0}function os(a){a=a|0;return x[a+8>>2]}function o9(a){a=a|0;return UK(a,1)|0}function nla(a,b){a=a|0;b=b|0;Or(a,b)}function mZ(a,b,c){bc(a,b,oc(b,c)<<2)}function ks(a,b,c){return aq(a,b,c,3)}function jP(a){return z[a+1074448>>1]}function jC(a,b,c){return aq(a,b,c,5)}function iD(a,b,c){Nk(a,(b<<2)+a|0,c)}function i9(a){a=a|0;return TK(a,0)|0}function hv(a,b,c){return aq(a,b,c,4)}function hX(a){return(a|0)>=120?120:a}function h9(a){a=a|0;return TK(a,1)|0}function gk(a,b){return qm(a,b)&65535}function gP(a){return x[a+1074424>>2]}function fP(a){return x[a+1074416>>2]}function ela(a,b){a=a|0;b=b|0;GU(a,b)}function dla(a,b){a=a|0;b=b|0;lT(a,b)}function _l(a,b){return v[a|0]<v[b|0]}function Zi(a,b,c){iD(b,c,a);return a}function Ye(a,b){x[a+4>>2]=b;return a}function XM(a){x[a>>2]=48780;return a}function Wn(a){x[a>>2]=77424;return a}function WV(a,b,c){return Fx(a,b,c,5)}function Ula(a,b){a=a|0;b=b|0;Vb(a,b)}function UI(a){a=E(a-a);return E(a/a)}function Tj(a){return(a-1&255)>>>0<17}function Tg(a,b,c){return aq(a,b,c,2)}function SP(a){return _i(UP(a)*32768)}function SM(a){x[a>>2]=74440;return a}function SL(a){x[a>>2]=94836;return a}function RE(a,b){Ns(a,b,20,214748365)}function Qz(a){a=a|0;dI(a,47512,1007)}function Qaa(a){a=a|0;return y[a+8|0]}function QV(a){return(a&65535)==65534}function Nn(a,b,c){return Fx(a,b,c,2)}function NP(a,b){a=a|0;b=b|0;return 0}function Mh(a){a=x[a>>2];if(a){EK(a)}}function Kr(a,b,c){return _p(a,b,c,6)}function Ki(a,b,c){_c(_c(a,b)+12|0,c)}function KT(a,b){return(0-b|0)!=(a|0)}function It(a,b){a=a|0;b=b|0;return-1}function Ip(a,b,c){return Fx(a,b,c,1)}function HR(a,b){Xc(a,b&4?16:8,1,0,0)}function Ez(a){x[a>>2]=48296;return a}function Eua(a,b){a=a|0;b=b|0;Ty(a,b)}function En(a){return(a&740327453)!=0}function Dz(a){x[a>>2]=48320;return a}function DY(a){bM(a);Ie(x[a+80>>2],a)}function Cz(a){x[a>>2]=48400;return a}function Bz(a){x[a>>2]=48440;return a}function AP(a){a=a|0;dI(a,47456,1005)}function $z(a,b){a=a|0;b=b|0;return 1}function $h(a,b,c){return aq(a,b,c,1)}function $G(a,b){Ns(a,b,12,357913942)}function zq(a){return z[a+480190>>1]}function zf(a){return F(a)==Infinity}function xta(a){a=a|0;return JD(a)|0}function xZ(a,b){Ns(a,b,6,715827883)}function xW(a,b){return D(b,872)+a|0}function vd(a,b){return D(b,160)+a|0}function uF(a,b){a=a|0;b=b|0;G_(a,b)}function tG(a,b){Gx(a,b,3,536870912)}function sT(a){return(a+5&255)>>>0<2}function rR(a,b){Ns(a,b,52,82595525)}function p4(a,b){a=a|0;b=b|0;Yw(a,b)}function nha(a){a=a|0;x[a+4224>>2]=0}function my(a){a=a|0;return v[a+8|0]}function ly(a){a=a|0;return v[a+9|0]}function lR(a,b){return Mk(a,b-a>>2)}function kla(a){a=a|0;return lh(a)|0}function i3(a,b){a=a|0;b=b|0;Ax(a,b)}function hl(a){x[a+4>>2]=x[a+4>>2]+1}function hP(a){return z[a+480214>>1]}function fv(a){return x[zb(a)>>2]<<5}function fo(a,b){a=a|0;b=b|0;$k(a,b)}function fk(a,b){a=a|0;b=b|0;l0(a,b)}function fX(a){return(a&255)>>>0<129}function fC(a,b,c,d,e){QU(a,b,c,d,e)}function eC(a,b){a=a|0;b=b|0;zV(a,b)}function bz(a){return!kd(a,125928,6)}function bua(a){a=a|0;return j$(a)|0}function a3(a,b){a=a|0;b=b|0;Cs(a,b)}function _V(a,b){Gx(a,b,4,268435456)}function Xr(a,b){a=a|0;b=b|0;ax(a,b)}function XV(a,b){Gx(a,b,5,134217728)}function Wf(a,b){a=a|0;b=b|0;lg(a,b)}function VP(a){x[a>>2]=0;x[a+4>>2]=0}function VD(a,b,c){vb(vb(a,b)+4|0,c)}function V2(a,b){a=a|0;b=b|0;Wp(a,b)}function SO(a){return x[a+480272>>2]}function Rx(a){return(a<<2)+502208|0}function RQ(a,b,c){a=a|0;b=b|0;c=c|0}function Pta(a){a=a|0;return Ec(a)|0}function Or(a,b){a=a|0;b=b|0;Wf(a,b)}function MC(a,b){if(!iY(a,b)){dY(b)}}function J2(a,b){a=a|0;b=b|0;fo(a,b)}function Co(a){return z[a+480188>>1]}function Ch(a){of(a+52|0);dc(a+40|0)}function Aq(a){return z[a+480192>>1]}function Aka(a){a=a|0;return Si(a)|0}function $k(a,b){a=a|0;b=b|0;Cm(a,b)}function zY(a){if(!y[a+4|0]){vY(a)}}function zJ(a){if(!y[a+4|0]){kJ(a)}}function yv(a,b){return(b-a|0)/56|0}function yl(a,b,c){return qK(a,b,c)}function y0(a){a=a|0;return Zw(a)|0}function xA(a,b){return D(b,28)+a|0}function wf(a,b){return D(b,24)+a|0}function vb(a,b){x[a>>2]=b;return a}function tU(a){if(!y[a+4|0]){zW(a)}}function re(a,b){return Fc(a,le(b))}function rM(a){if(!y[a+4|0]){QH(a)}}function qv(a,b){return D(b,36)+a|0}function qr(a){return(a&255)==1?1:2}function qm(a,b){return(b-a|0)/52|0}function qla(a){a=a|0;gI(a,117,116)}function qW(a){if(!y[a+4|0]){pW(a)}}function pj(a,b){return(b-a|0)/24|0}function pd(a,b){return(a|0)!=(b|0)}function pN(a){if(!y[a+4|0]){oN(a)}}function nr(a,b){return a>>>0<b>>>0}function mm(a,b){return lm(Zc(a,b))}function maa(a,b){a=a|0;b=b|0;Db(b)}function lc(a,b){return(a|0)==(b|0)}function l0(a,b){g0(a,x[a+16>>2]|b)}function kL(a){a=a|0;return Dl(a)|0}function kK(a,b,c){return kd(a,b,c)}function js(a,b){return(b-a|0)/36|0}function jm(a){if(!y[a+4|0]){M$(a)}}function jW(a){if(!y[a+4|0]){iW(a)}}function iZ(a,b){return D(b,33)+a|0}function hj(a,b){return D(b,52)+a|0}function gu(a,b,c){return Kz(a,b,c)}function gm(a){return lH(a,255,255)}function fda(a,b){a=a|0;b=b|0;$O(a)}function eh(a,b){return D(b,20)+a|0}function dj(a){if(!y[a+4|0]){NZ(a)}}function dh(a){if(!y[a+4|0]){gR(a)}}function b2(a){a=a|0;lG(Tb(a,0,36))}function ak(a){if(!y[a+4|0]){TF(a)}}function aL(a){a=a|0;return jx(a)|0}function a2(a){a=a|0;return bi(a)|0}function _x(a){a=a|0;return a+184|0}function Zx(a){a=a|0;return a+472|0}function ZG(a,b,c){return kK(a,b,c)}function Yx(a){a=a|0;return a+496|0}function YC(a,b){return Pe(a,0-b|0)}function Xx(a){a=a|0;return a+508|0}function Xb(a,b){return Oe(a,b&255)}function Wx(a){a=a|0;return a+520|0}function WD(a,b){return Pe(a,b-a|0)}function Vx(a){a=a|0;return a+532|0}function Vi(a,b,c){return nl(a,b,c)}function VE(a){if(!y[a+4|0]){UE(a)}}function Uf(a,b){return(b-a|0)/20|0}function Ud(a,b){return(b-a|0)/12|0}function Sw(a){v[a+2|0]=0;w[a>>1]=0}function RF(a){a=a|0;return ih(a)|0}function Qj(a,b){return Lg(a,b)&255}function Pr(a,b){return(b-a|0)/28|0}function Ol(a){return J$(a,251,255)}function Nq(a){if(y[a+24|0]){mT(a)}}function Lv(a,b){return(b-a|0)/33|0}function LW(a){if(!y[a+4|0]){KW(a)}}function L9(a){a=a|0;return Bl(a)|0}function Kja(a){a=a|0;sw(a,22255,1)}function Ju(a){return!(a&204473357)}function Jr(a,b){return(b-a|0)/40|0}function Hd(a,b){return D(b,12)+a|0}function Gw(a,b){w[a>>1]=b;return a}function Gca(a,b){a=a|0;b=b|0;pP(a)}function F2(a){a=a|0;return Pg(a)|0}function DF(a){a=a|0;return Zd(a)|0}function Cr(a,b,c){return Wg(a,b,c)}function CC(a,b){return D(b,56)+a|0}function C7(a){a=a|0;return gy(a)|0}function Be(a,b,c){return AK(a,b,c)}function $u(a){if(!y[a+4|0]){JG(a)}}function zp(a){v[a|0]=0;v[a+1|0]=0}function yF(a){return(a&255)+704|0}function xx(a,b){return am(a,b,12)}function xu(a,b){return(a-b|0)/6|0}function wl(a){return(a&255)>>>0>1}function td(a){a=a|0;return a+16|0}function tT(a){Ae(a+8|0);kT(a+4|0)}function sy(a,b){return!(b>>>31|0)}function sG(a,b){return am(a,b,36)}function rq(a,b){v[a|0]=b;return a}function ji(a,b){a=a|0;b=b|0;Fb(a)}function g_(a,b){return Dx(a,b,56)}function gZ(a,b){return Dx(a,b,18)}function gJ(a){C[(fb-16|0)+8>>3]=a}function f0(a,b){return am(a,b,28)}function es(a,b){return(b<<11)+a|0}function ej(a){return a&2147483647}function dr(a,b){return(a|0)<(b|0)}function c$(a,b){x[a>>2]=x[a>>2]+b}function bN(a){return(Ck(a)|0)==-1}function aN(a,b){a=a|0;b=b|0;dc(b)}function Xk(a,b){return D(el(b),a)}function Wc(a,b){return D(b,6)+a|0}function To(a,b){return(b<<13)+a|0}function SJ(a){return Xh(a,500296)}function RJ(a){return Xh(a,500288)}function Pk(a,b){return(b-a|0)/6|0}function Oi(a){a=a|0;v[a+4202|0]=0}function NJ(a){return Xh(a,500312)}function My(a){return lc(a,-1)?0:a}function MJ(a){return Xh(a,500304)}function Il(a,b){return(a+b|0)-1|0}function FB(a,b){return(b-a|0)/7|0}function Cd(a){return(a&128)>>>7|0}function Bc(a,b){return CH(a,b,-1)}function Ao(a,b){x[a+1298472>>2]=b}function $M(a,b){a=a|0;b=b|0;cn(b)}function zO(a,b){x[a+480272>>2]=b}function yz(a,b){return OR(a,b)^1}function yb(a,b){return(b<<2)+a|0}function sc(a){x[a>>2]=0;return a}function pn(a,b){return(b<<8)+a|0}function pM(a){return a+1298412|0}function mL(a){return dH(a,93576)}function kt(a,b){return AK(a,0,b)}function hC(a,b){return am(a,b,4)}function fA(a){x[a>>2]=x[a>>2]+24}function dU(a,b){return am(a,b,8)}function cl(a){w[a>>1]=0;return a}function cg(a){return a!=a?E(0):a}function ce(a){return x[ec(a)>>2]}function cc(a,b){return Kb(a)+b|0}function bF(a){return a>>>0>8?5:4}function aC(a){if(a){Db(a+-64|0)}}function _ta(a){a=a|0;ig(a,3872)}
function _b(a,b){return(b<<1)+a|0}function _3(a){a=a|0;return 10286}function Zh(a){x[a>>2]=1;return a}function Z$(a){Gs(a,17,125240,33)}function Xd(a,b){return(b<<4)+a|0}function Wq(a){Gs(a,17,125292,51)}function Ve(a,b){return(b<<3)+a|0}function UF(a){return(a&16)>>>4|0}function UA(a){dc(a+4|0);return a}function Tqa(a){a=a|0;ig(a,16829)}function Tc(a){return J$(a,1,120)}function Opa(a){a=a|0;RY(a,65535)}function Oka(a){a=a|0;xg(a,Rj(a))}function Oh(a){return a-48>>>0<10}function Oe(a,b){return(b<<5)+a|0}function Mx(a,b){return x[a+b>>2]}function Kt(a){return dH(a,93512)}function Ko(a){return a+1074328|0}function Ib(a,b){return lc(a,b)^1}function Gn(a){x[a>>2]=2;return a}function G3(a){a=a|0;return 13092}function F3(a){a=a|0;return 10809}function Bsa(a){a=a|0;ig(a,16226)}function A9(a){a=a|0;return 10406}function $3(a){a=a|0;return 13206}function xsa(a){a=a|0;ig(a,4484)}function xpa(a){a=a|0;ig(a,4165)}function ww(a,b,c,d){HB(a,b,c,d)}function wg(a,b,c,d){df(a,c,d,b)}function vF(a,b,c,d){kx(a,b,c,d)}function tsa(a){a=a|0;ig(a,4378)}function rv(a){v[a|0]=0;return a}function mf(a,b,c){yo(a,b,b+c|0)}function lra(a){a=a|0;lw(a,3863)}function kF(a){Wm(a,Vp(a),78784)}function jw(a,b,c){sH(a,b,c,128)}function jva(a){a=a|0;ig(a,4358)}function jra(a){a=a|0;lw(a,4887)}function jca(a){a=a|0;bu(a-92|0)}function iO(a){a=a|0;du(a);Db(a)}function e4(a){a=a|0;return 6920}function bca(a){a=a|0;bu(a-96|0)}function _K(a){x[a+72>>2]=499224}function YK(a){x[a+72>>2]=499308}function XN(a){a=a|0;Vm(a);Db(a)}function X3(a){a=a|0;return 6901}function VF(a){return(a&2)>>>1|0}function Uqa(a){a=a|0;ig(a,3985)}function UN(a){a=a|0;xq(a);Db(a)}function SY(a,b){yc(a,b+4|0,256)}function Ow(a,b){return rva(a,b)}function N2(a){a=a|0;ig(a,16856)}function L2(a){a=a|0;gI(a,50,49)}function Kg(a,b){vb(sc(a)+4|0,b)}function H3(a){a=a|0;return 9845}function EQ(a){return(a&8)>>>3|0}function E3(a){a=a|0;return 5720}function Bca(a){a=a|0;bu(a-88|0)}function zh(a,b){return Yc(a,b)}function zg(a){tb(a+20|0);tb(a)}function zd(a){return wb(Kb(a))}function zba(a){a=a|0;Db(Zt(a))}function yj(a,b){return a>>>b&1}function yf(a,b){return Fc(a,b)}function xl(a){if(JK(a)){Db(a)}}function x6(a){a=a|0;tb(500596)}function wi(a,b,c){df(a,c,20,b)}function vq(a,b){return yb(a,b)}function vE(a,b,c){df(a,c,30,b)}function v6(a){a=a|0;tb(500628)}function ub(a){ke(a+12|0);ke(a)}function t_(a,b,c){df(a,c,24,b)}function t6(a){a=a|0;tb(500532)}function r6(a){a=a|0;tb(500564)}function qk(a,b){return b-a>>11}function pE(a,b){return nr(a,b)}function nk(a,b,c){df(a,c,13,b)}function mT(a){jT(a+12|0);iT(a)}function mM(a,b){return kh(a,b)}function mE(a,b){return sp(b,a)}function lt(a,b){return Ud(a,b)}function kA(a,b){return lR(a,b)}function jq(a){return zb(a+8|0)}function jha(a){a=a|0;Db(eQ(a))}function ic(a,b){return zG(a,b)}function hn(a){tb(a+12|0);tb(a)}function gha(a){a=a|0;return 13}function fp(a,b){return dl(a,b)}function et(a){a=a|0;return 127}function e$(a,b){return WD(a,b)}function di(a,b){return pd(a,b)}function bj(a,b,c){df(a,c,28,b)}function _i(a){return Cn(Ee(a))}function _h(a,b){return Jw(a,b)}function _e(a){return Br(Ee(a))}function _G(a,b){return _c(a,b)}function Zk(a,b,c){df(a,c,22,b)}function Zg(a,b){return Ib(a,b)}function ZR(a,b){return XR(a,b)}function Yj(a,b){return Sc(a,b)}function Yha(a){a=a|0;Db(qQ(a))}function Yc(a,b){return Cb(a,b)}function YD(a,b){return Hk(b,a)}function Xj(a,b){return Oe(a,b)}function Xia(a){a=a|0;Db(MQ(a))}function We(a,b,c){df(a,c,32,b)}function Wb(a,b){return hj(a,b)}function Vg(a){return sT(a&255)}function Ui(a,b){return(a|b)!=0}function Sd(a,b){return oc(a,b)}function Rk(a,b,c){df(a,c,12,b)}function Raa(a){a=a|0;Db(Tt(a))}function Qu(a){nU(a+12|0);sU(a)}function Pc(a,b,c){gc(a,b,1<<c)}function O2(a){a=a|0;ig(a,4532)}function NE(a){return(a&255)==1}function Mw(a,b){return CF(a,b)}function Le(a){a=a|0;return a|0}function LA(a){w[a+480214>>1]=0}function L6(a){a=a|0;Qb(500612)}function J6(a){a=a|0;Qb(500644)}function Io(a,b){return Ut(a,b)}function Ik(a){tb(a+12|0);md(a)}function Ig(a){return Wi(a)?0:a}function IB(a,b){return Zc(a,b)}function Hj(a){OA(a,0);return a}function Hc(a,b){return es(a,b)}function Hb(a,b){return(a&b)!=0}function HC(a,b,c){df(a,c,64,b)}function H6(a){a=a|0;Qb(500548)}function Ge(a,b){return q0(a,b)}function Fy(a,b){return sh(a,b)}function Fc(a,b){return vb(a,b)}function FF(a,b){return BF(a,b)}function F6(a){a=a|0;Qb(500580)}function Ed(a){return(a&255)!=0}function Eaa(a){a=a|0;Db(tM(a))}function CR(a,b){return tA(a,b)}function Af(a,b){return gh(a,b)}function Ad(a,b){return!Cb(a,b)}function yQ(a){a=a|0;Db(zQ(a))}function xX(a){return ol(a,56)}function wd(a,b){HI(a,b,IC(b))}function uO(a){a=a|0;Db(xq(a))}function tZ(a,b){yo(a,b,td(b))}function sp(a,b){return a-b>>1}function sN(a,b){gH(a,b,13602)}function sC(a){return a+4096|0}function s4(a){a=a|0;Db(DI(a))}function rB(a,b){return a<<8|b}function r4(a){a=a|0;Db(CI(a))}function qU(a,b){Yu(a,Kb(a),b)}function q4(a){a=a|0;Db(BI(a))}function po(a){return(a|0)==-1}function p2(a){a=a|0;Db(xG(a))}function ou(a){return a>>>27^a}function oc(a,b){return b-a>>2}function oR(a){return ol(a,52)}function o4(a){a=a|0;Db(AI(a))}function mG(a){return ol(a,36)}function l4(a){a=a|0;Db(zI(a))}function ku(a){a=a|0;Db(ag(a))}function kh(a,b){return b-a>>3}function kE(a){return ol(a,28)}function i4(a){a=a|0;Db(yI(a))}function fc(a,b){x[a+100>>2]=b}function fJ(a){a=a|0;Db(ay(a))}function eo(a){a=a|0;Db(S_(a))}function eL(a){a=a|0;Db(pq(a))}function eJ(a){a=a|0;Db($x(a))}function dL(a){a=a|0;Db(Ff(a))}function bu(a){a=a|0;Db(wq(a))}function bA(a){a=a|0;Db(tu(a))}function _s(a){a=a|0;Db(by(a))}function _d(a){return a&64?2:1}function _U(a){return ol(a,32)}function Zc(a,b){return b-a>>1}function Z5(a){a=a|0;Db(Zs(a))}function Xp(a){return ol(a,12)}function X_(a){return ol(a,20)}function Wha(a){a=a|0;return 6}function WQ(a){return a-2048|0}function Vy(a){a=a|0;Db(Dl(a))}function Vn(a){a=a|0;Db(jx(a))}function Via(a){a=a|0;return 9}function V4(a){a=a|0;Db(RI(a))}function Uy(a){a=a|0;Db(mo(a))}function Uk(a){return a>>>0<11}function Th(a,b){return b-a>>8}function Sy(a){a=a|0;Db(Ht(a))}function Qy(a){a=a|0;Db(Ft(a))}function Q5(a){a=a|0;Db(YI(a))}function Py(a){a=a|0;Db(Et(a))}function Lk(a,b){return b-a>>4}function Lg(a,b){return b-a>>5}function JI(a){a=a|0;Db(Ys(a))}function Iv(a,b){return a-b>>2}function Ie(a,b){if(!a){Db(b)}}function GJ(a){a=a|0;Db(gy(a))}function G9(a){a=a|0;Db(Dt(a))}function FI(a){a=a|0;Db(Vs(a))}function EV(a){return a+4896|0}function CX(a,b){Ex(a,b,5,3,4)}function CO(a,b){gH(a,b,22255)}function CM(a){a=a|0;Db(DM(a))}function CG(a){return a+1024|0}function BL(){return(db()|0)>0}function Az(a){return ol(a,16)}function A4(a){a=a|0;Db(GI(a))}function xk(a){return(a&5)!=0}function xb(a,b){return a+b|0}function xQ(a){a=a|0;return 7}function xL(a){a=a|0;return-1}function wp(a,b){Ab(a+12|0,b)}function vM(a){return xk(a)^1}function oZ(a){rp(Tb(a,0,40))}function mc(a){a=a|0;return 0}function mQ(a){a=a|0;return 5}function lr(a){return a>>>0<2}function kD(a,b){bc(a,b,4896)}function fW(a){return a-256|0}function bf(a,b){w[a+28>>1]=b}function au(a,b){x[a+32>>2]=b}function as(a,b){df(a,b,26,3)}function Vj(a){return!(a&255)}function Uo(a,b){x[a+36>>2]=b}function TQ(a,b){fi(a,b,2048)}function Sc(a,b){return b-a|0}function R_(a,b){df(a,b,40,2)}function RX(a,b){bc(a,b,1108)}function Qn(a){return a&1?2:1}function Pj(a){return Dd(a)^1}function PC(a,b){bc(a,b,1024)}function NR(a,b,c){Xl(a,b,-c)}function NC(a){return a+128|0}function MP(){return 19989250}function Ke(a){a=a|0;return 2}function Ij(a){return a+4e4|0}function Hk(a,b){return a-b|0}function Fo(a){a=a|0;return 4}function Fb(a){QG(a);return a}function Ey(a){return FK(a,0)}function EX(a,b){df(a,b,33,1)}function E0(a,b){bc(a,b,1954)}function Dy(a){return FK(a,1)}function Dd(a){return(a|0)!=0}function DV(a){return a+512|0}function Ce(a){a=a|0;return 1}function CQ(a){a=a|0;return 3}function Bp(a){return a>>>0<5}function B0(a,b){df(a,b,13,1)}function Ar(a){return a+256|0}function xF(a,b){bc(a,b,772)}function xE(a,b){bc(a,b,512)}function w_(a,b){bc(a,b,236)}function wA(a,b){OA(a,le(b))}function vD(a,b,c){de(a,b,c)}function uW(a,b){yc(a,b,128)}function tp(a,b){Ge(a,b+8|0)}function tF(a,b){df(a,b,8,3)}function sX(a,b){bc(a,b,146)}function r_(a){return a+10|0}function ql(a){return a-24|0}function qd(a,b){return a>>b}function qZ(a,b){bc(a,b,128)}function oX(a,b){bc(a,b,608)}function oF(a,b){bc(a,b,497)}function nx(a,b){LG(a,le(b))}function nw(a,b){bc(a,b,192)}function nn(a){return a-32|0}function nc(a){return a+12|0}function mr(a,b){return a<<b}function mj(a){return a-36|0}function m_(a,b){bc(a,b,102)}function mU(a){lU(a,x[a>>2])}function lj(a){SF(a,x[a>>2])}function kl(a){return a-12|0}function kY(a){jY(a,x[a>>2])}function kC(a){return a-16|0}function jp(a){return a+14|0}function gp(a){LZ(a,x[a>>2])}function gY(a,b){bc(a,b,600)}function gW(a,b){fi(a,b,256)}function fw(a){z$(a,x[a>>2])}function fr(a,b,c){Fp(a,b,c)}function eV(a){dV(a,x[a>>2])}function dA(a){TQ(a,x[a>>2])}function cW(a){bW(a,x[a>>2])}function cU(a,b,c){we(a,b,c)}function cS(a){return a+24|0}function bw(a){return a-40|0}function bc(a,b,c){gc(a,b,c)}function bZ(a){return a-33|0}function a_(a,b){bc(a,b,576)}function ZZ(a,b){bc(a,b,674)}function ZV(a){gW(a,x[a>>2])}function ZS(a,b,c){j_(a,b,c)}function Yo(a){return a+32|0}function Yd(a,b){x[a+4>>2]=b}function W0(a,b,c){ff(a,c,b)}function Vp(a){return a+20|0}function Vh(a,b,c){l$(a,b,c)}function Ue(a,b){a=a|0;b=b|0}function UG(a,b,c){jf(a,c,b)}function TW(a,b){bc(a,b,204)}function TC(a,b){bc(a,b,130)}function SZ(a){return a+36|0}function OY(a){return a+3&-4}function OP(a){return a+48|0}function Nr(a){return a-28|0}function Nf(a){VQ(a,x[a>>2])}function ND(a,b){df(a,b,8,2)}function Me(a,b){v[a+11|0]=b}function M9(a){a=a|0;l0(a,1)}function L_(a,b){bc(a,b,218)}function L$(a){K$(a,x[a>>2])}function Jb(a,b,c){XF(a,b,c)}function JV(a,b){bc(a,b,263)}function JB(a){v[a+6152|0]=0}function I_(a,b){bc(a,b,157)}function IG(a){HG(a,x[a>>2])}function Hq(a,b){B[a+8>>2]=b}function Gq(a,b){B[a+4>>2]=b}function GA(a,b){v[a+34|0]=b}function Fq(a,b){v[a+33|0]=b}function FA(a,b){v[a+32|0]=b}function EA(a,b){v[a+35|0]=b}function Du(a){vS(a,x[a>>2])}function Dn(a,b){x[a+8>>2]=b}function DZ(a){FJ(a,x[a>>2])}function C_(a,b){bc(a,b,206)}function BX(a){return a-56|0}function Ac(a,b,c){xn(a,b,c)}function $X(a,b){bc(a,b,126)}function $$(a,b){bc(a,b,610)}function zb(a){return a+8|0}function z$(a,b){fi(a,b,40)}function yw(a,b){bc(a,b,65)}function yg(a,b){v[a+3|0]=b}function xf(a){return a-4|0}function vZ(a){return a-6|0}function uu(a){Tb(a,0,2048)}function tE(a,b){wH(a,b,32)}function s_(a){return a+6|0}function rZ(a,b){bc(a,b,80)}function qf(){Z$(11034);p()}function qE(a){x[a+12>>2]=0}function mw(a,b){wH(a,b,64)}function ln(){Wq(11034);p()}function jY(a,b){fi(a,b,32)}function hw(a,b){bc(a,b,64)}function hF(a,b){bc(a,b,38)}function hD(a,b){bc(a,b,33)}function gw(a,b){bc(a,b,66)}function fs(a,b){bc(a,b,36)}function fj(a){return a+3|0}function fF(a,b){Ei(a,b,37)}function ex(a,b){bc(a,b,20)}function ec(a){return a+4|0}function cZ(a,b){fi(a,b,33)}function bW(a,b){fi(a,b,16)}function bE(a,b){bc(a,b,16)}function af(a){return a+2|0}function aea(a){a=a|0;IP(a)}function aD(a,b){bc(a,b,40)}function Zv(a,b){bc(a,b,22)}function Wh(a){return a&127}function WY(a,b){bc(a,b,52)}function VT(a){return a-7|0}function VA(a){Tb(a,0,4096)}function U_(a,b){bc(a,b,98)}function U0(a,b){gc(a,b,20)}function R0(a,b){bc(a,b,17)}function Qp(a){return a-8|0}function Pw(a,b){gc(a,b,22)}function Pf(a){return a&255}function PE(a,b){bc(a,b,32)}function On(a){return a-2|0}function O_(a,b){bc(a,b,48)}function OV(a,b){return a<b}function NG(a,b){bc(a,b,24)}function Mv(a,b){return a<b}function Mn(a,b){gc(a,b,32)}function KP(){return 458755}function Jq(a){Tb(a,0,8192)}function Jc(a){return a+1|0}function JU(a,b){bc(a,b,27)}function Hw(a,b){bc(a,b,11)}function Hr(a,b){bc(a,b,12)}function HX(a,b){bc(a,b,96)}function HW(a){return a-1|0}function G$(a,b){yc(a,b,40)}function FJ(a,b){fi(a,b,24)}function Ev(a,b){bc(a,b,30)}function Dp(a,b){v[a+1|0]=b}function DN(a){return 0-a|0}function D0(a){Tb(a,0,1954)}function yd(a,b){x[a>>2]=b}function xc(a){x[a+8>>2]=0}function wQ(a,b){hR(a,3,b)}function wF(a){Tb(a,0,772)}function vs(a){a=a|0;xs(a)}function vc(a){a=a|0;Db(a)}function v_(a){Tb(a,0,236)}function tn(a,b){Fp(a,b,0)}function sfa(a){a=a|0;fb=a}function sF(a,b){Vh(a,2,b)}function rX(a){Tb(a,0,146)}function ph(a,b){bc(a,b,4)}function oW(a){oC(a,ce(a))}function nX(a){Tb(a,0,608)}function nW(a){pC(a,ce(a))}function nU(a){Sq(a,ce(a))}function nF(a){Tb(a,0,497)}function l1(a){a=a|0;bi(a)}function k_(a){ED(a,ce(a))}function jT(a){Lu(a,ce(a))}function ik(a,b){bc(a,b,5)}function iT(a){Mu(a,ce(a))}function fl(a,b){bc(a,b,8)}function fY(a){Tb(a,0,600)}function dd(){Z$(7718);p()}function dW(a){Tb(a,0,256)}function cD(a){bD(a,ce(a))}function _X(a){Tb(a,0,126)}function _$(a){Tb(a,0,610)}function Zr(a,b){bc(a,b,1)}function Zca(a){a=a|0;gb=a}function Zb(a){Bm(x[a>>2])}function Xs(a){xl(x[a>>2])}function Wi(a){return a!=a}function WZ(a){Tb(a,0,192)}function Vl(a){DB(a,ce(a))}function VQ(a,b){fi(a,b,4)}function Tv(a){DD(a,ce(a))}function TD(a,b){bc(a,b,6)}function SW(a){Tb(a,0,204)}function SF(a,b){fi(a,b,2)}function Rr(a,b){bc(a,b,7)}function RR(a){CA(a,ce(a))}function Qe(a){v[a+12|0]=1}function LZ(a,b){fi(a,b,1)}function KC(a){Tb(a,0,130)}function K$(a,b){fi(a,b,6)}function Jp(a,b){bc(a,b,2)}function JZ(a){pD(a,ce(a))}function Hga(){return fb|0}function H_(a){Tb(a,0,157)}function HZ(a){qD(a,ce(a))}function HG(a,b){fi(a,b,8)}function Ew(){Wq(7718);p()}function Dk(a,b){B[a>>2]=b}function B_(a){Tb(a,0,206)}function $w(a,b){bc(a,b,3)}function $Z(a){Tb(a,0,576)}function yO(){return 2048}function mD(a){Tb(a,0,80)}function jE(a){Tb(a,0,66)}function gs(a){Tb(a,0,36)}function gF(a){Tb(a,0,38)}function fd(a,b){v[a|0]=b}function f_(a){Tb(a,0,56)}function aw(a){Tb(a,0,64)}function XQ(a){Fm(a,2048)}function VY(a){Tb(a,0,52)}function T_(a){Tb(a,0,98)}function Qd(a){v[a+4|0]=1}function P_(a){Tb(a,0,48)}function Lp(a){return a&1}function IX(a){Tb(a,0,96)}function Hh(a){tb(a+16|0)}function $Y(a){Tb(a,0,33)}function vR(a,b){vS(a,b)}function uG(a,b){HG(a,b)}function sD(a,b){K$(a,b)}function pr(a,b){LZ(a,b)}function lE(a,b){Vk(a,b)}function kg(a,b){g0(a,b)}function kU(a){Ae(a+8|0)}function iW(a){hH(a,872)}function i$(a,b){TU(a,b)}function gj(a,b){Gw(a,b)}function gD(a,b){ZY(a,b)}function eA(a,b){re(a,b)}function bd(a,b){Ds(a,b)}function bV(a,b){dV(a,b)}function Zj(a){tb(a+4|0)}function ZU(a,b){pg(a,b)}function Xo(a,b){_c(a,b)}function Vu(a,b){fS(a,b)}function Tn(a,b){gG(a,b)}function Sh(a,b){Xo(a,b)}function SD(a,b){ic(a,b)}function Rd(a,b){Mg(a,b)}function Qg(a){a=a|0;p()}function MX(a,b){Ge(a,b)}function MU(a,b){Gh(a,b)}function Li(a,b){ni(a,b)}function Kn(a,b){SF(a,b)}function Kc(a){dc(a+8|0)}function Ih(a,b){VQ(a,b)}function Gd(a){ub(a+8|0)}function Fl(a,b){rq(a,b)}function FW(a,b){$l(a,b)}function Eo(a,b){vb(a,b)}function As(a,b){_G(a,b)}function $T(a,b){i0(a,b)}function $C(a,b){KY(a,b)}function np(a){DH(a,16)}function fh(a){v[a|0]=0}function _n(a){Bx(a,36)}function Nka(){ua();p()}function JJ(a){Fm(a,24)}function Ep(a){DH(a,11)}function EI(a){Bx(a,48)}function C$(a){Fm(a,40)}function Ag(a){Bx(a,24)}function yZ(a){Fm(a,6)}function xh(a){iN(a,0)}function wh(a){gN(a,0)}function tI(){va();p()}function rs(a){LG(a,0)}function og(a){IZ(a,0)}function ls(a){Fm(a,8)}function kj(a){Fm(a,2)}function aS(a){CS(a,0)}function XT(a){Fm(a,7)}function XA(a){yS(a,0)}function WA(a){xS(a,0)}function U3(){tI();p()}function Lc(a){Te(a,0)}function KW(a){hH(a,9)}function Jl(a){hN(a,0)}function ys(a){nc(a)}function yV(a){me(a)}function fU(a){Zo(a)}function cn(a){uc(a)}function Vw(a){cl(a)}function KV(a){sc(a)}function JC(a){vg(a)}function If(a){a=a|0}function IW(a){Nb(a)}function FX(a){rv(a)}function Eb(a){tb(a)}function BW(a){Je(a)}
// EMSCRIPTEN_END_FUNCS
e=y;var ib=c([null,tc,KG,Cm,z2,yG,j2,d2,c2,pG,kG,pe,J1,H1,uF,C1,u_,S_,Eoa,woa,soa,mva,hva,ow,fk,Uua,Z,yta,Aw,rm,nL,lh,up,Jta,Le,Goa,Dc,P5,FD,_j,tr,Bn,Msa,z_,ti,zV,eC,una,Rma,GU,Nla,gma,sg,Yka,Wj,Vka,Uka,Nka,Jka,Dka,BA,zka,ska,Vga,Gja,dR,eaa,daa,Jt,dR,fga,tP,lg,yfa,hfa,xea,sea,nea,iea,dea,Uda,Jda,Ada,Fca,sda,Ry,ua,Mb,X5,l5,a5,W4,T4,fo,B4,ela,p4,dla,b4,da,A3,l3,k3,j3,i3,h3,vH,g3,f3,e3,d3,c3,a3,$2,b3,x9,Cs,Zp,sg,_2,XG,WG,Z2,tx,Y2,VG,Wf,X2,V2,T2,vs,us,ci,ig,Q2,Wp,S2,R2,P2,W2,O2,RG,N2,RG,U2,SG,M2,L2,K2,J2,I2,cd,Mb,F2,Up,E2,lh,D2,rd,C2,il,rd,lx,B2,jx,ix,b2,A2,r2,q2,a2,Z1,W1,V1,Zw,lG,U1,T1,xka,yka,ST,vka,wka,DA,yu,Vb,Aka,fe,hG,Q1,P1,RF,N1,M1,RF,DF,Lw,G1,Ng,DF,Iw,Lja,Vja,Kja,lf,lla,O1,ug,$ua,kla,lua,_E,ZE,v1,u1,YE,t1,fg,s1,r1,Cc,Bw,q1,p1,o1,Vf,n1,sm,m1,WE,l1,i1,KE,h1,g1,f1,uw,e1,mF,JE,d1,c1,b1,a1,$0,EE,X0,N0,Bd,pw,jva,iva,CE,BE,gva,fva,eva,Bw,dva,M0,cva,vw,bva,ava,bl,Wua,Qr,Vua,Lb,dg,ig,Tua,wE,Sua,id,Wk,Rua,Qua,Pua,y0,x0,ld,Oua,vp,Nua,Mua,Lua,u0,t0,_j,lw,Kua,Jua,cma,Iua,hh,Hua,Gua,Aua,dk,Dua,Cua,Bua,Fua,Eua,Wf,k0,ai,Tf,xua,wua,vua,sua,dk,ck,rua,qua,pua,gE,T$,fE,oua,nua,mua,bl,x$,u$,iua,dua,m$,xo,cua,xg,Y$,bua,uw,aua,$ta,_D,_ta,k$,ix,Zta,Yta,f$,A_,Xta,bl,Uta,Qr,jk,Tta,Sta,x0,Rta,Qta,Ota,$_,__,tm,Nta,Mta,Lta,Ita,dk,Z_,Kta,ai,Tf,eE,Dta,Mr,k$,wta,vta,uta,tta,qta,Qr,pta,ota,qp,$_,nta,mta,ig,lta,kta,jta,ita,hta,q_,gta,fta,qK,p_,eta,dta,L0,o_,cta,bta,ata,jma,$sa,n_,_sa,n_,xta,Ysa,dk,Zsa,ai,Tf,kk,Tsa,Ssa,Rsa,Qsa,Nsa,Lsa,Ksa,Jsa,Isa,qp,Hsa,Gsa,Fsa,yD,I1,Esa,Dsa,Csa,Bsa,Asa,VZ,zsa,F1,ysa,xsa,wsa,vsa,UZ,usa,Usa,tsa,ssa,ig,rsa,iE,qsa,Vsa,psa,osa,nsa,uD,uD,TZ,msa,lsa,RZ,uD,OZ,ksa,u9,jsa,isa,hsa,gsa,fsa,esa,dsa,MZ,rd,rr,Ura,Rv,csa,wja,vja,uja,tja,sja,rja,bsa,asa,pg,$ra,_ra,Zra,Yra,KG,bma,$la,Ija,Tja,Uja,Xra,KZ,Wra,Vra,Ika,pja,$k,VG,Zla,ema,Yla,Xla,Qra,Pra,Ora,Nra,Mra,Lra,Kra,Jra,Ira,Hra,Gra,Era,Dra,Fra,_Y,Tf,TY,fD,Ara,eD,zra,yra,xra,wra,dD,vra,Lw,YE,ura,RY,QY,tra,Ur,sra,rf,rra,NY,qp,HE,qp,o_,Xr,ig,_E,qp,xo,ora,nra,mra,lra,_C,Gv,kra,jra,ira,hra,gra,fra,era,dra,cra,bra,ara,$qa,_qa,Zqa,Yqa,rD,Xqa,Wqa,Vqa,ig,QZ,PZ,AD,Uqa,Tqa,CE,ix,Sqa,Rqa,Qqa,Pqa,Oqa,Ila,Hla,Gla,Kqa,Lqa,Or,Mqa,Nqa,ew,pY,Hqa,jla,Mla,Xu,ila,hla,MT,Su,GT,gla,wT,RU,fla,RB,Oj,Ci,Aqa,zqa,Gr,Iqa,Ov,wqa,H0,vqa,uqa,XX,rr,tqa,sqa,Cw,rqa,KZ,qqa,pqa,Fr,oqa,nqa,mqa,lqa,GC,gqa,EC,fqa,eqa,QX,Gp,dqa,dk,ai,Tf,Ci,aqa,$pa,_pa,Zpa,eD,Wpa,Vpa,Fr,Upa,sm,Wja,Rpa,Qpa,ck,NX,EC,vw,Ppa,QX,Opa,Npa,Mpa,Av,Lpa,Av,Kpa,Dm,K1,Hpa,dk,Jpa,zC,wX,wv,Ipa,ai,Tf,Gr,Epa,Bpa,fD,Apa,xpa,wpa,kX,Cw,yD,vpa,CE,ig,mpa,lpa,Bw,kpa,jpa,ipa,hpa,Vv,gpa,vp,dpa,cpa,bpa,apa,$oa,_oa,qn,CW,Zoa,Yoa,Xoa,Woa,Voa,Uoa,Toa,Soa,Roa,Qoa,Poa,Ooa,Noa,eD,Moa,Loa,Koa,Ov,Joa,Ioa,Hoa,Qr,xla,Up,y0,Ela,Dla,Qr,Cla,Ci,Up,Bla,Ala,zla,Foa,kW,Boa,Aoa,zoa,yoa,xoa,$r,toa,roa,qoa,poa,ooa,noa,moa,loa,koa,joa,ioa,D3,VI,hoa,ig,goa,foa,Jla,kma,Pta,fV,hma,fma,aV,dma,ama,_la,SU,Tla,Vla,Ula,Sla,Zd,Rla,HU,Qla,Pla,Ola,xU,wU,uU,So,pU,Lla,Kla,Fla,op,vla,ck,TT,ss,uka,tka,rka,mla,qka,L1,pka,_w,ss,N0,oka,TT,tla,nka,yla,dk,ai,Tf,wla,dk,ai,Tf,ula,dk,ai,Tf,rla,ola,nla,Le,X0,cla,bla,ala,$ka,_ka,Zka,ima,boa,WP,Xka,Ec,Tka,Oja,Ska,H2,$1,S1,Y1,Qka,Pka,R1,_1,G2,X1,pS,Oka,Mka,Lka,oS,nS,SA,Kka,Wla,Hka,Gka,Fka,Eka,nR,Fja,Xja,sx,lT,yG,MG,DA,oS,Bka,$k,Bs,Tr,qla,sla,jka,ika,ck,hka,EC,gka,fka,eka,Gr,dka,Ci,cka,bka,aka,$ja,_ja,dk,ai,Tf,kka,Sja,Rja,Qja,Pja,ni,Um,Nja,Mja,vu,wu,Jja,Dja,Cja,Bja,Aja,zja,kR,Hja,Eq,jR,vl,ni,pg,xja,qja,T9,yja,Eja,nja,mja,Fia,lja,kja,ZQ,$f,iR,Yia,Gia,wn,Aia,mka,zia,xia,wia,via,DA,yia,se,mu,mu,uia,tia,ria,JQ,AQ,Zha,Pha,Iha,Bha,tha,kha,mha,aha,Uga,PP,ju,Oga,Nga,bba,cba,JP,Fga,IP,HP,Cka,eba,Bga,PP,Aga,Mba,Aba,Pba,BP,sM,AP,Qz,xga,tea,xq,rea,Tm,zP,Jba,xP,Iba,yP,Hba,vP,qK,$ba,sga,Kba,Pz,NY,Oz,Nz,Mz,iga,gga,AP,Qz,cga,bga,aga,$fa,_fa,Zfa,Yfa,Xfa,Wfa,Vfa,Ufa,Tfa,Sfa,Rfa,Qfa,Pfa,Ofa,Nfa,Mfa,Lfa,Kfa,Jfa,Ifa,Hfa,Gfa,sP,rP,qP,AG,raa,Qba,pP,cP,Fba,bP,aP,_ba,uaa,vaa,$O,Aaa,YO,XO,lz,VO,Qz,TO,RO,QO,Bo,taa,saa,PO,OO,NO,MO,KO,JO,IO,HO,GO,FO,EO,DO,Jz,BO,AO,kS,Dv,Iz,Hz,yea,xO,wea,vea,uea,rO,oea,BP,mea,Gda,lea,Fda,kea,Eda,jea,Dda,hea,Cda,gea,Bda,eea,Laa,sM,jr,pla,Ax,ts,uU,Wba,Vba,Uba,Sba,Oba,Wka,Lba,Dba,Gba,Z9,S9,R9,Eba,sm,bl,bl,Bba,Rka,Nba,Xba,Rba,mx,_,dba,kN,jN,Hz,FM,aba,$aa,Saa,wM,Kaa,Jaa,Faa,zaa,yaa,xaa,waa,qaa,paa,oaa,eS,coa,naa,maa,laa,kaa,gaa,faa,bL,aL,f4,_9,Y9,X9,W9,V9,U9,N9,lh,M9,Le,Y3,Z4,y9,aL,v9,Jn,lL,Ly,f9,e9,By,li,ki,mt,Db,Ay,uh,Cl,zy,Lm,Y8,X8,wj,th,rK,vj,Oy,uy,li,ki,it,mi,L9,rm,oo,wj,th,mK,vj,D8,y8,gL,t8,Bt,up,o8,ft,If,Y7,ko,X7,W7,V7,TJ,T7,Gt,R7,Q7,zj,P7,TJ,N7,pZ,L7,K7,H7,G7,v7,u7,t7,s7,r7,q7,p7,o7,n7,m7,l7,k7,j7,i7,h7,g7,f7,e7,d7,c7,b7,a7,$6,_6,Z6,Y6,X6,W6,V6,U6,T6,S6,R6,AJ,Q6,C6,D6,E6,L6,J6,H6,F6,o6,p6,q6,x6,v6,t6,r6,O5,N5,M5,L5,K5,XI,J5,WI,I5,H5,G5,F5,E5,D5,C5,B5,A5,z5,y5,x5,w5,v5,u5,t5,s5,r5,q5,p5,o5,n5,m5,k5,j5,i5,h5,g5,f5,e5,_4,m4,n4,d5,c5,b5,$4,Hm,lq,D4,C4,Y4,X4,G4,F4,E4,yk,u4,t4,jo,ny,ti,tI,Vn,ps,aoa,$na,_na,Zna,Yna,Xna,Wna,Vna,Una,Tna,Sna,Rna,Qna,Pna,Ona,Nna,Mna,Lna,Kna,Jna,Ina,Hna,Gna,Fna,Ena,Dna,Cna,Bna,Ana,zna,yna,xna,wna,vna,tna,sna,rna,qna,pna,ona,nna,mna,lna,kna,jna,ina,hna,gna,fna,ena,dna,cna,bna,ana,$ma,_ma,Zma,Yma,Xma,Wma,Vma,Uma,Tma,Sma,Qma,Pma,Oma,Nma,Mma,Lma,Kma,Jma,Ima,Hma,Gma,Fma,Ema,Dma,Cma,Bma,Ama,zma,yma,xma,wma,vma,uma,tma,sma,rma,qma,pma,oma,nma,mma,lma,Vn,voa,uoa,Psa,Osa,zpa,ypa,spa,rpa,Cra,Bra,kqa,jqa,Sra,Rra,Yua,Xua,Hta,Gta,k1,j1,lva,kva,cqa,bqa,Dpa,Cpa,Doa,Coa,uua,tua,kua,jua,z1,y1,x1,w1,Tpa,Spa,Gpa,Fpa,yqa,xqa,Tra,Z0,Cta,Bta,Xsa,Wsa,zua,yua,Wta,Vta,Ypa,Xpa,lka,Zja,Yja,sta,rta,Ata,zta,Cqa,Bqa,fpa,epa,iqa,hqa,Fta,Eta,upa,tpa,opa,npa,fua,eua,qpa,ppa,Jqa,Eqa,Dqa,B1,A1,E1,D1,_ua,Zua,qra,pra,hua,gua,Gqa,Fqa,eoa,doa,eo,ps,e2,vc,ym,NP,vc,Le,vc,mc,Ce,Ce,mc,mc,f2,u2,t2,g2,vc,ym,vc,xG,p2,o2,Ce,n2,m2,l2,k2,i2,h2,tu,bA,su,SQ,mc,If,mc,mc,mc,Ue,Fo,jja,ija,hja,gja,fja,Pi,$z,$z,_z,RQ,_z,QQ,_z,QQ,If,Z0,eja,dja,cja,bja,aja,Oi,PQ,Cia,mc,mc,Ce,Zz,Ke,Ke,Ce,$ia,_ia,Ue,If,Ue,If,MQ,Xia,Wia,mc,If,mc,mc,mc,Ue,Via,LQ,Uia,Tia,Sia,Ria,Pi,Qia,Pia,Oia,Nia,Mia,Lia,Kia,Jia,Iia,Hia,Oi,HQ,mc,mc,Ce,Ke,Ke,Ce,KQ,IQ,ag,Qg,U3,Eia,aA,Dia,mc,Bia,RQ,iia,_ha,Qha,Jha,Cha,uha,lha,bha,Wga,vha,oja,Zia,sia,tu,bA,SQ,mc,If,mc,mc,mc,Ue,CQ,qia,pia,oia,nia,mia,Pi,lia,Oi,BQ,mc,mc,Ce,Ke,Ke,Ce,kia,jia,qQ,Yha,Xha,mc,If,mc,mc,mc,Ue,Wha,Vha,Uha,Tha,Pi,Sha,Oi,nQ,mc,mc,Ce,Ke,Ke,ku,Oha,mc,If,mc,mc,mc,Ue,mQ,Nha,Mha,Lha,Pi,Kha,Oi,kQ,mc,mc,Ce,Ke,Ke,tu,bA,Hha,mc,If,mc,mc,mc,Ue,mQ,Gha,Fha,Eha,Pi,Dha,Oi,hQ,mc,mc,Ce,Ke,Ke,zQ,yQ,Aha,mc,If,mc,mc,mc,Ue,xQ,zha,fia,eia,Pi,dia,Oi,cia,mc,mc,Ce,Ke,Ke,Ue,If,vQ,yha,xha,uQ,wha,tQ,sQ,yQ,hia,xQ,gia,vQ,bia,aia,uQ,$ha,tQ,sQ,ku,sha,mc,If,mc,mc,mc,Ue,Ke,rha,qha,pha,Pi,oha,Oi,nha,mc,mc,Ce,Ke,Ke,eQ,jha,iha,mc,If,mc,mc,hha,Ue,gha,fha,eha,dha,Pi,cha,Oi,Sz,mc,mc,Ce,Ke,Ke,Ue,If,ku,$ga,mc,If,mc,mc,mc,Ue,CQ,_ga,Zga,Yga,Pi,Xga,Oi,$P,mc,mc,Ce,Ke,Ke,ku,Tga,mc,If,mc,mc,mc,Ue,Fo,Sga,Rga,Qga,Pi,Pga,Oi,ZP,mc,mc,Ce,Ke,Ke,eu,vc,qea,uO,RN,uO,UN,Vm,XN,du,iO,wq,bu,Eca,Dca,QN,PN,NN,MN,LN,KN,JN,IN,HN,GN,FN,EN,CN,BN,AN,zN,yN,xN,wN,vN,uN,tN,rN,Cca,Bca,Aca,zca,yca,xca,wca,vca,uca,tca,sca,rca,qca,pca,oca,nca,mca,lca,kca,jca,ica,hca,gca,fca,eca,dca,cca,bca,aca,Le,Qg,Le,Qg,Le,Qg,Le,Qg,Qg,Zba,vc,Yba,Zt,zba,Tba,Le,Qg,Le,vc,yba,xba,Qg,ZM,YM,ZM,YM,Ue,_t,Ue,_t,aN,$M,aN,$M,vc,Cba,Le,vc,wba,vba,vc,RM,QM,Qg,sba,OM,rba,OM,uba,PM,tba,PM,vc,qba,pba,vc,NM,MM,Wt,Wt,Wt,Wt,oba,rz,rz,rz,vc,nba,mba,vc,LM,KM,jba,IM,iba,IM,lba,JM,kba,JM,vc,hba,gba,vc,HM,GM,Vt,Vt,Vt,Vt,fba,pz,pz,pz,Maa,vc,ym,vc,Tt,Raa,Ce,Ce,Qaa,Paa,ps,Oaa,Naa,Qg,Qg,Taa,vc,ym,vc,DM,CM,Ce,mc,Ce,_aa,Zaa,Yaa,Xaa,Waa,Vaa,Uaa,Qg,Baa,vc,ym,vc,tM,Eaa,Daa,Caa,Qg,Gaa,vc,ym,vc,CM,Iaa,Haa,s2,vc,ym,vc,vc,y2,Ce,Ce,ps,os,x2,w2,v2,Ue,_t,Ue,_t,jaa,iaa,haa,mo,Uy,Ue,AL,zL,yL,mc,mc,baa,xL,aaa,It,$9,It,Et,Py,Ue,AL,zL,yL,mc,mc,Q9,xL,P9,It,O9,It,Dt,G9,H9,F9,K9,J9,I9,pq,eL,E9,D9,Ft,Qy,pL,oL,Ff,dL,C9,B9,Ht,Sy,vL,uL,Le,vc,A9,d4,c4,a4,z9,Vn,caa,mc,w9,Uy,j9,i9,h9,g9,kL,Vy,Dl,Vy,Uy,m9,VK,l9,k9,Py,q9,p9,o9,n9,Ht,Sy,vL,uL,kL,Vy,Py,t9,VK,s9,r9,Ft,Qy,pL,oL,YI,Q5,su,yI,i4,h4,g4,b9,zI,l4,k4,j4,_8,Zs,Z5,Y5,W5,V5,U5,lY,T5,S5,R5,Vs,FI,y4,x4,w4,v4,Ys,JI,S4,R4,Q4,P4,O4,N4,M4,L4,K4,J4,I4,H4,gy,GJ,B7,A7,z7,y7,mc,x7,w7,$x,eJ,my,ly,ky,l6,k6,ay,fJ,os,jy,iy,n6,m6,eJ,fJ,Le,vc,vc,i6,h6,g6,f6,e6,d6,c6,b6,lY,a6,$5,_5,vc,ZI,ZI,hq,Ce,Ce,j6,Ce,vc,aJ,$I,hq,mc,mc,_I,Fo,vc,aJ,$I,hq,mc,mc,_I,Fo,vc,dJ,cJ,hq,mc,mc,bJ,Fo,vc,dJ,cJ,hq,mc,mc,bJ,Fo,Le,vc,d9,c9,Le,vc,a9,$8,vc,Z8,W8,V8,U8,vK,vK,T8,S8,R8,Q8,P8,vc,O8,N8,M8,L8,lK,lK,K8,J8,I8,H8,G8,vc,F8,E8,C8,B8,A8,z8,x8,w8,vc,v8,u8,s8,r8,q8,p8,n8,m8,Le,vc,Ke,l8,k8,j8,i8,h8,g8,B6,A6,z6,y6,w6,u6,s6,Le,vc,Ke,f8,e8,d8,c8,b8,a8,P6,O6,N6,M6,K6,I6,G6,GI,A4,z4,td,_x,Zx,Yx,Xx,Wx,Vx,QI,PI,OI,NI,MI,LI,KI,RI,V4,U4,td,_x,Zx,Yx,Xx,Wx,Vx,QI,PI,OI,NI,MI,LI,KI,by,_s,$7,by,_s,_7,_s,_s,vc,et,et,ji,ji,ji,cK,mc,ii,ii,vc,et,et,ji,ji,ji,cK,mc,ii,ii,vc,dt,dt,ji,ji,ji,bK,mc,ii,ii,vc,dt,dt,ji,ji,ji,bK,mc,ii,ii,AI,o4,my,ly,ky,aK,lz,$J,_J,ZJ,ct,BI,q4,my,ly,ky,aK,lz,$J,_J,ZJ,ct,CI,r4,os,jy,iy,YJ,XJ,WJ,VJ,ct,UJ,DI,s4,os,jy,iy,YJ,XJ,WJ,VJ,ct,UJ,vc,Z7,U7,vc,S7,O7,vc,M7,J7,vc,I7,F7,vc,HJ,E7,Ue,vc,HJ,D7,Ue,vc,vc,Le,vc,C7,GJ,Le,vc,Le,vc,Le,vc,Le,vc,FI,JI,Le,Qg,vc,e4,vc,$3,vI,vc,_3,Z3,vI,Vn,Qg,vc,X3,va,Le,vc,If,If,T3,L3,N3,O3,vc,G3,vc,F3,eo,Vn,eo,eo,eo,eo,Vn,vc,E3,vc,K3,M3,P3,vc,S3,R3,Q3,vc,H3]);function jb(){return u.byteLength/65536|0}function ob(pb){pb=pb|0;var kb=jb()|0;var lb=kb+pb|0;if(kb<lb&&lb<65536){var mb=new ArrayBuffer(D(lb,65536));var nb=new Int8Array(mb);nb.set(v);v=new Int8Array(mb);w=new Int16Array(mb);x=new Int32Array(mb);y=new Uint8Array(mb);z=new Uint16Array(mb);A=new Uint32Array(mb);B=new Float32Array(mb);C=new Float64Array(mb);u=mb;t.buffer=u;e=y}return kb}return{"va":_0,"wa":KP,"xa":KP,"ya":MP,"za":MP,"Aa":vc,"Ba":Db,"Ca":Gga,"Da":JP,"Ea":Ega,"Fa":Dga,"Ga":ju,"Ha":Ue,"Ia":Jga,"Ja":Iga,"Ka":Mga,"La":$z,"Ma":Kga,"Na":NP,"Oa":Lga,"Pa":Le,"Qa":RP,"Ra":QP,"Sa":RP,"Ta":yO,"Ua":C3,"Va":B3,"Wa":z3,"Xa":Cga,"Ya":EP,"Za":zga,"_a":DP,"$a":oga,"ab":Dea,"bb":Eea,"cb":mga,"db":lga,"eb":kga,"fb":nga,"gb":Fea,"hb":Tea,"ib":zea,"jb":Vea,"kb":lfa,"lb":Bea,"mb":Xea,"nb":Cea,"ob":Wea,"pb":Aea,"qb":Iea,"rb":Gea,"sb":Hea,"tb":Pea,"ub":Nea,"vb":Oea,"wb":Jea,"xb":Kea,"yb":Lea,"zb":Mea,"Ab":ifa,"Bb":jfa,"Cb":ufa,"Db":ofa,"Eb":nfa,"Fb":mfa,"Gb":tfa,"Hb":rfa,"Ib":pfa,"Jb":qfa,"Kb":zfa,"Lb":Afa,"Mb":vfa,"Nb":xfa,"Ob":wfa,"Pb":bfa,"Qb":gfa,"Rb":efa,"Sb":dfa,"Tb":ffa,"Ub":cfa,"Vb":Sea,"Wb":Cfa,"Xb":afa,"Yb":_ea,"Zb":kfa,"_b":Uea,"$b":$ea,"ac":Zea,"bc":Yea,"cc":Dfa,"dc":Qea,"ec":Efa,"fc":Rea,"gc":Bfa,"hc":yga,"ic":wga,"jc":y3,"kc":vga,"lc":uga,"mc":tga,"nc":rga,"oc":x3,"pc":qga,"qc":pga,"rc":jga,"sc":hga,"tc":ega,"uc":Ffa,"vc":dga,"wc":xq,"xc":pc,"yc":RN,"zc":Fd,"Ac":VN,"Bc":WN,"Cc":yda,"Dc":zda,"Ec":UN,"Fc":aea,"Gc":cea,"Hc":bea,"Ic":hO,"Jc":hO,"Kc":yO,"Lc":mI,"Mc":mI,"Nc":lI,"Oc":lI,"Pc":w3,"Qc":YN,"Rc":$N,"Sc":gO,"Tc":fO,"Uc":ZN,"Vc":cO,"Wc":bO,"Xc":_N,"Yc":eO,"Zc":dO,"_c":aO,"$c":Vm,"ad":XN,"bd":_da,"cd":Vca,"dd":Xda,"ed":lda,"fd":_ca,"gd":Wda,"hd":Wca,"id":Rda,"jd":mda,"kd":Yda,"ld":Lda,"md":Kda,"nd":Ida,"od":Oda,"pd":Nda,"qd":Mda,"rd":Pda,"sd":Sda,"td":Qda,"ud":Tda,"vd":fda,"wd":wda,"xd":Tca,"yd":hda,"zd":gda,"Ad":bda,"Bd":ida,"Cd":ada,"Dd":tda,"Ed":Oca,"Fd":Qca,"Gd":Rca,"Hd":Pca,"Id":Lca,"Jd":Kca,"Kd":nda,"Ld":pda,"Md":vda,"Nd":oda,"Od":$ca,"Pd":rda,"Qd":cda,"Rd":jda,"Sd":qda,"Td":dda,"Ud":Yca,"Vd":kda,"Wd":eda,"Xd":Xca,"Yd":Mca,"Zd":Jca,"_d":Ica,"$d":Sca,"ae":Nca,"be":Gca,"ce":Hca,"de":uda,"ee":v3,"fe":Uca,"ge":xda,"he":Hda,"ie":Zda,"je":u3,"ke":Vda,"le":$da,"me":jO,"ne":lO,"oe":mO,"pe":nO,"qe":pO,"re":qO,"se":tO,"te":oO,"ue":du,"ve":iO,"we":kO,"xe":fea,"ye":pea,"ze":pc,"Ae":VN,"Be":WN,"Ce":xq,"De":YN,"Ee":$N,"Fe":gO,"Ge":fO,"He":ZN,"Ie":cO,"Je":bO,"Ke":_N,"Le":eO,"Me":dO,"Ne":aO,"Oe":Vm,"Pe":jO,"Qe":lO,"Re":mO,"Se":nO,"Te":pO,"Ue":qO,"Ve":tO,"We":oO,"Xe":du,"Ye":kO,"Ze":ib,"_e":Rha,"$e":Zca,"af":Hga,"bf":sfa,"cf":V3,"df":W3,"ef":J3,"ff":I3,"gf":t3,"hf":s3,"jf":q3,"kf":m3,"lf":r3,"mf":q3,"nf":p3,"of":n3,"pf":o3,"qf":n3,"rf":m3,"sf":m3}}return qb(sb)}
// EMSCRIPTEN_END_ASM


)(info);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module, info)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];
